--
-- $Id: satellite-3.2-to-3.4.sql 64427 2005-09-09 14:08:21Z jslagle $
--

-- fix this first of all...

alter table rhnPackageEVR modify (
	version varchar2(512),
	release varchar2(512)
);

alter type evr_t modify attribute release varchar2(512), modify attribute version varchar2(512) cascade;

create or replace type body evr_t
as
order member function compare (other_in IN evr_t)
  return integer
is
begin
        return rpm.vercmp(SELF.epoch, SELF.version, SELF.release,
                          other_in.epoch, other_in.version, other_in.release);
end;

member function as_vre
  return varchar2
is
begin
        return self.version || '-' || SELF.release || ':' || SELF.epoch;
end;

member function as_vre_simple
  return VARCHAR2
is
    vre_out VARCHAR2(256);
begin
    vre_out := self.version || '-' || self.release;

    if self.epoch is not null
    then
        vre_out := vre_out || ':' || self.epoch;
    end if;

    return vre_out;
end;

end;
/
show errors

-- now 3.2 -> 3.3

create or replace
package body rhn_entitlements
is
	function entitlement_grants_service (
	    entitlement_in in varchar2,
	    service_level_in in varchar2
	) return number	is
	begin
	    if service_level_in = 'provisioning' then

		if entitlement_in = 'provisioning_entitled' then
		    return 1;
		else
		    return 0;
		end if;
	    elsif service_level_in = 'management' then

		if entitlement_in = 'provisioning_entitled' then
		    return 1;
		elsif entitlement_in = 'enterprise_entitled' then
		    return 1;
		elsif entitlement_in = 'nonlinux_entitled' then
		    return 1;
		else
		    return 0;
		end if;

	    elsif service_level_in = 'updates' then
		return 1;

	    else
		return 0;
	    end if;

	end entitlement_grants_service;


	function lookup_entitlement_group (
		org_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	) return number is
		cursor server_groups is
			select	sg.id				server_group_id
			from	rhnServerGroup		sg,
					rhnServerGroupType	sgt
			where	sgt.label = type_label_in
				and sgt.id = sg.group_type
				and sg.org_id = org_id_in;
	begin
		for sg in server_groups loop
			return sg.server_group_id;
		end loop;
		return rhn_entitlements.create_entitlement_group(
				org_id_in,
				type_label_in
			);
	end lookup_entitlement_group;

	function create_entitlement_group (
		org_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	) return number is
		sg_id_val number;
	begin
		select	rhn_server_group_id_seq.nextval
		into	sg_id_val
		from	dual;

		insert into rhnServerGroup (
				id, name, description, max_members, current_members,
				group_type, org_id
			) (
				select	sg_id_val, sgt.label, sgt.label,
						0, 0, sgt.id, org_id_in
				from	rhnServerGroupType sgt
				where	sgt.label = type_label_in
			);

		return sg_id_val;
	end create_entitlement_group;

	function get_server_entitlement (
		server_id_in in number
	) return varchar2 is
		cursor server_groups is
			select	sgt.label
			from	rhnServerGroupType		sgt,
					rhnServerGroup			sg,
					rhnServerGroupMembers	sgm
			where	1=1
				and sgm.server_id = server_id_in
				and sg.id = sgm.server_group_id
				and sgt.id = sg.group_type
				and sgt.label in ('sw_mgr_entitled','enterprise_entitled',
					'provisioning_entitled', 'nonlinux_entitled');
	begin
		for sg in server_groups loop
			return sg.label;
		end loop;
		return 'none';
	end get_server_entitlement;

	procedure unentitle_server (
		server_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	) is
		group_id number;
	begin
		select	sg.id
		into	group_id
		from	rhnServerGroupType sgt,
				rhnServerGroup sg,
				rhnServerGroupMembers sgm,
				rhnServer s
		where	s.id = server_id_in
			and s.id = sgm.server_id
			and sgm.server_group_id = sg.id
			and sg.org_id = s.org_id
			and sgt.label = type_label_in
			and sgt.id = sg.group_type;

		rhn_server.delete_from_servergroup(server_id_in, group_id);
		exception
		when no_data_found then
		    null;
	end unentitle_server;

	-- right now, this is racy.  Don't do it twice at once
	-- for the same org.  You've been warned...
	procedure upgrade_server (
		server_id_in in number
	) is
		old_sgid number;
		new_sgid number;
		new_sg_max number;
		new_sg_used number;
	begin
		begin
			select	sg0.id, sg1.id,
					sg1.max_members, sg1.current_members
			into	old_sgid, new_sgid,
					new_sg_max, new_sg_used
			from	rhnServerGroup sg1,
					rhnServerGroupType sgt1,
					rhnServerGroupMembers sgm,
					rhnServerGroup sg0,
					rhnServerGroupType sgt0,
					rhnServer s
			where	s.id = server_id_in
				and s.org_id = sg0.org_id
				and sgt0.label = 'enterprise_entitled'
				and sgt0.id = sg0.group_type
				and s.id = sgm.server_id
				and sgm.server_group_id = sg0.id
				and s.org_id = sg1.org_id
				and sgt1.label = 'provisioning_entitled'
				and sgt1.id = sg1.group_type;
		exception
			when no_data_found then
				rhn_exception.raise_exception('invalid_upgrade');
		end;
		-- it could still happen that you run out after we check this.
		-- that's what the comment above is all about...
		if new_sg_used >= new_sg_max then
			rhn_exception.raise_exception('servergroup_max_members');
		end if;
		rhn_server.delete_from_servergroup(server_id_in, old_sgid);
		rhn_server.insert_into_servergroup(server_id_in, new_sgid);
	end upgrade_server;

	procedure entitle_server (
		server_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	) is
		cursor servergroups is
			select	sg.id id,
					s.server_arch_id server_arch_id,
					sgt.id server_group_type
			from	rhnServerGroupType sgt,
					rhnServerGroup sg,
					rhnServer s
			where	s.id = server_id_in
				and s.org_id = sg.org_id
				and sgt.label = type_label_in
				and sg.group_type = sgt.id;
		cursor sg_arches(sgt_id_in in number, sa_id_in in number) is
			select	1
			from	rhnServerServerGroupArchCompat
			where	server_group_type = sgt_id_in
				and server_arch_id = sa_id_in;
		previous_ent rhnServerGroupType.label%TYPE;
	begin
		previous_ent := rhn_entitlements.get_server_entitlement(server_id_in);
		if previous_ent != 'none' then
			rhn_exception.raise_exception(
								'no_server_multiple_swmgr_entitlements');
		end if;

		for sg in servergroups loop
			for a in sg_arches(sg.server_group_type, sg.server_arch_id) loop
				-- if the max_members is too low, this'll raise
				-- servergroup_max_members
				rhn_server.insert_into_servergroup(server_id_in, sg.id);
				return;
			end loop;
			-- we only get here if we can't find any compatible
			-- server_arch+server_group_type combination
			rhn_exception.raise_exception('mismatching_entitlement');
		end loop;
		-- we only get here if there's _no_ server group for that type;
		-- that's the same as max_members=0
		rhn_exception.raise_exception('servergroup_max_members');
	end;

	procedure set_customer_enterprise (
		customer_id in number
	) is
		entitlement_type_id number;
		status number;
	begin
		select	roet.id, roe.org_id
		into	entitlement_type_id, status
		from	rhnOrgEntitlementType	roet,
				rhnOrgEntitlements		roe
		where	1=1
			and roet.label = 'sw_mgr_enterprise'
			and roet.id = roe.entitlement_id(+)
			and roe.org_id(+) = customer_id;

		if status is null then
			insert into rhnOrgEntitlements (
					org_id, entitlement_id
				) values (
					customer_id, entitlement_type_id
			);
		end if;

		-- XXX is org_applicant even right to create anymore?
		update		rhnUserGroup
			set		max_members = null
			where	1=1
				and org_id = customer_id
				and group_type in (
					select	id
					from	rhnUserGroupType
					where	label in ('org_admin', 'org_applicant')
				);
	end set_customer_enterprise;

	procedure create_config_admin (
		customer_id_in in number
	) is
		cursor config_admin_groups is
			select	1
			from	rhnUserGroup ug,
				rhnUserGroupType ugt
			where	ugt.label = 'config_admin'
				and ug.org_id = customer_id_in
				and ugt.id = ug.group_type;
	begin
		for config_admin_group in config_admin_groups loop
			return;
		end loop;

		insert into rhnUserGroup (
			id, name,
			description,
			max_members, group_type, org_id
		) (
			select	rhn_user_group_id_seq.nextval,
					'Configuration Administrator',
					'Configuration Administrator for Org ' || ' (1)',
					NULL, id, 1
			from	rhnUserGroupType
			where	label = 'config_admin'
		);
	end create_config_admin;

	procedure set_customer_provisioning (
		customer_id_in in number
	) is
		cursor entitlements is
			select	roet.id entitlement_type_id,
					roe.org_id status
			from	rhnOrgEntitlements		roe,
					rhnOrgEntitlementType	roet
			where	1=1
				and roet.label in ('rhn_provisioning','sw_mgr_enterprise')
				and roet.id = roe.entitlement_id(+)
				and roe.org_id(+) = customer_id_in;
	begin
		for e in entitlements loop
			if e.status is null then
				insert into rhnOrgEntitlements (
						org_id, entitlement_id
					) values (
						customer_id_in, e.entitlement_type_id
					);
			end if;
		end loop;
		if is_satellite() = 1 then
			rhn_entitlements.create_config_admin(customer_id_in);
		end if;
	end set_customer_provisioning;

	procedure set_customer_nonlinux (
		customer_id_in in number
	) is
		cursor entitlements is
			select	roet.id entitlement_type_id,
					roe.org_id status
			from	rhnOrgEntitlements		roe,
					rhnOrgEntitlementType	roet
			where	1=1
				and roet.label in ('rhn_nonlinux')
				and roet.id = roe.entitlement_id(+)
				and roe.org_id(+) = customer_id_in;
	begin
		for e in entitlements loop
			if e.status is null then
				insert into rhnOrgEntitlements (
						org_id, entitlement_id
					) values (
						customer_id_in, e.entitlement_type_id
					);
			end if;
		end loop;
		if is_satellite() = 1 then
			rhn_entitlements.create_config_admin(customer_id_in);
		end if;
	end set_customer_nonlinux;

	procedure unset_customer_enterprise (
		customer_id in number
	) is
	begin
		delete	from	rhnOrgEntitlements
				where	1=1
					and org_id = customer_id
					and entitlement_id in (
						select	id
						from	rhnOrgEntitlementType
						where	label = 'sw_mgr_enterprise'
					);

		-- XXX there's no way this is right.  It probably should be pruning
		-- these groups to 0 and *removing* them (and anybody in
		-- org_applicant?).  But then, maybe not.  ISTR something about
		-- never becomming un-enterprise
		update		rhnUserGroup
			set		max_members = null
			where	1=1
				and org_id = customer_id
				and group_type in (
					select	id
					from	rhnUserGroupType
					where	label in ('org_admin', 'org_applicant')
				);
	end unset_customer_enterprise;

	procedure unset_customer_provisioning (
		customer_id_in in number
	) is
		usergroup number;
	begin
		delete from rhnOrgEntitlements
			where	1=1
				and org_id = customer_id_in
				and entitlement_id in (
					select	id
					from	rhnOrgEntitlementType
					where	label = 'rhn_provisioning'
				);
	end;

	procedure unset_customer_nonlinux (
		customer_id_in in number
	) is
		usergroup number;
	begin
		delete from rhnOrgEntitlements
			where	1=1
				and org_id = customer_id_in
				and entitlement_id in (
					select	id
					from	rhnOrgEntitlementType
					where	label = 'rhn_nonlinux'
				);
	end;

	procedure prune_group (
		group_id_in in number,
		type_in in char,
		quantity_in in number
	) is
		cursor usergroups is
			select	user_id, user_group_id, ugt.label
			from	rhnUserGroupType	ugt,
					rhnUserGroup		ug,
					rhnUserGroupMembers	ugm
			where	1=1
				and ugm.user_group_id = group_id_in
				and ugm.user_id in (
					select	user_id
					from	(
						select	rownum row_number,
								user_id,
								time
						from	(
							select	user_id,
									modified time
							from	rhnUserGroupMembers
							where	user_group_id = group_id_in
							order by time asc
						)
					)
					where	row_number > quantity_in
				)
				and ugm.user_group_id = ug.id
				and ug.group_type = ugt.id;
		cursor servergroups is
			select	server_id, server_group_id, sgt.label
			from	rhnServerGroupType		sgt,
					rhnServerGroup			sg,
					rhnServerGroupMembers	sgm
			where	1=1
				and sgm.server_group_id = group_id_in
				and sgm.server_id in (
					select	server_id
					from	(
						select	rownum row_number,
								server_id,
								time
						from	(
							select	server_id,
									modified time
							from	rhnServerGroupMembers
							where	server_group_id = group_id_in
							order by time asc
						)
					)
					where	row_number > quantity_in
				)
				and sgm.server_group_id = sg.id
				and sg.group_type = sgt.id;
	begin
		if type_in = 'U' then
			update		rhnUserGroup
				set		max_members = quantity_in
				where	id = group_id_in;

			for ug in usergroups loop
				-- rhnUserGroup.max_members gets fixed in a trigger, no
				-- need to do that here
				delete
					from	rhnUserGroupMembers
					where	user_group_id = ug.user_group_id
						and user_id = ug.user_id;
			end loop;
		elsif type_in = 'S' then
			update		rhnServerGroup
				set		max_members = quantity_in
				where	id = group_id_in;

			for sg in servergroups loop
				unentitle_server(sg.server_id, sg.label);
				rhn_channel.clear_subscriptions(sg.server_id);
			end loop;
		end if;
	end prune_group;

	procedure set_group_count (
		customer_id_in in number,
		type_in in char,
		group_type_in in number,
		quantity_in in number
	) is
		group_id number;
		quantity number;
	begin
		quantity := quantity_in;
		if quantity is not null and quantity < 0 then
			quantity := 0;
		end if;

		if type_in = 'U' then
			select	rug.id
			into	group_id
			from	rhnUserGroup rug
			where	1=1
				and rug.org_id = customer_id_in
				and rug.group_type = group_type_in;
		elsif type_in = 'S' then
			select	rsg.id
			into	group_id
			from	rhnServerGroup rsg
			where	1=1
				and rsg.org_id = customer_id_in
				and rsg.group_type = group_type_in;
		end if;

		rhn_entitlements.prune_group(
			group_id,
			type_in,
			quantity
		);
	exception
		when no_data_found then
			if type_in = 'U' then
				insert into rhnUserGroup (
						id, name, description, max_members, current_members,
						group_type, org_id, created, modified
					) (
						select	rhn_user_group_id_seq.nextval, name, name,
								quantity, 0, id, customer_id_in,
								sysdate, sysdate
						from	rhnUserGroupType
						where	id = group_type_in
				);
			elsif type_in = 'S' then
				insert into rhnServerGroup (
						id, name, description, max_members, current_members,
						group_type, org_id, created, modified
					) (
						select	rhn_server_group_id_seq.nextval, name, name,
								quantity, 0, id, customer_id_in,
								sysdate, sysdate
						from	rhnServerGroupType
						where	id = group_type_in
				);
			end if;
	end set_group_count;

	procedure prune_family (
		customer_id_in in number,
		channel_family_id_in in number,
		quantity_in in number
	) is
		cursor serverchannels is
			select	sc.server_id,
					sc.channel_id
			from	rhnServerChannel sc,
					rhnChannelFamilyMembers cfm
			where	1=1
				and cfm.channel_family_id = channel_family_id_in
				and cfm.channel_id = sc.channel_id
				and server_id in (
					select	server_id
					from	(
						select	server_id,
								time,
								rownum row_number
						from	(
							select	rs.id					server_id,
									rcfm.modified			time
							from	rhnServer				rs,
									rhnServerChannel		rsc,
									rhnChannelFamilyMembers	rcfm
							where	1=1
								and rs.org_id = customer_id_in
								and rs.id = rsc.server_id
								and rsc.channel_id = rcfm.channel_id
								and rcfm.channel_family_id =
									channel_family_id_in
							order by time asc
						)
					)
					where row_number > quantity_in
				);
	begin
		-- if we get a null customer_id, this is completely bogus.
		if customer_id_in is null then
			return;
		end if;

		update		rhnChannelFamilyPermissions
			set		max_members = quantity_in
			where	1=1
				and org_id = customer_id_in
				and channel_family_id = channel_family_id_in;

		for sc in serverchannels loop
			rhn_channel.unsubscribe_server(sc.server_id, sc.channel_id, 1, 1);
		end loop;
	end prune_family;

	procedure set_family_count (
		customer_id_in in number,
		channel_family_id_in in number,
		quantity_in in number
	) is
		perm_exists number;
		quantity number;
	begin
		quantity := quantity_in;
		if quantity is not null and quantity < 0 then
			quantity := 0;
		end if;

		-- if the perm _doesn't_ exist, we get the exception
		select	1
		into	perm_exists
		from	rhnChannelFamilyPermissions
		where	1=1
			and channel_family_id = channel_family_id_in
			and (org_id = customer_id_in or
				(org_id is null and customer_id_in is null));

		rhn_entitlements.prune_family(
				customer_id_in,
				channel_family_id_in,
				quantity
			);
	exception
		when no_data_found then
			insert into rhnChannelFamilyPermissions (
					channel_family_id, org_id, max_members, current_members
				) values (
					channel_family_id_in, customer_id_in, quantity, 0
				);
	end set_family_count;

	-- this expects quantity_in to be the number of available slots, not the
	-- max_members of the server group.  If you give it too many, it'll fail
	-- and raise servergroup_max_members.
	-- We should NEVER run this unless we're SURE that we won't
	-- be violating the max.
	procedure entitle_last_modified_servers (
		customer_id_in in number,
		type_label_in in varchar2,
		quantity_in in number
	) is
		-- find the servers that aren't currently in slots
		cursor servers(cid_in in number, quant_in in number) is
			select	server_id
			from	(
						select	rownum row_number,
								server_id
						from	(
									select	rs.id server_iD
									from	rhnServer rs
									where	1=1
										and rs.org_id = cid_in
										and not exists (
											select	1
											from	rhnServerGroup sg,
													rhnServerGroupMembers rsgm
											where	rsgm.server_id = rs.id
												and rsgm.server_group_id = sg.id
												and sg.group_type is not null
										)
									order by modified desc
								)
					)
			where	row_number <= quant_in;
	begin
		for server in servers(customer_id_in, quantity_in) loop
			rhn_entitlements.entitle_server(server.server_id, type_label_in);
		end loop;
	end entitle_last_modified_servers;

	procedure get_available_slots (
		customer_id_in in number,
		type_label_in in varchar2,
		server_group_id_out out number,
		available_out out number,
		upgrade_out out number
	) is
		mgmt_slots_unused number;
		mgmt_slots_used number;
		prov_slots_unused number;
		prov_slots_used number;
		swmgr_slots_unused number;
		sgid number;
	begin
		-- if it's the simple case, do it and get out
		if type_label_in in ('sw_mgr_entitled','nonlinux_entitled') then
			begin
				select	max_members - current_members, sg.id
				into	swmgr_slots_unused, sgid
				from	rhnServerGroup		sg,
						rhnServerGroupType	sgt
				where	sgt.label = type_label_in
					and sg.org_id = customer_id_in
					and sg.group_type = sgt.id;

				available_out := swmgr_slots_unused;
				upgrade_out := 0;
				server_group_id_out := sgid;
			exception
				when no_data_found then
					available_out := 0;
					if type_label_in = 'sw_mgr_entitled' then
						available_out := 1;
					end if;
					upgrade_out := 0;
					server_group_id_out := null;
			end;
			return;
		end if;

		begin
			select	sg.current_members,
					sg.max_members - sg.current_members,
					sg.id
			into	mgmt_slots_used,
					mgmt_slots_unused,
					sgid
			from	rhnServerGroup		sg,
					rhnServerGroupType	sgt
			where	sgt.label = 'enterprise_entitled'
				and sg.org_id = customer_id_in
				and sg.group_type = sgt.id;
		exception
			when no_data_found then
				-- if there's no enterprise_entitled group, then
				-- this user doesn't have mgmt or prov at all,
				-- so bail out now.
				available_out := 0;
				upgrade_out := 0;
				server_group_id_out := null;
				return;
		end;

		-- we list all mgmt slots as things you can upgrade to
		-- from basic
		if type_label_in = 'enterprise_entitled' then
			available_out := mgmt_slots_unused;
			upgrade_out := 0;
			server_group_id_out := sgid;
			return;
		end if;

		-- the only thing left is provisioning
		begin
			select	sg.current_members,
					sg.max_members - sg.current_members,
					sg.id
			into	prov_slots_used,
					prov_slots_unused,
					sgid
			from	rhnServerGroup		sg,
					rhnServerGroupType	sgt
			where	sgt.label = 'provisioning_entitled'
				and sg.org_id = customer_id_in
				and sg.group_type = sgt.id;
		exception
			when no_data_found then
				available_out := 0;
				upgrade_out := 0;
				server_group_id_out := null;
				return;
		end;

		-- An example to illustrate what I'm doing to compute upgradable slots
		-- 1) The user buys 3 provisioning entitlements.  This means:
		--      enterprise_entitled max_members = 3, current_members = 0    (prov_slots_unused = 3)
		--      provisioning_entitled max_members = 3, current_members = 0  (prov_slots_unsued = 3)
		--    0 upgrade, 3 available
		-- 2) The user subscribes a system for management.  This means:
		--      enterprise_entitled max_members = 3, current_members = 1    (mgmt_slots_unused = 2)
		--      provisioning_entitled max_members = 3, current_members = 0  (prov_slots_unused = 3)
		--    1 upgrade, 2 available
		-- 3) The user subscribes a system for provisioning.  This means:
		--      enterprise_entitled max_members = 2, current_members = 1    (mgmt_slots_unused = 1)
		--      provisioning_entitled max_members = 3, current_members = 1  (prov_slots_unused = 2)
		--    1 upgrade, 1 available
		-- 4) The user subscribes another provisioning.  I.e.:
		--      enterprise_entitled max_members = 1, current_members = 1    (mgmt_slots_unused = 0)
		--      provisioning_entitled max_members = 3, current_members = 2  (prov_slots_unused = 1)
		--    1 upgrade, 0 available
		-- 5) the user upgrades 1 mgmt to prov.  Here:
		--    1) unsubscribe from mgmt
		--      enterprise_entitled max_members = 1, current_members = 0    (mgmt_slots_unused = 1)
		--      provisioning_entitled max_members = 3, current_members = 2  (prov_slots_unused = 1)
		--    0 upgrade, 1 available
		--    2) subscribe to prov
		--      enterprise_entitled max_members = 0, current_members = 0    (mgmt_slots_unused = 0)
		--      provisioning_entitled max_members = 3, current_members = 3  (prov_slots_unused = 0)
		--    that'll result in 0 upgrade, 0 available
		-- 6) user buys 1 mgmt:
		--      enterprise_entitled max_members = 1, current_members = 0    (mgmt_slots_unused = 1)
		--      provisioning_entitled max_members = 3, current_members = 3  (prov_slots_unused = 0)
		--    -1 on upgrade, 1 on available, BORK, should be 0, 0 (special cased with p-m<0)
		-- 7) user registers a management box
		--      enterprise_entitled max_members = 1, current_members = 1    (mgmt_slots_unused = 0)
		--      provisioning_entitled max_members = 3, current_members = 3  (prov_slots_unused = 0)
		--    0, 0, which is right.
		-- 8) user deletes that management box
		--      enterprise_entitled max_members = 1, current_members = 0    (mgmt_slots_unused = 1)
		--      provisioning_entitled max_members = 3, current_members = 3  (prov_slots_unused = 0)
		--    -1 on upgrade, 1 on available, BORK, should be 0, 0 (special cased with p-m<0)
		-- 9) user buys a provisioning slot
		--      enterprise_entitled max_members = 2, current_members = 0    (mgmt_slots_unused = 2)
		--      provisioning_entitled max_members = 4, current_members = 3  (prov_slots_unused = 1)
		--    -1 upgrade, 0 available, BORK.  special case makes it 1 available, 0 upgrade
		-- 10) user registers a mgmt box
		--      enterprise_entitled max_members = 2, current_members = 1    (mgmt_slots_unused = 1)
		--      provisioning_entitled max_members = 4, current_members = 3  (prov_slots_unused = 1)
		--    0 upgrade, 1 available
		if prov_slots_unused - mgmt_slots_unused < 0 then
			-- swmgr_slots_unused is tmp here
			available_out := prov_slots_unused;
			upgrade_out := 0;
		elsif prov_slots_unused > 0 then
			-- if there's one of each, we list it as available
			-- if there's only a prov slot, then it's upgradable.
			upgrade_out := prov_slots_unused - mgmt_slots_unused;
			available_out := prov_slots_unused - (prov_slots_unused - mgmt_slots_unused);
		else
			upgrade_out := 0;
			available_out := 0;
		end if;
		server_group_id_out := sgid;
		return;
	end get_available_slots;

	procedure prune_everything (
		customer_id_in in number
	) is
		cursor everything is
			-- all our server groups
			select	sg.id					id,
					'S'						type,
					sg.max_members			quantity
			from	rhnServerGroup			sg
			where	sg.org_id = customer_id_in
			union
			-- all our user groups
			select	ug.id					id,
					'U'						type,
					ug.max_members 			quantity
			from	rhnUserGroup			ug
			where	ug.org_id = customer_id_in
			union (
			-- all the channel families we have perms to
			select	cfp.channel_family_id	id,
					'C'						type,
					cfp.max_members			quantity
			from	rhnChannelFamilyPermissions cfp
			where	cfp.org_id = customer_id_in
				or	cfp.org_id is null
			union
			-- plus all the ones we'rE Using that we have no perms for
			select	cfm.channel_family_id	id,
					'C'						type,
					0						quantity
			from	rhnChannelFamily		cf,
					rhnChannelFamilyMembers	cfm,
					rhnServerChannel		sc,
					rhnServer				s
			where	s.org_id = customer_id_in
				and s.id = sc.server_id
				and sc.channel_id = cfm.channel_id
				and not exists (
					select	1
					from	rhnChannelFamilyPermissions cfp
					where	(cfp.org_id = customer_id_in or cfp.org_id is null)
					)
				and cfm.channel_family_id = cf.id
				and cf.org_id is not null
				and cf.org_id != customer_id_in
			);
	begin
		for one in everything loop
			if one.type in ('U','S') then
				prune_group(one.id, one.type, one.quantity);
			else
				prune_family(customer_id_in, one.id, one.quantity);
			end if;
		end loop;
	end prune_everything;

	procedure subscribe_newest_servers (
		customer_id_in in number
	) is
		-- find servers without base channels
		cursor servers(cid_in in number) is
			select	s.id
			from	rhnServer			s
			where	1=1
				and s.org_id = cid_in
				and not exists (
						select 1
						from	rhnChannel			c,
								rhnServerChannel	sc
						where	sc.server_id = s.id
							and sc.channel_id = c.id
							and c.parent_channel is null
					)
			order by s.modified desc;
		channel_id number;
	begin
		for server in servers(customer_id_in) loop
			channel_id := rhn_channel.guess_server_base(server.id);
			if channel_id is not null then
				begin
					rhn_channel.subscribe_server(server.id, channel_id);
					commit;
				-- exception is really channel_family_no_subscriptions
				exception
					when others then
						null;
				end;
			end if;
		end loop;
	end subscribe_newest_servers;
end rhn_entitlements;
/
show errors

create or replace procedure
create_first_org
(
	name_in in varchar2,
	password_in in varchar2
) is
	ug_type			number;
	group_val		number;
begin
	insert into web_customer (
		id, name, password,
		oracle_customer_id, oracle_customer_number,
		customer_type
	) values (
		1, name_in, password_in,
		1, 1, 'B'
	);

	select rhn_user_group_id_seq.nextval into group_val from dual;

	select	id
	into	ug_type
	from	rhnUserGroupType
	where	label = 'org_admin';

	insert into rhnUserGroup (
		id, name,
		description,
		max_members, group_type, org_id
	) values (
		group_val, 'Organization Admins',
		'Organization Admins for Org ' || name_in || ' (1)',
		NULL, ug_type, 1
	);

	select rhn_user_group_id_seq.nextval into group_val from dual;

	select	id
	into	ug_type
	from	rhnUserGroupType
	where	label = 'org_applicant';

	insert into rhnUserGroup (
		id, name,
		description,
		max_members, group_type, org_id
	) values (
		group_val, 'Organization Applicants',
		'Organization Applicants for Org ' || name_in || ' (1)',
		NULL, ug_type, 1
	);

	-- config admin is special; it gets created in
	-- rhn_entitlements.set_customer_provisioning instead.

	select rhn_user_group_id_seq.nextval into group_val from dual;

	select	id
	into	ug_type
	from	rhnUserGroupType
	where	label = 'channel_admin';

	insert into rhnUserGroup (
		id, name,
		description,
		max_members, group_type, org_id
	) values (
		group_val, 'Channel Administrator',
		'Channel Administrator for Org ' || name_in || ' (1)',
		NULL, ug_type, 1
	);

	-- if they need more than 16GB, they'll call us and we'll whip
	-- out a "can be null" patch, which we should do for next
	-- version anyway.  (I thought we did that for this version?)
	insert into rhnOrgQuota(
		org_id, total
	) values (
		1, 1024*1024*1024*16
	);


	insert into rhnOrgState (org_id, state_id)
	select 1, id
	  from rhnOrgAvailableStates
	 where label = 'paid';

        insert into rhnServerGroup
		( id, name, description, max_members, group_type, org_id )
		select rhn_server_group_id_seq.nextval, sgt.name, sgt.name,
			0, sgt.id, 1
		from rhnServerGroupType sgt
		where sgt.label = 'sw_mgr_entitled';
end;
/
show errors

declare
	cursor orgs is
		select	distinct org_id id
		from	rhnOrgEntitlements oe,
			rhnOrgEntitlementType oet
		where	oet.label in ('rhn_provisioning','rhn_nonlinux')
			and oet.id = oe.entitlement_id
			and not exists (
				select	1
				from	rhnUserGroup ug,
					rhnUserGroupType ugt
				where	ugt.label = 'config_admin'
					and ug.org_id = oe.org_id
					and ugt.id = ug.group_type
			);
	cursor ugs(org_id_in in number) is
		select	rhn_user_group_id_seq.nextval id,
			'Configuration Administrator' name,
			'Configuration Administrator for Org  (1)' description,
			NULL max_members, id group_type, org_id_in org_id
		from	rhnUserGroupType
		where	label = 'config_admin';
begin
	for org in orgs loop
		for ug in ugs(org.id) loop
			insert into rhnUserGroup (
				id, name, description,
				max_members, group_type, org_id
			) values (
				ug.id, ug.name, ug.description,
				ug.max_members, ug.group_type, ug.org_id
			);
		end loop;
	end loop;
end;
/
show errors

-- now we're at 3.2-4, move to 3.3-53

alter table rhnActionConfigChannel drop constraint rhn_actioncc_aid_fk;
alter table rhnActionConfigChannel add constraint rhn_actioncc_aid_fk
        foreign key (action_id) references rhnAction(id)
        on delete cascade;

alter table rhnActionConfigDate drop constraint rhn_actioncd_aid_fk;
alter table rhnActionConfigDate add constraint rhn_actioncd_aid_fk
        foreign key (action_id) references rhnAction(id)
        on delete cascade;

alter table rhnActionKickstart drop constraint rhn_actionks_aid_fk;
alter table rhnActionKickstart add constraint rhn_actionks_aid_fk
        foreign key (action_id) references rhnAction(id)
        on delete cascade;

alter table rhnActionVerifyResult drop constraint rhn_actionvr_aid_fk;
alter table rhnActionVerifyResult add constraint rhn_actionvr_aid_fk
        foreign key (action_id) references rhnAction(id)
        on delete cascade;

create table
rhnActionDaemonConfig
(
	action_id		number
				constraint rhn_actiondc_aid_nn not null
				constraint rhn_actiondc_aid_fk
					references rhnAction(id)
					on delete cascade,
        interval                number
                                constraint rhn_actiondc_int_nn not null,
        restart                 char(1) default 'Y'
                                constraint rhn_actiondc_rest_nn not null
                                constraint rhn_actiondc_rest_ck check
                                    (restart in ('Y','N')),
	created			date default(sysdate)
				constraint rhn_actiondc_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_actiondc_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;

create unique index rhn_actiondc_aid_uq
	on rhnActionDaemonConfig ( action_id )
	storage ( freelists 16 )
	initrans 32;

create or replace trigger
rhn_actiondc_mod_trig
before insert or update on rhnActionDaemonConfig
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

insert into rhnActionType values (32, 'rhnsd.configure', 'RHN Daemon Configuration','N','N');
commit;

-- changes/dev/kickstart_from_host.1.rhn.sql
alter table rhnKickstartSession add (
        kickstart_from_host varchar2(256)
);

-- changes/dev/serveractionverify.1.rhn.sql
drop table rhnActionVerifyResult;

create table
rhnServerActionVerifyResult
(
	server_id		number
				constraint rhn_sactionvr_sid_nn not null
				constraint rhn_sactionvr_sid_fk
					references rhnServer(id),
	action_id		number
				constraint rhn_sactionvr_aid_nn not null
				constraint rhn_sactionvr_aid_fk
					references rhnAction(id)
					on delete cascade,
	package_name_id		number
				constraint rhn_sactionvr_pnid_nn not null
				constraint rhn_sactionvr_pnid_fk
					references rhnPackageName(id),
	package_evr_id		number
				constraint rhn_sactionvr_peid_nn not null
				constraint rhn_sactionvr_peid_fk
					references rhnPackageEVR(id),
	package_arch_id		number
				constraint rhn_sactionvr_paid_nn not null
				constraint rhn_sactionvr_paid_fk
					references rhnPackageArch(id),
	package_capability_id	number
				constraint rhn_sactionvr_pcid_nn not null
				constraint rhn_sactionvr_pcid_fk
					references rhnPackageCapability(id),
	attribute		char(1)
				constraint rhn_sactionvr_attr_ck
					check (attribute in ('c','d','g','l','r')),
	size_differs		char(1)
				constraint rhn_sactionvr_size_nn not null
				constraint rhn_sactionvr_size_ck
					check (size_differs in ('Y','N','?')),
	mode_differs		char(1)
				constraint rhn_sactionvr_mode_nn not null
				constraint rhn_sactionvr_mode_ck
					check (mode_differs in ('Y','N','?')),
	md5_differs		char(1)
				constraint rhn_sactionvr_md5_nn not null
				constraint rhn_sactionvr_md5_ck
					check (md5_differs in ('Y','N','?')),
	devnum_differs		char(1)
				constraint rhn_sactionvr_devnum_nn not null
				constraint rhn_sactionvr_devnum_ck
					check (devnum_differs in ('Y','N','?')),
	readlink_differs		char(1)
				constraint rhn_sactionvr_readlink_nn not null
				constraint rhn_sactionvr_readlink_ck
					check (readlink_differs in ('Y','N','?')),
	uid_differs		char(1)
				constraint rhn_sactionvr_uid_nn not null
				constraint rhn_sactionvr_uid_ck
					check (uid_differs in ('Y','N','?')),
	gid_differs		char(1)
				constraint rhn_sactionvr_gid_nn not null
				constraint rhn_sactionvr_gid_ck
					check (gid_differs in ('Y','N','?')),
	mtime_differs		char(1)
				constraint rhn_sactionvr_mtime_nn not null
				constraint rhn_sactionvr_mtime_ck
					check (mtime_differs in ('Y','N','?')),
	created			date default(sysdate)
				constraint rhn_sactionvr_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_sactionvr_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;

create unique index rhn_sactionvr_sanec_uq
	on rhnServerActionVerifyResult(
		server_id, action_id,
		package_name_id, package_evr_id, package_capability_id )
	storage ( freelists 16 )
	initrans 32;

create or replace trigger
rhn_sactionvr_mod_trig
before insert or update on rhnServerActionVerifyResult
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

-- kickstart-deploy-configs.1.rhn.sql
alter table rhnKickstartSession add (
        deploy_configs          char(1) default('N')
                                constraint rhn_ks_session_dc_nn not null
);

alter trigger RHN_KS_SESSION_MOD_TRIG compile;

-- cryptokey-unique-desc.1.rhn.sql
drop index rhn_cryptokey_oid_idx;

create unique index rhn_cryptokey_oid_desc_uq
        on rhnCryptoKey( org_id, description )
        storage ( freelists 16 )
        initrans 32;

-- server-uuid.1.rhn.sql
create table
rhnServerUuid
(
        server_id       number
			constraint rhn_server_uuid_sid_nn not null
                        constraint rhn_server_uuid_sid_fk
				references rhnServer(id),
	uuid            varchar2(36)
	                constraint rhn_server_uuid_uuid_nn not null
)
	storage ( pctincrease 1 freelists 16 )
	initrans 32;

create unique index rhn_server_uuid_sid_unq on
        rhnServerUuid(server_id)
	storage( pctincrease 1 freelists 16 )
	initrans 32;

alter table rhnServer add (
        channels_changed date
);

-- changes/prod/split-channel-perms.1.rhn.sql

create table
rhnPrivateChannelFamily
(
	channel_family_id	constraint rhn_privcf_cfid_nn not null,
	org_id			constraint rhn_privcf_oid_nn not null,
	max_members,
	current_members		constraint rhn_privcf_curmembers_nn not null,
	created			constraint rhn_privcf_created_nn not null,
	modified		constraint rhn_privcf_modified_nn not null
)
	storage ( freelists 16 )
	initrans 32
	as (
		select	channel_family_id, org_id,
			max_members, current_members,
			created, modified
		from	rhnChannelFamilyPermissions
		where	org_id is not null
	);

create unique index rhn_privcf_oid_cfid_uq
	on rhnPrivateChannelFamily( org_id, channel_family_id )
	storage ( freelists 16 )
	initrans 32;

create index rhn_cfperm_cfid_oid_idx on
	rhnPrivateChannelFamily( channel_family_id, org_id )
	storage ( freelists 16 )
	initrans 32
	nologging;

alter table rhnPrivateChannelFamily modify (
	current_members		number default (0),
	created			date default (sysdate),
	modified		date default (sysdate)
);

alter table rhnPrivateChannelFamily add constraint rhn_privcf_cfid_fk
	foreign key ( channel_family_id ) references rhnChannelFamily(id);


alter table rhnPrivateChannelFamily add constraint rhn_privcf_oid_fk
	foreign key ( org_id ) references web_customer(id)
	on delete cascade;

create table
rhnPublicChannelFamily
(
	channel_family_id	number
				constraint rhn_pubcf_cfid_nn not null
				constraint rhn_pubcf_cfid_fk
					references rhnChannelFamily(id),
	created			date default(sysdate)
				constraint rhn_pubcf_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_pubcf_mod_nn not null
);

create unique index rhn_pubcf_co_uq on
	rhnPublicChannelFamily(channel_family_id)
	storage ( freelists 16 )
	initrans 32;

insert into rhnPublicChannelFamily (
	select	channel_family_id, created, modified
        from	rhnChannelFamilyPermissions
	where	org_id is null
);

drop table rhnChannelFamilyPermissions;

create or replace view rhnChannelFamilyPermissions as
	select	channel_family_id,
		to_number(null) org_id,
		to_number(null) max_members,
		0 current_members,
		created,
		modified
	from	rhnPublicChannelFamily
	union
	select	channel_family_id,
		org_id,
		max_members,
		current_members,
		created,
		modified
	from	rhnPrivateChannelFamily;

create or replace view rhnOrgChannelFamilyPermissions as
	select	pcf.channel_family_id,
		u.org_id org_id,
		to_number(null) max_members,
		0 current_members,
		pcf.created,
		pcf.modified
	from	rhnPublicChannelFamily pcf,
		web_contact u
	union
	select	channel_family_id,
		org_id,
		max_members,
		current_members,
		created,
		modified
	from	rhnPrivateChannelFamily;

CREATE OR REPLACE VIEW rhnOrgChannelTreeView
(
	org_id,
        id,
        depth,
	name,
        padded_name,
	channel_arch_id,
        last_modified,
        label,
	parent_or_self_label,
	parent_or_self_id,
	end_of_life
)
AS
select * from (
	select	cfp.org_id		org_id,
		c.id			id,
		1			depth,
		c.name			name,
		'  ' || c.name		padded_name,
		c.channel_arch_id	channel_arch_id,
		c.last_modified		last_modified,
		c.label			label,
		c.label			parent_or_self_label,
		c.id			parent_or_self_id,
		c.end_of_life		end_of_life
	from	rhnChannel		c,
		rhnChannelFamilyMembers cfm,
		rhnOrgChannelFamilyPermissions cfp
	where	cfp.channel_family_id = cfm.channel_family_id
		and cfm.channel_id = c.id
		and c.parent_channel is null
	union
	select	cfp.org_id		org_id,
		c.id			id,
		2			depth,
		c.name			name,
		'' || c.name		padded_name,
		c.channel_arch_id 	channel_arch_id,
		c.last_modified		last_modified,
		c.label			label,
		pc.label		parent_or_self_label,
		pc.id			parent_or_self_id,
		c.end_of_life		end_of_life
	from	rhnChannel		pc,
		rhnChannel		c,
		rhnChannelFamilyMembers	cfm,
		rhnOrgChannelFamilyPermissions cfp
	where	cfp.channel_family_id = cfm.channel_family_id
		and cfm.channel_id = c.id
		and c.parent_channel = pc.id
) order by parent_or_self_label, parent_or_self_id;

drop view rhnAvailableChannels;

create or replace view
rhnAvailableChannels
(
	org_id,
	channel_id,
	channel_depth,
	channel_name,
	channel_arch_id,
	padded_name,
	current_members,
	available_members,
        last_modified,
        channel_label,
	parent_or_self_label,
	parent_or_self_id
)
as
select
     ct.org_id,
     ct.id,
     CT.depth,
     CT.name,
     CT.channel_arch_id,
     CT.padded_name,
     (SELECT COUNT(1)
        FROM rhnServer S
       WHERE S.org_id = ct.org_id
         AND EXISTS (SELECT 1 FROM rhnServerChannel WHERE channel_id = ct.id AND server_id = S.id)),
     rhn_channel.available_chan_subscriptions(ct.id, ct.org_id),
     CT.last_modified,
     CT.label,
     CT.parent_or_self_label,
     CT.parent_or_self_id
from
     rhnOrgChannelTreeView CT
/

drop view rhnChannelFamilyOverview;

create or replace view rhnChannelFamilyOverview as
select	pcf.org_id				org_id,
	f.id					id,
	f.name					name,
	f.product_url				url,
	NVL(pcf.current_members,0)		current_members,
	pcf.max_members				max_members,
	1					has_subscription
from	rhnChannelFamily			f,
	rhnPrivateChannelFamily			pcf
where	pcf.channel_family_id = f.id;

drop view rhnChannelPermissions;

create or replace view
rhnChannelPermissions
(
    org_id, channel_id
)
as
select distinct org_id, channel_id from (
select	privcf.org_id, cfm.channel_id
from	rhnChannelFamilyMembers cfm,
	rhnPrivateChannelFamily privcf
where	privcf.channel_family_id = cfm.channel_family_id
union all
select	u.org_id, cfm.channel_id
from	web_contact u,
	rhnChannelFamilyMembers cfm,
	rhnPublicChannelFamily pubcf
where	pubcf.channel_family_id = cfm.channel_family_id
);

drop view rhnChannelTreeView;

CREATE OR REPLACE VIEW rhnChannelTreeView
(
        id,
        depth,
	name,
        padded_name,
	channel_arch_id,
        last_modified,
        label,
	parent_or_self_label,
	parent_or_self_id,
	end_of_life
)
AS
select * from (
	select	c.id			id,
		1			depth,
		c.name			name,
		'  ' || c.name		padded_name,
		c.channel_arch_id	channel_arch_id,
		c.last_modified		last_modified,
		c.label			label,
		c.label			parent_or_self_label,
		c.id			parent_or_self_id,
		c.end_of_life		end_of_life
	from	rhnChannel		c
	where	c.parent_channel is null
	union
	select	c.id			id,
		2			depth,
		c.name			name,
		'' || c.name		padded_name,
		c.channel_arch_id 	channel_arch_id,
		c.last_modified		last_modified,
		c.label			label,
		pc.label		parent_or_self_label,
		pc.id			parent_or_self_id,
		c.end_of_life		end_of_life
	from	rhnChannel		pc,
		rhnChannel		c
	where	c.parent_channel = pc.id
) order by parent_or_self_label, parent_or_self_id;

-- rhnUserChannel is actually the 3.4 version here...
create or replace view rhnUserChannelFamilyPerms as
	select	pcf.channel_family_id,
		u.org_id org_id,
		u.id user_id,
		to_number(null) max_members,
		0 current_members,
		pcf.created,
		pcf.modified
	from	rhnPublicChannelFamily pcf,
		web_contact u
	union
	select	pcf.channel_family_id,
		u.org_id,
		u.id user_id,
		pcf.max_members,
		pcf.current_members,
		pcf.created,
		pcf.modified
	from	rhnPrivateChannelFamily pcf,
		web_contact u
	where	u.org_id = pcf.org_id;

CREATE OR REPLACE VIEW rhnUserChannelTreeView
(
	user_id,
	org_id,
        id,
        depth,
	name,
        padded_name,
	channel_arch_id,
        last_modified,
        label,
	parent_or_self_label,
	parent_or_self_id,
	end_of_life
)
AS
select * from (
	select	cfp.user_id		user_id,
		cfp.org_id		org_id,
		c.id			id,
		1			depth,
		c.name			name,
		'  ' || c.name		padded_name,
		c.channel_arch_id	channel_arch_id,
		c.last_modified		last_modified,
		c.label			label,
		c.label			parent_or_self_label,
		c.id			parent_or_self_id,
		c.end_of_life		end_of_life
	from	rhnChannel		c,
		rhnChannelFamilyMembers cfm,
		rhnUserChannelFamilyPerms cfp
	where	1=1
		and cfp.channel_family_id = cfm.channel_family_id
		and cfm.channel_id = c.id
		and c.parent_channel is null
	union
	select	cfp.user_id		user_id,
		cfp.org_id		org_id,
		c.id			id,
		2			depth,
		c.name			name,
		'' || c.name		padded_name,
		c.channel_arch_id 	channel_arch_id,
		c.last_modified		last_modified,
		c.label			label,
		pc.label		parent_or_self_label,
		pc.id			parent_or_self_id,
		c.end_of_life		end_of_life
	from	rhnChannel		pc,
		rhnChannel		c,
		rhnChannelFamilyMembers	cfm,
		rhnUserChannelFamilyPerms cfp
	where	1=1
		and cfp.channel_family_id = cfm.channel_family_id
		and cfm.channel_id = c.id
		and c.parent_channel = pc.id
) order by parent_or_self_label, parent_or_self_id;

drop view rhnUserAvailableChannels;

create or replace view
rhnUserAvailableChannels
(
	user_id,
	org_id,
	channel_id,
	channel_depth,
	channel_name,
	channel_arch_id,
	padded_name,
	current_members,
	available_members,
        last_modified,
        channel_label,
	parent_or_self_label,
	parent_or_self_id,
	end_of_life
)
as
select
     ct.user_id,
     ct.org_id,
     ct.id,
     CT.depth,
     CT.name,
     CT.channel_arch_id,
     CT.padded_name,
     (
     SELECT COUNT(1)
       FROM rhnUserServerPerms USP
      WHERE USP.user_id = ct.user_id
        AND EXISTS (SELECT 1 FROM rhnServerChannel WHERE channel_id = ct.id AND server_id = USP.server_id)
     ),
     rhn_channel.available_chan_subscriptions(ct.id, ct.org_id),
     CT.last_modified,
     CT.label,
     CT.parent_or_self_label,
     CT.parent_or_self_id,
     CT.end_of_life
from
     rhnUserChannelTreeView ct
/

drop view rhnUserChannel;

create or replace view rhnUserChannel as
select	cfp.user_id		user_id,
	cfp.org_id		org_id,
	cfm.channel_id		channel_id,
	'manage'		role
from	rhnChannelFamilyMembers	cfm,
	rhnUserChannelFamilyPerms cfp
where	cfp.channel_family_id = cfm.channel_family_id
	and rhn_channel.user_role_check(cfm.channel_id,
		cfp.user_id, 'manage') = 1
union all
select	cfp.user_id		user_id,
	cfp.org_id		org_id,
	cfm.channel_id		channel_id,
	'subscribe'		role
from	rhnChannelFamilyMembers	cfm,
	rhnUserChannelFamilyPerms cfp
where	cfp.channel_family_id = cfm.channel_family_id
	and rhn_channel.user_role_check(cfm.channel_id,
		cfp.user_id, 'subscribe') = 1;

-- changes/prod/split-channel-perms.1.rhn.sql is all covered by the previous

-- changes/proc/admin-names.1.rhn.sql

update rhnUserGroupType set name = 'Coma CMS Administrator'
	where label = 'coma_admin';

update rhnUserGroupType set name = 'Red Hat Network Support Administrator'
	where label = 'rhn_support';

commit;

-- now procedures and packages

create or replace
package rhn_user
is
	version varchar2(100) := '$Id: satellite-3.2-to-3.4.sql 64427 2005-09-09 14:08:21Z jslagle $';

    function check_role(user_id_in in number, role_in in varchar2) return number;
    PRAGMA RESTRICT_REFERENCES(check_role, WNDS, RNPS, WNPS);

    function check_role_implied(user_id_in in number, role_in in varchar2) return number;
    PRAGMA RESTRICT_REFERENCES(check_role_implied, WNDS, RNPS, WNPS);

    function get_org_id(user_id_in in number) return number;
    PRAGMA RESTRICT_REFERENCES(get_org_id, WNDS, RNPS, WNPS);

	function find_mailable_address(user_id_in in number)
	return varchar2;
end rhn_user;
/
SHOW ERRORS

CREATE OR REPLACE
PACKAGE rhn_org
IS
	version varchar2(100) := '$Id: satellite-3.2-to-3.4.sql 64427 2005-09-09 14:08:21Z jslagle $';

    CURSOR server_group_by_label(org_id_in NUMBER, group_label_in VARCHAR2) IS
	   SELECT SG.*
	     FROM rhnServerGroupType SGT,
		  rhnServerGroup SG
	    WHERE SG.group_type = SGT.id
	      AND SGT.label = group_label_in
	      AND SG.org_id = org_id_in;

    FUNCTION find_server_group_by_type(org_id_in NUMBER, group_label_in VARCHAR2) RETURN NUMBER;
    PROCEDURE update_errata_cache(org_id_in NUMBER, threshold_in NUMBER);
	procedure delete_user(user_id_in number);
END rhn_org;
/
SHOW ERRORS

create or replace
package rhn_entitlements
is

	function entitlement_grants_service (
		entitlement_in in varchar2,
		service_level_in in varchar2
	) return number;

	function lookup_entitlement_group (
		org_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	) return number;

	function create_entitlement_group (
		org_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	) return number;

	procedure entitle_server (
		server_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	);

	procedure unentitle_server (
		server_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	);

	-- upgrade server wants you already to be in an
	-- enterprise_entitled server group, and tries to
	-- put you in a provisioning_entitled one instead.
	procedure upgrade_server (
		server_id_in in number
	);

	function get_server_entitlement (
		server_id_in in number
	) return varchar2;

    procedure set_customer_enterprise (
		customer_id in number
	);

	procedure set_customer_provisioning (
		customer_id_in in number
	);

	procedure set_customer_nonlinux (
		customer_id_in in number
	);

    procedure unset_customer_enterprise (
		customer_id in number
	);

	procedure unset_customer_provisioning (
		customer_id_in in number
	);

	procedure unset_customer_nonlinux (
		customer_id_in in number
	);

    procedure set_group_count (
		customer_id_in in number,	-- customer_id
		type_in in char,			-- 'U' or 'S'
		group_type_in in number,	-- rhn[User|Server]GroupType.id
		quantity_in in number		-- quantity
    );

    procedure set_family_count (
		customer_id_in in number,		-- customer_id
		channel_family_id_in in number,	-- 246
		quantity_in in number			-- 3
    );

    -- this makes NO checks that the quantity is within max,
    -- so we should NEVER run this unless we KNOW that we won't be
    -- violating the max
    procedure entitle_last_modified_servers (
		customer_id_in in number,	-- customer_id
		type_label_in in varchar2,	-- 'enterprise_entitled'
		quantity_in in number		-- 3
    );

	-- results from this are valid _only_ in the context of the
	-- server group label queried.  If you ask for provisioning
	-- data, don't compare that with results for enterprise data.
	procedure get_available_slots (
		customer_id_in in number,
		type_label_in in varchar2,
		server_group_id_out out number,
		available_out out number,
		upgrade_out out number
	);

	procedure prune_everything (
		customer_id_in in number
	);

	procedure subscribe_newest_servers (
		customer_id_in in number
	);
end rhn_entitlements;
/
show errors

CREATE OR REPLACE
PACKAGE rhn_channel
IS
	version varchar2(100) := '$Id: satellite-3.2-to-3.4.sql 64427 2005-09-09 14:08:21Z jslagle $';

    CURSOR server_base_subscriptions(server_id_in NUMBER) IS
	   SELECT C.id
	     FROM rhnChannel C, rhnServerChannel SC
	    WHERE C.id = SC.channel_id
	      AND SC.server_id = server_id_in
	      AND C.parent_channel IS NULL;

    CURSOR check_server_subscription(server_id_in NUMBER, channel_id_in NUMBER) IS
           SELECT channel_id
	     FROM rhnServerChannel
	    WHERE server_id = server_id_in
	      AND channel_id = channel_id_in;

    CURSOR check_server_parent_membership(server_id_in NUMBER, channel_id_in NUMBER) IS
	   SELECT C.id
	     FROM rhnChannel C, rhnServerChannel SC
	    WHERE C.parent_channel = channel_id_in
	      AND C.id = SC.channel_id
	      AND SC.server_id = server_id_in;

    CURSOR channel_family_perm_cursor(channel_family_id_in NUMBER, org_id_in NUMBER) IS
           SELECT *
	     FROM rhnOrgChannelFamilyPermissions
	    WHERE channel_family_id = channel_family_id_in
	      AND org_id = org_id_in;

    PROCEDURE license_consent(channel_id_in IN NUMBER, user_id_in IN NUMBER, server_id_in IN NUMBER);
    FUNCTION get_license_path(channel_id_in IN NUMBER) RETURN VARCHAR2;

    PROCEDURE unsubscribe_server(server_id_in IN NUMBER, channel_id_in NUMBER, immediate_in NUMBER := 1, unsubscribe_children_in number := 0);
    PROCEDURE subscribe_server(server_id_in IN NUMBER, channel_id_in NUMBER, immediate_in NUMBER := 1, user_id_in number := null);

    FUNCTION guess_server_base(server_id_in IN NUMBER) RETURN NUMBER;

    FUNCTION base_channel_for_release_arch(release_in in varchar2,
	server_arch_in in varchar2, org_id_in in number := -1,
	user_id_in in number := null) RETURN number;

    FUNCTION base_channel_rel_archid(release_in in varchar2,
	server_arch_id_in in number, org_id_in in number := -1,
	user_id_in in number := null) RETURN number;

    FUNCTION channel_priority(channel_id_in in number) RETURN number;

    PROCEDURE bulk_subscribe_server(channel_id_in IN NUMBER, set_label_in IN VARCHAR2, set_uid_in IN NUMBER);
    PROCEDURE bulk_unsubscribe_server(channel_id_in IN NUMBER, set_label_in IN VARCHAR2, set_uid_in IN NUMBER);

    PROCEDURE bulk_server_base_change(channel_id_in IN NUMBER, set_label_in IN VARCHAR2, set_uid_in IN NUMBER);
    procedure bulk_server_basechange_from(
	set_label_in in varchar2,
	set_uid_in in number,
	old_channel_id_in in number,
	new_channel_id_in in number);

    procedure bulk_guess_server_base(
	set_label_in in varchar2,
	set_uid_in in number);

    procedure bulk_guess_server_base_from(
	set_label_in in varchar2,
	set_uid_in in number,
	channel_id_in in number);

    PROCEDURE clear_subscriptions(server_id_in IN NUMBER);

    FUNCTION available_family_subscriptions(channel_family_id_in IN NUMBER, org_id_in IN NUMBER) RETURN NUMBER;
    PROCEDURE update_family_counts(channel_family_id_in IN NUMBER, org_id_in IN NUMBER);
    FUNCTION family_for_channel(channel_id_in IN NUMBER) RETURN NUMBER;

    FUNCTION available_chan_subscriptions(channel_id_in IN NUMBER, org_id_in IN NUMBER) RETURN NUMBER;

    procedure entitle_customer(customer_id_in in number, channel_family_id_in in number, quantity_in in number);
    procedure set_family_maxmembers(customer_id_in in number, channel_family_id_in in number, quantity_in in number);
    procedure unsubscribe_server_from_family(server_id_in in number, channel_family_id_in in number);

    procedure delete_server_channels(server_id_in in number);
    procedure refresh_newest_package(channel_id_in in number, caller_in in varchar2 := '(unknown)');

    function get_org_id(channel_id_in in number) return number;
    PRAGMA RESTRICT_REFERENCES(get_org_id, WNDS, RNPS, WNPS);

    function get_org_access(channel_id_in in number, org_id_in in number) return number;
    PRAGMA RESTRICT_REFERENCES(get_org_access, WNDS, RNPS, WNPS);

    function get_cfam_org_access(cfam_id_in in number, org_id_in in number) return number;

    function user_role_check_debug(channel_id_in in number, user_id_in in number, role_in in varchar2, reason_out out varchar2)
	RETURN NUMBER;
    PRAGMA RESTRICT_REFERENCES(user_role_check_debug, WNDS, RNPS, WNPS);

    function user_role_check(channel_id_in in number, user_id_in in number, role_in in varchar2)
	RETURN NUMBER;
    PRAGMA RESTRICT_REFERENCES(user_role_check, WNDS, RNPS, WNPS);

    function loose_user_role_check(channel_id_in in number, user_id_in in number, role_in in varchar2)
	RETURN NUMBER;
    PRAGMA RESTRICT_REFERENCES(loose_user_role_check, WNDS, RNPS, WNPS);

    function direct_user_role_check(channel_id_in in number, user_id_in in number, role_in in varchar2)
	RETURN NUMBER;
    PRAGMA RESTRICT_REFERENCES(direct_user_role_check, WNDS, RNPS, WNPS);

    function org_channel_setting(channel_id_in in number, org_id_in in number, setting_in in varchar2)
	RETURN NUMBER;
    PRAGMA RESTRICT_REFERENCES(org_channel_setting, WNDS, RNPS, WNPS);

END rhn_channel;
/
SHOW ERRORS

create or replace procedure
create_first_org
(
	name_in in varchar2,
	password_in in varchar2
) is
	ug_type			number;
	group_val		number;
begin
	insert into web_customer (
		id, name, password,
		oracle_customer_id, oracle_customer_number,
		customer_type
	) values (
		1, name_in, password_in,
		1, 1, 'B'
	);

	select rhn_user_group_id_seq.nextval into group_val from dual;

	select	id
	into	ug_type
	from	rhnUserGroupType
	where	label = 'org_admin';

	insert into rhnUserGroup (
		id, name,
		description,
		max_members, group_type, org_id
	) values (
		group_val, 'Organization Administrators',
		'Organization Administrators for Org ' || name_in || ' (1)',
		NULL, ug_type, 1
	);

	select rhn_user_group_id_seq.nextval into group_val from dual;

	select	id
	into	ug_type
	from	rhnUserGroupType
	where	label = 'org_applicant';

	insert into rhnUserGroup (
		id, name,
		description,
		max_members, group_type, org_id
	) values (
		group_val, 'Organization Applicants',
		'Organization Applicants for Org ' || name_in || ' (1)',
		NULL, ug_type, 1
	);

	-- config admin is special; it gets created in
	-- rhn_entitlements.set_customer_provisioning instead.

	select rhn_user_group_id_seq.nextval into group_val from dual;

	select	id
	into	ug_type
	from	rhnUserGroupType
	where	label = 'channel_admin';

	insert into rhnUserGroup (
		id, name,
		description,
		max_members, group_type, org_id
	) values (
		group_val, 'Channel Administrators',
		'Channel Administrators for Org ' || name_in || ' (1)',
		NULL, ug_type, 1
	);

	-- if they need more than 16GB, they'll call us and we'll whip
	-- out a "can be null" patch, which we should do for next
	-- version anyway.  (I thought we did that for this version?)
	insert into rhnOrgQuota(
		org_id, total
	) values (
		1, 1024*1024*1024*16
	);


	insert into rhnOrgState (org_id, state_id)
	select 1, id
	  from rhnOrgAvailableStates
	 where label = 'paid';

        insert into rhnServerGroup
		( id, name, description, max_members, group_type, org_id )
		select rhn_server_group_id_seq.nextval, sgt.name, sgt.name,
			0, sgt.id, 1
		from rhnServerGroupType sgt
		where sgt.label = 'sw_mgr_entitled';
end;
/
show errors

create or replace
package body rhn_user
is
	body_version varchar2(100) := '$Id: satellite-3.2-to-3.4.sql 64427 2005-09-09 14:08:21Z jslagle $';

    function check_role(user_id_in in number, role_in in varchar2)
    return number
    is
	throwaway number;
    begin
	-- the idea: if we get past this query, the org has the setting, else catch the exception and return 0
	select 1 into throwaway
	  from rhnUserGroupType UGT,
	       rhnUserGroup UG,
	       rhnUserGroupMembers UGM
	 where UGM.user_id = user_id_in
	   and UGM.user_group_id = UG.id
	   and UG.group_type = UGT.id
	   and UGT.label = role_in;

	return 1;
    exception
	when no_data_found
	    then
	    return 0;
    end check_role;

    function check_role_implied(user_id_in in number, role_in in varchar2)
    return number
    is
	throwaway number;
    begin
	-- if the user directly has the role, they win
	if rhn_user.check_role(user_id_in, role_in) = 1
	then
	    return 1;
	end if;

	-- config_admin and channel_admin are automatically implied for org admins
	if role_in = 'config_admin' and rhn_user.check_role(user_id_in, 'org_admin') = 1
	then
	    return 1;
	end if;

	if role_in = 'channel_admin' and rhn_user.check_role(user_id_in, 'org_admin') = 1
	then
	    return 1;
	end if;

	return 0;
    end check_role_implied;

    function get_org_id(user_id_in in number)
    return number
    is
	org_id_out number;
    begin
	select org_id into org_id_out
	  from web_contact
	 where id = user_id_in;

	return org_id_out;
    end get_org_id;

	-- paid users often don't have verified email addresses, so
	-- try to find an address that is useful to us.
	function find_mailable_address(user_id_in in number)
	return varchar2 is
		PRAGMA AUTONOMOUS_TRANSACTION;
		-- this would be so much prettier if we just had an order built
		-- into rhnEmailAddressState
		cursor addrs is
			select	ea.state_id, ea.address
			from	rhnEmailAddressState eas,
					rhnEmailAddress ea
			where	ea.user_id = user_id_in
				and eas.label = 'verified'
				and ea.state_id = eas.id
			union all
			select	ea.state_id, ea.address
			from	rhnEmailAddressState eas,
					rhnEmailAddress ea
			where	ea.user_id = user_id_in
				and eas.label = 'unverified'
				and ea.state_id = eas.id
			union all
			select	ea.state_id, ea.address
			from	rhnEmailAddressState eas,
					rhnEmailAddress ea
			where	ea.user_id = user_id_in
				and eas.label = 'pending'
				and ea.state_id = eas.id
			union all
			select	ea.state_id, ea.address
			from	rhnEmailAddressState eas,
					rhnEmailAddress ea
			where	ea.user_id = user_id_in
				and eas.label = 'pending_warned'
				and ea.state_id = eas.id
			union all
			select	ea.state_id, ea.address
			from	rhnEmailAddressState eas,
					rhnEmailAddress ea
			where	ea.user_id = user_id_in
				and eas.label = 'needs_verifying'
				and ea.state_id = eas.id
			union all
			select	-1 state_id,
					email address
			from	web_user_personal_info
			where	web_user_id = user_id_in;
		retval rhnEmailAddress.address%TYPE;
	begin
		for addr in addrs loop
			retval := addr.address;
			if addr.address is null then
				update web_user_contact_permission
					set email = 'N'
					where web_user_id = user_id_in;
				commit;
				return null;
			end if;
			if addr.state_id = -1 then
				insert into rhnEmailAddress (
						id, address,
						user_id, state_id
					) (
						select	rhn_eaddress_id_seq.nextval, addr.address,
								user_id_in, eas.id
						from	rhnEmailAddressState eas
						where	eas.label = 'unverified'
					);
			end if;
			commit;
			return retval;
		end loop;
		return null;
	end;
end rhn_user;
/
SHOW ERRORS

CREATE OR REPLACE
PACKAGE BODY rhn_org
IS
	body_version varchar2(100) := '$Id: satellite-3.2-to-3.4.sql 64427 2005-09-09 14:08:21Z jslagle $';

    FUNCTION find_server_group_by_type(org_id_in NUMBER, group_label_in VARCHAR2)
    RETURN NUMBER
    IS
	server_group       server_group_by_label%ROWTYPE;
    BEGIN
	OPEN server_group_by_label(org_id_in, group_label_in);
	FETCH server_group_by_label INTO server_group;
	CLOSE server_group_by_label;

	RETURN server_group.id;
    END find_server_group_by_type;

    PROCEDURE update_errata_cache(org_id_in NUMBER, threshold_in NUMBER)
    IS
	records_present NUMBER;
    BEGIN
	SELECT NVL(SUM(server_count), 0) INTO records_present
	  FROM rhnOrgErrataCacheQueue
	 WHERE org_id = org_id_in
	   AND processed = 0;

	IF records_present < 1 OR records_present > threshold_in
	THEN
	    RETURN;
	END IF;

	DELETE FROM rhnOrgErrataCacheQueue WHERE org_id = org_id_in;

	DELETE FROM rhnServerNeededPackageCache
	      WHERE server_id IN (SELECT id
				    FROM rhnServer
				   WHERE org_id = org_id_in);

        INSERT INTO rhnServerNeededPackageCache
        SELECT *
	  FROM rhnServerNeededPackageView
	 WHERE server_id IN (SELECT id
			       FROM rhnServer
			      WHERE org_id = org_id_in);
    END update_errata_cache;

	procedure delete_user(user_id_in in number) is
		cursor is_admin is
			select	1
			from	rhnUserGroupType	ugt,
					rhnUserGroup		ug,
					rhnUserGroupMembers	ugm
			where	ugm.user_id = user_id_in
				and ugm.user_group_id = ug.id
				and ug.group_type = ugt.id
				and ugt.label = 'org_admin';
		cursor servergroups_needing_admins is
			select	usgp.server_group_id	server_group_id
			from	rhnUserServerGroupPerms	usgp
			where	1=1
				and usgp.user_id = user_id_in
				and not exists (
					select	1
					from	rhnUserServerGroupPerms	sq_usgp
					where	1=1
						and sq_usgp.server_group_id = usgp.server_group_id
						and	sq_usgp.user_id != user_id_in
				);
		cursor servergroups_for_deletion(org_id_in in number) is
			select	sgm.server_id, sgm.server_group_id
			from	rhnServerGroupMembers sgm,
					rhnServerGroup sg
			where	sg.org_id = org_id_in
				and sg.id = sgm.server_group_id;
		cursor servers_for_deletion(org_id_in in number) is
			select	id
			from	rhnServer
			where	org_id = org_id_in;
		cursor snapshots(sgid_in in number) is
			select	snapshot_id id
			from	rhnSnapshotServerGroup
			where	server_group_id = sgid_in;
		cursor messages is
			select	message_id id
			from	rhnUserMessage
			where	user_id = user_id_in;
		users			number;
		our_org_id		number;
		del_check_ok	number;
		other_users		number;
		other_org_admin	number;
	begin
		select	wc.org_id, xxrh_contact_del_check_num(user_id_in)
		into	our_org_id, del_check_ok
		from	web_contact wc
		where	id = user_id_in;

		-- bail early if we know it won't work
		if del_check_ok != 1 then
			rhn_exception.raise_exception('cannot_delete_user');
			return;
		end if;

		-- find any other users
		begin
			select	1
			into	other_users
			from	web_contact
			where	1=1
				and org_id = our_org_id
				and id != user_id_in
				and rownum = 1;
		exception
			when no_data_found then
				other_users := 0;
		end;

		-- now do org admin stuff
		if other_users != 0 then
			for ignore in is_admin loop
				begin
					select	new_ugm.user_id
					into	other_org_admin
					from	rhnUserGroupMembers	new_ugm,
							rhnUserGroupType	ugt,
							rhnUserGroup		ug,
							rhnUserGroupMembers	ugm
					where	ugm.user_id = user_id_in
						and ugm.user_group_id = ug.id
						and ug.group_type = ugt.id
						and ugt.label = 'org_admin'
						and ug.id = new_ugm.user_group_id
						and new_ugm.user_id != user_id_in
						and rownum = 1;
				exception
					when no_data_found then
						rhn_exception.raise_exception('cannot_delete_user');
				end;

				for sg in servergroups_needing_admins loop
					insert into rhnUserServerGroupPerms
						( user_id , server_group_id )
						values ( other_org_admin, sg.server_group_id );
				end loop;
			end loop;
		end if;

		-- and now things for every user
		for message in messages loop
			delete
				from	rhnUserMessage
				where	user_id = user_id_in
					and message_id = message.id;
			begin
				select	1
				into	users
				from	rhnUserMessage
				where	message_id = message.id
					and rownum = 1;
				delete
					from	rhnMessage
					where	id = message.id;
			exception
				when no_data_found then
					null;
			end;
		end loop;
		if other_users != 0 then
			update		rhnRegToken
				set		user_id = other_org_admin
				where	org_id = our_org_id
					and user_id = user_id_in;
			begin
				delete from web_contact where id = user_id_in;
			exception
				when others then
					rhn_exception.raise_exception('cannot_delete_user');
			end;
		else
			-- so that the delete trigger doesn't bite us
			for sgm in servergroups_for_deletion(our_org_id) loop
				for snapshot in snapshots(sgm.server_group_id) loop
					update rhnSnapshot
						set invalid =
							lookup_snapshot_invalid_reason('sg_removed')
						where id = snapshot.id;
					delete from rhnSnapshotServerGroup
						where snapshot_id = snapshot.id
						and server_group_id = sgm.server_group_id;
				end loop;
				rhn_server.delete_from_servergroup(
						sgm.server_id, sgm.server_group_id);
			end loop;
			update rhnServerGroup set group_type = null
				where org_id = our_org_id;
			delete from rhnServerGroup where org_id = our_org_id;
			for s in servers_for_deletion(our_org_id) loop
				delete_server(s.id);
			end loop;
			begin
				delete from web_contact where id = user_id_in;
				delete from web_customer where id = our_org_id;
			exception
				when others then
					rhn_exception.raise_exception('cannot_delete_user');
			end;
		end if;
		return;
	end delete_user;
END rhn_org;
/
SHOW ERRORS

CREATE OR REPLACE
PACKAGE BODY rhn_channel
IS
	body_version varchar2(100) := '$Id: satellite-3.2-to-3.4.sql 64427 2005-09-09 14:08:21Z jslagle $';

    -- Cursor that fetches all the possible base channels for a
    -- (server_arch_id, release, org_id) combination
	cursor	base_channel_cursor(
		release_in in varchar2,
		server_arch_id_in in number,
		org_id_in in number
	) return rhnChannel%ROWTYPE is
		select distinct c.*
		from	rhnDistChannelMap			dcm,
				rhnServerChannelArchCompat	scac,
				rhnChannel					c,
				rhnChannelPermissions		cp
		where	cp.org_id = org_id_in
			and cp.channel_id = c.id
			and c.parent_channel is null
			and c.id = dcm.channel_id
			and c.channel_arch_id = dcm.channel_arch_id
			and dcm.release = release_in
			and scac.server_arch_id = server_arch_id_in
			and scac.channel_arch_id = c.channel_arch_id;

    FUNCTION get_license_path(channel_id_in IN NUMBER)
    RETURN VARCHAR2
    IS
	license_val VARCHAR2(1000);
    BEGIN
	SELECT CFL.license_path INTO license_val
	  FROM rhnChannelFamilyLicense CFL, rhnChannelFamilyMembers CFM
	 WHERE CFM.channel_id = channel_id_in
	   AND CFM.channel_family_id = CFL.channel_family_id;

	RETURN license_val;

    EXCEPTION
	WHEN NO_DATA_FOUND
	    THEN
	    RETURN NULL;
    END get_license_path;


    PROCEDURE license_consent(channel_id_in IN NUMBER, user_id_in IN NUMBER, server_id_in IN NUMBER)
    IS
	channel_family_id_val NUMBER;
    BEGIN
	channel_family_id_val := rhn_channel.family_for_channel(channel_id_in);
	IF channel_family_id_val IS NULL
	THEN
	    rhn_exception.raise_exception('channel_subscribe_no_family');
	END IF;

	IF rhn_channel.get_license_path(channel_id_in) IS NULL
	THEN
	    rhn_exception.raise_exception('channel_consent_no_license');
	END IF;

	INSERT INTO rhnChannelFamilyLicenseConsent (channel_family_id, user_id, server_id)
	VALUES (channel_family_id_val, user_id_in, server_id_in);
    END license_consent;

    PROCEDURE subscribe_server(server_id_in IN NUMBER, channel_id_in NUMBER, immediate_in NUMBER := 1, user_id_in in number := null)
    IS
        channel_parent_val      rhnChannel.parent_channel%TYPE;
        parent_subscribed       BOOLEAN;
        server_has_base_chan    BOOLEAN;
	server_already_in_chan  BOOLEAN;
	channel_family_id_val   NUMBER;
	server_org_id_val       NUMBER;
	available_subscriptions NUMBER;
	consenting_user         NUMBER;
	allowed			number := 0;
    BEGIN
	if user_id_in is not null then
		allowed := rhn_channel.user_role_check(channel_id_in, user_id_in, 'subscribe');
	else
		allowed := 1;
	end if;

	if allowed = 0 then
		rhn_exception.raise_exception('no_subscribe_permissions');
	end if;


        SELECT parent_channel INTO channel_parent_val FROM rhnChannel WHERE id = channel_id_in;

        IF channel_parent_val IS NOT NULL
        THEN
	    -- child channel; if attempting to cross-subscribe a child to the wrong base, silently ignore
            parent_subscribed := FALSE;

            FOR check_subscription IN check_server_subscription(server_id_in, channel_parent_val)
            LOOP
                parent_subscribed := TRUE;
            END LOOP check_subscription;

            IF NOT parent_subscribed
            THEN
		RETURN;
            END IF;
        ELSE
	    -- base channel
            server_has_base_chan := FALSE;
            FOR base IN server_base_subscriptions(server_id_in)
            LOOP
                server_has_base_chan := TRUE;
            END LOOP base;

            IF server_has_base_chan
            THEN
                rhn_exception.raise_exception('channel_server_one_base');
            END IF;
        END IF;

        FOR check_subscription IN check_server_subscription(server_id_in, channel_id_in)
        LOOP
            server_already_in_chan := TRUE;
        END LOOP check_subscription;

        IF server_already_in_chan
        THEN
	    RETURN;
        END IF;

	channel_family_id_val := rhn_channel.family_for_channel(channel_id_in);
	IF channel_family_id_val IS NULL
	THEN
	    rhn_exception.raise_exception('channel_subscribe_no_family');
	END IF;

	SELECT org_id INTO server_org_id_val
	  FROM rhnServer
	 WHERE id = server_id_in;

	available_subscriptions := rhn_channel.available_family_subscriptions(channel_family_id_val, server_org_id_val);

	IF available_subscriptions IS NULL OR available_subscriptions > 0
	THEN

	    IF rhn_channel.get_license_path(channel_id_in) IS NOT NULL
	    THEN
		BEGIN

		SELECT user_id INTO consenting_user
		  FROM rhnChannelFamilyLicenseConsent
		 WHERE channel_family_id = channel_family_id_val
		   AND server_id = server_id_in;

		EXCEPTION
		    WHEN NO_DATA_FOUND
			THEN
			    rhn_exception.raise_exception('channel_subscribe_no_consent');
		END;
	    END IF;

	    insert into rhnServerHistory (id,server_id,summary,details) (
		select	rhn_event_id_seq.nextval,
			server_id_in,
			'subscribed to channel ' || SUBSTR(c.label, 0, 106),
			c.label
		from	rhnChannel c
		where	c.id = channel_id_in
	    );
	    UPDATE rhnServer SET channels_changed = sysdate WHERE id = server_id_in;
            INSERT INTO rhnServerChannel (server_id, channel_id) VALUES (server_id_in, channel_id_in);

	    rhn_channel.update_family_counts(channel_family_id_val, server_org_id_val);
	    queue_server(server_id_in, immediate_in);
	ELSE
	    rhn_exception.raise_exception('channel_family_no_subscriptions');
	END IF;

    END subscribe_server;

    PROCEDURE bulk_subscribe_server(channel_id_in IN NUMBER, set_label_in IN VARCHAR2, set_uid_in IN NUMBER)
    IS
    BEGIN
        FOR server IN rhn_set.set_iterator(set_label_in, set_uid_in)
        LOOP
            rhn_channel.subscribe_server(server.element, channel_id_in, 0, set_uid_in);
        END LOOP server;
    END bulk_subscribe_server;

    PROCEDURE bulk_server_base_change(channel_id_in IN NUMBER, set_label_in IN VARCHAR2, set_uid_in IN NUMBER)
    IS
    BEGIN
        FOR server IN rhn_set.set_iterator(set_label_in, set_uid_in)
        LOOP
	    IF rhn_server.can_change_base_channel(server.element) = 1
	    THEN
                rhn_channel.clear_subscriptions(TO_NUMBER(server.element));
                rhn_channel.subscribe_server(server.element, channel_id_in, 0, set_uid_in);
            END IF;
        END LOOP server;
    END bulk_server_base_change;

    procedure bulk_server_basechange_from(
	set_label_in in varchar2,
	set_uid_in in number,
	old_channel_id_in in number,
	new_channel_id_in in number
    ) is
	cursor channels(server_id_in in number) is
	    select  rsc.channel_id
	    from    rhnServerChannel rsc,
		    rhnChannel rc,
		    rhnServerChannelArchCompat scac,
		    rhnServer s
	    where   server_id_in = s.id
		-- first, see if it's compatible with the new channel
		and s.server_arch_id = scac.server_arch_id
		and scac.channel_arch_id = new_channel_id_in
		-- now that we know it is, make sure it's in the old channel
		and s.id = rsc.server_id
		and rsc.channel_id = old_channel_id_in
		-- and now make sure the old channel is a base channel
		and rsc.channel_id = rc.id
		and rc.parent_channel is null;
    begin
	for server in rhn_set.set_iterator(set_label_in, set_uid_in) loop
	    for channel in channels(server.element) loop
		insert into rhnSet (user_id, label, element) values (set_uid_in, set_label_in || 'basechange', server.element);
	    end loop channel;
	end loop server;
	bulk_server_base_change(new_channel_id_in, set_label_in||'basechange',set_uid_in);
	delete from rhnSet where label = set_label_in||'basechange' and user_id = set_uid_in;
    end;

    procedure bulk_guess_server_base(
	set_label_in in varchar2,
	set_uid_in in number
    ) is
	channel_id number;
    begin
	for server in rhn_set.set_iterator(set_label_in, set_uid_in)
	loop
	    -- anything that doesn't work, we just ignore
	    begin
		if rhn_server.can_change_base_channel(server.element) = 1
		then
	            channel_id := guess_server_base(TO_NUMBER(server.element));
		    rhn_channel.clear_subscriptions(TO_NUMBER(server.element));
		    rhn_channel.subscribe_server(TO_NUMBER(server.element), channel_id, 0, set_uid_in);
		end if;
	    exception when others then
		null;
	    end;
	end loop server;
    end;

    function guess_server_base(
	server_id_in in number
    ) RETURN number is
	cursor server_cursor is
	    select s.server_arch_id, s.release, s.org_id
	      from rhnServer s
	     where s.id = server_id_in;
    begin
	for s in server_cursor loop
	    for channel in base_channel_cursor(s.release,
		s.server_arch_id, s.org_id)
	    loop
		return channel.id;
	    end loop base_channel_cursor;
        end loop server_cursor;
	-- Server not found, or no base channel applies to it
        return null;
    end;

    -- Private function
    function normalize_server_arch(server_arch_in in varchar2)
    return varchar2
    is
	suffix VARCHAR2(128) := '-redhat-linux';
	suffix_len NUMBER := length(suffix);
    begin
	if server_arch_in is NULL then
	    return NULL;
	end if;
        if instr(server_arch_in, '-') > 0
	then
	    -- Suffix already present
	    return server_arch_in;
	end if;
	return server_arch_in || suffix;
    end normalize_server_arch;

    --
    --
    -- Raises:
    --   server_arch_not_found
    --   no_subscribe_permissions
    function base_channel_for_release_arch(
	release_in in varchar2,
	server_arch_in in varchar2,
	org_id_in in number := -1,
	user_id_in in number := null
    ) return number is
	server_arch varchar2(256) := normalize_server_arch(server_arch_in);
	server_arch_id number;
    begin
	-- Look up the server arch
	begin
	    select id
	      into server_arch_id
	      from rhnServerArch
	     where label = server_arch;
	exception
	    when no_data_found then
		rhn_exception.raise_exception('server_arch_not_found');
	end;
	return base_channel_rel_archid(release_in, server_arch_id,
	    org_id_in, user_id_in);
    end base_channel_for_release_arch;

    function base_channel_rel_archid(
	release_in in varchar2,
	server_arch_id_in in number,
	org_id_in in number := -1,
	user_id_in in number := null
    ) return number is
	denied_channel_id number := null;
	valid_org_id number := org_id_in;
	valid_user_id number := user_id_in;
	channel_subscribable number;
    begin
	if org_id_in = -1 and user_id_in is not null then
	    -- Get the org id from the user id
	    begin
		select org_id
		  into valid_org_id
		  from web_contact
		 where id = user_id_in;
	    exception
		when no_data_found then
		    -- User doesn't exist
		    -- XXX Only list public stuff for now
		    valid_user_id := null;
		    valid_org_id := -1;
	    end;
	end if;

	for c in base_channel_cursor(release_in, server_arch_id_in, valid_org_id)
	loop
	    -- This row is a possible match
	    if valid_user_id is null then
		-- User ID not specified, so no user to channel permissions to
		-- check
		return c.id;
	    end if;

	    -- Check user to channel permissions
	    select loose_user_role_check(c.id, user_id_in, 'subscribe')
	      into channel_subscribable
	      from dual;

	    if channel_subscribable = 1 then
		return c.id;
	    end if;

	    -- Base channel exists, but is not subscribable; keep trying
	    denied_channel_id := c.id;
	end loop base_channel_fetch;

	if denied_channel_id is not null then
	    rhn_exception.raise_exception('no_subscribe_permissions');
	end if;
	-- No base channel applies
	return NULL;
    end base_channel_rel_archid;

    procedure bulk_guess_server_base_from(
	set_label_in in varchar2,
	set_uid_in in number,
	channel_id_in in number
    ) is
	cursor channels(server_id_in in number) is
	    select	rsc.channel_id
	    from	rhnServerChannel rsc,
			rhnChannel rc
	    where	server_id_in = rsc.server_id
			and rsc.channel_id = rc.id
			and rc.parent_channel is null;
    begin
	for server in rhn_set.set_iterator(set_label_in, set_uid_in)
	loop
	    for channel in channels(server.element)
	    loop
		if channel.channel_id = channel_id_in
		then
		    insert into rhnSet (user_id, label, element) values (set_uid_in, set_label_in || 'baseguess', server.element);
		end if;
	    end loop channel;
	end loop server;
	bulk_guess_server_base(set_label_in||'baseguess',set_uid_in);
	delete from rhnSet where label = set_label_in||'baseguess' and user_id = set_uid_in;
    end;


    PROCEDURE clear_subscriptions(server_id_in IN NUMBER)
    IS
	cursor server_channels(server_id_in in number) is
		select	s.org_id, sc.channel_id, cfm.channel_family_id
		from	rhnServer s,
			rhnServerChannel sc,
			rhnChannelFamilyMembers cfm
		where	s.id = server_id_in
			and s.id = sc.server_id
			and sc.channel_id = cfm.channel_id;
    BEGIN
	for channel in server_channels(server_id_in)
	loop
		unsubscribe_server(server_id_in, channel.channel_id, 1, 1);
		rhn_channel.update_family_counts(channel.channel_family_id, channel.org_id);
	end loop channel;
    END clear_subscriptions;

    PROCEDURE unsubscribe_server(server_id_in IN NUMBER, channel_id_in NUMBER, immediate_in NUMBER := 1, unsubscribe_children_in number := 0)
    IS
	channel_family_id_val   NUMBER;
	server_org_id_val       NUMBER;
	available_subscriptions NUMBER;
	server_already_in_chan  BOOLEAN;
	cursor	channel_family_is_proxy(channel_family_id_in in number) is
		select	1
		from	rhnChannelFamily
		where	id = channel_family_id_in
		    and label = 'rhn-proxy';
	cursor	channel_family_is_satellite(channel_family_id_in in number) is
		select	1
		from	rhnChannelFamily
		where	id = channel_family_id_in
		    and label = 'rhn-satellite';
	-- this is *EXACTLY* like check_server_parent_membership, but if we recurse
	-- with the package-level one, we get a "cursor already open", so we need a
	-- copy on our call stack instead.  GROAN.
	cursor local_chk_server_parent_memb (
			server_id_in number,
			channel_id_in number ) is
		select	c.id
		from	rhnChannel			c,
				rhnServerChannel	sc
		where	1=1
			and c.parent_channel = channel_id_in
			and c.id = sc.channel_id
			and sc.server_id = server_id_in;
    BEGIN
        FOR child IN local_chk_server_parent_memb(server_id_in, channel_id_in)
        LOOP
	    if unsubscribe_children_in = 1 then
		unsubscribe_server(server_id_in => server_id_in,
								channel_id_in => child.id,
								immediate_in => immediate_in,
								unsubscribe_children_in => unsubscribe_children_in);
	    else
		rhn_exception.raise_exception('channel_unsubscribe_child_exists');
	    end if;
        END LOOP child;

	server_already_in_chan := FALSE;

        FOR check_subscription IN check_server_subscription(server_id_in, channel_id_in)
        LOOP
            server_already_in_chan := TRUE;
        END LOOP check_subscription;

        IF NOT server_already_in_chan
        THEN
	    RETURN;
        END IF;

	insert into rhnServerHistory (id,server_id,summary,details) (
	    select  rhn_event_id_seq.nextval,
		    server_id_in,
		    'unsubscribed from channel ' || SUBSTR(c.label, 0, 106),
		    c.label
	    from    rhnChannel c
	    where   c.id = channel_id_in
	);
	UPDATE rhnServer SET channels_changed = sysdate WHERE id = server_id_in;
        DELETE FROM rhnServerChannel WHERE server_id = server_id_in AND channel_id = channel_id_in;
	queue_server(server_id_in, immediate_in);

	channel_family_id_val := rhn_channel.family_for_channel(channel_id_in);
	IF channel_family_id_val IS NULL
	THEN
	    rhn_exception.raise_exception('channel_unsubscribe_no_family');
	END IF;

	for ignore in channel_family_is_satellite(channel_family_id_val) loop
		delete from rhnSatelliteInfo where server_id = server_id_in;
		delete from rhnSatelliteChannelFamily where server_id = server_id_in;
	end loop;

	for ignore in channel_family_is_proxy(channel_family_id_val) loop
		delete from rhnProxyInfo where server_id = server_id_in;
	end loop;

	DELETE FROM rhnChannelFamilyLicenseConsent
	 WHERE channel_family_id = channel_family_id_val
	   AND server_id = server_id_in;

	SELECT org_id INTO server_org_id_val
	  FROM rhnServer
	 WHERE id = server_id_in;

	rhn_channel.update_family_counts(channel_family_id_val, server_org_id_val);
    END unsubscribe_server;

    PROCEDURE bulk_unsubscribe_server(channel_id_in IN NUMBER, set_label_in IN VARCHAR2, set_uid_in IN NUMBER)
    IS
    BEGIN
        FOR server IN rhn_set.set_iterator(set_label_in, set_uid_in)
        LOOP
            rhn_channel.unsubscribe_server(server.element, channel_id_in, 0);
        END LOOP server;
    END bulk_unsubscribe_server;

    FUNCTION family_for_channel(channel_id_in IN NUMBER)
    RETURN NUMBER
    IS
	channel_family_id_val NUMBER;
    BEGIN
	SELECT channel_family_id INTO channel_family_id_val
	  FROM rhnChannelFamilyMembers
         WHERE channel_id = channel_id_in;

	RETURN channel_family_id_val;
    EXCEPTION
        WHEN NO_DATA_FOUND
	THEN
	    RETURN NULL;
    END family_for_channel;

    FUNCTION available_family_subscriptions(channel_family_id_in IN NUMBER, org_id_in IN NUMBER)
    RETURN NUMBER
    IS
	cfp channel_family_perm_cursor%ROWTYPE;
	current_members_val NUMBER;
	max_members_val     NUMBER;
	found               NUMBER;
    BEGIN
	IF NOT channel_family_perm_cursor%ISOPEN
	THEN
	    OPEN channel_family_perm_cursor(channel_family_id_in, org_id_in);
	END IF;

	FETCH channel_family_perm_cursor INTO cfp;

	WHILE channel_family_perm_cursor%FOUND
	LOOP
	    found := 1;

	    current_members_val := cfp.current_members;
	    max_members_val := cfp.max_members;

	    FETCH channel_family_perm_cursor INTO cfp;
	END LOOP;

	IF channel_family_perm_cursor%ISOPEN
	THEN
	    CLOSE channel_family_perm_cursor;
	END IF;

	-- not found: either the channel fam doesn't have an entry in cfp, or the org doesn't have access to it.
	-- either way, there are no available subscriptions

	IF found IS NULL
	THEN
	    RETURN 0;
	END IF;

	-- null max members?  in that case, pass it on; NULL means infinite
	IF max_members_val IS NULL
	THEN
	    RETURN NULL;
	END IF;

	-- otherwise, return the delta
	RETURN max_members_val - current_members_val;
    END available_family_subscriptions;

    PROCEDURE update_family_counts(channel_family_id_in IN NUMBER, org_id_in IN NUMBER)
    IS
    BEGIN
		update rhnPrivateChannelFamily
		set current_members = (
				select	count(sc.server_id)
				from	rhnServerChannel sc,
						rhnChannelFamilyMembers cfm,
						rhnServer s
				where	s.org_id = org_id_in
					and s.id = sc.server_id
					and cfm.channel_family_id = channel_family_id_in
					and cfm.channel_id = sc.channel_id
				)
			where org_id = org_id_in
				and channel_family_id = channel_family_id_in;
    END update_family_counts;

    FUNCTION available_chan_subscriptions(channel_id_in IN NUMBER, org_id_in IN NUMBER)
    RETURN NUMBER
    IS
	channel_family_id_val NUMBER;
    BEGIN
	SELECT channel_family_id INTO channel_family_id_val
	  FROM rhnChannelFamilyMembers
	 WHERE channel_id = channel_id_in;

	 RETURN rhn_channel.available_family_subscriptions(channel_family_id_val, org_id_in);
    END available_chan_subscriptions;

    -- this sets max_members for a family
    procedure entitle_customer(customer_id_in in number, channel_family_id_in in number, quantity_in in number)
    is
		cursor permissions is
			select	1
			from	rhnPrivateChannelFamily pcf
			where	pcf.org_id = customer_id_in
				and	pcf.channel_family_id = channel_family_id_in;
    begin
		for perm in permissions loop
			set_family_maxmembers(
				customer_id_in,
				channel_family_id_in,
				quantity_in
			);
			rhn_channel.update_family_counts(
				channel_family_id_in,
				customer_id_in
			);
			return;
		end loop;

		insert into rhnPrivateChannelFamily pcf (
				channel_family_id, org_id, max_members, current_members
			) values (
				channel_family_id_in, customer_id_in, quantity_in, 0
			);
    end;

    procedure set_family_maxmembers(customer_id_in in number, channel_family_id_in in number, quantity_in in number)
    is
	cursor servers is
	    select  server_id from (
		select	rownum row_number, server_id, modified from (
		    select  rcfs.server_id,
			    rcfs.modified
		    from    rhnChannelFamilyServers rcfs
		    where   rcfs.customer_id = customer_id_in
			    and rcfs.channel_family_id = channel_family_id_in
		    order by modified
		)
		where rownum > quantity_in
	    );
    begin
	-- prune subscribed servers
	for server in servers
	loop
	    rhn_channel.unsubscribe_server_from_family(server.server_id, channel_family_id_in);
	end loop;
	update	rhnPrivateChannelFamily pcf
	set	pcf.max_members = quantity_in
	where	pcf.org_id = customer_id_in
		and pcf.channel_family_id = channel_family_id_in;
    end;

    procedure unsubscribe_server_from_family(server_id_in in number, channel_family_id_in in number)
    is
    begin
	delete
	from	rhnServerChannel rsc
	where	rsc.server_id = server_id_in
		and channel_id in (
			select	rcfm.channel_id
			from	rhnChannelFamilyMembers rcfm
			where	rcfm.channel_family_id = channel_family_id_in);
    end;

    function get_org_id(channel_id_in in number)
    return number
    is
	org_id_out number;
    begin
	select org_id into org_id_out
	  from rhnChannel
	 where id = channel_id_in;

	return org_id_out;
    end get_org_id;

    function get_cfam_org_access(cfam_id_in in number, org_id_in in number)
    return number
    is
	cursor	families is
			select	1
			from	rhnOrgChannelFamilyPermissions cfp
			where	cfp.org_id = org_id_in;
    begin
		-- the idea: if we get past this query, the user has the role, else catch the exception and return 0
		for family in families loop
		return 1;
		end loop;
		return 0;
    end;

    function get_org_access(channel_id_in in number, org_id_in in number)
    return number
    is
	throwaway number;
    begin
	-- the idea: if we get past this query, the user has the role, else catch the exception and return 0
	select distinct 1 into throwaway
	  from rhnChannelFamilyMembers CFM,
	       rhnOrgChannelFamilyPermissions CFP
	 where cfp.org_id = org_id_in
	   and CFM.channel_family_id = CFP.channel_family_id
	   and CFM.channel_id = channel_id_in;

	return 1;
    exception
	when no_data_found
	    then
	    return 0;
    end;

    -- check if a user has a given role, or if such a role is inferrable
    function user_role_check_debug(channel_id_in in number, user_id_in in number, role_in in varchar2, reason_out out varchar2)
    return number
    is
	org_id number;
    begin
	org_id := rhn_user.get_org_id(user_id_in);

	if role_in = 'manage' and NVL(rhn_channel.get_org_id(channel_id_in), -1) <> org_id
	then
	    reason_out := 'channel_not_owned';
	    return 0;
	end if;

	if role_in = 'subscribe' and rhn_channel.get_org_access(channel_id_in, org_id) = 0
	then
	    reason_out := 'channel_not_available';
	    return 0;
	end if;

	-- channel admins have all roles
	if rhn_user.check_role_implied(user_id_in, 'channel_admin') = 1
	then
	    reason_out := 'channel_admin';
	    return 1;
	end if;

	-- the subscribe permission is inferred UNLESS the not_globally_subscribable flag is set
	if role_in = 'subscribe'
	then
	    if rhn_channel.org_channel_setting(channel_id_in, org_id, 'not_globally_subscribable') = 0
	    then
		reason_out := 'globally_subscribable';
		return 1;
	    end if;
	end if;

	-- all other roles (manage right now) are explicitly granted
	reason_out := 'direct_permission';
	return rhn_channel.direct_user_role_check(channel_id_in, user_id_in, role_in);
    end;

    -- same as above, but with no OUT param; useful in views, etc
    function user_role_check(channel_id_in in number, user_id_in in number, role_in in varchar2)
    return number
    is
	throwaway varchar2(256);
    begin
	return rhn_channel.user_role_check_debug(channel_id_in, user_id_in, role_in, throwaway);
    end;

    -- same as above, but returns 1 if user_id_in is null
    -- This is useful in queries where user_id is not specified
    function loose_user_role_check(channel_id_in in number, user_id_in in number, role_in in varchar2)
    return number
    is
    begin
        if user_id_in is null then
            return 1;
        end if;
        return user_role_check(channel_id_in, user_id_in, role_in);
    end loose_user_role_check;

    -- directly checks the table, no inferred permissions
    function direct_user_role_check(channel_id_in in number, user_id_in in number, role_in in varchar2)
    return number
    is
	throwaway number;
    begin
	-- the idea: if we get past this query, the user has the role, else catch the exception and return 0
	select 1 into throwaway
	  from rhnChannelPermissionRole CPR,
	       rhnChannelPermission CP
	 where CP.user_id = user_id_in
	   and CP.channel_id = channel_id_in
	   and CPR.label = role_in
	   and CP.role_id = CPR.id;

	return 1;
    exception
	when no_data_found
	    then
	    return 0;
    end;

    -- check if an org has a certain setting
    function org_channel_setting(channel_id_in in number, org_id_in in number, setting_in in varchar2)
    return number
    is
	throwaway number;
    begin
	-- the idea: if we get past this query, the org has the setting, else catch the exception and return 0
	select 1 into throwaway
	  from rhnOrgChannelSettingsType OCST,
	       rhnOrgChannelSettings OCS
	 where OCS.org_id = org_id_in
	   and OCS.channel_id = channel_id_in
	   and OCST.label = setting_in
	   and OCS.setting_id = OCST.id;

	return 1;
    exception
	when no_data_found
	    then
	    return 0;
    end;

    FUNCTION channel_priority(channel_id_in IN number)
    RETURN number
    IS
        cursor channels is
                select  2 priority
                from    rhnChannel
                where   id = channel_id_in
                        and org_id is not null
                union all
                select  4 priority
                from    rhnChannel
                where   id = channel_id_in
                        and end_of_life is not null
                union all
                select  1 priority
                from    rhnChannel
                where   id = channel_id_in
                        and name like '%Enterprise%'
                union all
                select  3 priority
                from    dual;
    BEGIN
        for channel in channels loop
                return channel.priority;
        end loop;
    end channel_priority;

    -- right now this only does the accounting changes; the cascade
    -- actually does the rhnServerChannel delete.
    procedure delete_server_channels(server_id_in in number)
    is
    begin
	update	rhnPrivateChannelFamily
	set	current_members = current_members -1
	where	org_id in (
			select	org_id
			from	rhnServer
			where	id = server_id_in
		)
		and channel_family_id in (
			select	rcfm.channel_family_id
			from	rhnChannelFamilyMembers rcfm,
				rhnServerChannel rsc
			where	rsc.server_id = server_id_in
				and rsc.channel_id = rcfm.channel_id
		);
    end;

	-- this could certainly be optimized to do updates if needs be
	procedure refresh_newest_package(channel_id_in in number, caller_in in varchar2 := '(unknown)')
	is
	begin
		delete from rhnChannelNewestPackage where channel_id = channel_id_in;
		insert into rhnChannelNewestPackage
			( channel_id, name_id, evr_id, package_id, package_arch_id )
			(	select	channel_id,
						name_id, evr_id,
						package_id, package_arch_id
				from	rhnChannelNewestPackageView
				where	channel_id = channel_id_in
			);
                insert into rhnChannelNewestPackageAudit (channel_id, caller)
                    values (channel_id_in, caller_in);
                update rhnChannel
                    set last_modified = greatest(sysdate, last_modified + 1/86400)
                    where id = channel_id_in;
	end;

END rhn_channel;
/
SHOW ERRORS

create or replace
package body rhn_entitlements
is
	function entitlement_grants_service (
	    entitlement_in in varchar2,
	    service_level_in in varchar2
	) return number	is
	begin
	    if service_level_in = 'provisioning' then

		if entitlement_in = 'provisioning_entitled' then
		    return 1;
		else
		    return 0;
		end if;
	    elsif service_level_in = 'management' then

		if entitlement_in = 'provisioning_entitled' then
		    return 1;
		elsif entitlement_in = 'enterprise_entitled' then
		    return 1;
		elsif entitlement_in = 'nonlinux_entitled' then
		    return 1;
		else
		    return 0;
		end if;

	    elsif service_level_in = 'updates' then
		return 1;

	    else
		return 0;
	    end if;

	end entitlement_grants_service;


	function lookup_entitlement_group (
		org_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	) return number is
		cursor server_groups is
			select	sg.id				server_group_id
			from	rhnServerGroup		sg,
					rhnServerGroupType	sgt
			where	sgt.label = type_label_in
				and sgt.id = sg.group_type
				and sg.org_id = org_id_in;
	begin
		for sg in server_groups loop
			return sg.server_group_id;
		end loop;
		return rhn_entitlements.create_entitlement_group(
				org_id_in,
				type_label_in
			);
	end lookup_entitlement_group;

	function create_entitlement_group (
		org_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	) return number is
		sg_id_val number;
	begin
		select	rhn_server_group_id_seq.nextval
		into	sg_id_val
		from	dual;

		insert into rhnServerGroup (
				id, name, description, max_members, current_members,
				group_type, org_id
			) (
				select	sg_id_val, sgt.label, sgt.label,
						0, 0, sgt.id, org_id_in
				from	rhnServerGroupType sgt
				where	sgt.label = type_label_in
			);

		return sg_id_val;
	end create_entitlement_group;

	function get_server_entitlement (
		server_id_in in number
	) return varchar2 is
		cursor server_groups is
			select	sgt.label
			from	rhnServerGroupType		sgt,
					rhnServerGroup			sg,
					rhnServerGroupMembers	sgm
			where	1=1
				and sgm.server_id = server_id_in
				and sg.id = sgm.server_group_id
				and sgt.id = sg.group_type
				and sgt.label in ('sw_mgr_entitled','enterprise_entitled',
					'provisioning_entitled', 'nonlinux_entitled');
	begin
		for sg in server_groups loop
			return sg.label;
		end loop;
		return 'none';
	end get_server_entitlement;

	procedure unentitle_server (
		server_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	) is
		group_id number;
	begin
		select	sg.id
		into	group_id
		from	rhnServerGroupType sgt,
				rhnServerGroup sg,
				rhnServerGroupMembers sgm,
				rhnServer s
		where	s.id = server_id_in
			and s.id = sgm.server_id
			and sgm.server_group_id = sg.id
			and sg.org_id = s.org_id
			and sgt.label = type_label_in
			and sgt.id = sg.group_type;

		rhn_server.delete_from_servergroup(server_id_in, group_id);
		exception
		when no_data_found then
		    null;
	end unentitle_server;

	-- right now, this is racy.  Don't do it twice at once
	-- for the same org.  You've been warned...
	procedure upgrade_server (
		server_id_in in number
	) is
		old_sgid number;
		new_sgid number;
		new_sg_max number;
		new_sg_used number;
	begin
		begin
			select	sg0.id, sg1.id,
					sg1.max_members, sg1.current_members
			into	old_sgid, new_sgid,
					new_sg_max, new_sg_used
			from	rhnServerGroup sg1,
					rhnServerGroupType sgt1,
					rhnServerGroupMembers sgm,
					rhnServerGroup sg0,
					rhnServerGroupType sgt0,
					rhnServer s
			where	s.id = server_id_in
				and s.org_id = sg0.org_id
				and sgt0.label = 'enterprise_entitled'
				and sgt0.id = sg0.group_type
				and s.id = sgm.server_id
				and sgm.server_group_id = sg0.id
				and s.org_id = sg1.org_id
				and sgt1.label = 'provisioning_entitled'
				and sgt1.id = sg1.group_type;
		exception
			when no_data_found then
				rhn_exception.raise_exception('invalid_upgrade');
		end;
		-- it could still happen that you run out after we check this.
		-- that's what the comment above is all about...
		if new_sg_used >= new_sg_max then
			rhn_exception.raise_exception('servergroup_max_members');
		end if;
		rhn_server.delete_from_servergroup(server_id_in, old_sgid);
		rhn_server.insert_into_servergroup(server_id_in, new_sgid);
	end upgrade_server;

	procedure entitle_server (
		server_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	) is
		cursor servergroups is
			select	sg.id id,
					s.server_arch_id server_arch_id,
					sgt.id server_group_type
			from	rhnServerGroupType sgt,
					rhnServerGroup sg,
					rhnServer s
			where	s.id = server_id_in
				and s.org_id = sg.org_id
				and sgt.label = type_label_in
				and sg.group_type = sgt.id;
		cursor sg_arches(sgt_id_in in number, sa_id_in in number) is
			select	1
			from	rhnServerServerGroupArchCompat
			where	server_group_type = sgt_id_in
				and server_arch_id = sa_id_in;
		previous_ent rhnServerGroupType.label%TYPE;
	begin
		previous_ent := rhn_entitlements.get_server_entitlement(server_id_in);
		if previous_ent != 'none' then
			rhn_exception.raise_exception(
								'no_server_multiple_swmgr_entitlements');
		end if;

		for sg in servergroups loop
			for a in sg_arches(sg.server_group_type, sg.server_arch_id) loop
				-- if the max_members is too low, this'll raise
				-- servergroup_max_members
				rhn_server.insert_into_servergroup(server_id_in, sg.id);
				return;
			end loop;
			-- we only get here if we can't find any compatible
			-- server_arch+server_group_type combination
			rhn_exception.raise_exception('mismatching_entitlement');
		end loop;
		-- we only get here if there's _no_ server group for that type;
		-- that's the same as max_members=0
		rhn_exception.raise_exception('servergroup_max_members');
	end;

	procedure set_customer_enterprise (
		customer_id in number
	) is
		entitlement_type_id number;
		status number;
	begin
		select	roet.id, roe.org_id
		into	entitlement_type_id, status
		from	rhnOrgEntitlementType	roet,
				rhnOrgEntitlements		roe
		where	1=1
			and roet.label = 'sw_mgr_enterprise'
			and roet.id = roe.entitlement_id(+)
			and roe.org_id(+) = customer_id;

		if status is null then
			insert into rhnOrgEntitlements (
					org_id, entitlement_id
				) values (
					customer_id, entitlement_type_id
			);
		end if;

		-- XXX is org_applicant even right to create anymore?
		update		rhnUserGroup
			set		max_members = null
			where	1=1
				and org_id = customer_id
				and group_type in (
					select	id
					from	rhnUserGroupType
					where	label in ('org_admin', 'org_applicant')
				);
	end set_customer_enterprise;

	procedure create_config_admin (
		customer_id_in in number
	) is
		cursor config_admin_groups is
			select	1
			from	rhnUserGroup ug,
				rhnUserGroupType ugt
			where	ugt.label = 'config_admin'
				and ug.org_id = customer_id_in
				and ugt.id = ug.group_type;
	begin
		for config_admin_group in config_admin_groups loop
			return;
		end loop;

		insert into rhnUserGroup (
			id, name,
			description,
			max_members, group_type, org_id
		) (
			select	rhn_user_group_id_seq.nextval,
					'Configuration Administrator',
					'Configuration Administrator for Org ' || ' (1)',
					NULL, id, 1
			from	rhnUserGroupType
			where	label = 'config_admin'
		);
	end create_config_admin;

	procedure set_customer_provisioning (
		customer_id_in in number
	) is
		cursor entitlements is
			select	roet.id entitlement_type_id,
					roe.org_id status
			from	rhnOrgEntitlements		roe,
					rhnOrgEntitlementType	roet
			where	1=1
				and roet.label in ('rhn_provisioning','sw_mgr_enterprise')
				and roet.id = roe.entitlement_id(+)
				and roe.org_id(+) = customer_id_in;
	begin
		for e in entitlements loop
			if e.status is null then
				insert into rhnOrgEntitlements (
						org_id, entitlement_id
					) values (
						customer_id_in, e.entitlement_type_id
					);
			end if;
		end loop;
		if is_satellite() = 1 then
			rhn_entitlements.create_config_admin(customer_id_in);
		end if;
	end set_customer_provisioning;

	procedure set_customer_nonlinux (
		customer_id_in in number
	) is
		cursor entitlements is
			select	roet.id entitlement_type_id,
					roe.org_id status
			from	rhnOrgEntitlements		roe,
					rhnOrgEntitlementType	roet
			where	1=1
				and roet.label in ('rhn_nonlinux')
				and roet.id = roe.entitlement_id(+)
				and roe.org_id(+) = customer_id_in;
	begin
		for e in entitlements loop
			if e.status is null then
				insert into rhnOrgEntitlements (
						org_id, entitlement_id
					) values (
						customer_id_in, e.entitlement_type_id
					);
			end if;
		end loop;
		if is_satellite() = 1 then
			rhn_entitlements.create_config_admin(customer_id_in);
		end if;
	end set_customer_nonlinux;

	procedure unset_customer_enterprise (
		customer_id in number
	) is
	begin
		delete	from	rhnOrgEntitlements
				where	1=1
					and org_id = customer_id
					and entitlement_id in (
						select	id
						from	rhnOrgEntitlementType
						where	label = 'sw_mgr_enterprise'
					);

		-- XXX there's no way this is right.  It probably should be pruning
		-- these groups to 0 and *removing* them (and anybody in
		-- org_applicant?).  But then, maybe not.  ISTR something about
		-- never becomming un-enterprise
		update		rhnUserGroup
			set		max_members = null
			where	1=1
				and org_id = customer_id
				and group_type in (
					select	id
					from	rhnUserGroupType
					where	label in ('org_admin', 'org_applicant')
				);
	end unset_customer_enterprise;

	procedure unset_customer_provisioning (
		customer_id_in in number
	) is
		usergroup number;
	begin
		delete from rhnOrgEntitlements
			where	1=1
				and org_id = customer_id_in
				and entitlement_id in (
					select	id
					from	rhnOrgEntitlementType
					where	label = 'rhn_provisioning'
				);
	end;

	procedure unset_customer_nonlinux (
		customer_id_in in number
	) is
		usergroup number;
	begin
		delete from rhnOrgEntitlements
			where	1=1
				and org_id = customer_id_in
				and entitlement_id in (
					select	id
					from	rhnOrgEntitlementType
					where	label = 'rhn_nonlinux'
				);
	end;

	procedure prune_group (
		group_id_in in number,
		type_in in char,
		quantity_in in number
	) is
		cursor usergroups is
			select	user_id, user_group_id, ugt.label
			from	rhnUserGroupType	ugt,
					rhnUserGroup		ug,
					rhnUserGroupMembers	ugm
			where	1=1
				and ugm.user_group_id = group_id_in
				and ugm.user_id in (
					select	user_id
					from	(
						select	rownum row_number,
								user_id,
								time
						from	(
							select	user_id,
									modified time
							from	rhnUserGroupMembers
							where	user_group_id = group_id_in
							order by time asc
						)
					)
					where	row_number > quantity_in
				)
				and ugm.user_group_id = ug.id
				and ug.group_type = ugt.id;
		cursor servergroups is
			select	server_id, server_group_id, sgt.label
			from	rhnServerGroupType		sgt,
					rhnServerGroup			sg,
					rhnServerGroupMembers	sgm
			where	1=1
				and sgm.server_group_id = group_id_in
				and sgm.server_id in (
					select	server_id
					from	(
						select	rownum row_number,
								server_id,
								time
						from	(
							select	server_id,
									modified time
							from	rhnServerGroupMembers
							where	server_group_id = group_id_in
							order by time asc
						)
					)
					where	row_number > quantity_in
				)
				and sgm.server_group_id = sg.id
				and sg.group_type = sgt.id;
	begin
		if type_in = 'U' then
			update		rhnUserGroup
				set		max_members = quantity_in
				where	id = group_id_in;

			for ug in usergroups loop
				-- rhnUserGroup.max_members gets fixed in a trigger, no
				-- need to do that here
				delete
					from	rhnUserGroupMembers
					where	user_group_id = ug.user_group_id
						and user_id = ug.user_id;
			end loop;
		elsif type_in = 'S' then
			update		rhnServerGroup
				set		max_members = quantity_in
				where	id = group_id_in;

			for sg in servergroups loop
				unentitle_server(sg.server_id, sg.label);
				rhn_channel.clear_subscriptions(sg.server_id);
			end loop;
		end if;
	end prune_group;

	procedure set_group_count (
		customer_id_in in number,
		type_in in char,
		group_type_in in number,
		quantity_in in number
	) is
		group_id number;
		quantity number;
	begin
		quantity := quantity_in;
		if quantity is not null and quantity < 0 then
			quantity := 0;
		end if;

		if type_in = 'U' then
			select	rug.id
			into	group_id
			from	rhnUserGroup rug
			where	1=1
				and rug.org_id = customer_id_in
				and rug.group_type = group_type_in;
		elsif type_in = 'S' then
			select	rsg.id
			into	group_id
			from	rhnServerGroup rsg
			where	1=1
				and rsg.org_id = customer_id_in
				and rsg.group_type = group_type_in;
		end if;

		rhn_entitlements.prune_group(
			group_id,
			type_in,
			quantity
		);
	exception
		when no_data_found then
			if type_in = 'U' then
				insert into rhnUserGroup (
						id, name, description, max_members, current_members,
						group_type, org_id, created, modified
					) (
						select	rhn_user_group_id_seq.nextval, name, name,
								quantity, 0, id, customer_id_in,
								sysdate, sysdate
						from	rhnUserGroupType
						where	id = group_type_in
				);
			elsif type_in = 'S' then
				insert into rhnServerGroup (
						id, name, description, max_members, current_members,
						group_type, org_id, created, modified
					) (
						select	rhn_server_group_id_seq.nextval, name, name,
								quantity, 0, id, customer_id_in,
								sysdate, sysdate
						from	rhnServerGroupType
						where	id = group_type_in
				);
			end if;
	end set_group_count;

	procedure prune_family (
		customer_id_in in number,
		channel_family_id_in in number,
		quantity_in in number
	) is
		cursor serverchannels is
			select	sc.server_id,
					sc.channel_id
			from	rhnServerChannel sc,
					rhnChannelFamilyMembers cfm
			where	1=1
				and cfm.channel_family_id = channel_family_id_in
				and cfm.channel_id = sc.channel_id
				and server_id in (
					select	server_id
					from	(
						select	server_id,
								time,
								rownum row_number
						from	(
							select	rs.id					server_id,
									rcfm.modified			time
							from	rhnServer				rs,
									rhnServerChannel		rsc,
									rhnChannelFamilyMembers	rcfm
							where	1=1
								and rs.org_id = customer_id_in
								and rs.id = rsc.server_id
								and rsc.channel_id = rcfm.channel_id
								and rcfm.channel_family_id =
									channel_family_id_in
							order by time asc
						)
					)
					where row_number > quantity_in
				);
	begin
		-- if we get a null customer_id, this is completely bogus.
		if customer_id_in is null then
			return;
		end if;

		update		rhnPrivateChannelFamily
			set		max_members = quantity_in
			where	1=1
				and org_id = customer_id_in
				and channel_family_id = channel_family_id_in;

		for sc in serverchannels loop
			rhn_channel.unsubscribe_server(sc.server_id, sc.channel_id, 1, 1);
		end loop;
	end prune_family;

	procedure set_family_count (
		customer_id_in in number,
		channel_family_id_in in number,
		quantity_in in number
	) is
		cursor privperms is
			select	1
			from	rhnPrivateChannelFamily
			where	org_id = customer_id_in
				and channel_family_id = channel_family_id_in;
		cursor pubperms is
			select	o.id org_id
			from	web_customer o,
					rhnPublicChannelFamily pcf
			where	pcf.channel_family_id = channel_family_id_in;
		quantity number;
		done number := 0;
	begin
		quantity := quantity_in;
		if quantity is not null and quantity < 0 then
			quantity := 0;
		end if;

		if customer_id_in is not null then
			for perm in privperms loop
				rhn_entitlements.prune_family(
					customer_id_in,
					channel_family_id_in,
					quantity
				);
				update rhnPrivateChannelFamily
					set max_members = quantity
					where org_id = customer_id_in
						and channel_family_id = channel_family_id_in;
				return;
			end loop;

			insert into rhnPrivateChannelFamily (
					channel_family_id, org_id, max_members, current_members
				) values (
					channel_family_id_in, customer_id_in, quantity, 0
				);
			return;
		end if;

		for perm in pubperms loop
			if quantity = 0 then
				rhn_entitlements.prune_family(
					perm.org_id,
					channel_family_id_in,
					quantity
				);
				if done = 0 then
					delete from rhnPublicChannelFamily
						where channel_family_id = channel_family_id_in;
				end if;
			end if;
			done := 1;
		end loop;
		-- if done's not 1, then we don't have any entitlements
		if done != 1 then
			insert into rhnPublicChannelFamily (
					channel_family_id
				) values (
					channel_family_id_in
				);
		end if;
	end set_family_count;

	-- this expects quantity_in to be the number of available slots, not the
	-- max_members of the server group.  If you give it too many, it'll fail
	-- and raise servergroup_max_members.
	-- We should NEVER run this unless we're SURE that we won't
	-- be violating the max.
	procedure entitle_last_modified_servers (
		customer_id_in in number,
		type_label_in in varchar2,
		quantity_in in number
	) is
		-- find the servers that aren't currently in slots
		cursor servers(cid_in in number, quant_in in number) is
			select	server_id
			from	(
						select	rownum row_number,
								server_id
						from	(
									select	rs.id server_iD
									from	rhnServer rs
									where	1=1
										and rs.org_id = cid_in
										and not exists (
											select	1
											from	rhnServerGroup sg,
													rhnServerGroupMembers rsgm
											where	rsgm.server_id = rs.id
												and rsgm.server_group_id = sg.id
												and sg.group_type is not null
										)
									order by modified desc
								)
					)
			where	row_number <= quant_in;
	begin
		for server in servers(customer_id_in, quantity_in) loop
			rhn_entitlements.entitle_server(server.server_id, type_label_in);
		end loop;
	end entitle_last_modified_servers;

	procedure get_available_slots (
		customer_id_in in number,
		type_label_in in varchar2,
		server_group_id_out out number,
		available_out out number,
		upgrade_out out number
	) is
		mgmt_slots_unused number;
		mgmt_slots_used number;
		prov_slots_unused number;
		prov_slots_used number;
		swmgr_slots_unused number;
		sgid number;
	begin
		-- if it's the simple case, do it and get out
		if type_label_in in ('sw_mgr_entitled','nonlinux_entitled') then
			begin
				select	max_members - current_members, sg.id
				into	swmgr_slots_unused, sgid
				from	rhnServerGroup		sg,
						rhnServerGroupType	sgt
				where	sgt.label = type_label_in
					and sg.org_id = customer_id_in
					and sg.group_type = sgt.id;

				available_out := swmgr_slots_unused;
				upgrade_out := 0;
				server_group_id_out := sgid;
			exception
				when no_data_found then
					available_out := 0;
					if type_label_in = 'sw_mgr_entitled' then
						available_out := 1;
					end if;
					upgrade_out := 0;
					server_group_id_out := null;
			end;
			return;
		end if;

		begin
			select	sg.current_members,
					sg.max_members - sg.current_members,
					sg.id
			into	mgmt_slots_used,
					mgmt_slots_unused,
					sgid
			from	rhnServerGroup		sg,
					rhnServerGroupType	sgt
			where	sgt.label = 'enterprise_entitled'
				and sg.org_id = customer_id_in
				and sg.group_type = sgt.id;
		exception
			when no_data_found then
				-- if there's no enterprise_entitled group, then
				-- this user doesn't have mgmt or prov at all,
				-- so bail out now.
				available_out := 0;
				upgrade_out := 0;
				server_group_id_out := null;
				return;
		end;

		-- we list all mgmt slots as things you can upgrade to
		-- from basic
		if type_label_in = 'enterprise_entitled' then
			available_out := mgmt_slots_unused;
			upgrade_out := 0;
			server_group_id_out := sgid;
			return;
		end if;

		-- the only thing left is provisioning
		begin
			select	sg.current_members,
					sg.max_members - sg.current_members,
					sg.id
			into	prov_slots_used,
					prov_slots_unused,
					sgid
			from	rhnServerGroup		sg,
					rhnServerGroupType	sgt
			where	sgt.label = 'provisioning_entitled'
				and sg.org_id = customer_id_in
				and sg.group_type = sgt.id;
		exception
			when no_data_found then
				available_out := 0;
				upgrade_out := 0;
				server_group_id_out := null;
				return;
		end;

		-- An example to illustrate what I'm doing to compute upgradable slots
		-- 1) The user buys 3 provisioning entitlements.  This means:
		--      enterprise_entitled max_members = 3, current_members = 0    (prov_slots_unused = 3)
		--      provisioning_entitled max_members = 3, current_members = 0  (prov_slots_unsued = 3)
		--    0 upgrade, 3 available
		-- 2) The user subscribes a system for management.  This means:
		--      enterprise_entitled max_members = 3, current_members = 1    (mgmt_slots_unused = 2)
		--      provisioning_entitled max_members = 3, current_members = 0  (prov_slots_unused = 3)
		--    1 upgrade, 2 available
		-- 3) The user subscribes a system for provisioning.  This means:
		--      enterprise_entitled max_members = 2, current_members = 1    (mgmt_slots_unused = 1)
		--      provisioning_entitled max_members = 3, current_members = 1  (prov_slots_unused = 2)
		--    1 upgrade, 1 available
		-- 4) The user subscribes another provisioning.  I.e.:
		--      enterprise_entitled max_members = 1, current_members = 1    (mgmt_slots_unused = 0)
		--      provisioning_entitled max_members = 3, current_members = 2  (prov_slots_unused = 1)
		--    1 upgrade, 0 available
		-- 5) the user upgrades 1 mgmt to prov.  Here:
		--    1) unsubscribe from mgmt
		--      enterprise_entitled max_members = 1, current_members = 0    (mgmt_slots_unused = 1)
		--      provisioning_entitled max_members = 3, current_members = 2  (prov_slots_unused = 1)
		--    0 upgrade, 1 available
		--    2) subscribe to prov
		--      enterprise_entitled max_members = 0, current_members = 0    (mgmt_slots_unused = 0)
		--      provisioning_entitled max_members = 3, current_members = 3  (prov_slots_unused = 0)
		--    that'll result in 0 upgrade, 0 available
		-- 6) user buys 1 mgmt:
		--      enterprise_entitled max_members = 1, current_members = 0    (mgmt_slots_unused = 1)
		--      provisioning_entitled max_members = 3, current_members = 3  (prov_slots_unused = 0)
		--    -1 on upgrade, 1 on available, BORK, should be 0, 0 (special cased with p-m<0)
		-- 7) user registers a management box
		--      enterprise_entitled max_members = 1, current_members = 1    (mgmt_slots_unused = 0)
		--      provisioning_entitled max_members = 3, current_members = 3  (prov_slots_unused = 0)
		--    0, 0, which is right.
		-- 8) user deletes that management box
		--      enterprise_entitled max_members = 1, current_members = 0    (mgmt_slots_unused = 1)
		--      provisioning_entitled max_members = 3, current_members = 3  (prov_slots_unused = 0)
		--    -1 on upgrade, 1 on available, BORK, should be 0, 0 (special cased with p-m<0)
		-- 9) user buys a provisioning slot
		--      enterprise_entitled max_members = 2, current_members = 0    (mgmt_slots_unused = 2)
		--      provisioning_entitled max_members = 4, current_members = 3  (prov_slots_unused = 1)
		--    -1 upgrade, 0 available, BORK.  special case makes it 1 available, 0 upgrade
		-- 10) user registers a mgmt box
		--      enterprise_entitled max_members = 2, current_members = 1    (mgmt_slots_unused = 1)
		--      provisioning_entitled max_members = 4, current_members = 3  (prov_slots_unused = 1)
		--    0 upgrade, 1 available
		if prov_slots_unused - mgmt_slots_unused < 0 then
			-- swmgr_slots_unused is tmp here
			available_out := prov_slots_unused;
			upgrade_out := 0;
		elsif prov_slots_unused > 0 then
			-- if there's one of each, we list it as available
			-- if there's only a prov slot, then it's upgradable.
			upgrade_out := prov_slots_unused - mgmt_slots_unused;
			available_out := prov_slots_unused - (prov_slots_unused - mgmt_slots_unused);
		else
			upgrade_out := 0;
			available_out := 0;
		end if;
		server_group_id_out := sgid;
		return;
	end get_available_slots;

	procedure prune_everything (
		customer_id_in in number
	) is
		cursor everything is
			-- all our server groups
			select	sg.id					id,
					'S'						type,
					sg.max_members			quantity
			from	rhnServerGroup			sg
			where	sg.org_id = customer_id_in
			union
			-- all our user groups
			select	ug.id					id,
					'U'						type,
					ug.max_members 			quantity
			from	rhnUserGroup			ug
			where	ug.org_id = customer_id_in
			union (
			-- all the channel families we have perms to
			select	cfp.channel_family_id	id,
					'C'						type,
					cfp.max_members			quantity
			from	rhnOrgChannelFamilyPermissions cfp
			where	cfp.org_id = customer_id_in
			union
			-- plus all the ones we're using that we have no perms for
			select	cfm.channel_family_id	id,
					'C'						type,
					0						quantity
			from	rhnChannelFamily		cf,
					rhnChannelFamilyMembers	cfm,
					rhnServerChannel		sc,
					rhnServer				s
			where	s.org_id = customer_id_in
				and s.id = sc.server_id
				and sc.channel_id = cfm.channel_id
				and cfm.channel_family_id = cf.id
				and cf.org_id is not null
				and cf.org_id != customer_id_in
				and not exists (
					select	1
					from	rhnOrgChannelFamilyPermissions cfp
					where	cfp.org_id = customer_id_in
						and cfp.channel_family_id = cfm.channel_family_id
					)
			);
	begin
		for one in everything loop
			if one.type in ('U','S') then
				prune_group(one.id, one.type, one.quantity);
			else
				prune_family(customer_id_in, one.id, one.quantity);
			end if;
		end loop;
	end prune_everything;

	procedure subscribe_newest_servers (
		customer_id_in in number
	) is
		-- find servers without base channels
		cursor servers(cid_in in number) is
			select	s.id
			from	rhnServer			s
			where	1=1
				and s.org_id = cid_in
				and not exists (
						select 1
						from	rhnChannel			c,
								rhnServerChannel	sc
						where	sc.server_id = s.id
							and sc.channel_id = c.id
							and c.parent_channel is null
					)
			order by s.modified desc;
		channel_id number;
	begin
		for server in servers(customer_id_in) loop
			channel_id := rhn_channel.guess_server_base(server.id);
			if channel_id is not null then
				begin
					rhn_channel.subscribe_server(server.id, channel_id);
					commit;
				-- exception is really channel_family_no_subscriptions
				exception
					when others then
						null;
				end;
			end if;
		end loop;
	end subscribe_newest_servers;
end rhn_entitlements;
/
show errors

-- serveractionverify.2.rhnuser.sql
insert into rhnActionType values (33, 'packages.verify', 'Verify deployed packages','N','N');
INSERT
  INTO rhnArchTypeActions (arch_type_id, action_style, action_type_id)
       (SELECT ArchT.id, 'verify', ActionT.id
          FROM rhnArchType ArchT, rhnActionType ActionT
         WHERE ArchT.label = 'rpm'
           AND ActionT.label = 'packages.verify');
commit;

-- server-uuid.2.rhnuser.sql
insert into rhnActionType values (34, 'rhn_applet.use_satellite', 'Allows for rhn-applet use with an RHN Satellite','N','N');
commit;


-- add-kickstartsessionstate-data.113914.1.rhnuser.sql
insert
  into rhnKickstartSessionState
       (id, name, label, description)
values (rhn_ks_session_state_id_seq.nextval, 'Configuration Deployment',
        'configuration_deploy', 'Configuration files are being deployed.'
       );
commit;

-- rhn_server needs replacing from 330.3.rhn.sql


create or replace
package rhn_server
is

    -- i.e., "can this box do management stuff?" and yes if provisioning box
    function system_service_level(
	server_id_in in number,
	service_level_in in varchar2
    ) return number;

    function can_change_base_channel(
	server_id_in in number
    ) return number;

    procedure set_custom_value(
	server_id_in in number,
	user_id_in in number,
	key_label_in varchar2,
	value_in in varchar2
    );

    procedure bulk_set_custom_value(
	key_label_in in varchar2,
	value_in in varchar2,
	set_label_in in varchar2,
	set_uid_in in number
    );

    procedure snapshot_server(
	server_id_in in number,
	reason_in in varchar2
    );

    procedure bulk_snapshot(
	reason_in in varchar2,
	set_label_in in varchar2,
	set_uid_in in number
    );

    procedure tag_delete(
	server_id_in in number,
	tag_id_in in number
    );

    procedure tag_snapshot(
	snapshot_id_in in number,
	org_id_in in number,
	tagname_in in varchar2
    );

    procedure bulk_snapshot_tag(
	org_id_in in number,
	tagname_in varchar2,
	set_label_in in varchar2,
	set_uid_in in number
    );

    procedure remove_action(
	server_id_in in number,
	action_id_in in number
    );

    function check_user_access(server_id_in in number, user_id_in in number) return number;

    procedure insert_into_servergroup (
	server_id_in in number,
	server_group_id_in in number
    );

    function insert_into_servergroup_maybe (
	server_id_in in number,
	server_group_id_in in number
    ) return number;

	procedure insert_set_into_servergroup (
	server_group_id_in in number,
	user_id_in in number,
	set_label_in in varchar2
	);

    procedure delete_from_servergroup (
	server_id_in in number,
	server_group_id_in in number
    );

	procedure delete_set_from_servergroup (
	server_group_id_in in number,
	user_id_in in number,
	set_label_in in varchar2
	);

	procedure clear_servergroup (
	server_group_id_in in number
	);

	procedure delete_from_org_servergroups (
	server_id_in in number
	);
end rhn_server;
/
SHOW ERRORS

-- rhnUserChannel already happened

-- now rhn_server.pkb

-- This is the 3.4 version...
create or replace
package body rhn_server
is
    function system_service_level(
	server_id_in in number,
	service_level_in in varchar2
    ) return number is
    begin
	return rhn_entitlements.entitlement_grants_service(
	    rhn_entitlements.get_server_entitlement(server_id_in),
	    service_level_in
	);
    end system_service_level;


    function can_change_base_channel(server_id_in IN NUMBER)
    return number
    is
	throwaway number;
    begin
	-- the idea: if we get past this query, the server is
	-- neither sat nor proxy, so base channel is changeable

	select 1 into throwaway
	  from rhnServer S
	 where S.id = server_id_in
	   and not exists (select 1 from rhnSatelliteInfo SI where SI.server_id = S.id)
	   and not exists (select 1 from rhnProxyInfo PI where PI.server_id = S.id);

	return 1;
    exception
	when no_data_found
	    then
	    return 0;
    end can_change_base_channel;

    procedure set_custom_value(
	server_id_in in number,
	user_id_in in number,
	key_label_in in varchar2,
	value_in in varchar2
    ) is
	key_id_val number;
    begin
	select CDK.id into key_id_val
	  from rhnCustomDataKey CDK,
	       rhnServer S
	 where S.id = server_id_in
	   and S.org_id = CDK.org_id
	   and CDK.label = key_label_in;

	begin
	    insert into rhnServerCustomDataValue (server_id, key_id, value, created_by, last_modified_by)
	    values (server_id_in, key_id_val, value_in, user_id_in, user_id_in);
	exception
	    when DUP_VAL_ON_INDEX
		then
		update rhnServerCustomDataValue
		   set value = value_in,
		       last_modified_by = user_id_in
		 where server_id = server_id_in
		   and key_id = key_id_val;
	end;

    end set_custom_value;

    procedure bulk_set_custom_value(
	key_label_in in varchar2,
	value_in in varchar2,
	set_label_in in varchar2,
	set_uid_in in number
    ) is
    begin
	for server in rhn_set.set_iterator(set_label_in, set_uid_in)
	loop
	    if rhn_server.system_service_level(server.element, 'provisioning') = 1 then
		rhn_server.set_custom_value(server.element, set_uid_in, key_label_in, value_in);
	    end if;
	end loop server;
    end bulk_set_custom_value;

    procedure bulk_snapshot_tag(
	org_id_in in number,
        tagname_in in varchar2,
	set_label_in in varchar2,
	set_uid_in in number
    ) is
	snapshot_id number;
    begin
	for server in rhn_set.set_iterator(set_label_in, set_uid_in)
	loop
	    if rhn_server.system_service_level(server.element, 'provisioning') = 1 then
		begin
		    select max(id) into snapshot_id
		    from rhnSnapshot
		    where server_id = server.element;
		exception
		    when NO_DATA_FOUND then
			rhn_server.snapshot_server(server.element, 'tagging system:  ' || tagname_in);

			select max(id) into snapshot_id
			from rhnSnapshot
			where server_id = server.element;
		end;

		-- now have a snapshot_id to work with...
		begin
		    rhn_server.tag_snapshot(snapshot_id, org_id_in, tagname_in);
		exception
		    when DUP_VAL_ON_INDEX
			then
			-- do nothing, be forgiving...
			null;
		end;
	    end if;
	end loop server;
    end bulk_snapshot_tag;

    procedure tag_delete(
	server_id_in in number,
	tag_id_in in number
    ) is
	cursor snapshots is
		select	snapshot_id
		from	rhnSnapshotTag
		where	tag_id = tag_id_in;
	tag_id_tmp number;
    begin
	select	id into tag_id_tmp
	from	rhnTag
	where	id = tag_id_in
	for update;

	delete
		from	rhnSnapshotTag
		where	server_id = server_id_in
			and tag_id = tag_id_in;
	for snapshot in snapshots loop
		return;
	end loop;
	delete
		from rhnTag
		where id = tag_id_in;
    end tag_delete;

    procedure tag_snapshot(
        snapshot_id_in in number,
	org_id_in in number,
	tagname_in in varchar2
    ) is
    begin
	insert into rhnSnapshotTag (snapshot_id, server_id, tag_id)
	select snapshot_id_in, server_id, lookup_tag(org_id_in, tagname_in)
	from rhnSnapshot
	where id = snapshot_id_in;
    end tag_snapshot;

    procedure bulk_snapshot(
	reason_in in varchar2,
	set_label_in in varchar2,
	set_uid_in in number
    ) is
    begin
	for server in rhn_set.set_iterator(set_label_in, set_uid_in)
	loop
	    if rhn_server.system_service_level(server.element, 'provisioning') = 1 then
		rhn_server.snapshot_server(server.element, reason_in);
	    end if;
	end loop server;
    end bulk_snapshot;

    procedure snapshot_server(
	server_id_in in number,
	reason_in in varchar2
    ) is
	snapshot_id number;
	cursor revisions is
		select distinct
			cr.id
		from	rhnConfigRevision	cr,
			rhnConfigFileName	cfn,
			rhnConfigFile		cf,
			rhnConfigChannel	cc,
			rhnServerConfigChannel	scc
		where	1=1
			and scc.server_id = server_id_in
			and scc.config_channel_id = cc.id
			and cc.id = cf.config_channel_id
			and cf.id = cr.config_file_id
			and cr.id = cf.latest_config_revision_id
			and cf.config_file_name_id = cfn.id
			and cf.id = lookup_first_matching_cf(scc.server_id, cfn.path);
    begin
	select rhn_snapshot_id_seq.nextval into snapshot_id from dual;

	insert into rhnSnapshot (id, org_id, server_id, reason) (
		select	snapshot_id,
			s.org_id,
			server_id_in,
			reason_in
		from	rhnServer s
		where	s.id = server_id_in
	);
	insert into rhnSnapshotChannel (snapshot_id, channel_id) (
		select	snapshot_id, sc.channel_id
		from	rhnServerChannel sc
		where	sc.server_id = server_id_in
	);
	insert into rhnSnapshotServerGroup (snapshot_id, server_group_id) (
		select	snapshot_id, sgm.server_group_id
		from	rhnServerGroupMembers sgm
		where	sgm.server_id = server_id_in
	);
	insert into rhnSnapshotPackage (snapshot_id, nevra_id) (
		select	distinct snapshot_id,
			lookup_package_nevra(sp.name_id, sp.evr_id, null)
		from	rhnServerPackage sp
		where	sp.server_id = server_id_in
	);

	insert into rhnSnapshotConfigChannel ( snapshot_id, config_channel_id ) (
		select	snapshot_id, scc.config_channel_id
		from	rhnServerConfigChannel scc
		where	server_id = server_id_in
	);

	for revision in revisions loop
		insert into rhnSnapshotConfigRevision (
				snapshot_id, config_revision_id
			) values (
				snapshot_id, revision.id
			);
	end loop;
    end snapshot_server;

    procedure remove_action(
	server_id_in in number,
	action_id_in in number
    ) is
	-- this really wants "nulls last", but 8.1.7.3.0 sucks ass.
	-- instead, we make a local table that holds our
	-- list of ids with null prereqs.  There's surely a better way
	-- (an array instead of a table maybe?  who knows...)
	-- but I've got code to do this handy that I can look at ;)
	cursor chained_actions is
		select	id, prerequisite
		from	rhnAction
		start with id = action_id_in
		connect by prior id = prerequisite
		order by prerequisite desc;
	cursor sessions is
		select	s.id
		from	rhnKickstartSession s
		where	server_id_in in (s.old_server_id, s.new_server_id)
			and s.action_id = action_id_in
			and not exists (
				select	1
				from	rhnKickstartSessionState ss
				where	ss.id = s.state_id
					and ss.label in ('failed','complete')
			);
	type chain_end_type is table of number index by binary_integer;
	chain_ends chain_end_type;
	i number;
	prereq number := 1;
    begin
	select	prerequisite
	into	prereq
	from	rhnAction
	where	id = action_id_in;

	if prereq is not null then
		rhn_exception.raise_exception('action_is_child');
	end if;

	i := 0;
	for action in chained_actions loop
		if action.prerequisite is null then
			chain_ends(i) := action.id;
			i := i + 1;
		else
			delete from rhnServerAction
				where server_id = server_id_in
				and action_id = action.id;
		end if;
	end loop;
	i := chain_ends.first;
	while i is not null loop
		delete from rhnServerAction
			where server_id = server_id_in
			and action_id = chain_ends(i);
		i := chain_ends.next(i);
	end loop;
	for s in sessions loop
		update rhnKickstartSession
			set 	state_id = (
					select	id
					from	rhnKickstartSessionState
					where	label = 'failed'
				),
				action_id = null
			where	id = s.id;
		set_ks_session_history_message(s.id, 'failed', 'Kickstart cancelled due to action removal');
	end loop;
    end remove_action;

    function check_user_access(server_id_in in number, user_id_in in number)
    return number
    is
	has_access number;
    begin
	-- first check; if this returns no rows, then the server/user are in different orgs, and we bail
        select 1 into has_access
	  from rhnServer S,
	       web_contact wc
	 where wc.org_id = s.org_id
	   and s.id = server_id_in
	   and wc.id = user_id_in;

	-- okay, so they're in the same org.  if we have an org admin, they get a free pass
	if rhn_user.check_role(user_id_in, 'org_admin') = 1
	then
	    return 1;
	end if;

	select 1 into has_access
	  from rhnServerGroupMembers SGM,
	       rhnUserServerGroupPerms USG
	 where SGM.server_group_id = USG.server_group_id
	   and SGM.server_id = server_id_in
	   and USG.user_id = user_id_in
	   and rownum = 1;

	return 1;
    exception
	when no_data_found
	    then
	    return 0;
    end check_user_access;

    procedure insert_into_servergroup (
		server_id_in in number,
		server_group_id_in in number
    ) is
		used_slots number;
		max_slots number;
		org_id number;
		mgmt_available number;
		mgmt_upgrade number;
		mgmt_sgid number;
		prov_available number;
		prov_upgrade number;
		prov_sgid number;
		group_label rhnServerGroupType.label%TYPE;
		group_type number;
	begin
		-- frist, group_type = null, because it's easy...

		-- this will rowlock the servergroup we're trying to change;
		-- we probably need to lock the other one, but I think the chances
		-- of it being a real issue are very small for now...
		select	sg.group_type, sg.org_id, sg.current_members, sg.max_members
		into	group_type, org_id, used_slots, max_slots
		from	rhnServerGroup sg
		where	sg.id = server_group_id_in
		for update of sg.current_members;

		if group_type is null then
			if used_slots >= max_slots then
				rhn_exception.raise_exception('servergroup_max_members');
			end if;

			insert into rhnServerGroupMembers(
					server_id, server_group_id
				) values (
					server_id_in, server_group_id_in
				);
			update rhnServerGroup
				set current_members = current_members + 1
				where id = server_group_id_in;
			return;
		end if;

		-- now for group_type != null
		--
		select	label
		into	group_label
		from	rhnServerGroupType	sgt
		where	sgt.id = group_type;

		-- the naive easy path that gets hit most often and has to be quickest.
		if group_label in ('sw_mgr_entitled','enterprise_entitled') then
			if used_slots >= max_slots then
				rhn_exception.raise_exception('servergroup_max_members');
			end if;

			insert into rhnServerGroupMembers(
					server_id, server_group_id
				) values (
					server_id_in, server_group_id_in
				);
			update rhnServerGroup
				set current_members = current_members + 1
				where id = server_group_id_in;
			return;
		else -- we're doing provisioning
			-- now, complication
			-- first, find out what's available where.
			rhn_entitlements.get_available_slots(
					org_id, 'provisioning_entitled', prov_sgid,
					prov_available, prov_upgrade);
			rhn_entitlements.get_available_slots(
					org_id, 'enterprise_entitled', mgmt_sgid,
					mgmt_available, mgmt_upgrade);

			-- now, what're we trying to do...
			if prov_available < 1 then
				if prov_upgrade > 0 then
					rhn_exception.raise_exception('servergroup_use_upgrade');
				end if;
				rhn_exception.raise_exception('servergroup_max_members');
			end if;
			insert into rhnServerGroupMembers(
					server_id, server_group_id
				) values (
					server_id_in, server_group_id_in
				);
			update rhnServerGroup
				set current_members = current_members + 1
				where id = server_group_id_in;
			update rhnServerGroup
				set max_members = max_members - 1
				where id = mgmt_sgid;
		end if;
	end;

	function insert_into_servergroup_maybe (
		server_id_in in number,
		server_group_id_in in number
	) return number is
		retval number := 0;
		cursor servergroups is
			select	s.id	server_id,
					sg.id	server_group_id
			from	rhnServerGroup	sg,
					rhnServer		s
			where	s.id = server_id_in
				and sg.id = server_group_id_in
				and s.org_id = sg.org_id
				and not exists (
					select	1
					from	rhnServerGroupMembers sgm
					where	sgm.server_id = s.id
						and sgm.server_group_id = sg.id
				);
	begin
		for sgm in servergroups loop
			rhn_server.insert_into_servergroup(sgm.server_id, sgm.server_group_id);
			retval := retval + 1;
		end loop;
		return retval;
	end insert_into_servergroup_maybe;

	procedure insert_set_into_servergroup (
		server_group_id_in in number,
		user_id_in in number,
		set_label_in in varchar2
	) is
		cursor servers is
			select	st.element	id
			from	rhnSet		st
			where	st.user_id = user_id_in
				and st.label = set_label_in
				and exists (
					select	1
					from	rhnUserManagedServerGroups umsg
					where	umsg.server_group_id = server_group_id_in
						and umsg.user_id = user_id_in
					)
				and not exists (
					select	1
					from	rhnServerGroupMembers sgm
					where	sgm.server_id = st.element
						and sgm.server_group_id = server_group_id_in
				);
	begin
		for s in servers loop
			rhn_server.insert_into_servergroup(s.id, server_group_id_in);
		end loop;
	end insert_set_into_servergroup;

    procedure delete_from_servergroup (
	server_id_in in number,
		server_group_id_in in number
    ) is
		oid number;
		mgmt_sgid number;
		label rhnServerGroupType.label%TYPE;
		group_type number;
	begin
		begin
			select	sg.group_type, sg.org_id
			into	group_type,	oid
			from	rhnServerGroupMembers	sgm,
					rhnServerGroup			sg
			where	sg.id = server_group_id_in
				and sg.id = sgm.server_group_id
				and sgm.server_id = server_id_in
			for update of sg.current_members;
		exception
			when no_data_found then
				rhn_exception.raise_exception('server_not_in_group');
		end;

		-- do group_type is null first
		if group_type is null then
			delete from rhnServerGroupMembers
				where server_group_id = server_group_id_in
				and	server_id = server_id_in;
			update rhnServerGroup
				set current_members = current_members - 1
				where id = server_group_id_in;
			return;
		end if;

		select	sgt.label
		into	label
		from	rhnServerGroupType sgt
		where	sgt.id = group_type;

		if label in ('sw_mgr_entitled','enterprise_entitled') then
			delete from rhnServerGroupMembers
				where server_group_id = server_group_id_in
				and	server_id = server_id_in;
			update rhnServerGroup
				set current_members = current_members - 1
				where id = server_group_id_in;
		else
			-- now we're in provisoning land...
			-- 1) find the mgmt group this prov group is coupled with...
			select	sg.id
			into	mgmt_sgid
			from	rhnServerGroupType	sgt,
					rhnServerGroup		sg
			where	sg.org_id = oid
				and sgt.label = 'enterprise_entitled'
				and sgt.id = sg.group_type
			for update of sg.max_members;

			-- 2) do the delete
			delete from rhnServerGroupMembers
				where server_group_id = server_group_id_in
				and	server_id = server_id_in;
			-- 3) fix the current/max members for both server groups
			update rhnServerGroup
				set max_members = max_members + 1
				where id = mgmt_sgid;
			update rhnServerGroup
				set current_members = current_members - 1
				where id = server_group_id_in;
		end if;
	end;

	procedure delete_set_from_servergroup (
		server_group_id_in in number,
		user_id_in in number,
		set_label_in in varchar2
	) is
		cursor servergroups is
			select	sgm.server_id, sgm.server_group_id
			from	rhnSet st,
					rhnServerGroupMembers sgm
			where	sgm.server_group_id = server_group_id_in
				and st.user_id = user_id_in
				and st.label = set_label_in
				and sgm.server_id = st.element
				and exists (
					select	1
					from	rhnUserManagedServerGroups usgp
					where	usgp.server_group_id = server_group_id_in
						and usgp.user_id = user_id_in
				);
	begin
		for sgm in servergroups loop
			rhn_server.delete_from_servergroup(sgm.server_id, server_group_id_in);
		end loop;
	end delete_set_from_servergroup;

	procedure clear_servergroup (
		server_group_id_in in number
	) is
		cursor servers is
			select	sgm.server_id	id
			from	rhnServerGroupMembers sgm
			where	sgm.server_group_id = server_group_id_in;
	begin
		for s in servers loop
			rhn_server.delete_from_servergroup(s.id, server_group_id_in);
		end loop;
	end clear_servergroup;

	procedure delete_from_org_servergroups (
		server_id_in in number
	) is
		cursor servergroups is
			select	sgm.server_group_id id
			from	rhnServerGroup sg,
					rhnServerGroupMembers sgm
			where	sgm.server_id = server_id_in
				and sgm.server_group_id = sg.id
				and sg.group_type is null;
	begin
		for sg in servergroups loop
			rhn_server.delete_from_servergroup(server_id_in, sg.id);
		end loop;
	end delete_from_org_servergroups;
end rhn_server;
/
SHOW ERRORS

drop package rhn_qos;

CREATE OR REPLACE
PACKAGE rhn_config_channel
IS
    FUNCTION get_user_chan_access(config_channel_id_in IN NUMBER, user_id_in IN NUMBER) RETURN NUMBER;
    FUNCTION get_user_revision_access(config_revision_id_in IN NUMBER, user_id_in IN NUMBER) RETURN NUMBER;
    FUNCTION get_user_file_access(config_file_id_in IN NUMBER, user_id_in IN NUMBER) RETURN NUMBER;

    FUNCTION action_diff_revision_status(action_config_revision_id_in IN NUMBER) RETURN VARCHAR2;

END rhn_config_channel;
/
SHOW ERRORS

CREATE OR REPLACE
PACKAGE BODY rhn_config_channel
IS
    FUNCTION action_diff_revision_status(action_config_revision_id_in IN NUMBER)
    RETURN VARCHAR2
    IS
	failure_reason VARCHAR2(4000);
	result_is_null NUMBER;
	result_exists NUMBER;
    BEGIN
	-- result_is_null obviously wants NVL2, but stupid 8.1.7.3.0 doesn't
	-- have that.  Or case.  So we're using union, instead.
	select extant, is_null, reason
	into   result_exists, result_is_null, failure_reason
	from   (
		SELECT ACRR.action_config_revision_id extant,
		       1 is_null, -- NVL2(ACRR.result, 0, 1),
		       CFF.name reason
		  FROM rhnConfigFileFailure CFF,
		       rhnActionConfigRevisionResult ACRR,
		       rhnActionConfigRevision ACR
		 WHERE ACR.id = action_config_revision_id_in
		   AND ACR.id = ACRR.action_config_revision_id (+)
		   and acrr.result is null
		   AND ACR.failure_id = CFF.id (+)
		union all
		SELECT ACRR.action_config_revision_id extant,
		       0 is_null, -- NVL2(ACRR.result, 0, 1),
		       CFF.name reason
		  FROM rhnConfigFileFailure CFF,
		       rhnActionConfigRevisionResult ACRR,
		       rhnActionConfigRevision ACR
		 WHERE ACR.id = action_config_revision_id_in
		   AND ACR.id = ACRR.action_config_revision_id (+)
		   and acrr.result is not null
		   AND ACR.failure_id = CFF.id (+)
		);

	IF failure_reason IS NOT NULL
	THEN
	    RETURN failure_reason;
	END IF;

	IF result_exists IS NOT NULL
	THEN
	    IF result_is_null = 1
	    THEN
		RETURN 'No differences';
	    END IF;

	    RETURN 'Differences exist';
	END IF;

	RETURN NULL;
    END action_diff_revision_status;

    FUNCTION get_user_chan_access(config_channel_id_in IN NUMBER, user_id_in IN NUMBER)
    RETURN NUMBER
    IS
	server_id NUMBER;
	org_matches NUMBER;
	any_visible_servers_subscribed NUMBER;
    BEGIN
	org_matches := 0;

	SELECT 1 INTO org_matches
	  FROM rhnConfigChannel CC,
	       web_contact WC
	 WHERE WC.id = user_id_in
	   AND CC.id = config_channel_id_in
	   AND WC.org_id = CC.org_id;

	IF org_matches != 1
	THEN
	    RETURN 0;
	END IF;

	IF rhn_user.check_role_implied(user_id_in, 'config_admin') = 1
	THEN
	    RETURN 1;
	END IF;

	any_visible_servers_subscribed := 0;

	SELECT 1 INTO any_visible_servers_subscribed
	  FROM DUAL
         WHERE EXISTS (
	   SELECT SCC.server_id
	     FROM rhnServerConfigChannel SCC,
	          rhnUserServerPermsDupes USPD
	    WHERE USPD.user_id = user_id_in
	      AND USPD.server_id = SCC.server_id
	      AND SCC.config_channel_id = config_channel_id_in
	 );

	IF any_visible_servers_subscribed = 1
	THEN
	    RETURN 1;
	END IF;

	RETURN 0;
    END get_user_chan_access;

    FUNCTION get_user_revision_access(config_revision_id_in IN NUMBER, user_id_in IN NUMBER)
    RETURN NUMBER
    IS
	config_channel_id NUMBER;
    BEGIN
	SELECT CF.config_channel_id INTO config_channel_id
	  FROM rhnConfigFile CF,
	       rhnConfigRevision CR
	 WHERE CF.id = CR.config_file_id
	   AND CR.id = config_revision_id_in;

	RETURN rhn_config_channel.get_user_chan_access(config_channel_id, user_id_in);
    END get_user_revision_access;

    FUNCTION get_user_file_access(config_file_id_in IN NUMBER, user_id_in IN NUMBER)
    RETURN NUMBER
    IS
	config_channel_id NUMBER;
    BEGIN
	SELECT CF.config_channel_id INTO config_channel_id
	  FROM rhnConfigFile CF
	 WHERE CF.id = config_file_id_in;

	RETURN rhn_config_channel.get_user_chan_access(config_channel_id, user_id_in);
    END get_user_file_access;

END rhn_config_channel;
/
SHOW ERRORS

-- now we're at 3.3-53, move to 3.4-48

-- 000.rhn.sql
create sequence rhn_filelist_id_seq;
create table
rhnFileList
(
	id		number
			constraint rhn_filelist_id_nn not null
			constraint rhn_filelist_id_pk primary key,
	label		varchar(128)
			constraint rhn_filelist_l_nn not null,
	org_id		number
			constraint rhn_filelist_oid_nn not null
			constraint rhn_filelist_oid_fk
				references web_customer(id),
	created		date default (sysdate)
			constraint rhn_filelist_creat_nn not null,
	modified	date default (sysdate)
			constraint rhn_filelist_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_filelist_oid_l_uq
	on rhnFileList( org_id, label )
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_filelist_mod_trig
before insert or update on rhnFileList
for each row
begin
	:new.modified := sysdate;
end rhn_filelist_mod_trig;
/
show errors

create table
rhnFileListMembers
(
	file_list_id		number
				constraint rhn_flmembers_flid_nn not null
				constraint rhn_flmembers_flid_fk
					references rhnFileList(id)
					on delete cascade,
	config_file_name_id	number
				constraint rhn_flmembers_cfnid_nn not null
				constraint rhn_flmembers_cfnid_fk
					references rhnConfigFileName(id),
	created			date default (sysdate)
				constraint rhn_flmembers_creat_nn not null,
	modified		date default (sysdate)
				constraint rhn_flmembers_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_flmembers_flid_cfnid_uq
	on rhnFileListMembers( file_list_id, config_file_name_id )
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_flmembers_mod_trig
before insert or update on rhnFileListMembers
for each row
begin
	:new.modified := sysdate;
end rhn_flmembers_mod_trig;
/
show errors

create table
rhnServerPreserveFileList
(
	server_id	number
			constraint rhn_serverpfl_ksid_nn not null
			constraint rhn_serverpfl_ksid_fk
				references rhnServer(id),
	file_list_id	number
			constraint rhn_serverpfl_flid_nn not null
			constraint rhn_serverpfl_flid_fk
				references rhnFileList(id),
	created		date default (sysdate)
			constraint rhn_serverpfl_creat_nn not null,
	modified	date default (sysdate)
			constraint rhn_serverpfl_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_serverpfl_ksid_flid_uq
	on rhnServerPreserveFileList( server_id, file_list_id )
	storage ( freelists 16 )
	initrans 32;
-- needed for delete server
create index rhn_serverpfl_flid_ksid_idx
	on rhnServerPreserveFileList( file_list_id, server_id )
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_serverpfl_mod_trig
before insert or update on rhnServerPreserveFileList
for each row
begin
	:new.modified := sysdate;
end rhn_serverpfl_mod_trig;
/
show errors

create table
rhnKickstartPreserveFileList
(
	kickstart_id	number
			constraint rhn_kspreservefl_ksid_nn not null
			constraint rhn_kspreservefl_ksid_fk
				references rhnKSData(id)
				on delete cascade,
	file_list_id	number
			constraint rhn_kspreservefl_flid_nn not null
			constraint rhn_kspreservefl_flid_fk
				references rhnFileList(id),
	created		date default (sysdate)
			constraint rhn_kspreservefl_creat_nn not null,
	modified	date default (sysdate)
			constraint rhn_kspreservefl_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create unique index rhn_kspreservefl_ksid_flid_uq
	on rhnKickstartPreserveFileList( kickstart_id, file_list_id )
	storage ( freelists 16 )
	initrans 32;
-- needed for delete_server
create index rhn_kspreservefl_flid_ksid_idx
	on rhnKickstartPreserveFileList( file_list_id, kickstart_id )
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_kspreservefl_mod_trig
before insert or update on rhnKickstartPreserveFileList
for each row
begin
	:new.modified := sysdate;
end rhn_kspreservefl_mod_trig;
/
show errors
-- delete_server removed, 007 has it.

-- 004.rhn.sql

create table
rhnKickstartDefaultRegToken
(
	kickstart_id		number
				constraint rhn_ksdrt_ksid_nn not null
				constraint rhn_ksdrt_ksid_fk
					references rhnKSData(id)
					on delete cascade,
	regtoken_id		number
				constraint rhn_ksdrt_rtid_nn not null
				constraint rhn_ksdrt_rtid_fk
					references rhnRegToken(id)
					on delete cascade,
	created			date default (sysdate)
				constraint rhn_ksdrt_creat_nn not null,
	modified		date default (sysdate)
				constraint rhn_ksdrt_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;
create index rhn_ksdrt_ksid_rtid_idx
	on rhnKickstartDefaultRegToken( kickstart_id, regtoken_id )
	storage ( freelists 16 )
	initrans 32;
alter table rhnKickstartDefaultRegToken add constraint rhn_ksdrt_ksid_uq
	unique ( kickstart_id );
-- supports the "on delete cascade"
create index rhn_ksdrt_rtid_idx
	on rhnKickstartDefaultRegToken( regtoken_id )
	storage ( freelists 16 )
	initrans 32;
create or replace trigger
rhn_ksdrt_mod_trig
before insert or update on rhnKickstartDefaultRegToken
for each row
begin
	:new.modified := sysdate;
end rhn_ksdrt_mod_trig;
/
show errors
insert into rhnKickstartDefaultRegToken ( kickstart_id, regtoken_id )
	select kickstart_id, regtoken_id
	  from rhnKickstartDefaults
	 where regtoken_id is not null;
alter table rhnKickstartDefaults drop ( regtoken_id );

-- 007.rhn.sql
create or replace
procedure delete_server (
	server_id_in in number
) is
	cursor servergroups is
		select	server_id, server_group_id
		from	rhnServerGroupMembers sgm
		where	sgm.server_id = server_id_in;
	cursor configchannels is
		select	cc.id
		from	rhnConfigChannel cc,
			rhnConfigChannelType cct,
			rhnServerConfigChannel scc
		where	1=1
			and scc.server_id = server_id_in
			and scc.config_channel_id = cc.id
			-- these config channel types are reserved
			-- for use by a single server, so we don't
			-- need to check for other servers subscribed
			and cct.label in
				('local_override','server_import')
			and cct.id = cc.confchan_type_id;
	cursor filelists is
		select	spfl.file_list_id id
		from	rhnServerPreserveFileList spfl
		where	spfl.server_id = server_id_in
			and not exists (
				select	1
				from	rhnServerPreserveFileList
				where	file_list_id = spfl.file_list_id
					and server_id != server_id_in
				union
				select	1
				from	rhnKickstartPreserveFileList
				where	file_list_id = spfl.file_list_id
			);
begin
	rhn_channel.delete_server_channels(server_id_in);
	-- rhn_channel.clear_subscriptions(server_id_in);
	for filelist in filelists loop
		delete from rhnFileList where id = filelist.id;
	end loop;
	for configchannel in configchannels loop
		rhn_config.delete_channel(configchannel.id);
	end loop;
	for sgm in servergroups loop
		rhn_server.delete_from_servergroup(
			sgm.server_id, sgm.server_group_id);
	end loop;
	-- we're handling this instead of letting an "on delete
	-- set null" do it so that we don't run the risk
	-- of setting off the triggers and killing us with a
	-- mutating table
	-- we cna't use a cursor to do this because we need "case"
	-- in a select to do that, and 8.1.7.3.0 doesn't support it.
	update rhnKickstartSession
		set old_server_id = null
		where old_server_id = server_id_in;
	update rhnKickstartSession
		set new_server_id = null
		where new_server_id = server_id_in;
	rhn_channel.clear_subscriptions(server_id_in);
	-- We're deleting everything with a foreign key to rhnServer
	-- here, now.  I'm hoping this will help aleviate our deadlock
	-- problem.
	delete from rhnActionConfigChannel where server_id = server_id_in;
	delete from rhnActionConfigRevision where server_id = server_id_in;
	delete from rhnActionPackageRemovalFailure where server_id = server_id_in;
	delete from rhnChannelFamilyLicenseConsent where server_id = server_id_in;
	delete from rhnClientCapability where server_id = server_id_in;
	delete from rhnCpu where server_id = server_id_in;
	-- there's still a cascade here, because the constraint keeps the
	-- table locked for too long to rebuild it.  Ugh...
	delete from rhnDevice where server_id = server_id_in;
	delete from rhnProxyInfo where server_id = server_id_in;
	delete from rhnRam where server_id = server_id_in;
	delete from rhnRegToken where server_id = server_id_in;
	delete from rhnSNPServerQueue where server_id = server_id_in;
	delete from rhnSatelliteChannelFamily where server_id = server_id_in;
	delete from rhnSatelliteInfo where server_id = server_id_in;
	-- this cascades to rhnActionConfigChannel and rhnActionConfigFileName
	delete from rhnServerAction where server_id = server_id_in;
	delete from rhnServerActionPackageResult where server_id = server_id_in;
	delete from rhnServerActionScriptResult where server_id = server_id_in;
	delete from rhnServerActionVerifyResult where server_id = server_id_in;
	-- counts are handled above.  this should be a delete_ function.
	delete from rhnServerChannel where server_id = server_id_in;
	delete from rhnServerConfigChannel where server_id = server_id_in;
	delete from rhnServerCustomDataValue where server_id = server_id_in;
	delete from rhnServerDMI where server_id = server_id_in;
	delete from rhnServerMessage where server_id = server_id_in;
	-- this gets rhnServerMessage (only) on cascade; it's handled just above
	delete from rhnServerEvent where server_id = server_id_in;
	delete from rhnServerHistory where server_id = server_id_in;
	delete from rhnServerInfo where server_id = server_id_in;
	delete from rhnServerInstallInfo where server_id = server_id_in;
	delete from rhnServerLocation where server_id = server_id_in;
	delete from rhnServerLock where server_id = server_id_in;
	delete from rhnServerNeededPackageCache where server_id = server_id_in;
	delete from rhnServerNetInterface where server_id = server_id_in;
	delete from rhnServerNetwork where server_id = server_id_in;
	delete from rhnServerNotes where server_id = server_id_in;
	-- I'm not removing the foreign key from rhnServerPackage; that'll
	-- take forever.  Do the delete anyway.
	delete from rhnServerPackage where server_id = server_id_in;
	delete from rhnServerTokenRegs where server_id = server_id_in;
	delete from rhnSnapshotTag where server_id = server_id_in;
	-- this cascades to:
	--   rhnSnapshotChannel, rhnSnapshotConfigChannel, rhnSnapshotPackage,
	--   rhnSnapshotConfigRevision, rhnSnapshotServerGroup,
	--   rhnSnapshotTag.
	-- We may want to consider delete_snapshot() at some point, but
	--   I don't think we need to yet.
	delete from rhnSnapshot where server_id = server_id_in;
	delete from rhnTransaction where server_id = server_id_in;
	delete from rhnUserServerPrefs where server_id = server_id_in;
	-- hrm, this one's interesting... we _probably_ should delete
	-- everything for the parent server_id when we delete the proxy,
	-- but we don't currently.
	delete from rhnServerPath where server_id_in in (server_id, proxy_server_id);
	-- now get rhnServer itself.
	delete
	from	rhnServer
		where id = server_id_in;
	delete
	from	rhnSet
	where	1=1
		and user_id in (
			select	wc.id
			from	rhnServer rs,
				web_contact wc
			where	rs.id = server_id_in
				and rs.org_id = wc.org_id
		)
		and label = 'system_list'
		and element = server_id_in;
end delete_server;
/
show errors

create or replace
procedure delete_server_bulk (
	user_id_in in number
) is
	cursor systems is
		select	s.element id
		from	rhnSet s
		where	s.user_id = user_id_in
			and s.label = 'system_list';
	cursor servergroups is
		select	sgm.server_group_id, sgm.server_id
		from	rhnServerGroupMembers sgm,
			rhnSet s
		where	s.user_id = user_id_in
			and s.label = 'system_list'
			and s.element = sgm.server_id;
	cursor configchannels is
		select	cc.id
		from	rhnConfigChannel cc,
			rhnConfigChannelType cct,
			rhnServerConfigChannel scc,
			rhnSet s
		where	1=1
			and s.user_id = user_id_in
			and s.label = 'system_list'
			and s.element = scc.server_id
			and scc.config_channel_id = cc.id
			-- these config channel types are reserved
			-- for use by a single server, so we don't
			-- need to check for other servers subscribed
			and cct.label in
				('local_override','server_import')
			and cct.id = cc.confchan_type_id;
	cursor filelists is
		select	spfl.file_list_id id
		from	rhnServerPreserveFileList spfl,
			rhnSet s
		where	s.user_id = user_id_in
			and s.label = 'system_list'
			and s.element = spfl.server_id
			and not exists (
				select	1
				from	rhnKickstartPreserveFileList
				where	file_list_id = spfl.file_list_id
			)
			and not exists (
				-- this has the org_id just to make the set -much- smaller.
				select	spfl.server_id
				from	rhnServerPreserveFileList spfl,
					rhnServer s,
					web_contact u
				where	u.id = user_id_in
					and u.org_id = s.org_id
					and s.id = spfl.server_id
					and spfl.file_list_id = spfl.file_list_id
				minus
				select	element server_id
				from	rhnSet
				where	s.user_id = user_id_in
					and s.label = 'system_list'
			);
begin
	for filelist in filelists loop
		delete from rhnFileList where id = filelist.id;
	end loop;
	for cc in configchannels loop
		rhn_config.delete_channel(cc.id);
	end loop;
	for sgm in servergroups loop
		rhn_server.delete_from_servergroup(
			sgm.server_id, sgm.server_group_id);
	end loop;
	-- it's too bad you can't use "current of" with deletes
	for s in systems loop
		-- we can't use a cursor like planned to for delete_server
		-- to fix rhnKickstartSession entries, because
		-- we miss entries where old_server_id and new_server_id
		-- are both in the set.
		update rhnKickstartSession
			set old_server_id = null
			where old_server_id = s.id;
		update rhnKickstartSession
			set new_server_id = null
			where new_server_id = s.id;
		rhn_channel.clear_subscriptions(s.id);
		-- We're deleting everything with a foreign key to rhnServer
		-- here, now.  I'm hoping this will help aleviate our deadlock
		-- problem.
		delete from rhnActionConfigChannel where server_id = s.id;
		delete from rhnActionConfigRevision where server_id = s.id;
		delete from rhnActionPackageRemovalFailure where server_id = s.id;
		delete from rhnChannelFamilyLicenseConsent where server_id = s.id;
		delete from rhnClientCapability where server_id = s.id;
		delete from rhnCpu where server_id = s.id;
		-- there's still a cascade here, because the constraint keeps the
		-- table locked for too long to rebuild it.  Ugh...
		delete from rhnDevice where server_id = s.id;
		delete from rhnProxyInfo where server_id = s.id;
		delete from rhnRam where server_id = s.id;
		delete from rhnRegToken where server_id = s.id;
		delete from rhnSNPServerQueue where server_id = s.id;
		delete from rhnSatelliteChannelFamily where server_id = s.id;
		delete from rhnSatelliteInfo where server_id = s.id;
		-- this cascades to rhnActionConfigChannel and rhnActionConfigFileName
		delete from rhnServerAction where server_id = s.id;
		delete from rhnServerActionPackageResult where server_id = s.id;
		delete from rhnServerActionScriptResult where server_id = s.id;
		delete from rhnServerActionVerifyResult where server_id = s.id;
		-- counts are handled above.  this should be a delete_ function.
		delete from rhnServerChannel where server_id = s.id;
		delete from rhnServerConfigChannel where server_id = s.id;
		delete from rhnServerCustomDataValue where server_id = s.id;
		delete from rhnServerDMI where server_id = s.id;
		delete from rhnServerMessage where server_id = s.id;
		-- this gets rhnServerMessage (only) on cascade; it's handled just above
		delete from rhnServerEvent where server_id = s.id;
		delete from rhnServerHistory where server_id = s.id;
		delete from rhnServerInfo where server_id = s.id;
		delete from rhnServerInstallInfo where server_id = s.id;
		delete from rhnServerLocation where server_id = s.id;
		delete from rhnServerLock where server_id = s.id;
		delete from rhnServerNeededPackageCache where server_id = s.id;
		delete from rhnServerNetInterface where server_id = s.id;
		delete from rhnServerNetwork where server_id = s.id;
		delete from rhnServerNotes where server_id = s.id;
		-- I'm not removing the foreign key from rhnServerPackage; that'll
		-- take forever.  Do the delete anyway.
		delete from rhnServerPackage where server_id = s.id;
		delete from rhnServerTokenRegs where server_id = s.id;
		delete from rhnSnapshotTag where server_id = s.id;
		-- this cascades to:
		--   rhnSnapshotChannel, rhnSnapshotConfigChannel, rhnSnapshotPackage,
		--   rhnSnapshotConfigRevision, rhnSnapshotServerGroup,
		--   rhnSnapshotTag.
		-- We may want to consider delete_snapshot() at some point, but
		--   I don't think we need to yet.
		delete from rhnSnapshot where server_id = s.id;
		delete from rhnTransaction where server_id = s.id;
		delete from rhnUserServerPrefs where server_id = s.id;
		-- hrm, this one's interesting... we _probably_ should delete
		-- everything for the parent server_id when we delete the proxy,
		-- but we don't currently.
		delete from rhnServerPath where s.id in (server_id, proxy_server_id);
		delete from rhnServer
			where id = s.id;
		delete from rhnSet
			where user_id in (
				select	wc.id
				from	rhnServer rs,
					web_contact wc
				where	rs.id = s.id
					and rs.org_id = wc.org_id
			)
			and label = 'system_list'
			and element = s.id;
	end loop;
end delete_server_bulk;
/
show errors

-- 008.rhn.sql

alter table rhnKickstartDefaultRegToken drop constraint rhn_ksdrt_ksid_uq;

-- 009.rhn.sql

insert into rhnServerGroupType (id, label, name)
	values (rhn_servergroup_type_seq.nextval,
		'monitoring_entitled','RHN Monitoring Entitled Servers'
	);
commit;

-- 010.rhn.sql only does rhn_ep, not for sat.

-- 011.rhn.sql

create or replace
package rhn_entitlements
is
	body_version varchar2(100) := '$Id: satellite-3.2-to-3.4.sql 64427 2005-09-09 14:08:21Z jslagle $';
    function entitlement_grants_service (
	    entitlement_in in varchar2,
		service_level_in in varchar2
	) return number;
	function lookup_entitlement_group (
		org_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	) return number;
	function create_entitlement_group (
		org_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	) return number;
	procedure entitle_server (
		server_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	);
	procedure unentitle_server (
		server_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	);
	-- upgrade server wants you already to be in an
	-- enterprise_entitled server group, and tries to
	-- put you in a provisioning_entitled one instead.
	procedure upgrade_server (
		server_id_in in number
	);
	function get_server_entitlement (
		server_id_in in number
	) return varchar2;
	procedure modify_org_service (
		org_id_in in number,
		service_label_in in varchar2,
		enable_in in char
	);
    procedure set_customer_enterprise (
		customer_id_in in number
	);
	procedure set_customer_provisioning (
		customer_id_in in number
	);
	procedure set_customer_nonlinux (
		customer_id_in in number
	);
    procedure unset_customer_enterprise (
		customer_id_in in number
	);
	procedure unset_customer_provisioning (
		customer_id_in in number
	);
	procedure unset_customer_nonlinux (
		customer_id_in in number
	);
    procedure set_group_count (
		customer_id_in in number,	-- customer_id
		type_in in char,			-- 'U' or 'S'
		group_type_in in number,	-- rhn[User|Server]GroupType.id
		quantity_in in number		-- quantity
    );
    procedure set_family_count (
		customer_id_in in number,		-- customer_id
		channel_family_id_in in number,	-- 246
		quantity_in in number			-- 3
    );
    -- this makes NO checks that the quantity is within max,
    -- so we should NEVER run this unless we KNOW that we won't be
    -- violating the max
    procedure entitle_last_modified_servers (
		customer_id_in in number,	-- customer_id
		type_label_in in varchar2,	-- 'enterprise_entitled'
		quantity_in in number		-- 3
    );
	-- results from this are valid _only_ in the context of the
	-- server group label queried.  If you ask for provisioning
	-- data, don't compare that with results for enterprise data.
	procedure get_available_slots (
		customer_id_in in number,
		type_label_in in varchar2,
		server_group_id_out out number,
		available_out out number,
		upgrade_out out number
	);

	procedure prune_everything (
		customer_id_in in number
	);
	procedure subscribe_newest_servers (
		customer_id_in in number
	);
end rhn_entitlements;
/
show errors

-- 012.rhn.sql

create or replace
package body rhn_entitlements
is
	body_version varchar2(100) := '$Id: satellite-3.2-to-3.4.sql 64427 2005-09-09 14:08:21Z jslagle $';
	function entitlement_grants_service (
	    entitlement_in in varchar2,
	    service_level_in in varchar2
	) return number	is
	begin
		if service_level_in = 'provisioning' then
			if entitlement_in = 'provisioning_entitled' then
				return 1;
			else
				return 0;
			end if;
		elsif service_level_in = 'management' then
			if entitlement_in = 'provisioning_entitled' then
				return 1;
			elsif entitlement_in = 'enterprise_entitled' then
				return 1;
			elsif entitlement_in = 'nonlinux_entitled' then
				return 1;
			else
				return 0;
			end if;
		elsif service_level_in = 'monitoring' then
			if entitlement_in = 'monitoring_entitled' then
				return 1;
			end if;
		elsif service_level_in = 'updates' then
			return 1;
		else
			return 0;
		end if;
	end entitlement_grants_service;
	function lookup_entitlement_group (
		org_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	) return number is
		cursor server_groups is
			select	sg.id				server_group_id
			from	rhnServerGroup		sg,
					rhnServerGroupType	sgt
			where	sgt.label = type_label_in
				and sgt.id = sg.group_type
				and sg.org_id = org_id_in;
	begin
		for sg in server_groups loop
			return sg.server_group_id;
		end loop;
		return rhn_entitlements.create_entitlement_group(
				org_id_in,
				type_label_in
			);
	end lookup_entitlement_group;
	function create_entitlement_group (
		org_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	) return number is
		sg_id_val number;
	begin
		select	rhn_server_group_id_seq.nextval
		into	sg_id_val
		from	dual;
		insert into rhnServerGroup (
				id, name, description, max_members, current_members,
				group_type, org_id
			) (
				select	sg_id_val, sgt.label, sgt.label,
						0, 0, sgt.id, org_id_in
				from	rhnServerGroupType sgt
				where	sgt.label = type_label_in
			);
		return sg_id_val;
	end create_entitlement_group;
	procedure entitle_server (
		server_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	) is
		cursor servergroups is
			select	sg.id id,
					s.server_arch_id server_arch_id,
					sgt.id server_group_type
			from	rhnServerGroupType sgt,
					rhnServerGroup sg,
					rhnServer s
			where	s.id = server_id_in
				and s.org_id = sg.org_id
				and sgt.label = type_label_in
				and sg.group_type = sgt.id;
		cursor sg_arches(sgt_id_in in number, sa_id_in in number) is
			select	1
			from	rhnServerServerGroupArchCompat
			where	server_group_type = sgt_id_in
				and server_arch_id = sa_id_in;
		previous_ent rhnServerGroupType.label%TYPE;
	begin
		previous_ent := rhn_entitlements.get_server_entitlement(server_id_in);
		if previous_ent != 'none' then
			rhn_exception.raise_exception(
								'no_server_multiple_swmgr_entitlements');
		end if;
		for sg in servergroups loop
			for a in sg_arches(sg.server_group_type, sg.server_arch_id) loop
				-- if the max_members is too low, this'll raise
				-- servergroup_max_members
				rhn_server.insert_into_servergroup(server_id_in, sg.id);
				return;
			end loop;
			-- we only get here if we can't find any compatible
			-- server_arch+server_group_type combination
			rhn_exception.raise_exception('mismatching_entitlement');
		end loop;
		-- we only get here if there's _no_ server group for that type;
		-- that's the same as max_members=0
		rhn_exception.raise_exception('servergroup_max_members');
	end entitle_server;
	procedure unentitle_server (
		server_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	) is
		group_id number;
	begin
		select	sg.id
		into	group_id
		from	rhnServerGroupType sgt,
				rhnServerGroup sg,
				rhnServerGroupMembers sgm,
				rhnServer s
		where	s.id = server_id_in
			and s.id = sgm.server_id
			and sgm.server_group_id = sg.id
			and sg.org_id = s.org_id
			and sgt.label = type_label_in
			and sgt.id = sg.group_type;
		rhn_server.delete_from_servergroup(server_id_in, group_id);
		exception
		when no_data_found then
					null;
	end unentitle_server;
	-- right now, this is racy.  Don't do it twice at once
	-- for the same org.  You've been warned...
	procedure upgrade_server (
		server_id_in in number
	) is
		old_sgid number;
		new_sgid number;
		new_sg_max number;
		new_sg_used number;
	begin
		begin
			select	sg0.id, sg1.id,
					sg1.max_members, sg1.current_members
			into	old_sgid, new_sgid,
					new_sg_max, new_sg_used
			from	rhnServerGroup sg1,
					rhnServerGroupType sgt1,
					rhnServerGroupMembers sgm,
					rhnServerGroup sg0,
					rhnServerGroupType sgt0,
					rhnServer s
			where	s.id = server_id_in
				and s.org_id = sg0.org_id
				and sgt0.label = 'enterprise_entitled'
				and sgt0.id = sg0.group_type
				and s.id = sgm.server_id
				and sgm.server_group_id = sg0.id
				and s.org_id = sg1.org_id
				and sgt1.label = 'provisioning_entitled'
				and sgt1.id = sg1.group_type;
		exception
			when no_data_found then
				rhn_exception.raise_exception('invalid_upgrade');
		end;
		-- it could still happen that you run out after we check this.
		-- that's what the comment above is all about...
		if new_sg_used >= new_sg_max then
			rhn_exception.raise_exception('servergroup_max_members');
		end if;
		rhn_server.delete_from_servergroup(server_id_in, old_sgid);
		rhn_server.insert_into_servergroup(server_id_in, new_sgid);
	end upgrade_server;
	function get_server_entitlement (
		server_id_in in number
	) return varchar2 is
		cursor server_groups is
			select	sgt.label
			from	rhnServerGroupType		sgt,
					rhnServerGroup			sg,
					rhnServerGroupMembers	sgm
			where	1=1
				and sgm.server_id = server_id_in
				and sg.id = sgm.server_group_id
				and sgt.id = sg.group_type
				and sgt.label in (
					'sw_mgr_entitled','enterprise_entitled',
					'provisioning_entitled', 'nonlinux_entitled',
					'monitoring_entitled'
					);
	begin
		for sg in server_groups loop
			return sg.label;
		end loop;
		return 'none';
	end get_server_entitlement;
	-- this desperately needs to be table driven.
	procedure modify_org_service (
		org_id_in in number,
		service_label_in in varchar2,
		enable_in in char
	) is
		type roles_v is varray(10) of rhnUserGroupType.label%TYPE;
		roles_to_process roles_v;
		cursor roles(role_label_in in varchar2) is
			select	label, id
			from	rhnUserGroupType
			where	label = role_label_in;
		cursor org_roles(role_label_in in varchar2) is
			select	1
			from	rhnUserGroup ug,
					rhnUserGroupType ugt
			where	ugt.label = role_label_in
				and ugt.id = ug.group_type;
		type ents_v is varray(10) of rhnOrgEntitlementType.label%TYPE;
		ents_to_process ents_v;
		cursor ents(ent_label_in in varchar2) is
			select	label, id
			from	rhnOrgEntitlementType
			where	label = ent_label_in;
		cursor org_ents(ent_label_in in varchar2) is
			select	1
			from	rhnOrgEntitlements oe,
					rhnOrgEntitlementType oet
			where	oet.label = ent_label_in
				and oet.id = oe.entitlement_id;
		create_row char(1);
		pos number := 1;
	begin
		-- a bit kludgy, but only for 3.4 really.  Certainly no
		-- worse than the old code...
		if service_label_in = 'enterprise' then
			ents_to_process.extend;
			ents_to_process(1) := 'sw_mgr_enterprise';
			roles_to_process.extend;
			roles_to_process(1) := 'org_admin';
			if is_satellite() = 1 then
				roles_to_process.extend;
				roles_to_process(2) := 'org_applicant';
			end if;
		elsif service_label_in = 'provisioning' then
			ents_to_process.extend;
			ents_to_process(1) := 'rhn_provisioning';
			pos:=2;
			if is_satellite() = 1 then
				roles_to_process.extend;
				roles_to_process(pos) := 'config_admin';
				pos := pos + 1;
			end if;
			-- another nasty special case...
			if enable_in = 'Y' then
				ents_to_process.extend;
				ents_to_process(pos) := 'sw_mgr_enterprise';
			end if;
		elsif service_label_in = 'nonlinux' then
			ents_to_process.extend;
			ents_to_process(1) := 'rhn_nonlinux';
			if is_satellite() = 1 then
				roles_to_process.extend;
				roles_to_process(2) := 'config_admin';
			end if;
		end if;
		if enable_in = 'Y' then
			for i in 1..ents_to_process.count loop
				for ent in ents(ents_to_process(i)) loop
					create_row := 'Y';
					for oe in org_ents(ent.label) loop
						create_row := 'N';
					end loop;
					if create_row = 'Y' then
						insert into rhnOrgEntitlements(org_id, entitlement_id)
							values (org_id_in, ent.id);
					end if;
				end loop;
			end loop;
			for i in 1..roles_to_process.count loop
				for role in roles(roles_to_process(i)) loop
					create_row := 'Y';
					for o_r in org_roles(role.label) loop
						create_row := 'N';
					end loop;
					if create_row = 'Y' then
						insert into rhnUserGroup(
								id, name, description, current_members,
								group_type, org_id
							) (
								select	rhn_user_group_id_seq.nextval,
										ugt.name || 's',
										ugt.name || 's for Org ' ||
											o.name || ' ('|| o.id ||')',
										0, ugt.id, o.id
								from	rhnUserGroupType ugt,
										web_customer o
								where	o.id = org_id_in
									and ugt.id = role.id
							);
					end if;
				end loop;
			end loop;
		else
			for i in 1..ents_to_process.count loop
				for ent in ents(ents_to_process(i)) loop
					delete from rhnOrgEntitlements
					 where org_id = org_id_in
					   and entitlement_id = ent.id;
				end loop;
			end loop;
		end if;
	end modify_org_service;
	procedure set_customer_enterprise (
		customer_id_in in number
	) is
	begin
		modify_org_service(customer_id_in, 'enterprise', 'Y');
	end set_customer_enterprise;
	procedure set_customer_provisioning (
		customer_id_in in number
	) is
	begin
		modify_org_service(customer_id_in, 'provisioning', 'Y');
	end set_customer_provisioning;
	procedure set_customer_nonlinux (
		customer_id_in in number
	) is
	begin
		modify_org_service(customer_id_in, 'nonlinux', 'Y');
	end set_customer_nonlinux;
	procedure unset_customer_enterprise (
		customer_id_in in number
	) is
	begin
		modify_org_service(customer_id_in, 'enterprise', 'N');
	end unset_customer_enterprise;
	procedure unset_customer_provisioning (
		customer_id_in in number
	) is
	begin
		modify_org_service(customer_id_in, 'provisioning', 'N');
	end unset_customer_provisioning;
	procedure unset_customer_nonlinux (
		customer_id_in in number
	) is
	begin
		modify_org_service(customer_id_in, 'nonlinux', 'N');
	end unset_customer_nonlinux;
	procedure prune_group (
		group_id_in in number,
		type_in in char,
		quantity_in in number
	) is
		cursor usergroups is
			select	user_id, user_group_id, ugt.label
			from	rhnUserGroupType	ugt,
					rhnUserGroup		ug,
					rhnUserGroupMembers	ugm
			where	1=1
				and ugm.user_group_id = group_id_in
				and ugm.user_id in (
					select	user_id
					from	(
						select	rownum row_number,
								user_id,
								time
						from	(
							select	user_id,
									modified time
							from	rhnUserGroupMembers
							where	user_group_id = group_id_in
							order by time asc
						)
					)
					where	row_number > quantity_in
				)
				and ugm.user_group_id = ug.id
				and ug.group_type = ugt.id;
		cursor servergroups is
			select	server_id, server_group_id, sgt.label
			from	rhnServerGroupType		sgt,
					rhnServerGroup			sg,
					rhnServerGroupMembers	sgm
			where	1=1
				and sgm.server_group_id = group_id_in
				and sgm.server_id in (
					select	server_id
					from	(
						select	rownum row_number,
								server_id,
								time
						from	(
							select	server_id,
									modified time
							from	rhnServerGroupMembers
							where	server_group_id = group_id_in
							order by time asc
						)
					)
					where	row_number > quantity_in
				)
				and sgm.server_group_id = sg.id
				and sg.group_type = sgt.id;
	begin
		if type_in = 'U' then
			update		rhnUserGroup
				set		max_members = quantity_in
				where	id = group_id_in;
			for ug in usergroups loop
				-- rhnUserGroup.max_members gets fixed in a trigger, no
				-- need to do that here
				delete
					from	rhnUserGroupMembers
					where	user_group_id = ug.user_group_id
						and user_id = ug.user_id;
			end loop;
		elsif type_in = 'S' then
			update		rhnServerGroup
				set		max_members = quantity_in
				where	id = group_id_in;
			for sg in servergroups loop
				unentitle_server(sg.server_id, sg.label);
				rhn_channel.clear_subscriptions(sg.server_id);
			end loop;
		end if;
	end prune_group;
	procedure set_group_count (
		customer_id_in in number,
		type_in in char,
		group_type_in in number,
		quantity_in in number
	) is
		group_id number;
		quantity number;
	begin
		quantity := quantity_in;
		if quantity is not null and quantity < 0 then
			quantity := 0;
		end if;
		if type_in = 'U' then
			select	rug.id
			into	group_id
			from	rhnUserGroup rug
			where	1=1
				and rug.org_id = customer_id_in
				and rug.group_type = group_type_in;
		elsif type_in = 'S' then
			select	rsg.id
			into	group_id
			from	rhnServerGroup rsg
			where	1=1
				and rsg.org_id = customer_id_in
				and rsg.group_type = group_type_in;
		end if;
		rhn_entitlements.prune_group(
			group_id,
			type_in,
			quantity
		);
	exception
		when no_data_found then
			if type_in = 'U' then
				insert into rhnUserGroup (
						id, name, description, max_members, current_members,
						group_type, org_id, created, modified
					) (
						select	rhn_user_group_id_seq.nextval, name, name,
								quantity, 0, id, customer_id_in,
								sysdate, sysdate
						from	rhnUserGroupType
						where	id = group_type_in
				);
			elsif type_in = 'S' then
				insert into rhnServerGroup (
						id, name, description, max_members, current_members,
						group_type, org_id, created, modified
					) (
						select	rhn_server_group_id_seq.nextval, name, name,
								quantity, 0, id, customer_id_in,
								sysdate, sysdate
						from	rhnServerGroupType
						where	id = group_type_in
				);
			end if;
	end set_group_count;
	procedure prune_family (
		customer_id_in in number,
		channel_family_id_in in number,
		quantity_in in number
	) is
		cursor serverchannels is
			select	sc.server_id,
					sc.channel_id
			from	rhnServerChannel sc,
					rhnChannelFamilyMembers cfm
			where	1=1
				and cfm.channel_family_id = channel_family_id_in
				and cfm.channel_id = sc.channel_id
				and server_id in (
					select	server_id
					from	(
						select	server_id,
								time,
								rownum row_number
						from	(
							select	rs.id					server_id,
									rcfm.modified			time
							from	rhnServer				rs,
									rhnServerChannel		rsc,
									rhnChannelFamilyMembers	rcfm
							where	1=1
								and rs.org_id = customer_id_in
								and rs.id = rsc.server_id
								and rsc.channel_id = rcfm.channel_id
								and rcfm.channel_family_id =
									channel_family_id_in
							order by time asc
						)
					)
					where row_number > quantity_in
				);
	begin
		-- if we get a null customer_id, this is completely bogus.
		if customer_id_in is null then
			return;
		end if;
		update		rhnPrivateChannelFamily
			set		max_members = quantity_in
			where	1=1
				and org_id = customer_id_in
				and channel_family_id = channel_family_id_in;
		for sc in serverchannels loop
			rhn_channel.unsubscribe_server(sc.server_id, sc.channel_id, 1, 1);
		end loop;
	end prune_family;

	procedure set_family_count (
		customer_id_in in number,
		channel_family_id_in in number,
		quantity_in in number
	) is
		cursor privperms is
			select	1
			from	rhnPrivateChannelFamily
			where	org_id = customer_id_in
				and channel_family_id = channel_family_id_in;
		cursor pubperms is
			select	o.id org_id
			from	web_customer o,
					rhnPublicChannelFamily pcf
			where	pcf.channel_family_id = channel_family_id_in;
		quantity number;
		done number := 0;
	begin
		quantity := quantity_in;
		if quantity is not null and quantity < 0 then
			quantity := 0;
		end if;
		if customer_id_in is not null then
			for perm in privperms loop
				rhn_entitlements.prune_family(
					customer_id_in,
					channel_family_id_in,
					quantity
				);
				update rhnPrivateChannelFamily
					set max_members = quantity
					where org_id = customer_id_in
						and channel_family_id = channel_family_id_in;
				return;
			end loop;

			insert into rhnPrivateChannelFamily (
					channel_family_id, org_id, max_members, current_members
				) values (
					channel_family_id_in, customer_id_in, quantity, 0
				);
			return;
		end if;
		for perm in pubperms loop
			if quantity = 0 then
				rhn_entitlements.prune_family(
					perm.org_id,
					channel_family_id_in,
					quantity
				);
				if done = 0 then
					delete from rhnPublicChannelFamily
						where channel_family_id = channel_family_id_in;
				end if;
			end if;
			done := 1;
		end loop;
		-- if done's not 1, then we don't have any entitlements
		if done != 1 then
			insert into rhnPublicChannelFamily (
					channel_family_id
				) values (
					channel_family_id_in
				);
		end if;
	end set_family_count;
	-- this expects quantity_in to be the number of available slots, not the
	-- max_members of the server group.  If you give it too many, it'll fail
	-- and raise servergroup_max_members.
	-- We should NEVER run this unless we're SURE that we won't
	-- be violating the max.
	procedure entitle_last_modified_servers (
		customer_id_in in number,
		type_label_in in varchar2,
		quantity_in in number
	) is
		-- find the servers that aren't currently in slots
		cursor servers(cid_in in number, quant_in in number) is
			select	server_id
			from	(
						select	rownum row_number,
								server_id
						from	(
									select	rs.id server_iD
									from	rhnServer rs
									where	1=1
										and rs.org_id = cid_in
										and not exists (
											select	1
											from	rhnServerGroup sg,
													rhnServerGroupMembers rsgm
											where	rsgm.server_id = rs.id
												and rsgm.server_group_id = sg.id
												and sg.group_type is not null
										)
									order by modified desc
								)
					)
			where	row_number <= quant_in;
	begin
		for server in servers(customer_id_in, quantity_in) loop
			rhn_entitlements.entitle_server(server.server_id, type_label_in);
		end loop;
	end entitle_last_modified_servers;
	procedure get_available_slots (
		customer_id_in in number,
		type_label_in in varchar2,
		server_group_id_out out number,
		available_out out number,
		upgrade_out out number
	) is
		mgmt_slots_unused number;
		mgmt_slots_used number;
		prov_slots_unused number;
		prov_slots_used number;
		swmgr_slots_unused number;
		sgid number;
	begin
		-- if it's the simple case, do it and get out
		if type_label_in in (
					'sw_mgr_entitled',
					'nonlinux_entitled',
					'monitoring_entitled'
				) then
			begin
				select	max_members - current_members, sg.id
				into	swmgr_slots_unused, sgid
				from	rhnServerGroup		sg,
						rhnServerGroupType	sgt
				where	sgt.label = type_label_in
					and sg.org_id = customer_id_in
					and sg.group_type = sgt.id;

				available_out := swmgr_slots_unused;
				upgrade_out := 0;
				server_group_id_out := sgid;
			exception
				when no_data_found then
					available_out := 0;
					if type_label_in = 'sw_mgr_entitled' then
						available_out := 1;
					end if;
					upgrade_out := 0;
					server_group_id_out := null;
			end;
			return;
		end if;
		begin
			select	sg.current_members,
					sg.max_members - sg.current_members,
					sg.id
			into	mgmt_slots_used,
					mgmt_slots_unused,
					sgid
			from	rhnServerGroup		sg,
					rhnServerGroupType	sgt
			where	sgt.label = 'enterprise_entitled'
				and sg.org_id = customer_id_in
				and sg.group_type = sgt.id;
		exception
			when no_data_found then
				-- if there's no enterprise_entitled group, then
				-- this user doesn't have mgmt or prov at all,
				-- so bail out now.
				available_out := 0;
				upgrade_out := 0;
				server_group_id_out := null;
				return;
		end;
		-- we list all mgmt slots as things you can upgrade to
		-- from basic
		if type_label_in = 'enterprise_entitled' then
			available_out := mgmt_slots_unused;
			upgrade_out := 0;
			server_group_id_out := sgid;
			return;
		end if;
		-- the only thing left is provisioning
		begin
			select	sg.current_members,
					sg.max_members - sg.current_members,
					sg.id
			into	prov_slots_used,
					prov_slots_unused,
					sgid
			from	rhnServerGroup		sg,
					rhnServerGroupType	sgt
			where	sgt.label = 'provisioning_entitled'
				and sg.org_id = customer_id_in
				and sg.group_type = sgt.id;
		exception
			when no_data_found then
				available_out := 0;
				upgrade_out := 0;
				server_group_id_out := null;
				return;
		end;
		-- An example to illustrate what I'm doing to compute upgradable slots
		-- 1) The user buys 3 provisioning entitlements.  This means:
		--      enterprise_entitled max_members = 3, current_members = 0    (prov_slots_unused = 3)
		--      provisioning_entitled max_members = 3, current_members = 0  (prov_slots_unsued = 3)
		--    0 upgrade, 3 available
		-- 2) The user subscribes a system for management.  This means:
		--      enterprise_entitled max_members = 3, current_members = 1    (mgmt_slots_unused = 2)
		--      provisioning_entitled max_members = 3, current_members = 0  (prov_slots_unused = 3)
		--    1 upgrade, 2 available
		-- 3) The user subscribes a system for provisioning.  This means:
		--      enterprise_entitled max_members = 2, current_members = 1    (mgmt_slots_unused = 1)
		--      provisioning_entitled max_members = 3, current_members = 1  (prov_slots_unused = 2)
		--    1 upgrade, 1 available
		-- 4) The user subscribes another provisioning.  I.e.:
		--      enterprise_entitled max_members = 1, current_members = 1    (mgmt_slots_unused = 0)
		--      provisioning_entitled max_members = 3, current_members = 2  (prov_slots_unused = 1)
		--    1 upgrade, 0 available
		-- 5) the user upgrades 1 mgmt to prov.  Here:
		--    1) unsubscribe from mgmt
		--      enterprise_entitled max_members = 1, current_members = 0    (mgmt_slots_unused = 1)
		--      provisioning_entitled max_members = 3, current_members = 2  (prov_slots_unused = 1)
		--    0 upgrade, 1 available
		--    2) subscribe to prov
		--      enterprise_entitled max_members = 0, current_members = 0    (mgmt_slots_unused = 0)
		--      provisioning_entitled max_members = 3, current_members = 3  (prov_slots_unused = 0)
		--    that'll result in 0 upgrade, 0 available
		-- 6) user buys 1 mgmt:
		--      enterprise_entitled max_members = 1, current_members = 0    (mgmt_slots_unused = 1)
		--      provisioning_entitled max_members = 3, current_members = 3  (prov_slots_unused = 0)
		--    -1 on upgrade, 1 on available, BORK, should be 0, 0 (special cased with p-m<0)
		-- 7) user registers a management box
		--      enterprise_entitled max_members = 1, current_members = 1    (mgmt_slots_unused = 0)
		--      provisioning_entitled max_members = 3, current_members = 3  (prov_slots_unused = 0)
		--    0, 0, which is right.
		-- 8) user deletes that management box
		--      enterprise_entitled max_members = 1, current_members = 0    (mgmt_slots_unused = 1)
		--      provisioning_entitled max_members = 3, current_members = 3  (prov_slots_unused = 0)
		--    -1 on upgrade, 1 on available, BORK, should be 0, 0 (special cased with p-m<0)
		-- 9) user buys a provisioning slot
		--      enterprise_entitled max_members = 2, current_members = 0    (mgmt_slots_unused = 2)
		--      provisioning_entitled max_members = 4, current_members = 3  (prov_slots_unused = 1)
		--    -1 upgrade, 0 available, BORK.  special case makes it 1 available, 0 upgrade
		-- 10) user registers a mgmt box
		--      enterprise_entitled max_members = 2, current_members = 1    (mgmt_slots_unused = 1)
		--      provisioning_entitled max_members = 4, current_members = 3  (prov_slots_unused = 1)
		--    0 upgrade, 1 available
		if prov_slots_unused - mgmt_slots_unused < 0 then
			-- swmgr_slots_unused is tmp here
			available_out := prov_slots_unused;
			upgrade_out := 0;
		elsif prov_slots_unused > 0 then
			-- if there's one of each, we list it as available
			-- if there's only a prov slot, then it's upgradable.
			upgrade_out := prov_slots_unused - mgmt_slots_unused;
			available_out := prov_slots_unused - (prov_slots_unused - mgmt_slots_unused);
		else
			upgrade_out := 0;
			available_out := 0;
		end if;
		server_group_id_out := sgid;
		return;
	end get_available_slots;
	procedure prune_everything (
		customer_id_in in number
	) is
		cursor everything is
			-- all our server groups
			select	sg.id					id,
					'S'						type,
					sg.max_members			quantity
			from	rhnServerGroup			sg
			where	sg.org_id = customer_id_in
			union
			-- all our user groups
			select	ug.id					id,
					'U'						type,
					ug.max_members 			quantity
			from	rhnUserGroup			ug
			where	ug.org_id = customer_id_in
			union (
			-- all the channel families we have perms to
			select	cfp.channel_family_id	id,
					'C'						type,
					cfp.max_members			quantity
			from	rhnOrgChannelFamilyPermissions cfp
			where	cfp.org_id = customer_id_in
			union
			-- plus all the ones we're using that we have no perms for
			select	cfm.channel_family_id	id,
					'C'						type,
					0						quantity
			from	rhnChannelFamily		cf,
					rhnChannelFamilyMembers	cfm,
					rhnServerChannel		sc,
					rhnServer				s
			where	s.org_id = customer_id_in
				and s.id = sc.server_id
				and sc.channel_id = cfm.channel_id
				and cfm.channel_family_id = cf.id
				and cf.org_id is not null
				and cf.org_id != customer_id_in
				and not exists (
					select	1
					from	rhnOrgChannelFamilyPermissions cfp
					where	cfp.org_id = customer_id_in
						and cfp.channel_family_id = cfm.channel_family_id
					)
			);
	begin
		for one in everything loop
			if one.type in ('U','S') then
				prune_group(one.id, one.type, one.quantity);
			else
				prune_family(customer_id_in, one.id, one.quantity);
			end if;
		end loop;
	end prune_everything;
	procedure subscribe_newest_servers (
		customer_id_in in number
	) is
		-- find servers without base channels
		cursor servers(cid_in in number) is
			select	s.id
			from	rhnServer			s
			where	1=1
				and s.org_id = cid_in
				and not exists (
						select 1
						from	rhnChannel			c,
								rhnServerChannel	sc
						where	sc.server_id = s.id
							and sc.channel_id = c.id
							and c.parent_channel is null
					)
			order by s.modified desc;
		channel_id number;
	begin
		for server in servers(customer_id_in) loop
			channel_id := rhn_channel.guess_server_base(server.id);
			if channel_id is not null then
				begin
					rhn_channel.subscribe_server(server.id, channel_id);
					commit;
				-- exception is really channel_family_no_subscriptions
				exception
					when others then
						null;
				end;
			end if;
		end loop;
	end subscribe_newest_servers;
end rhn_entitlements;
/
show errors

-- 013.rhn.sql only does rhn_ep, no sat.

-- 014.rhn.sql

alter table rhnServerTokenRegs drop constraint rhn_srv_reg_tok_sid_uq;

-- 015.rhn.sql

create or replace procedure fix_keys is
	cursor keys is
		select	reg_token_id, token,
			replace(token,' !"#$%&''()*+,./:;<=>?@\]^`{|}~','')
				new_token
		from	rhnActivationKey;
begin
	for key in keys loop
		update	rhnActivationKey
		    set token = key.new_token
		  where reg_token_id = key.reg_token_id
		    and token = key.token;
	end loop;
	commit;
end fix_keys;
/
show errors

begin fix_keys();
end;
/
show errors

drop procedure fix_keys;

-- 016.rhn.sql

alter table rhnRegToken drop constraint rhn_reg_token_uid_fk;

alter table rhnRegToken add constraint rhn_reg_token_uid_fk
	foreign key (user_id) references web_contact(id)
	on delete set null;

-- 017.rhn.sql

create sequence rhn_actionks_id_seq;

alter table rhnActionKickstart add (id number);

update rhnActionKickstart set id = rhn_actionks_id_seq.nextval;

commit;

alter table rhnActionKickstart modify (
	id		number
			constraint rhn_actionks_id_nn not null
);

create index rhn_actionks_id_idx
	on rhnActionKickstart( id )
	storage ( freelists 16 )
	initrans 32;

alter table rhnActionKickstart add constraint rhn_actionks_id_pk
	primary key ( id );

-- 020.rhn.sql

create table
rhnActionKickstartFileList
(
	action_ks_id		number
				constraint rhn_actionksfl_aksid_nn not null
				constraint rhn_actionksfl_askid_fk
					references rhnActionKickstart(id)
					on delete cascade,
	file_list_id		number
				constraint rhn_actionksfl_flid_nn not null
				constraint rhn_actionksfl_flid_fk
					references rhnFileList(id)
					on delete cascade,
	created			date default (sysdate)
				constraint rhn_actionksfl_creat_nn not null,
	modified		date default (sysdate)
				constraint rhn_actionksfl_mod_nn not null
)
	storage ( freelists 16 )
	initrans 32;

create unique index rhn_actionksfl_aksid_flid_uq
	on rhnActionKickstartFileList( action_ks_id, file_list_id )
	storage ( freelists 16 )
	initrans 32;
create index rhn_actionksfl_flid_idx
	on rhnActionKickstartFileList( file_list_id )
	storage ( freelists 16 )
	initrans 32;

create or replace trigger
rhn_actionksfl_mod_trig
before insert or update on rhnActionKickstartFileList
for each row
begin
	:new.modified := sysdate;
end rhn_actionksfl_mod_trig;
/
show errors

-- 023.rhn.sql

alter table rhnKickstartPreserveFileList
	drop constraint rhn_kspreservefl_flid_fk;
alter table rhnKickstartPreserveFileList
	add constraint rhn_kspreservefl_flid_fk
	foreign key ( file_list_id ) references rhnFileList(id)
	on delete cascade;
alter table rhnServerPreserveFileList drop constraint rhn_serverpfl_flid_fk;
alter table rhnServerPreserveFileList add constraint rhn_serverpfl_flid_fk
	foreign key ( file_list_id ) references rhnFileList(id)
	on delete cascade;

-- 024.rhn.sql

create procedure tmp_fix_package_sync is
begin
	begin
		insert into rhnPackageSyncBlacklist(package_name_id)
			values (lookup_package_name('gpg-pubkey'));
	exception when others then null;
	end;
	begin
		insert into rhnPackageSyncBlacklist(package_name_id)
			values (lookup_package_name('rhns-ca-cert'));
	exception when others then null;
	end;
	begin
		insert into rhnPackageSyncBlacklist(package_name_id)
		values (lookup_package_name('rhn-org-trusted-ssl-cert'));
	exception when others then null;
	end;
	commit;
end tmp_fix_package_sync;
/
show errors
begin tmp_fix_package_sync();
end;
/
show errors
drop procedure tmp_fix_package_sync;

-- 025.rhn.sql

create table
    rhn_command_target
(
    recid       number   (12)
        constraint rhn_cmdtg_recid_nn not null,
    target_type varchar2 (10)
        constraint rhn_cmdtg_target_ty_nn not null
        constraint cmdtg_target_type_ck check
            (target_type in ('cluster','node')),
    customer_id number   (12)
        constraint rhn_cmdtg_cust_id_nn not null
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_command_target
    is 'cmdtg  command target (cluster or node)';
create unique index rhn_cmdtg_recid_pk
    on rhn_command_target ( recid, target_type )
    storage ( freelists 16 )
    initrans 32;
alter table rhn_command_target
    add constraint rhn_cmdtg_recid_target_type_pk
    primary key (recid, target_type);
create index rhn_cmdtg_cid_idx
        on rhn_command_target( customer_id )
        storage ( freelists 16 )
        initrans 32;
alter table rhn_command_target
    add constraint rhn_cmdtg_cstmr_customer_id_fk
    foreign key ( customer_id )
    references web_customer( id );
create sequence rhn_command_target_recid_seq;

-- 026.rhn.sql

create table
rhn_sat_cluster
(
    recid                   number   (12)
        constraint rhn_satcl_recid_nn not null
        constraint rhn_satcl_recid_pk primary key,
    target_type             varchar2 (10) default 'cluster'
        constraint rhn_satcl_target_type_nn not null
        constraint rhn_satcl_target_type_ck check (target_type in ('cluster')),
    customer_id             number   (12)
        constraint rhn_satcl_cust_id_nn not null,
    description             varchar2 (255)
        constraint rhn_satcl_desc_nn not null,
    last_update_user        varchar2 (40),
    last_update_date        date,
    physical_location_id    number   (12)
        constraint rhn_satcl_location_id_nn not null,
    public_key              varchar2 (2000),
    vip                     varchar2 (15),
    deployed                char     (1)  default '0'
        constraint rhn_satcl_deployed_nn not null
        constraint rhn_satcl_deployed_ck check (deployed in ('0','1')),
    pem_public_key          varchar2 (2000),
    pem_public_key_hash     varchar2 (20)
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_sat_cluster
    is 'satcl  satellite cluster';
alter table rhn_sat_cluster
    add constraint rhn_satcl_cmdtg_recid_tar_fk
    foreign key ( recid, target_type )
    references rhn_command_target( recid, target_type )
    on delete cascade;
create index rhn_satcl_cid_idx
        on rhn_sat_cluster( customer_id )
        storage ( freelists 16 )
        initrans 32;
alter table rhn_sat_cluster
    add constraint rhn_satcl_cstmr_customer_id_fk
    foreign key ( customer_id )
    references web_customer( id );

-- 027.rhn.sql

create table
rhn_command_class
(
    class_name  varchar2 (40)
        constraint rhn_comcl_class_name_nn not null
        constraint rhn_comcl_class_name_pk primary key
)
    storage ( freelists 16 )
    initrans 32;
COMMENT ON TABLE rhn_command_class IS 'COMCL Command classes';

-- 028.rhn.sql

create table
rhn_command_groups
(
    group_name  varchar2 (10)
        constraint rhn_cmdgr_group_name_nn not null
        constraint rhn_cmdgr_group_name_pk primary key,
    description varchar2 (80)
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_command_groups
    is 'CMDGR  Command group definitions';

-- 029.rhn.sql

create table
rhn_command_requirements
(
    name        varchar2 (40)
        constraint rhn_creqs_name_nn not null
        constraint rhn_creqs_name_pk primary key,
    description varchar2 (4000)
        constraint rhn_creqs_description_nn not null
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_command_requirements
    is 'creqs storage for system requirements for commands';

-- 030.rhn.sql

create table
rhn_command
(
    recid               number   (12)
        constraint rhn_cmmnd_recid_nn not null
        constraint rhn_cmmnd_recid_pk primary key,
    name                varchar2 (40)
        constraint rhn_cmmnd_name_nn not null,
    description         varchar2 (80)
        constraint rhn_cmmnd_desc_nn not null,
    group_name          varchar2 (40),
    allowed_in_suite    char     (1) default '1'
        constraint rhn_cmmnd_allowed_nn not null,
    command_class       varchar2 (255) default '/home/nocpulse/libexec/plugin'
        constraint rhn_cmmnd_class_nn not null,
    enabled             char     (1) default '1'
        constraint rhn_cmmnd_enabled_nn not null,
    for_host_probe      char     (1) default '0'
        constraint rhn_cmmnd_host_probe_nn not null,
    last_update_user    varchar2 (40),
    last_update_date    date,
    system_requirements varchar2 (40),
    version_support     varchar2 (1024),
    help_url            varchar2 (1024)
)
    storage( pctincrease 1 freelists 16 )
    initrans 32;
comment on table rhn_command
    is 'CMMND A command that probes can run';
comment on column rhn_command.command_class
    is 'Program to run ';
comment on column rhn_command.enabled
    is 'Whether command should be usable';
comment on column rhn_command.for_host_probe
    is 'Whether this is one of the host-alive checks';
create unique index rhn_cmmnd_name_uq
    on rhn_command ( name )
    storage( pctincrease 1 freelists 16 )
    initrans 32;
create unique index rhn_cmmnd_recid_comm_cl_uq
    on rhn_command ( recid, command_class )
    storage( pctincrease 1 freelists 16 )
    initrans 32;
alter table rhn_command
    add constraint rhn_cmmnd_name_uq
    unique ( recid, command_class );
alter table rhn_command
    add constraint rhn_cmmnd_cmdgr_group_name_fk
    foreign key ( group_name )
    references rhn_command_groups( group_name );
alter table rhn_command
    add constraint rhn_cmmnd_comcl_class_name_fk
    foreign key ( command_class )
    references rhn_command_class( class_name );
alter table rhn_command
    add constraint rhn_cmmnd_sys_reqs_fk
    foreign key ( system_requirements )
    references rhn_command_requirements( name )
    on delete cascade;
create sequence rhn_commands_recid_seq
    start with 305;

-- 031.rhn.sql

create table
rhn_probe
(
    recid                            number   (12)
        constraint rhn_probe_recid_nn not null
        constraint rhn_probe_recid_pk primary key,
    probe_type                       varchar2 (15)
        constraint rhn_probe_probe_type_nn not null,
    description                      varchar2 (255),
    customer_id                      number   (12)
        constraint rhn_probe_cust_id_nn not null,
    command_id                       number   (16)
        constraint rhn_probe_command_id_nn not null,
    contact_group_id                 number   (12),
    notify_critical                  char     (1),
    notify_warning                   char     (1),
    notify_unknown                   char     (1),
    notify_recovery                  char     (1),
    notification_interval_minutes    number   (16)
        constraint rhn_probe_notif_int_nn not null,
    check_interval_minutes           number   (16)
        constraint rhn_probe_chk_int_nn not null,
    retry_interval_minutes           number   (16)
        constraint rhn_probe_retry_int_nn not null,
    max_attempts                     number   (16),
    last_update_user                 varchar2 (40),
    last_update_date                 date
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_probe
    is 'probe  probe definitions';
create unique index rhn_probe_recid_probe_type_uq
    on rhn_probe ( recid, probe_type )
    storage ( freelists 16 )
    initrans 32;
create index rhn_probe_check_command_id_idx
    on rhn_probe ( command_id )
    storage ( freelists 16 )
    initrans 32;
create index rhn_probe_customer_id_idx
    on rhn_probe ( customer_id )
    storage ( freelists 16 )
    initrans 32;
create index rhn_probe_probe_type_idx
    on rhn_probe ( probe_type )
    storage ( freelists 16 )
    initrans 32;
alter table rhn_probe
    add constraint rhn_probe_recid_probe_type_uq
    unique ( recid, probe_type );
alter table rhn_probe
    add constraint rhn_probe_cmmnd_command_id_fk
    foreign key ( command_id )
    references rhn_command( recid );
alter table rhn_probe
    add constraint rhn_probe_cstmr_customer_id_fk
    foreign key ( customer_id )
    references web_customer( id );
create sequence rhn_probes_recid_seq;

-- 032.rhn.sql

create table
rhn_check_probe
(
    probe_id        number   (12)
        constraint rhn_chkpb_probe_id_nn not null
        constraint rhn_chkpb_probe_id_pk primary key,
    probe_type      varchar2 (12) default 'check'
        constraint rhn_chk_probe_type_nn not null
        constraint chkpb_probe_type_ck
            check (probe_type='check'),
    host_id         number   (12)
        constraint rhn_chk_host_id_nn not null,
    sat_cluster_id  number   (12)
        constraint rhn_chk_sat_cluster_id_nn not null
)
    storage ( pctincrease 1 freelists 16 )
    initrans 32;
comment on table rhn_check_probe
    is 'CHKPB  Service check probe definitions (monitoring)';
create index rhn_chkpb_host_id_idx
    on rhn_check_probe ( host_id )
    storage( pctincrease 1 freelists 16 )
    initrans 32;
create index rhn_chkpb_sat_cluster_id_idx
    on rhn_check_probe ( sat_cluster_id )
    storage( pctincrease 1 freelists 16 )
    initrans 32;
alter table rhn_check_probe
    add constraint rhn_chkpb_host_id_fk
    foreign key ( host_id )
    references rhnServer( id );
alter table rhn_check_probe
    add constraint rhn_chkpb_recid_probe_typ_fk
    foreign key ( probe_id, probe_type )
    references rhn_probe( recid, probe_type )
    on delete cascade;
alter table rhn_check_probe
    add constraint rhn_chkpb_satcl_sat_cl_id_fk
    foreign key ( sat_cluster_id )
    references rhn_sat_cluster( recid )
    on delete cascade;

-- 033.rhn.sql

create table
rhn_check_suite_probe
(
    probe_id        number   (12)
        constraint rhn_ckspb_probe_id_nn not null
        constraint rhn_ckspb_probe_id_pk primary key,
    probe_type      varchar2 (12) default 'suite'
        constraint rhn_ckspb_probe_type_nn not null
        constraint rhn_ckspb_probe_type_ck check ( probe_type = 'suite' ),
    check_suite_id  number   (12)
        constraint rhn_ckspb_check_suite_id_nn not null
)
    storage ( pctincrease 1 freelists 16 )
    initrans 32;
comment on table rhn_check_suite_probe
    is 'CKSPB  Check suite probe definitions (monitoring)';
create index rhn_ckspb_check_suite_id_idx
    on rhn_check_suite_probe ( check_suite_id )
    storage( pctincrease 1 freelists 16 )
    initrans 32;

-- changes/034.rhn.sql

create table
rhn_command_center_state
(
    cust_admin_access_allowed char     (1)
        constraint rhn_cmdcs_allowed_nn not null,
    reason                    varchar2 (2000)
        constraint rhn_cmdcs_reason_nn not null,
    last_update_user          varchar2 (40)
        constraint rhn_cmdcs_last_user_nn not null,
    last_update_date          date
        constraint rhn_cmdcs_last_date_nn not null
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_command_center_state
    is 'CMDCS  State of the command center (monitoring)';

-- changes/035.rhn.sql

create table
rhn_widget
(
    name                varchar2 (20)
        constraint rhn_wdget_name_nn not null
        constraint rhn_wdget_name_pk primary key,
    description         varchar2 (80)
        constraint rhn_wdget_desc_nn not null,
    last_update_user    varchar2 (40),
    last_update_date    date
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_widget
    is 'wdget  text,password,menu,radio,checkbox';

-- changes/036.rhn.sql

create table
rhn_command_parameter
(
    command_id              number   (12)
        constraint rhn_cparm_command_id_nn  not null,
    param_name              varchar2 (40)
        constraint rhn_cparm_param_name_nn not null,
    param_type              varchar2 (10) default 'config'
        constraint rhn_cparm_param_type_nn  not null,
    data_type_name          varchar2 (10)
        constraint rhn_cparm_data_type_name_nn  not null,
    description             varchar2 (80)
        constraint rhn_cparm_description_nn not null,
    mandatory               char     (1) default '0'
        constraint rhn_cparm_mandatory_nn  not null,
    default_value           varchar2 (1024),
    min_value               number,
    max_value               number,
    field_order             number
        constraint rhn_cparm_field_order_nn not null,
    field_widget_name       varchar2 (20)
        constraint rhn_cparm_field_widget_name_nn not null,
    field_visible_length    number,
    field_maximum_length    number,
    field_visible           char     (1) default '1'
        constraint rhn_cparm_field_visible_nn not null,
    default_value_visible   char     (1) default '1'
        constraint rhn_cparm_def_value_vis_nn not null,
    last_update_user        varchar2 (40),
    last_update_date        date
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_command_parameter
    is 'CPARM  A parameter for a particular command';
comment on column rhn_command_parameter.field_visible
    is 'if default is $HOSTADDRESS$, param is marked as default not visible ';
create unique index rhn_cparm_cmd_id_param_name_uq
    ON rhn_command_parameter ( command_id, param_name )
    storage ( freelists 16 )
    initrans 32;
create unique index rhn_cparm_id_p_name_p_type_uq
    on rhn_command_parameter ( command_id, param_name, param_type )
    storage ( freelists 16 )
    initrans 32;
create unique index rhn_cparm_cmd_id_field_orde_uq
    on rhn_command_parameter (command_id, field_order)
    storage ( freelists 16 )
    initrans 32;
alter table rhn_command_parameter
    add constraint rhn_cparm_id_parm_name_pk
    primary key ( command_id, param_name );
alter table rhn_command_parameter
    add constraint rhn_cparm_id_p_name_p_type_uq
    unique ( command_id, param_name, param_type );
alter table rhn_command_parameter
    add constraint rhn_cparm_id_field_orde_uq
    unique ( command_id, field_order );
alter table rhn_command_parameter
    add constraint rhn_cparm_cmd_command_id_fk
    foreign key ( command_id )
    references rhn_command( recid )
    on delete cascade;


-- changes/037.rhn.sql

create table
rhn_quanta
(
    quantum_id          varchar2 (10)
        constraint rhn_qnta0_quantum_id_nn not null
        constraint rhn_qnta0_quantum_id_pk primary key,
    basic_unit_id       varchar2 (20),
    description         varchar2 (200),
    last_update_user    varchar2 (40),
    last_update_date    date
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_quanta
    is 'qnta0  quanta definitions';

-- changes/038.rhn.sql

create table
rhn_units
(
    unit_id             varchar2 (10)
        constraint rhn_units_unit_id_nn not null
        constraint rhn_units_unit_id_pk primary key,
    quantum_id          varchar2 (10)
        constraint rhn_units_quantum_id_nn not null,
    unit_label          varchar2 (20),
    description         varchar2 (200),
    to_base_unit_fn     varchar2 (2000),
    from_base_unit_fn   varchar2 (2000),
    validate_fn         varchar2 (2000),
    last_update_user    varchar2 (40),
    last_update_date    date
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_units
    is 'units  unit definitions';
create index rhn_units_quantum_id_idx
    on rhn_units ( quantum_id )
    storage ( freelists 16 )
    initrans 32;
alter table rhn_units
    add constraint rhn_units_qnta0_quantum_id_fk
    foreign key ( quantum_id )
    references rhn_quanta( quantum_id );

-- changes/039.rhn.sql

create table
rhn_metrics
(
    metric_id           varchar2 (40)
        constraint rhn_metric_metric_id_nn not null,
    storage_unit_id     varchar2 (10)
        constraint rhn_metric_storage_id_nn not null,
    description         varchar2 (200),
    last_update_user    varchar2 (40),
    last_update_date    date,
    label               varchar2 (40),
    command_class       varchar2 (255) default 'nothing'
        constraint rhn_metric_cmd_class_nn not null
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_metrics
    is 'metrc  metric definitions';
create unique index rhn_metrc_cmd_cl_met_id_pk
    on rhn_metrics ( command_class, metric_id )
    storage ( freelists 16 )
    initrans 32;
create index rhn_metrc_storage_unit_id_idx
    on rhn_metrics ( storage_unit_id )
    storage ( freelists 16 )
    initrans 32;
alter table rhn_metrics
    add constraint rhn_metrc_cmd_cl_metric_id_pk
    primary key ( command_class, metric_id );
alter table rhn_metrics
    add constraint rhn_metrc_comcl_cmd_class_fk
    foreign key ( command_class )
    references rhn_command_class( class_name );
alter table rhn_metrics
    add constraint rhn_metrc_uts_stor_ut_id_fk
    foreign key ( storage_unit_id )
    references rhn_units( unit_id );

-- changes/040.rhn.sql

create table
rhn_threshold_type
(
    name                varchar2 (10)
        constraint rhn_trtyp_name_nn not null
        constraint rhn_trtyp_name_pk primary key,
    description         varchar2 (80)
        constraint rhn_trtyp_desc_nn not null,
    ordinal             number   (3)
        constraint rhn_trtyp_ord_nn not null,
    last_update_user    varchar2 (40),
    last_update_date    date
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_threshold_type
    is 'trtyp threshold type:warn_min, warn_max, crit_min, crit_max';

-- changes/041.rhn.sql

create table
rhn_command_param_threshold
(
    command_id              number   (12)
        constraint rhn_coptr_command_id_nn not null,
    param_name              varchar2 (40)
        constraint rhn_coptr_param_name_nn not null,
    param_type              varchar2 (10)
        constraint rhn_coptr_param_type_nn  not null
        constraint rhn_coptr_param_type_ck check (param_type='threshold'),
    threshold_type_name     varchar2 (10)
        constraint rhn_coptr_thres_name_nn not null,
    threshold_metric_id     varchar2 (40)
        constraint rhn_coptr_thres_met_id_nn not null,
    last_update_user        varchar2 (40),
    last_update_date        date,
    command_class           varchar2 (255)
        constraint rhn_coptr_command_class_nn not null
)
    storage ( pctincrease 1 freelists 16 )
    initrans 32;
comment on table rhn_command_param_threshold
    is 'coptr  a parameter for a particular command';
create unique index rhn_coptr_id_p_name_p_type_pk
    on rhn_command_param_threshold ( command_id, param_name, param_type )
    storage ( freelists 16 )
    initrans 32;
alter table rhn_command_param_threshold
    add constraint rhn_coptr_id_p_name_p_type_pk
        primary key ( command_id, param_name, param_type );
alter table rhn_command_param_threshold
    add constraint rhn_coptr_cmd_id_cmd_cl_fk
    foreign key ( command_id, command_class )
    references rhn_command( recid, command_class )
    on delete cascade;
alter table rhn_command_param_threshold
    add constraint rhn_coptr_m_thr_m_cmd_cl_fk
    foreign key ( command_class, threshold_metric_id )
    references rhn_metrics( command_class, metric_id )
    on delete cascade;
alter table rhn_command_param_threshold
    add constraint rhn_coptr_thrtp_thres_type_fk
    foreign key ( threshold_type_name )
    references rhn_threshold_type( name );

-- changes/042.rhn.sql

create table
rhn_command_queue_commands
(
    recid               number   (12)
        constraint rhn_cqcmd_recid_nn not null
        constraint rhn_cqcmd_recid_pk primary key,
    description         varchar2 (40)
        constraint rhn_cqcmd_description_nn not null,
    notes               varchar2 (2000),
    command_line        varchar2 (2000)
        constraint rhn_cqcmd_command_line_nn not null,
    permanent           char     (1)
        constraint rhn_cqcmd_permanent_nn not null,
    restartable         char     (1)
        constraint rhn_cqcmd_restartable_nn not null,
    effective_user      varchar2 (40)
        constraint rhn_cqcmd_effective_usr_nn not null,
    effective_group     varchar2 (40)
        constraint rhn_cqcmd_effective_grp_nn not null,
    last_update_user    varchar2 (40),
    last_update_date    date
)
    storage ( pctincrease 1 freelists 16 )
    initrans 32;
comment on table rhn_command_queue_commands
    is 'cqcmd  command queue command definitions';
create sequence rhn_command_q_comm_recid_seq
    start with 100;

-- changes/043.rhn.sql

create table
rhn_command_queue_instances
(
    recid               number   (12)
        constraint rhn_cqins_recid_nn not null
        constraint rhn_cqins_recid_pk primary key,
    command_id          number   (12)
        constraint rhn_cqins_command_id_nn not null,
    notes               varchar2 (2000),
    date_submitted      date
        constraint rhn_cqins_date_submitted_nn not null,
    expiration_date     date
        constraint rhn_cqins_expiration_date_nn not null,
    notify_email        varchar2 (50),
    timeout             number   (5),
    last_update_user    varchar2 (40),
    last_update_date    date
)
    storage ( pctincrease 1 freelists 16 )
    initrans 32;
comment on table rhn_command_queue_instances
    is 'cqins  command queue instance definitions';
create index rhn_cqins_command_id_idx
    on rhn_command_queue_instances ( command_id )
    storage ( pctincrease 1 freelists 16 )
    initrans 32
    logging;
alter table rhn_command_queue_instances
    add constraint rhn_cqins_cqcmd_command_id_fk
    foreign key ( command_id )
    references rhn_command_queue_commands( recid );
create sequence rhn_command_q_inst_recid_seq;

-- changes/044.rhn.sql

create table
rhn_command_queue_instances_bk
(
    recid               number   (12)
        constraint rhn_cqinsbk_recid_nn not null,
    command_id          number   (12)
        constraint rhn_cqinsbk_command_id_nn not null,
    notes               varchar2 (2000),
    date_submitted      date
        constraint rhn_cqinsbk_date_sub_nn not null,
    expiration_date     date
        constraint rhn_cqinsbk_exp_date_nn not null,
    notify_email        varchar2 (50),
    timeout             number   (5),
    last_update_user    varchar2 (40),
    last_update_date    date
)
    storage ( pctincrease 1 freelists 16 )
    initrans 32;

-- changes/045.rhn.sql

create table
rhn_command_queue_execs
(
    instance_id         number   (12)
        constraint rhn_cqexe_instance_id_nn not null,
    netsaint_id         number   (12)
        constraint rhn_cqexe_netsaint_id_nn not null,
    date_executed       date,
    exit_status         number   (5),
    execution_time      number   (10,6),
    stdout              varchar2 (4000),
    stderr              varchar2 (4000),
    last_update_date    date,
    target_type         varchar2 (10)
        constraint rhn_cqexe_target_type_nn not null
)
    storage ( pctincrease 1 freelists 16 )
    initrans 32;
comment on table rhn_command_queue_execs
    is 'cqexe  command queue execution records';
create unique index rhn_cqexe_inst_id_nsaint_pk
    on rhn_command_queue_execs ( instance_id, netsaint_id );
create index rhn_command_queue_netsaint_idx
    on rhn_command_queue_execs ( netsaint_id )
    storage( pctincrease 1 freelists 16 )
    initrans 32;
create index rhn_cqexe_instance_id_idx
    on rhn_command_queue_execs ( instance_id )
    storage( pctincrease 1 freelists 16 )
    initrans 32;
create index rhn_cqexe_date_executed_idx
    on rhn_command_queue_execs ( date_executed )
    storage( pctincrease 1 freelists 16 )
    initrans 32;
alter table rhn_command_queue_execs
    add constraint rhn_cqexe_inst_id_nsaint_pk
    primary key ( instance_id, netsaint_id );
alter table rhn_command_queue_execs
    add constraint rhn_cqexe_cqins_inst_id_fk
    foreign key ( instance_id )
    references rhn_command_queue_instances( recid )
    on delete cascade;
alter table rhn_command_queue_execs
    add constraint rhn_cqexe_satcl_nsaint_id_fk
    foreign key ( netsaint_id, target_type )
    references rhn_command_target( recid, target_type )
    on delete cascade;

-- changes/046.rhn.sql

create table
rhn_command_queue_execs_bk
(
    instance_id         number   (12)
        constraint rhn_cqcmdbk_instance_id_nn not null,
    netsaint_id         number   (12)
        constraint rhn_cqcmdbk_netsaint_id_nn not null,
    date_accepted       date,
    date_executed       date,
    exit_status         number   (5),
    execution_time      number   (10),
    stdout              varchar2 (4000),
    stderr              varchar2 (4000),
    last_update_date    date,
    target_type         varchar2 (10)
        constraint rhn_cqcmdbk_target_type_nn not null
)
    storage ( pctincrease 1 freelists 16 )
    initrans 32;

-- changes/047.rhn.sql

create table
rhn_command_queue_params
(
    instance_id     number   (12)
        constraint rhn_cqprm_instance_id_nn not null,
    ord             number   (3)
        constraint rhn_cqprm_ord_nn not null,
    value           varchar2 (1024)
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_command_queue_params
    is 'cqprm   command queue parameter definitions';
create unique index rhn_cqprm_instance_id_ord_pk
    on rhn_command_queue_params ( instance_id, ord )
    storage( pctincrease 1 freelists 16 )
    initrans 32;
alter table rhn_command_queue_params
    add constraint rhn_cqprm_instance_id_ord_pk
    primary key ( instance_id, ord );
alter table rhn_command_queue_params
    add constraint rhn_cqprm_cqins_instance_id_fk
    foreign key ( instance_id )
    references rhn_command_queue_instances( recid )
    on delete cascade;

-- changes/048.rhn.sql

create table
rhn_command_queue_sessions
(
    contact_id          number   (12)
        constraint rhn_cqses_contact_id_nn not null,
    session_id          varchar2 (255),
    expiration_date     date,
    last_update_user    varchar2 (40),
    last_update_date    date
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_command_queue_sessions
    is 'cqses  command queue sessions';
create unique index rhn_cqses_cid_uq
        on rhn_command_queue_sessions( contact_id )
        storage ( freelists 16 )
        initrans 32;
alter table rhn_command_queue_sessions
    add constraint rhn_cqses_cntct_contact_idfk
    foreign key ( contact_id )
    references web_contact( id );

-- changes/049.rhn.sql

create table
rhn_config_group
(
    name        varchar2 (255)
        constraint rhn_confg_name_nn not null
        constraint rhn_confg_name_pk primary key,
    description varchar2 (255)
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_config_group
    is 'confg  configuration group definition:general,mail,cf_db';

-- changes/050.rhn.sql

create table
rhn_environment
(
    name            varchar2 (255)
        constraint rhn_envir_name_nn not null
        constraint rhn_envir_name_pk primary key,
    description     varchar2 (255)
)
    storage ( pctincrease 1 freelists 16 )
    initrans 32;
comment on table rhn_environment
    is 'envir environments:dev,qa,stage,prod,license';

-- changes/051.rhn.sql

create table
rhn_config_macro
(
    environment         varchar2 (255)
        constraint rhn_confm_env_nn not null,
    name                varchar2 (255)
        constraint rhn_confm_name_nn not null,
    definition          varchar2 (255),
    description         varchar2 (255),
    editable            char     (1) default 0
        constraint rhn_confm_editable_nn not null,
    last_update_user    varchar2 (40),
    last_update_date    date
)
    storage ( pctincrease 1 freelists 16 )
    initrans 32;
comment on table rhn_config_macro
    is 'confm configuration macro def';
create unique index rhn_confm_environment_name_pk
    on rhn_config_macro ( environment, name )
    storage ( freelists 16 )
    initrans 32;
alter table rhn_config_macro
    add constraint rhn_confm_environment_name_pk
    primary key ( environment, name );
alter table rhn_config_macro
    add constraint rhn_confm_envir_environment_fk
    foreign key ( environment )
    references rhn_environment( name );

-- changes/052.rhn.sql

create table
rhn_config_security_type
(
    name        varchar2 (255)
        constraint rhn_conct_name_nn not null
        constraint rhn_conct_name_pk primary key,
    description varchar2 (255)
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_config_security_type
    is 'conct security levels internal,external,all';

-- changes/053.rhn.sql

create table
rhn_config_parameter
(
    group_name          varchar2 (255)
        constraint rhn_confp_group_name_nn not null,
    name                varchar2 (255)
        constraint rhn_confp_name_nn not null,
    value               varchar2 (255),
    security_type       varchar2 (255)
        constraint rhn_confp_security_type_nn not null,
    last_update_user    varchar2 (40),
    last_update_date    date
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_config_parameter
    is 'confp  configuration parameter definition';
create unique index rhn_confp_group_name_name_pk
    on rhn_config_parameter ( group_name,  name )
    storage ( freelists 16 )
    initrans 32;
alter table rhn_config_parameter
    add constraint rhn_confp_group_name_name_pk primary key ( group_name, name);
alter table rhn_config_parameter
    add constraint rhn_confp_grpnm_group_name_fk
    foreign key ( group_name )
    references rhn_config_group( name );
alter table rhn_config_parameter
    add constraint rhn_confp_scrty_sec_type_fk
    foreign key ( security_type )
    references rhn_config_security_type( name );

-- changes/054.rhn.sql

create table
rhn_strategies
(
    recid               number   (12)
        constraint rhn_strat_recid_nn not null
        constraint rhn_strat_recid_ck check (recid > 0)
        constraint rhn_strat_recid_pk primary key,
    name                varchar2 (80),
    comp_crit           varchar2 (80),
    esc_crit            varchar2 (80),
    contact_strategy    varchar2 (32)
        constraint rhn_strat_cont_strat_ck
            check (contact_strategy in ('Broadcast','Escalate')),
    ack_completed       varchar2 (32)
        constraint rhn_strat_ack_comp_ck
            check (ack_completed in ( 'All', 'One','No' ))
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_strategies
    is 'strat  strategy definitions';
create sequence rhn_strategies_recid_seq;

-- changes/055.rhn.sql

create table
rhn_notification_formats
(
    recid               number   (12)
        constraint rhn_ntfmt_recid_nn not null
        constraint rhn_ntfmt_recid_pk primary key,
    customer_id         number   (12),
    description         varchar2 (255)
        constraint rhn_ntfmt_desc_nn not null,
    subject_format      varchar2 (4000),
    body_format         varchar2 (4000)
        constraint rhn_ntfmt_body_fmt_nn not null,
    max_subject_length  number   (12),
    max_body_length     number   (12) default 1920
        constraint rhn_ntfmt_max_body_nn not null,
    reply_format        varchar2 (4000)
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_notification_formats
    is 'ntfmt  notification message formats';
create index rhn_ntfmt_customer_idx
    on rhn_notification_formats ( customer_id )
    storage ( freelists 16 )
    initrans 32;
alter table rhn_notification_formats
    add constraint rhn_ntfmt_customer_fk
    foreign key ( customer_id )
    references web_customer( id );
create sequence rhn_ntfmt_recid_seq;

-- changes/056.rhn.sql

create table
rhn_method_types
(
    recid                   number   (12)
        constraint rhn_mthtp_recid_nn not null
        constraint rhn_mthtp_recid_ck check (recid > 0)
        constraint rhn_mthtp_recid_pk primary key,
    method_type_name        varchar2 (20),
    notification_format_id  number   (12) default 4
        constraint rhn_mthtp_notif_fmt_nn not null
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_method_types
    is 'mthtp  method types';

-- changes/057.rhn.sql

create table
rhn_pager_types
(
    recid           number   (12)
        constraint rhn_pgrtp_recid_nn not null
        constraint rhn_pgrtp_recid_ck check (recid > 0)
        constraint rhn_pgrtp_recid_pk primary key,
    pager_type_name varchar2 (50)
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_pager_types
    is 'pgrtp  pager types';
create sequence rhn_pager_types_recid_seq;

-- changes/058.rhn.sql

create table
rhn_schedule_types
(
    recid           number   (12)
        constraint rhn_schtp_recid_nn not null
        constraint rhn_schtp_recid_ck check (recid > 0)
        constraint rhn_schtp_recid_pk primary key,
    description     varchar2 (40)
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_schedule_types
    is 'schtp  schedule types';
create sequence rhn_schedule_types_recid_seq;

-- changes/059.rhn.sql

create table
rhn_schedules
(
    recid               number   (12)
        constraint rhn_sched_recid_nn not null
        constraint rhn_sched_recid_ck check (recid > 0)
        constraint rhn_sched_recid_pk primary key,
    schedule_type_id    number   (12)
        constraint rhn_sched_type_id_nn not null,
    description         varchar2 (40) default 'unknown'
        constraint rhn_sched_desc_nn not null,
    last_update_user    varchar2 (40),
    last_update_date    date,
    customer_id         number   (12)
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_schedules
    is 'sched  schedule definitions';
create index rhn_sched_schedule_type_id_idx
    on rhn_schedules ( schedule_type_id )
    storage ( freelists 16 )
    initrans 32;
create unique index rhn_cust_cust_id_desc_uq
    on rhn_schedules ( customer_id, description )
    storage ( freelists 16 )
    initrans 32;
alter table rhn_schedules
    add constraint rhn_sched_cstmr_cust_id_fk
    foreign key ( customer_id )
    references web_customer( id );
alter table rhn_schedules
    add constraint rhn_sched_schtp_sched_ty_fk
    foreign key ( schedule_type_id )
    references rhn_schedule_types( recid );
create sequence rhn_schedules_recid_seq;

-- changes/060.rhn.sql

create table
rhn_time_zone_names
(
    recid                            number   (12)
        constraint rhn_tznms_recid_nn not null,
    java_id                          varchar2 (40)
        constraint rhn_tznms_java_id_nn not null
        constraint rhn_tznms_java_id_pk primary key,
    display_name                     varchar2 (60)
        constraint rhn_tznms_display_name_nn not null,
    gmt_offset_minutes               number   (4)
        constraint rhn_tznms_gmt_offset_nn not null,
    use_daylight_time                char     (1)
        constraint rhn_tznms_use_dst_nn not null,
    last_update_user                 varchar2 (40),
    last_update_date                 date
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_time_zone_names
    is 'tznms  time zone names';
create unique index rhn_time_zone_names_uq
    on rhn_time_zone_names ( display_name )
    storage ( freelists 16 )
    initrans 32;
alter table rhn_time_zone_names
    add constraint rhn_time_zone_names_uq unique ( display_name );

-- changes/061.rhn.sql

create table
rhn_contact_methods
(
    recid                            number   (12)
        constraint rhn_cmeth_recid_nn not null
        constraint rhn_cmeth_recid_notzero check (recid > 0)
        constraint rhn_cmeth_recid_pk primary key,
    method_name                      varchar2 (20),
    contact_id                       number   (12)
        constraint rhn_cmeth_contact_id_nn not null,
    schedule_id                      number   (12),
    method_type_id                   number   (12)
        constraint rhn_cmeth_meth_type_nn not null,
    pager_type_id                    number   (12),
    pager_pin                        varchar2 (20),
    pager_email                      varchar2 (50),
    pager_max_message_length         number   (6)
        constraint rhn_cmeth_pgr_length_limit
        check (pager_max_message_length between 10 and 1920),
    pager_split_long_messages        char     (1),
    email_address                    varchar2 (50),
    email_reply_to                   varchar2 (50),
    last_update_user                 varchar2 (40),
    last_update_date                 date,
    snmp_host                        varchar2 (255),
    snmp_port                        number   (5),
    notification_format_id           number   (12) default 4
        constraint rhn_cmeth_notif_fmt_nn not null,
    sender_sat_cluster_id            number   (12),
    schedule_zone_id                 varchar2 (40) default 'gmt'
)
    storage ( pctincrease 1 freelists 16 )
    initrans 32;
comment on table rhn_contact_methods
    is 'cmeth  contact method definitions';
create index rhn_cmeth_contact_id_idx
    on rhn_contact_methods ( contact_id )
    storage ( freelists 16 )
    initrans 32;
create unique index rhn_cmeth_id_name_uq
    on rhn_contact_methods ( contact_id, method_name )
    storage ( freelists 16 )
    initrans 32;
create index rhn_cmeth_method_type_id_idx
    on rhn_contact_methods ( method_type_id )
    storage ( freelists 16 )
    initrans 32;
create index rhn_cmeth_schedule_id_idx
    on rhn_contact_methods ( schedule_id )
    storage ( freelists 16 )
    initrans 32;
alter table rhn_contact_methods
    add constraint rhn_cmeth_contact_id_fk
    foreign key ( contact_id )
    references web_contact( id );
alter table rhn_contact_methods
    add constraint rhn_cmeth_method_type_id_fk
    foreign key ( method_type_id )
    references rhn_method_types( recid );
alter table rhn_contact_methods
    add constraint rhn_cmeth_pager_type_id_fk
    foreign key ( pager_type_id )
    references rhn_pager_types( recid );
alter table rhn_contact_methods
    add constraint rhn_cmeth_sender_sat_clus_fk
    foreign key ( sender_sat_cluster_id )
    references rhn_sat_cluster( recid );
alter table rhn_contact_methods
    add constraint rhn_cmeth_schedule_id_fk
    foreign key ( schedule_id )
    references rhn_schedules( recid );
alter table rhn_contact_methods
    add constraint rhn_cmeth_tznms_sched_zone_id
    foreign key ( schedule_zone_id )
    references rhn_time_zone_names( java_id );
alter table rhn_contact_methods
    add constraint rhn_cmeth_ntfmt_id_fk
    foreign key ( notification_format_id )
    references rhn_notification_formats( recid );
create sequence rhn_contact_methods_recid_seq;

-- changes/062.rhn.sql

create table
rhn_contact_groups
(
    recid                   number   (12)
        constraint rhn_cntgp_recid_nn not null
        constraint rhn_cntgp_recid_notzero check (recid > 0)
        constraint rhn_cntgp_recid_pk primary key,
    contact_group_name      varchar2 (30)
        constraint rhn_cntgp_group_name_nn not null,
    customer_id             number   (12)
        constraint rhn_cntgp_cust_id_nn not null,
    strategy_id             number   (12)
        constraint rhn_cntgp_strat_id_nn not null,
    ack_wait                number   (4)
        constraint rhn_cntgp_ack_wait_nn not null
        constraint rhn_cntgp_ack_wait_ck check ( ack_wait < 20160 ),
    rotate_first            char     (1)
        constraint rhn_cntgp_rotate_f_nn not null
        constraint rhn_cntgp_rotate_f_ck check (rotate_first in (0,1)),
    last_update_user        varchar2 (40)
        constraint rhn_cntgp_last_user_nn not null,
    last_update_date        date
        constraint rhn_cntgp_last_date_nn not null,
    notification_format_id  number   (12) default 4
        constraint rhn_cntgp_notif_fmt_nn not null
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_contact_groups
    is 'cntgp  contact group definitions';
create index rhn_cntgp_strategy_id_idx
    on rhn_contact_groups ( strategy_id )
    storage( pctincrease 1 freelists 16 )
    initrans 32;
create index rhn_cntgp_customer_id_idx
    on rhn_contact_groups ( customer_id )
    storage( pctincrease 1 freelists 16 )
    initrans 32;
alter table rhn_contact_groups
    add constraint rhn_cntgp_cstmr_customer_id_fk
    foreign key ( customer_id )
    references web_customer( id );
alter table rhn_contact_groups
    add constraint rhn_cntgp_strat_strategy_id_fk
    foreign key ( strategy_id )
    references rhn_strategies( recid );
alter table rhn_contact_groups
    add constraint rhn_ntfmt_cntgp_id_fk
    foreign key ( notification_format_id )
    references rhn_notification_formats( recid );
create sequence rhn_contact_groups_recid_seq;

-- changes/063.rhn.sql

create table
rhn_contact_group_members
(
        contact_group_id        number
                                constraint rhn_cntgm_cgid_nn not null
                                constraint rhn_cntgm_cgid_fk
                                        references rhn_contact_groups(recid)
                                        on delete cascade,
        order_number            number
                                constraint rhn_cntgm_on_nn not null,
        member_contact_method_id number
                                constraint rhn_cntgm_mcmid_fk
                                        references rhn_contact_methods(recid)
                                        on delete cascade,
        member_contact_group_id number
                                constraint rhn_cntgm_mcgid_fk
                                        references rhn_contact_groups(recid)
                                        on delete cascade,
        last_update_user        varchar2 (40)
                                constraint rhn_cntgm_last_user_nn not null,
        last_update_date        date
                                constraint rhn_cntgm_last_date_nn not null
)
        storage ( pctincrease 1 freelists 16 )
        initrans 32;

comment on table rhn_contact_group_members
        is 'cntgm  contact group membership records';

-- supports rhn_cntgm_cgid_fk's delete cascade, and also the pk
create index rhn_cntgm_cgid_order_idx
        on rhn_contact_group_members( contact_group_id, order_number )
        storage ( freelists 16 )
        initrans 32;
alter table rhn_contact_group_members add constraint rhn_cntgm_cgid_order_pk
        primary key ( contact_group_id, order_number );

-- supports rhn_cntgm_mcmid_fk's delete cascade
create index rhn_cntgm_mcmid_idx
        on rhn_contact_group_members( member_contact_method_id )
        storage ( freelists 16 )
        initrans 32;

-- supports rhn_cntgm_mcgid_fk's delete cascade
create index rhn_cntgm_mcgid_idx
        on rhn_contact_group_members( member_contact_group_id )
        storage ( freelists 16 )
        initrans 32;

-- changes/064.rhn.sql

create table
rhn_current_alerts
(
    recid               number   (12)
        constraint rhn_alrts_recid_nn not null
        constraint rhn_alrts_recid_pk primary key,
    date_submitted      date,
    last_server_change  date,
    date_completed      date    default to_date('31-12-9999', 'dd-mm-yyyy'),
    original_server     number   (12),
    current_server      number   (12),
    tel_args            varchar2 (2200),
    message             varchar2 (2000),
    ticket_id           varchar2 (80),
    destination_name    varchar2 (50),
    escalation_level    number   (2)    default 0,
    host_probe_id       number   (12),
    host_state          varchar2 (255),
    service_probe_id    number   (12),
    service_state       varchar2 (255),
    customer_id         number   (12)
        constraint rhn_alrts_cust_id_nn not null,
    netsaint_id         number   (12),
    probe_type          varchar2 (20)   default 'none',
    in_progress         char     (1)    default 1
        constraint rhn_alrts_in_prog_nn not null,
    last_update_date    date,
    event_timestamp     date
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_current_alerts
    is 'alrts  current alert records';
create index rhn_alrts_service_probe_id_idx
    on rhn_current_alerts ( service_probe_id )
    storage ( freelists 16 )
    initrans 32;
create index rhn_alrts_current_server_idx
    on rhn_current_alerts ( current_server )
    storage ( freelists 16 )
    initrans 32;
create index rhn_alrts_in_progress_idx
    on rhn_current_alerts ( in_progress )
    storage ( freelists 16 )
    initrans 32;
create index rhn_alrts_ticket_id_idx
    on rhn_current_alerts ( ticket_id )
    storage ( freelists 16 )
    initrans 32;
create index rhn_alrts_customer_id_idx
    on rhn_current_alerts ( customer_id )
    storage ( freelists 16 )
    initrans 32;
create index rhn_alrts_netsaint_id_idx
    on rhn_current_alerts ( netsaint_id )
    storage ( freelists 16 )
    initrans 32;
create index rhn_alrts_probe_type_idx
    on rhn_current_alerts ( probe_type )
    storage ( freelists 16 )
    initrans 32;
create index rhn_alrts_original_server_idx
    on rhn_current_alerts ( original_server )
    storage ( freelists 16 )
    initrans 32;
create index rhn_alrts_host_probe_id_idx
    on rhn_current_alerts ( host_probe_id )
    storage ( freelists 16 )
    initrans 32;
create sequence rhn_current_alerts_recid_seq;

-- changes/065.rhn.sql

create table
rhn_current_state_summaries
(
    customer_id                      number   (12)
        constraint rhn_cursu_cust_id_nn not null,
    template_id                      varchar2 (10)
        constraint rhn_cursu_template_id_nn not null,
    state                            varchar2 (20)
        constraint rhn_cursu_state_nn not null,
    state_count                      number   (9),
    last_check                       date
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_current_state_summaries
    is 'cursu  current state summaries (monitoring)';
create unique index rhn_current_state_summaries_pk
on rhn_current_state_summaries ( customer_id, template_id, state )
    storage ( freelists 16 )
    initrans 32;
alter table rhn_current_state_summaries
    add constraint rhn_current_state_summaries_pk
    primary key ( customer_id, template_id, state );

-- changes/066.rhn.sql

create table
rhn_db_environment
(
    db_name     varchar2 (20)
        constraint rhn_dbenv_db_name_nn not null
        constraint rhn_dbenv_db_name_pk primary key,
    environment varchar2 (255)
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_db_environment
    is 'dbenv environments - database_names xref';
alter table rhn_db_environment
    add constraint rhn_dbenv_envir_environment_fk
    foreign key ( environment )
    references rhn_environment( name );

-- changes/067.rhn.sql

create table
rhn_deployed_probe
(
    recid                            number   (12)
        constraint rhn_dprob_recid_nn not null
        constraint rhn_dprob_recid_pk primary key,
    probe_type                       varchar2 (15)
        constraint rhn_dprob_probe_type_nn not null,
    description                      varchar2 (255),
    customer_id                      number   (12)
        constraint rhn_dprob_cust_id_nn not null,
    command_id                       number   (16)
        constraint rhn_dprob_command_id_nn not null,
    contact_group_id                 number   (12),
    os_id                            number   (12),
    notify_critical                  char     (1),
    notify_warning                   char     (1),
    notify_recovery                  char     (1),
    notify_unknown                   char     (1),
    notification_interval_minutes    number   (16)
        constraint rhn_dprob_notif_int_nn not null,
    check_interval_minutes           number   (16)
        constraint rhn_dprob_check_int_nn not null,
    retry_interval_minutes           number   (16)
        constraint rhn_dprob_retry_int_nn not null,
    max_attempts                     number   (16),
    sat_cluster_id                   number   (12),
    parent_probe_id                  number   (12),
    last_update_user                 varchar2 (40),
    last_update_date                 date
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_deployed_probe is 'dprob  deployed_probe definitions';
create unique index rhn_dprob_recid_probe_type_uq
    on rhn_deployed_probe ( recid, probe_type )
    storage ( freelists 16 )
    initrans 32;
create index rhn_dprob_check_command_id_idx
    on rhn_deployed_probe ( command_id )
    storage ( freelists 16 )
    initrans 32;
create index rhn_dprob_customer_id_idx
    on rhn_deployed_probe ( customer_id )
    storage ( freelists 16 )
    initrans 32;
create index rhn_dprob_sat_cluster_id_idx
    on rhn_deployed_probe ( sat_cluster_id )
    storage ( freelists 16 )
    initrans 32;
alter table rhn_deployed_probe
    add constraint dprob_recid_probe_type_uq unique ( recid, probe_type );

-- changes/068.rhn.sql

create table
rhn_check_suites
(
    recid               number   (12)
        constraint rhn_cksut_recid_nn not null
        constraint rhn_cksut_recid_pk primary key,
    customer_id         number   (12)
        constraint rhn_cksut_custid_nn not null,
    suite_name          varchar2 (40)
        constraint rhn_cksut_suite_name_nn not null,
    description         varchar2 (255),
    last_update_user    varchar2 (40)
        constraint rhn_cksut_last_user_nn not null,
    last_update_date    date
        constraint rhn_cksut_last_date_nn not null
)
    storage ( pctincrease 1 freelists 16 )
    initrans 32;
comment on table rhn_check_suites
    is 'CKSUT  check suites';
create index rhn_cksut_cid_idx
        on rhn_check_suites( customer_id )
        storage ( freelists 16 )
        initrans 32;
alter table rhn_check_suites
    add constraint rhn_cksut_cstmr_customer_id_fk
    foreign key ( customer_id )
    references web_customer( id );
create sequence rhn_check_suites_recid_seq;

-- changes/069.rhn.sql

create table
rhn_host_probe
(
    probe_id        number   (12)
        constraint rhn_hstpb_probe_id_nn not null
        constraint rhn_hstpb_probe_id_pk primary key,
    probe_type      varchar2 (12) default 'host'
        constraint rhn_hstpb_probe_type_nn not null
        constraint rhn_hstpb_probe_type_ck check ( probe_type='host' ),
    host_id         number   (12)
        constraint rhn_hstpb_host_id_nn not null,
    sat_cluster_id  number   (12)
        constraint rhn_hstpb_sat_cl_id_nn not null
)
    storage ( pctincrease 1 freelists 16 )
    initrans 32;
comment on table rhn_host_probe
    is 'hstpb  host probe definitions';
create index rhn_hstpb_host_id_idx
    on rhn_host_probe ( host_id )
    storage ( freelists 16 )
    initrans 32;
create index rhn_hstpb_sat_cluster_id_idx
    on rhn_host_probe ( sat_cluster_id )
    storage ( freelists 16 )
    initrans 32;
alter table rhn_host_probe
    add constraint rhn_hstpb_host_id_fk
    foreign key ( host_id )
    references rhnServer( id );
alter table rhn_host_probe
    add constraint rhn_hstpb_probe_probe_id_fk
    foreign key ( probe_id, probe_type )
    references rhn_probe( recid, probe_type )
    on delete cascade;
alter table rhn_host_probe
    add constraint rhn_hstpb_satcl_id_fk
    foreign key ( sat_cluster_id )
    references rhn_sat_cluster( recid )
    on delete cascade;
create sequence rhn_host_probes_recid_seq;

-- changes/070.rhn.sql

create table
rhn_host_check_suites
(
    host_probe_id   number   (12)
        constraint rhn_hstck_host_probe_nn not null,
    suite_id        number   (12)
        constraint rhn_hstck_suite_id_nn not null
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_host_check_suites
    is 'hstck  check suites used by hosts. the host_probe_id must reference a probe oftype hostprobe.';
create unique index rhn_hstck_suite_id_probe_id_pk
    on rhn_host_check_suites ( host_probe_id , suite_id )
    storage ( freelists 16 )
    initrans 32;
alter table rhn_host_check_suites
    add constraint rhn_hstck_suite_id_probe_id_pk
    primary key ( host_probe_id, suite_id );
alter table rhn_host_check_suites
    add constraint rhn_hstck_cksut_suite_id_fk
    foreign key ( suite_id )
    references rhn_check_suites( recid )
    on delete cascade;
alter table rhn_host_check_suites
    add constraint rhn_hstck_hstpb_probe_id_fk
    foreign key ( host_probe_id )
    references rhn_host_probe( probe_id )
    on delete cascade;

-- changes/071.rhn.sql

create table
rhn_interface_monitoring
(
    server_id       number
        constraint rhn_monif_server_id_nn not null
        constraint rhn_monif_server_pk primary key,
    server_name     varchar (32)
        constraint rhn_monif_server_name_nn not null
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_interface_monitoring
   is 'monif  Monitoring interface.  The one entry from rhnservernetinterface to be used for monitoring on a host.';
alter table rhn_interface_monitoring
    add constraint rhn_monif_server_name_fk
    foreign key ( server_id, server_name )
    references rhnServerNetInterface ( server_id, name );

-- changes/072.rhn.sql

create table
rhn_ll_netsaint
(
    netsaint_id number
        constraint rhn_llnet_netsaint_id_nn not null,
    city        varchar2 (255)
)
    storage ( pctincrease 1 freelists 16 )
    initrans 32;
comment on table rhn_ll_netsaint
    is 'llnet  scout records';
alter table rhn_ll_netsaint
    add constraint rhn_llnts_sat_cluster_idfk
    foreign key ( netsaint_id )
    references rhn_sat_cluster( recid );

-- changes/073.rhn.sql

create table
rhn_multi_scout_threshold
(
    probe_id                         number   (12)
        constraint rhn_msthr_probe_id_nn not null
        constraint rhn_msthr_probe_id_pk primary key,
    scout_warning_threshold_is_all   char     (1)  default '1'
        constraint rhn_msthr_warn_thres_nn not null,
    scout_crit_threshold_is_all      char     (1)  default '1'
        constraint rhn_msthr_crit_thres_nn not null,
    scout_warning_threshold          number   (12),
    scout_critical_threshold         number   (12)
)
    storage ( pctincrease 1 freelists 16 )
    initrans 32;
comment on table rhn_multi_scout_threshold
    is 'msthr  multi_scout_threshold definitions';

-- changes/074.rhn.sql

create table
rhn_notifservers
(
    recid   number   (12)
        constraint rhn_notsv_recid_nn not null
        constraint rhn_notsv_recid_pk primary key,
    name    varchar2 (255)
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_notifservers
    is 'notsv  notification host table';

-- changes/075.rhn.sql

create table
rhn_os
(
    recid       number   (12)
        constraint rhn_os000_recid_nn not null
        constraint rhn_os000_recid_pk primary key,
    os_name     varchar2 (128)
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_os
    is 'os000  operating systems';

-- changes/076.rhn.sql

create table
rhn_server_monitoring_info
(
    recid               number (12)
        constraint rhn_host_recid_nn not null
        constraint rhn_host_recid_pk primary key,
    os_id               number (12)
)
    storage ( pctincrease 1 freelists 16 )
    initrans 32;
comment on table rhn_server_monitoring_info
    is 'host   additional fields to rhn_server for monitoring servers';
alter table rhn_server_monitoring_info
    add constraint rhn_host_server_id_fk
    foreign key ( recid )
    references rhnServer ( id );
alter table rhn_server_monitoring_info
    add constraint rhn_host_server_name_fk
    foreign key ( os_id )
    references rhn_os ( recid );

-- changes/077.rhn.sql

create table
rhn_os_commands_xref
(
    os_id           number   (12)
        constraint rhn_oscxr_os_id_nn not null,
    commands_id     number   (12)
        constraint rhn_oscxr_commands_id_nn not null
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_os_commands_xref
    is 'oscxr  operating systems - commands cross ref';
create unique index rhn_oscxr_os_id_commands_id_pk
    on rhn_os_commands_xref ( os_id, commands_id )
    storage ( freelists 16 )
    initrans 32;
alter table rhn_os_commands_xref
    add constraint rhn_oscxr_os_id_commands_id_pk
    primary key ( os_id, commands_id );
alter table rhn_os_commands_xref
    add constraint rhn_oscxr_cmmnd_commands_id_fk
    foreign key ( commands_id )
    references rhn_command( recid );
alter table rhn_os_commands_xref
    add constraint rhn_oscxr_os000_os_id_fk
    foreign key ( os_id )
    references rhn_os( recid );

-- changes/078.rhn.sql

create table
rhn_physical_location
(
    recid               number   (12)
        constraint rhn_phslc_recid_nn not null
        constraint rhn_phslc_recid_pk primary key,
    location_name       varchar2 (40),
    address1            varchar2 (255),
    address2            varchar2 (255),
    city                varchar2 (128),
    state               varchar2 (128),
    country             varchar2 (2),
    zipcode             varchar2 (10),
    phone               varchar2 (40),
    deleted             char     (1),
    last_update_user    varchar2 (40),
    last_update_date    date,
    customer_id         number   (12)  default 999
        constraint rhn_phslc_cust_id_nn not null
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_physical_location
    is 'phslc  physical location records';
create sequence rhn_physical_loc_recid_seq;

-- changes/079.rhn.sql

create table
rhn_probe_param_value
(
    probe_id            number
        constraint rhn_ppval_probe_id_nn not null,
    command_id          number
        constraint rhn_ppval_command_id_nn not null,
    param_name          varchar2 (40)
        constraint rhn_ppval_param_name_nn not null,
    value               varchar2 (1024),
    last_update_user    varchar2 (40),
    last_update_date    date
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_probe_param_value
    is 'ppval  param value for a probe running a command';
create unique index rhn_ppval_p_id_cmd_id_parm_pk
    on rhn_probe_param_value ( probe_id, command_id, param_name )
    storage ( freelists 16 )
    initrans 32;
alter table rhn_probe_param_value
    add constraint rhn_ppval_p_id_cmd_id_parm_pk
    primary key ( probe_id, command_id, param_name );
alter table rhn_probe_param_value
    add constraint rhn_ppval_chkpb_probe_id_fk
    foreign key ( probe_id )
    references rhn_probe( recid )
    on delete cascade;
alter table rhn_probe_param_value
    add constraint rhn_ppval_cmd_id_parm_nm_fk
    foreign key ( command_id, param_name )
    references rhn_command_parameter( command_id, param_name )
    on delete cascade;

-- changes/080.rhn.sql

create table rhn_probe_state
(
    probe_id                         number   (12)
        constraint rhn_prbst_probe_id_nn not null,
    scout_id                         number   (12)
        constraint rhn_prbst_scout_id_nn not null,
    state                            varchar2 (20),
    output                           varchar2 (4000),
    last_check                       date
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_probe_state is 'prbst  probe state';
create unique index rhn_prbst_probe_id_scout_id_pk
    on rhn_probe_state ( probe_id, scout_id )
    storage ( freelists 16 )
    initrans 32;
alter table rhn_probe_state
    add constraint prbst_probe_id_scout_id_pk
    primary key ( probe_id, scout_id );

-- changes/081.rhn.sql

create table
rhn_probe_types
(
    probe_type          varchar2 (20)
        constraint rhn_prbtp_probe_type_nn not null
        constraint rhn_prbtp_probe_type_pk primary key,
    type_description    varchar2 (200)
        constraint rhn_prbtp_type_desc_nn not null
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_probe_types
    is 'prbtp  probe types';

-- changes/082.rhn.sql

create table
rhn_redirect_types
(
    name            varchar2 (20)
        constraint rhn_rdrtp_name_nn not null
        constraint rhn_rdrtp_name_pk primary key,
    description     varchar2 (255),
    long_name       varchar2 (80)
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_redirect_types
    is 'rdrtp  redirect types';
create sequence rhn_redirect_types_recid_seq;

-- changes/083.rhn.sql

create table
rhn_redirects
(
    recid                            number   (12)
        constraint rhn_rdrct_recid_nn not null
        constraint rhn_rdrct_recid_pk primary key,
    customer_id                      number   (12),
    contact_id                       number   (12),
    redirect_type                    varchar2 (20)
        constraint rhn_rdrct_redirect_type_nn not null,
    description                      varchar2 (25),
    reason                           varchar2 (2000),
    expiration                       date
        constraint rhn_rdrct_expiration_nn not null,
    last_update_user                 varchar2 (40),
    last_update_date                 date,
    start_date                       date
        constraint rhn_rdrct_start_date_nn not null
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_redirects
    is 'rdrct  redirect definitions';
create index rhn_rdrct_customer_id_idx
    on rhn_redirects ( customer_id )
    storage ( freelists 16 )
    initrans 32;
create index rhn_rdrct_redirect_type_idx
    on rhn_redirects ( redirect_type )
    storage ( freelists 16 )
    initrans 32;
alter table rhn_redirects
    add constraint rhn_rdrct_start_lte_expir check (start_date <= expiration );
create index rhn_rdrct_cid_idx
        on rhn_redirects( contact_id )
        storage ( freelists 16 )
        initrans 32;
alter table rhn_redirects
    add constraint rhn_rdrct_cntct_contact_id_fk
    foreign key ( contact_id )
    references web_contact( id );
alter table rhn_redirects
    add constraint rhn_rdrct_cstmr_customer_id_fk
    foreign key ( customer_id )
    references web_customer( id );
alter table rhn_redirects
    add constraint rhn_rdrct_rdrtp_redir_type_fk
    foreign key ( redirect_type )
    references rhn_redirect_types( name );
create sequence rhn_redirects_recid_seq;

-- changes/084.rhn.sql

create table
rhn_redirect_match_types
(
    name                             varchar2 (255)
        constraint rhn_rdrmt_name_nn not null
        constraint rhn_rdrmt_name_pk primary key
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_redirect_match_types
    is 'rdrmt  redirect match types';

-- changes/085.rhn.sql

create table
rhn_redirect_criteria
(
    recid           number   (12)
        constraint rhn_rdrcr_recid_nn not null
        constraint rhn_rdrcr_recid_pk primary key,
    redirect_id     number   (12)
        constraint rhn_rdrcr_redirect_id_nn not null,
    match_param     varchar2 (255)
        constraint rhn_rdrcr_match_param_nn not null,
    match_value     varchar2 (255),
    inverted        char     (1) default 0
        constraint rhn_rdrcr_inverted_nn not null
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_redirect_criteria
    is 'rdrcr  redirect criteria';
create index rhn_rdrcr_redirect_id_idx
    on rhn_redirect_criteria ( redirect_id )
    storage ( freelists 16 )
    initrans 32;
alter table rhn_redirect_criteria
    add constraint rhn_rdrcr_rdrct_redirect_id_fk
    foreign key ( redirect_id )
    references rhn_redirects( recid )
    on delete cascade;
alter table rhn_redirect_criteria
    add constraint rhn_rdrcr_rdrmt_match_nm_fk
    foreign key ( match_param )
    references rhn_redirect_match_types( name );
create sequence rhn_redirect_crit_recid_seq;

-- changes/086.rhn.sql

create table
rhn_redirect_email_targets
(
    redirect_id     number   (12)
        constraint rhn_rdret_redirect_id_nn not null,
    email_address   varchar2 (255)
        constraint rhn_rdret_email_addr_nn not null
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_redirect_email_targets
    is 'rdret  redirect email targets';
create unique index rhn_rdret_pk
    on rhn_redirect_email_targets ( redirect_id, email_address )
    storage ( freelists 16 )
    initrans 32;
create index rhn_rdret_redirect_id_idx
    on rhn_redirect_email_targets ( redirect_id )
    storage ( freelists 16 )
    initrans 32;
alter table rhn_redirect_email_targets
    add constraint rhn_rdret_pk primary key ( redirect_id, email_address );
alter table rhn_redirect_email_targets
    add constraint rhn_rdret_rdrct_redirect_id_fk
    foreign key ( redirect_id )
    references rhn_redirects( recid )
    on delete cascade;

-- changes/087.rhn.sql

create table
rhn_redirect_group_targets
(
    redirect_id         number   (12)
        constraint rhn_rdrgt_redirect_id_nn not null,
    contact_group_id    number   (12)
        constraint rhn_rdrgt_group_id_nn not null
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_redirect_group_targets
    is 'rdrgt  redirect group targets';
create unique index rhn_rdrgt_pk
    on rhn_redirect_group_targets ( redirect_id , contact_group_id )
    storage ( freelists 16 )
    initrans 32;
create index rhn_rdrgt_redirect_id_idx
    on rhn_redirect_group_targets ( redirect_id )
    storage ( freelists 16 )
    initrans 32;
alter table rhn_redirect_group_targets
    add constraint rhn_rdrgt_pk primary key ( redirect_id, contact_group_id );
alter table rhn_redirect_group_targets
    add constraint rhn_rdrgt_rdrct_redirect_id_fk
    foreign key ( redirect_id )
    references rhn_redirects( recid )
    on delete cascade;

-- changes/088.rhn.sql

create table
rhn_redirect_method_targets
(
    redirect_id         number   (12)
        constraint rhn_rdrme_redirect_id not null,
    contact_method_id   number   (12)
        constraint rhn_rdrme_method_id not null
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_redirect_method_targets
    is 'rdrme  redirect method targets';
create unique index rhn_rdrme_pk
    on rhn_redirect_method_targets ( redirect_id , contact_method_id )
    storage ( freelists 16 )
    initrans 32;
create index rhn_rdrme_redirect_id_idx
    on rhn_redirect_method_targets ( redirect_id )
    storage ( freelists 16 )
    initrans 32;
alter table rhn_redirect_method_targets
    add constraint rhn_rdrme_pk primary key ( redirect_id, contact_method_id );
alter table rhn_redirect_method_targets
    add constraint rhn_rdrmt_cmeth_redirect_id_fk
    foreign key ( contact_method_id )
    references rhn_contact_methods( recid )
    on delete cascade;
alter table rhn_redirect_method_targets
    add constraint rhn_rdrmt_rdrct_redirect_id_fk
    foreign key ( redirect_id )
    references rhn_redirects( recid )
    on delete cascade;

-- changes/089.rhn.sql

create table
rhn_sat_cluster_probe
(
    probe_id        number   (12)
        constraint rhn_sclpb_probe_id_nn not null
        constraint rhn_sclpb_probe_id_pk primary key,
    probe_type      varchar2 (12) default 'satcluster'
        constraint rhn_sclpb_probe_type_nn not null
        constraint rhn_sclpb_probe_type_ck check (probe_type='satcluster'),
    sat_cluster_id  number   (12)
        constraint rhn_sclpb_sat_cluster_id_nn not null
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_sat_cluster_probe
    is 'sclpb  satellite cluster probe definitions';
create index rhn_sclpb_sat_cluster_id_idx
    on rhn_sat_cluster_probe ( sat_cluster_id )
    storage ( freelists 16 )
    initrans 32;
alter table rhn_sat_cluster_probe
    add constraint rhn_sclpb_prb_recid_prb_typ_fk
    foreign key ( probe_id, probe_type )
    references rhn_probe( recid, probe_type )
    on delete cascade;
alter table rhn_sat_cluster_probe
    add constraint rhn_sclpb_satcl_sat_cl_id_fk
    foreign key ( sat_cluster_id )
    references rhn_sat_cluster( recid )
    on delete cascade;

-- changes/090.rhn.sql

create table
rhn_satellite_state
(
    satellite_id                     number   (12)
        constraint rhn_satst_sat_id_nn not null
        constraint rhn_satst_sat_id_pk primary key,
    last_check                       date,
    probe_count                      number   (10),
    pct_ok                           number   (10,2),
    pct_warning                      number   (10,2),
    pct_critical                     number   (10,2),
    pct_unknown                      number   (10,2),
    pct_pending                      number   (10,2),
    recent_state_changes             number   (10),
    imminent_probes                  number   (10),
    max_exec_time                    number   (10,2),
    min_exec_time                    number   (10,2),
    avg_exec_time                    number   (10,2),
    max_latency                      number   (10,2),
    min_latency                      number   (10,2),
    avg_latency                      number   (10,2)
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_satellite_state
    is 'satst  satellite state (monitoring)';

-- changes/091.rhn.sql

create table
rhn_sat_node
(
    recid                   number   (12)
        constraint rhn_satnd_recid_nn not null
        constraint rhn_satnd_recid_pk primary key,
    target_type             varchar2 (10) default 'node'
        constraint rhn_satnd_target_type_nn not null
        constraint rhn_satnd_target_type_ck check (target_type in ('node')),
    last_update_user        varchar2 (40),
    last_update_date        date,
    mac_address             varchar2 (17)
        constraint rhn_satnd_mac_address_nn not null,
    max_concurrent_checks   number   (4),
    sat_cluster_id          number   (12)
        constraint rhn_satnd_sat_cluster_id_nn not null,
    ip                      varchar2 (15),
    sched_log_level         number   (4) default 0
        constraint rhn_satnd_sched_log_level_nn not null,
    sput_log_level          number   (4) default 0
        constraint rhn_satnd_sput_log_level_nn not null,
    dq_log_level            number   (4) default 0
        constraint rhn_satnd_dq_log_level_nn not null
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_sat_node
    is 'satnd  satellite node';
alter table rhn_sat_node
    add constraint rhn_satnd_cmdtg_rid_tar_ty_fk
    foreign key ( recid, target_type )
    references rhn_command_target( recid, target_type )
    on delete cascade;
alter table rhn_sat_node
    add constraint rhn_satnd_satcl_sat_cl_id_fk
    foreign key ( sat_cluster_id )
    references rhn_sat_cluster( recid )
    on delete cascade;

-- changes/092.rhn.sql

create table
rhn_sat_node_probe
(
    probe_id        number   (12)
        constraint rhn_sndpb_probe_id_nn not null
        constraint rhn_sndpb_probe_id_pk primary key,
    probe_type      varchar2 (12)  default 'satnode'
        constraint rhn_sndpb_probe_type_nn not null
        constraint rhn_sndpb_probe_type_ck check (probe_type='satnode'),
    sat_node_id     number   (12)
        constraint rhn_sndpb_sat_node_id_nn not null
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_sat_node_probe
    is 'sndpb  satellite node probe definitions';
create index rhn_sndpb_sat_node_id_idx
    on rhn_sat_node_probe ( sat_node_id )
    storage ( freelists 16 )
    initrans 32;
alter table rhn_sat_node_probe
    add constraint rhn_sndpb_pr_recid_pr_typ_fk
    foreign key ( probe_id, probe_type )
    references rhn_probe( recid, probe_type )
    on delete cascade;
alter table rhn_sat_node_probe
    add constraint rhn_sndpb_satnd_sat_nd_id_fk
    foreign key ( sat_node_id )
    references rhn_sat_node( recid )
    on delete cascade;

-- changes/093.rhn.sql

create table
rhn_schedule_days_norm
(
    schedule_id     number   (12),
    ord             number   (3),
    start_int       number   (12),
    end_int         number   (12)
);

-- changes/094.rhn.sql

create table
rhn_schedule_days
(
    recid               number   (12)
        constraint rhn_schdy_recid_nn not null
        constraint rhn_schdy_recid_ck check (recid > 0)
        constraint rhn_schdy_recid_pk primary key,
    schedule_id         number   (12),
    ord                 number   (3),
    start_1             date,
    end_1               date,
    start_2             date,
    end_2               date,
    start_3             date,
    end_3               date,
    start_4             date,
    end_4               date,
    last_update_user    varchar2 (40),
    last_update_date    varchar2 (40)
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_schedule_days
    is 'schdy  individual day records for schedules';
create index rhn_schdy_schedule_id_idx
    on rhn_schedule_days ( schedule_id )
    storage ( freelists 16 )
    initrans 32;
alter table rhn_schedule_days
    add constraint rhn_schdy_sched_schedule_id_fk
    foreign key ( schedule_id )
    references rhn_schedules( recid )
    on delete cascade;
create sequence rhn_schedule_days_recid_seq;

-- changes/095.rhn.sql

create table
rhn_schedule_weeks
(
    recid                   number   (12)
        constraint rhn_schwk_recid_nn not null
        constraint rhn_schwk_recid_ck check (recid > 0)
        constraint rhn_schwk_recid_pk primary key,
    schedule_id             number   (12)
        constraint rhn_schwk_sched_id_nn not null,
    component_schedule_id   number   (12),
    ord                     number   (3),
    last_update_user        varchar2 (40),
    last_update_date        date
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_schedule_weeks
    is 'schwk  individual week records for schedules';
create index rhn_schwk_schedule_id_idx
    on rhn_schedule_weeks ( schedule_id )
    storage ( freelists 16 )
    initrans 32;
create index rhn_schwk_comp_sched_id_idx
    on rhn_schedule_weeks ( component_schedule_id )
    storage ( freelists 16 )
    initrans 32;
alter table rhn_schedule_weeks
    add constraint rhn_schwk_sched_comp_sched_fk
    foreign key ( component_schedule_id )
    references rhn_schedules( recid );
alter table rhn_schedule_weeks
    add constraint rhn_schwk_sched_sched_id_fk
    foreign key ( schedule_id )
    references rhn_schedules( recid )
    on delete cascade;
create sequence rhn_schedule_weeks_recid_seq;

-- changes/096.rhn.sql

create table
rhn_service_probe_origins
(
    service_probe_id    number   (12)
        constraint rhn_srvpo_serv_p_id_nn not null,
    origin_probe_id     number   (12),
    decoupled           char     (1) default '0'
        constraint rhn_srvpo_decoupled_nn not null
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_service_probe_origins
    is 'srvpo  mapping from a replicated service probe to the check suite probe it was copied from.  uq instead of pk because need to set origin_probe_id to null!!!';
create unique index rhn_srvpo_serv_pr_id_orig_uq
    on rhn_service_probe_origins ( service_probe_id, origin_probe_id )
    storage ( freelists 16 )
    initrans 32;
alter table rhn_service_probe_origins
    add constraint rhn_srvpo_serv_pr_id_orig_uq
    unique ( service_probe_id, origin_probe_id );
alter table rhn_service_probe_origins
    add constraint rhn_srvpo_chkpb_orig_pr_id_fk
    foreign key ( origin_probe_id )
    references rhn_check_suite_probe( probe_id )
    on delete cascade;
alter table rhn_service_probe_origins
    add constraint rhn_srvpo_pr_serv_pr_fk
    foreign key ( service_probe_id )
    references rhn_probe( recid )
    on delete cascade;

-- changes/097.rhn.sql

create table
rhn_snmp_alert
(
   recid                number   (12)
        constraint rhn_snmpa_recid_nn not null
        constraint rhn_snmpa_recid_pk primary key,
    sender_cluster_id   number   (12)
        constraint rhn_snmpa_send_clust_id_nn not null,
    dest_ip             varchar2 (255)
        constraint rhn_snmpa_dest_ip_nn not null,
    dest_port           number   (5)
        constraint rhn_snmpa_dest_port_nn not null,
    date_generated      date,
    date_submitted      date,
    command_name        varchar2 (255),
    notif_type          number   (5),
    op_center           varchar2 (255),
    notif_url           varchar2 (255),
    os_name             varchar2 (128),
    message             varchar2 (2000),
    probe_id            number   (12),
    host_ip             varchar2 (255),
    severity            number   (5),
    command_id          number   (12),
    probe_class         number   (5),
    host_name           varchar2 (255),
    support_center      varchar2 (255)
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_snmp_alert
    is 'snmpa  snmp alerts';
alter table rhn_snmp_alert
    add constraint rhn_snmp_alert_sat_cluster_fk
    foreign key ( sender_cluster_id )
    references rhn_sat_cluster( recid );
create sequence rhn_snmp_alert_recid_seq;

-- changes/098.rhn.sql

create table
rhn_url_probe
(
    username                         varchar2 (40),
    password                         varchar2 (255),
    cookie_enabled                   char     (1)   default 0
        constraint rhn_urlpb_cookie_en_nn not null,
    multi_step                       char     (1)   default 0
        constraint rhn_urlpb_multi_step_nn not null
        constraint rhn_urlpb_multi_step_ck check (multi_step in ('0','1')),
    run_on_scouts                    char     (1)   default ('1')
        constraint rhn_urlpb_run_on_scouts_nn not null
        constraint rhn_urlpb_run_on_scouts_ck
            check (run_on_scouts in ('0','1')),
    probe_id                         number   (12)
        constraint rhn_urlpb_probe_id_nn not null
        constraint rhn_urlpb_probe_id_pk primary key,
    probe_type                       varchar2 (12)  default 'url'
        constraint rhn_urlpb_probe_type_nn not null
        constraint rhn_urlpb_probe_type_ck check (probe_type='url'),
    sat_cluster_id                   number   (12),
    scout_warning_threshold_is_all   char     (1)   default '1'
        constraint rhn_urlpb_scout_warn_isall_nn not null,
    scout_crit_threshold_is_all      char     (1)   default '1'
        constraint rhn_urlpb_scout_crit_isall_nn not null,
    scout_warning_threshold          number   (12)  default -1,
    scout_critical_threshold         number   (12)  default -1
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_url_probe
    is 'urlpb  url probe';
alter table rhn_url_probe
    add constraint rhn_urlpb_probe_pr_id_pr_fk
    foreign key ( probe_id, probe_type )
    references rhn_probe( recid, probe_type )
    on delete cascade;

-- changes/099.rhn.sql

create table
rhn_url_probe_step
(
    recid               number   (12)
        constraint rhn_urlps_recid_nn not null
        constraint rhn_urlps_recid_pk primary key,
    url_probe_id        number   (12)
        constraint rhn_urlps_url_prob_id_nn not null,
    step_number         number   (3)
        constraint rhn_urlps_url_step_no_nn not null,
    description         varchar2 (255),
    url                 varchar2 (2000)
        constraint rhn_urlps_url_nn not null,
    protocol_method     varchar2 (12)
        constraint rhn_urlps_protocol_nn not null,
    verify_links        char     (1)     default 0
        constraint rhn_urlps_ver_links_nn not null
        constraint rhn_urlps_ver_links_ck check (verify_links in ('0','1')),
    load_subsidiary     char     (1)     default 0
        constraint rhn_urlps_load_sub_nn not null
        constraint rhn_urlps_load_sub_ck check (load_subsidiary in ('0','1')),
    pattern             varchar2 (255),
    vpattern            varchar2 (255),
    post_content        varchar2 (4000),
    post_content_type   varchar2 (255),
    connect_warn        number   (10,3)  default 0
        constraint rhn_urlps_conn_warn_nn not null,
    connect_crit        number   (10,3)  default 0
        constraint rhn_urlps_conn_crit_nn not null,
    latency_warn        number   (10,3)  default 0
        constraint rhn_urlps_late_warn_nn not null,
    latency_crit        number   (10,3)  default 0
        constraint rhn_urlps_late_crit_nn not null,
    dns_warn            number   (10,3)  default 0
        constraint rhn_urlps_dns_warn_nn not null,
    dns_crit            number   (10,3)  default 0
        constraint rhn_urlps_dns_crit_nn not null,
    total_warn          number   (10,3)  default 0
        constraint rhn_urlps_total_warn_nn not null,
    total_crit          number   (10,3)  default 0
        constraint rhn_urlps_total_crit_nn not null,
    trans_warn          number   (12)    default 0
        constraint rhn_urlps_trans_warn_nn not null,
    trans_crit          number   (12)    default 0
        constraint rhn_urlps_trans_crit_nn not null,
    through_warn        number   (12)    default 0
        constraint rhn_urlps_thru_warn_nn not null,
    through_crit        number   (12)    default 0
        constraint rhn_urlps_thru_crit_nn not null,
    cookie_key          varchar2 (255),
    cookie_value        varchar2 (255),
    cookie_path         varchar2 (255),
    cookie_domain       varchar2 (255),
    cookie_port         number   (5),
    cookie_secure       char     (1)     default 0
        constraint rhn_urlps_cookie_sec_nn not null
        constraint rhn_urlps_cookie_sec_ck check (cookie_secure in ('0','1')),
    cookie_maxage       number   (9)
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_url_probe_step
    is 'urlps  url probe step';
create unique index rhn_urlps_url_pr_id_stp_n_uq
    on rhn_url_probe_step ( url_probe_id, step_number )
    storage ( freelists 16 )
    initrans 32;
alter table rhn_url_probe_step
    add constraint rhn_urlps_urlpb_url_pr_id_fk
    foreign key ( url_probe_id )
    references rhn_url_probe( probe_id )
    on delete cascade;
create sequence rhn_url_probe_step_recid_seq;

-- changes/100.rhn.sql

--
-- $Id: satellite-3.2-to-3.4.sql 64427 2005-09-09 14:08:21Z jslagle $
--
--

create or replace view rhn_contact_monitoring as
select	u.id			recid,
	u.org_id		customer_id,
	wupi.last_name		contact_last_name,
	wupi.first_names	contact_first_name,
	rhn_user.find_mailable_address(u.id)
				email_address,
--	null			pager,
	u.login			username,
	u.password		password,
--	null			roles,
--	null			deleted,
--	null			last_update_user,
--	null			last_update_date,
	1			schedule_id,
					--references rhn_schedule(recid)
--	null			num_userid,
--	null			password_question,
--	null			password_answer,
	'GMT'			preferred_time_zone,
				--derive from rhnuserinfo.tz_offset ??
				--references rhn_time_zone_names(java_id)
--	null			security_access_vulnerabiliity,
--	null			security_access_management,
--	0			failed_logins,
--	null			privilege_type_name
				--references rhn_privelege_type(name)
--	null			taserial,
	'GMT'			schedule_zone_id
				 --references rhn_time_zone_names(java_id)
from
	web_user_personal_info wupi,
	web_contact u
where	1=1
	and u.id = wupi.web_user_id
	--  and some logic here to check org id for entitlements?
/
show errors

-- changes/101.rhn.sql

create or replace view rhn_customer_monitoring as
select	org.id			recid,
	org.name		description,
--	null			ssh_password,
--	null			deleted,
--	null			last_update_user,
--	null			last_update_date,
	1			schedule_id,	--24 x 7
				--references rhn_schedules(recid)
	0			def_ack_wait,
	1			def_strategy,	--Broadcast, No Ack
				--references rhn_strategies(recid)
	'GMT'			preferred_time_zone,
				--references rhn_time_zone_names(java_id)
--	0			security_service_vulnerability,
--	0			security_service_management,
	0			auto_update,	--Windows only
--	'external-paying'	type,
	'GMT'			schedule_zone_id
				--references rhn_time_zone_names(java_id)
from
	web_customer org
where	1=1
--	and some logic here to check for entitlements?
/
show errors

-- changes/102.rhn.sql

create or replace view rhn_host_monitoring
(
	recid,
	ip,
	name,
	description,
	customer_id,
	os_id,
	asset_id,
	last_update_user,
	last_update_date
) as
select
	s.id		recid,
	i.ip_addr	ip,
	s.name		name,
	s.description	description,
	s.org_id	customer_id,
	host.os_id	os_id,
			--references rhn_os(recid)
			--		4  =  Linux system
			--		14 = Scout
	null		asset_id,
			--references rhn_assets(recid)
	null		last_update_user,
	null		last_update_date
from
	rhnServerNetInterface i,
	rhn_interface_monitoring m,
	rhn_server_monitoring_info host,
	rhnServer s
where	1=1
	and s.id = host.recid
	and s.id = m.server_id
	and s.id = i.server_id
	and i.name = m.server_name
/
show errors

-- changes/103.rhn.sql

create or replace procedure
rhn_clean_current_state
(
    for_customer_id in rhn_probe.customer_id%type
) is
begin
    null;
end rhn_clean_current_state;
/
show errors

-- changes/104.rhn.sql

--monitoring stored procedure
create or replace procedure
rhn_prepare_install
(
    username            in rhn_command_queue_instances.last_update_user%type,
    command_instance_id in out rhn_command_queue_instances.recid%type,
    install_command     in rhn_command_queue_instances.command_id%type
)
is
    /* ignore this command if it has not been run after five minutes */
    stale_after_minutes number := 10;

    /* should take no more than five minutes to run the install */
    max_execution_time_seconds number := 10 * 60;

begin
    select rhn_command_q_inst_recid_seq.nextval
    into command_instance_id
    from dual;

    insert into rhn_command_queue_instances (
        recid,
        command_id,
        notes,
        expiration_date,
        notify_email,
        timeout,
        date_submitted,
        last_update_user,
        last_update_date
    )
    values (
        command_instance_id,
        install_command,
        null, /* no notes */
        sysdate + (stale_after_minutes / (60*24)),
        null, /* no notification email */
        max_execution_time_seconds,
        sysdate,
        username,
        sysdate
    );
end rhn_prepare_install;
/
show errors

-- changes/105.rhn.sql

create or replace procedure
rhn_install_satellite
(
    command_instance_id in rhn_command_queue_instances.recid%type,
    satellite_id in rhn_sat_cluster.recid%type
)
is
begin
    insert into rhn_command_queue_execs (
           instance_id,
           netsaint_id,
           target_type)
    values (command_instance_id, satellite_id, 'cluster');
end rhn_install_satellite;
/
show errors

-- changes/106.rhn.sql

create or replace procedure
rhn_install_org_satellites
(
    for_customer_id in web_customer.id%type,
    sat_cluster_id in rhn_sat_cluster.recid%type,
    username in rhn_command_queue_instances.last_update_user%type
)
is

    cursor satellite_cursor is
        select recid from rhn_sat_cluster
        where customer_id = for_customer_id
        and recid not in (
            select netsaint_id from rhn_ll_netsaint
        )
        minus
        select recid from rhn_sat_cluster
        where customer_id = for_customer_id
        and recid not in (sat_cluster_id);
    command_instance_id rhn_command_queue_instances.recid%type;
begin
    rhn_prepare_install(username, command_instance_id, 1);
    for satellite in satellite_cursor loop
        rhn_install_satellite(command_instance_id, satellite.recid);
    end loop;
end rhn_install_org_satellites;
/
show errors

-- changes/107.rhn.sql

create or replace procedure
rhn_synch_probe_state
is
begin
    update
        rhn_probe_state
    set state = 'PENDING',
        output = 'Awaiting update'
    where last_check < (
        select (
            sysdate - greatest(15 / 60 / 24,
            ((3 * rhn_deployed_probe.check_interval_minutes) / 60 / 24)))
        from rhn_deployed_probe
        where rhn_deployed_probe.recid = rhn_probe_state.probe_id
    );
    delete
    from rhn_probe_state
    where not exists (
        select 1
        from rhn_deployed_probe
        where rhn_deployed_probe.recid = rhn_probe_state.probe_id
    );
    delete
    from rhn_current_state_summaries;
    update rhn_multi_scout_threshold t
    set (scout_warning_threshold, scout_critical_threshold)=(
        select
            decode(scout_warning_threshold_is_all,0,
                scout_warning_threshold,count(scout_id)),
            decode(scout_crit_threshold_is_all,0,
                scout_critical_threshold,count(scout_id))
        from rhn_probe_state p
        where t.probe_id=p.probe_id
          and state in ('OK', 'WARNING', 'CRITICAL')
        group by t.probe_id
    );
    insert into rhn_current_state_summaries(
        customer_id,
        template_id,
        state,
        state_count,
        last_check)
    select /* satellite hosts and checks */
        p.customer_id,
        decode(p.probe_type, 'host', 'sat_host', 'check', 'sat_probe'),
        nvl(state, 'NONE'),
        count(state),
        max(last_check)
    from rhn_deployed_probe p, rhn_probe_state
    where p.recid = rhn_probe_state.probe_id
      and p.probe_type in ('host', 'check')
      and p.os_id = 14
    group by p.customer_id, p.probe_type, state
    union
    select /* non-satellite hosts and checks, for valid satellites only */
        p.customer_id,
        decode(p.probe_type, 'host', 'host_probe', 'check', 'svc_probe'),
        nvl(state, 'NONE'),
        count(state),
        max(last_check)
    from rhn_deployed_probe p, rhn_probe_state
    where p.recid = rhn_probe_state.probe_id
      and p.sat_cluster_id = rhn_probe_state.scout_id
      and p.probe_type in ('host', 'check')
      and p.os_id != 14
    group by p.customer_id, p.probe_type, state
    union
    select  /* urls */
        p.customer_id,
        decode(p.probe_type, 'url', 'll_url'),
        nvl(c.state, 'NONE'),
        count(c.state),
        max(last_check)
    from (
        -- start with a table of all of the states.
        select s.probe_id, state
        from rhn_deployed_probe p, rhn_probe_state s
        where p.recid=s.probe_id
          and p.probe_type='url'
        group by s.probe_id, state
        union
        -- every url with at least one ok, warn, or crit should start with
        -- an ok entry
        select s.probe_id, 'OK' state
        from rhn_deployed_probe p, rhn_probe_state s
        where p.recid=s.probe_id
          and p.probe_type='url'
          and state in ('WARNING', 'CRITICAL')
        group by s.probe_id, state
        minus
        -- urls that have ok, warning or critical should never be
        -- unknown or pending.
        select cs.probe_id, state
        from
            (select distinct probe_id
                from rhn_deployed_probe p, rhn_probe_state s
                where p.recid=s.probe_id
                  and p.probe_type='url'
                  and s.state in ('OK', 'WARNING','CRITICAL')
            ) cs,
            ( select 'PENDING' state from dual
              union all
              select 'UNKNOWN' state from dual
            ) ps
        minus
        -- a url that has fewer criticals than the threshold is not critical
        select ms.probe_id, 'CRITICAL'
        from (
            select probe_id, count(scout_id) state_count
            from rhn_deployed_probe p, rhn_probe_state s
            where p.recid=s.probe_id
              and p.probe_type='url'
              and s.state='CRITICAL'
            group by probe_id
            ) ps, rhn_multi_scout_threshold ms
            where ps.probe_id=ms.probe_id
              and ps.state_count<ms.scout_critical_threshold
        minus
        -- a url that has fewer warnings + criticals than the threshold
        -- is not warning
        select ms.probe_id, 'WARNING'
        from
            (   select probe_id, count(scout_id) state_count
                from rhn_deployed_probe p, rhn_probe_state s
                where p.recid=s.probe_id
                  and p.probe_type='url'
                  and s.state in ('WARNING','CRITICAL')
                group by probe_id
            ) ps, rhn_multi_scout_threshold ms
        where ps.probe_id=ms.probe_id
          and ps.state_count<ms.scout_warning_threshold
        minus
        -- false warnings and false criticals have been eliminated.
        -- a url that is critical is not ok, pending, warning or unknown.
        select cs.probe_id, state
        from
            (   select probe_id, count(scout_id) state_count
                from rhn_deployed_probe p, rhn_probe_state s
                where p.recid=s.probe_id
                and p.probe_type='url'
                and s.state='CRITICAL'
                group by probe_id
            ) cs,
            (   select 'OK' state from dual
                union all
                select 'WARNING' state from dual
                union all
                select 'PENDING' state from dual
                union all
                select 'UNKNOWN' state from dual
            ) ps,
        rhn_multi_scout_threshold ms
        where cs.probe_id=ms.probe_id
          and cs.state_count>=ms.scout_critical_threshold
        minus
        -- a url that is warning is not ok, pending or unknown.
        select cs.probe_id, state
        from  (  select probe_id, count(scout_id) state_count
                from rhn_deployed_probe p, rhn_probe_state s
                where p.recid=s.probe_id
                  and p.probe_type='url'
                  and s.state in ('CRITICAL', 'WARNING')
                group by probe_id
            ) cs,
            (   select 'OK' state from dual
                union all
                select 'PENDING' state from dual
                union all
                select 'UNKNOWN' state from dual
            ) ps,
            rhn_multi_scout_threshold ms
        where cs.probe_id=ms.probe_id
          and cs.state_count>=ms.scout_warning_threshold
        minus
        -- a url that is unknown is not pending
        select distinct s.probe_id, 'PENDING' state
        from
            rhn_probe_state s,
            rhn_deployed_probe p
        where p.probe_type='url'
          and s.probe_id=p.recid
          and state='UNKNOWN'
    ) c,
    (   select
            probe_id,
            max(last_check) last_check
        from
            rhn_probe_state s,
            rhn_deployed_probe p
        where probe_id=recid
          and probe_type='url'
        group by probe_id
    ) l,
    rhn_deployed_probe p
    where c.probe_id=p.recid
      and c.probe_id=l.probe_id
    group by p.customer_id, p.probe_type, c.state;
    insert into rhn_current_state_summaries(
        customer_id,
        template_id,
        state,
        state_count,
        last_check)
    select
        nvl(min(rhn_deployed_probe.customer_id), 0),
        'satellite',
        'NONE',
        0,
        max(last_check)
    from rhn_satellite_state, rhn_deployed_probe
    where satellite_id = rhn_deployed_probe.sat_cluster_id
    group by rhn_deployed_probe.customer_id;
end rhn_synch_probe_state;
/
show errors

-- changes/108.rhn.sql

create or replace trigger
rhn_cmeth_val_trig
before insert or update on rhn_contact_methods
referencing new as new old as old
for each row
declare
    msg  varchar2(200);
    missing_data exception;
begin
    msg :='missing or invalid data for contact_methods table';

    if :new.method_type_id = 1
    then
    --- pager fields pager_email,pager_split_long_messages should be not null
        if (
            :new.pager_email   is null     or
            :new.pager_split_long_messages  is null )
        then
            raise missing_data;
        end if;
    end if;
    if :new.method_type_id = 2
    then

    --- the all email fields but email_reply_to should be not null
        if :new.email_address is null
        then
            raise missing_data;
        end if;
    end if;

    if :new.method_type_id = 5
    then

    --- the all sntp fields be not null
        if (:new.snmp_host is null   or
           :new.snmp_port is null)
        then
            raise missing_data;
        end if;
    end if;

    exception
    when missing_data then
    raise_application_error (-20012,msg);
    when others then
    raise;
end rhn_cmeth_val_trig;
/
show errors


-- changes/109.rhn.sql

create or replace trigger
rhn_current_alerts_mod_trig
before insert or update on rhn_current_alerts
referencing new as new old as old
for each row
declare
msg varchar2(200);
date_completed_is_null exception;
date_completed_is_not_null exception;
begin
    if :new.in_progress=0 and :new.date_completed is null
    then
        --- in_progress and date_completed are being updated simultaneously
        if ( updating( 'in_progress' ) and updating( 'date_completed') )
             or inserting
        then
            raise date_completed_is_null;
        elsif  updating( 'in_progress' )
        ---  date_completed is not being updated - so we can close the alert
        then
            :new.date_completed:=sysdate;
        else
        ---  date_completed is being updated - so we have to reopen alert
            :new.in_progress:=1;
        end if;
    elsif :new.in_progress=1 and :new.date_completed is not null
    then

        if ( updating( 'in_progress' ) and updating( 'date_completed') )
            or inserting
        --- in_progress and date_completed are being updated simultaneously
        then
            raise date_completed_is_not_null;
        elsif  updating( 'in_progress' )
        ---  date_completed is not being updated - so we can reopen the alert
        then
            :new.date_completed:=null;
        else
        ---  date_completed is being updated - so we have to close alert
            :new.in_progress:=0;
        end if;

    end if;

    exception
    when date_completed_is_null then
    msg:='date_completed is null while in_progress=0';
    raise_application_error (-20012,msg);
    when date_completed_is_not_null then
    msg:='date_completed is not null while in_progress=1';
    raise_application_error (-20012,msg);
    when others then
    raise;
end rhn_current_alerts_mod_trig;
/
show errors


-- changes/110.rhn.sql

create table
rhn_semantic_data_type
(
    name                varchar2 (10)
        constraint rhn_sdtyp_name_nn not null
        constraint rhn_sdtyp_name_pk primary key,
    description         varchar2 (80)
        constraint rhn_sdtyp_desc_nn not null,
    label_name          varchar2 (80),
    converter_name      varchar2 (128),
    help_file           varchar2 (128),
    last_update_user    varchar2 (40),
    last_update_date    date
)
    storage ( freelists 16 )
    initrans 32;
comment on table rhn_semantic_data_type
    is 'sdtyp  data type int, float, string, ipaddress, hostname';

-- changes/111.rhn.sql

alter table rhn_sat_cluster
    add constraint rhn_satcl_phslc_phys_loc_fk
    foreign key ( physical_location_id )
    references rhn_physical_location( recid );
alter table rhn_probe
    add constraint rhn_probe_prbtp_probe_type_fk
    foreign key ( probe_type )
    references rhn_probe_types( probe_type );
alter table rhn_check_suite_probe
    add constraint rhn_ckspb_cksut_ck_suite_id_fk
    foreign key ( check_suite_id )
    references rhn_check_suites( recid )
    on delete cascade;
alter table rhn_command_parameter
    add constraint rhn_cparm_sdtyp_name_fk
    foreign key ( data_type_name )
    references rhn_semantic_data_type( name );
alter table rhn_command_parameter
    add constraint rhn_cparm_wdgt_fld_wdgt_n_fk
    foreign key ( field_widget_name )
    references rhn_widget( name );

-- changes/114.rhn.sql

create or replace
package rhn_server
is

    -- i.e., "can this box do management stuff?" and yes if provisioning box
    function system_service_level(
	server_id_in in number,
	service_level_in in varchar2
    ) return number;

    function can_change_base_channel(
	server_id_in in number
    ) return number;

    procedure set_custom_value(
	server_id_in in number,
	user_id_in in number,
	key_label_in varchar2,
	value_in in varchar2
    );

    procedure bulk_set_custom_value(
	key_label_in in varchar2,
	value_in in varchar2,
	set_label_in in varchar2,
	set_uid_in in number
    );

    procedure snapshot_server(
	server_id_in in number,
	reason_in in varchar2
    );

    procedure bulk_snapshot(
	reason_in in varchar2,
	set_label_in in varchar2,
	set_uid_in in number
    );

    procedure tag_delete(
	server_id_in in number,
	tag_id_in in number
    );

    procedure tag_snapshot(
	snapshot_id_in in number,
	org_id_in in number,
	tagname_in in varchar2
    );

    procedure bulk_snapshot_tag(
	org_id_in in number,
	tagname_in varchar2,
	set_label_in in varchar2,
	set_uid_in in number
    );

    procedure remove_action(
	server_id_in in number,
	action_id_in in number
    );

    function check_user_access(server_id_in in number, user_id_in in number) return number;

    procedure insert_into_servergroup (
	server_id_in in number,
	server_group_id_in in number
    );

    function insert_into_servergroup_maybe (
	server_id_in in number,
	server_group_id_in in number
    ) return number;

	procedure insert_set_into_servergroup (
	server_group_id_in in number,
	user_id_in in number,
	set_label_in in varchar2
	);

    procedure delete_from_servergroup (
	server_id_in in number,
	server_group_id_in in number
    );

	procedure delete_set_from_servergroup (
	server_group_id_in in number,
	user_id_in in number,
	set_label_in in varchar2
	);

	procedure clear_servergroup (
	server_group_id_in in number
	);

	procedure delete_from_org_servergroups (
	server_id_in in number
	);
end rhn_server;
/
SHOW ERRORS

create or replace
package body rhn_server
is
    function system_service_level(
	server_id_in in number,
	service_level_in in varchar2
    ) return number is
    begin
	return rhn_entitlements.entitlement_grants_service(
	    rhn_entitlements.get_server_entitlement(server_id_in),
	    service_level_in
	);
    end system_service_level;


    function can_change_base_channel(server_id_in IN NUMBER)
    return number
    is
	throwaway number;
    begin
	-- the idea: if we get past this query, the server is
	-- neither sat nor proxy, so base channel is changeable

	select 1 into throwaway
	  from rhnServer S
	 where S.id = server_id_in
	   and not exists (select 1 from rhnSatelliteInfo SI where SI.server_id = S.id)
	   and not exists (select 1 from rhnProxyInfo PI where PI.server_id = S.id);

	return 1;
    exception
	when no_data_found
	    then
	    return 0;
    end can_change_base_channel;

    procedure set_custom_value(
	server_id_in in number,
	user_id_in in number,
	key_label_in in varchar2,
	value_in in varchar2
    ) is
	key_id_val number;
    begin
	select CDK.id into key_id_val
	  from rhnCustomDataKey CDK,
	       rhnServer S
	 where S.id = server_id_in
	   and S.org_id = CDK.org_id
	   and CDK.label = key_label_in;

	begin
	    insert into rhnServerCustomDataValue (server_id, key_id, value, created_by, last_modified_by)
	    values (server_id_in, key_id_val, value_in, user_id_in, user_id_in);
	exception
	    when DUP_VAL_ON_INDEX
		then
		update rhnServerCustomDataValue
		   set value = value_in,
		       last_modified_by = user_id_in
		 where server_id = server_id_in
		   and key_id = key_id_val;
	end;

    end set_custom_value;

    procedure bulk_set_custom_value(
	key_label_in in varchar2,
	value_in in varchar2,
	set_label_in in varchar2,
	set_uid_in in number
    ) is
    begin
	for server in rhn_set.set_iterator(set_label_in, set_uid_in)
	loop
	    if rhn_server.system_service_level(server.element, 'provisioning') = 1 then
		rhn_server.set_custom_value(server.element, set_uid_in, key_label_in, value_in);
	    end if;
	end loop server;
    end bulk_set_custom_value;

    procedure bulk_snapshot_tag(
	org_id_in in number,
        tagname_in in varchar2,
	set_label_in in varchar2,
	set_uid_in in number
    ) is
	snapshot_id number;
    begin
	for server in rhn_set.set_iterator(set_label_in, set_uid_in)
	loop
	    if rhn_server.system_service_level(server.element, 'provisioning') = 1 then
		begin
		    select max(id) into snapshot_id
		    from rhnSnapshot
		    where server_id = server.element;
		exception
		    when NO_DATA_FOUND then
			rhn_server.snapshot_server(server.element, 'tagging system:  ' || tagname_in);

			select max(id) into snapshot_id
			from rhnSnapshot
			where server_id = server.element;
		end;

		-- now have a snapshot_id to work with...
		begin
		    rhn_server.tag_snapshot(snapshot_id, org_id_in, tagname_in);
		exception
		    when DUP_VAL_ON_INDEX
			then
			-- do nothing, be forgiving...
			null;
		end;
	    end if;
	end loop server;
    end bulk_snapshot_tag;

    procedure tag_delete(
	server_id_in in number,
	tag_id_in in number
    ) is
	cursor snapshots is
		select	snapshot_id
		from	rhnSnapshotTag
		where	tag_id = tag_id_in;
	tag_id_tmp number;
    begin
	select	id into tag_id_tmp
	from	rhnTag
	where	id = tag_id_in
	for update;

	delete
		from	rhnSnapshotTag
		where	server_id = server_id_in
			and tag_id = tag_id_in;
	for snapshot in snapshots loop
		return;
	end loop;
	delete
		from rhnTag
		where id = tag_id_in;
    end tag_delete;

    procedure tag_snapshot(
        snapshot_id_in in number,
	org_id_in in number,
	tagname_in in varchar2
    ) is
    begin
	insert into rhnSnapshotTag (snapshot_id, server_id, tag_id)
	select snapshot_id_in, server_id, lookup_tag(org_id_in, tagname_in)
	from rhnSnapshot
	where id = snapshot_id_in;
    end tag_snapshot;

    procedure bulk_snapshot(
	reason_in in varchar2,
	set_label_in in varchar2,
	set_uid_in in number
    ) is
    begin
	for server in rhn_set.set_iterator(set_label_in, set_uid_in)
	loop
	    if rhn_server.system_service_level(server.element, 'provisioning') = 1 then
		rhn_server.snapshot_server(server.element, reason_in);
	    end if;
	end loop server;
    end bulk_snapshot;

    procedure snapshot_server(
	server_id_in in number,
	reason_in in varchar2
    ) is
	snapshot_id number;
	cursor revisions is
		select distinct
			cr.id
		from	rhnConfigRevision	cr,
			rhnConfigFileName	cfn,
			rhnConfigFile		cf,
			rhnConfigChannel	cc,
			rhnServerConfigChannel	scc
		where	1=1
			and scc.server_id = server_id_in
			and scc.config_channel_id = cc.id
			and cc.id = cf.config_channel_id
			and cf.id = cr.config_file_id
			and cr.id = cf.latest_config_revision_id
			and cf.config_file_name_id = cfn.id
			and cf.id = lookup_first_matching_cf(scc.server_id, cfn.path);
    begin
	select rhn_snapshot_id_seq.nextval into snapshot_id from dual;

	insert into rhnSnapshot (id, org_id, server_id, reason) (
		select	snapshot_id,
			s.org_id,
			server_id_in,
			reason_in
		from	rhnServer s
		where	s.id = server_id_in
	);
	insert into rhnSnapshotChannel (snapshot_id, channel_id) (
		select	snapshot_id, sc.channel_id
		from	rhnServerChannel sc
		where	sc.server_id = server_id_in
	);
	insert into rhnSnapshotServerGroup (snapshot_id, server_group_id) (
		select	snapshot_id, sgm.server_group_id
		from	rhnServerGroupMembers sgm
		where	sgm.server_id = server_id_in
	);
	insert into rhnSnapshotPackage (snapshot_id, nevra_id) (
		select	distinct snapshot_id,
			lookup_package_nevra(sp.name_id, sp.evr_id, null)
		from	rhnServerPackage sp
		where	sp.server_id = server_id_in
	);

	insert into rhnSnapshotConfigChannel ( snapshot_id, config_channel_id ) (
		select	snapshot_id, scc.config_channel_id
		from	rhnServerConfigChannel scc
		where	server_id = server_id_in
	);

	for revision in revisions loop
		insert into rhnSnapshotConfigRevision (
				snapshot_id, config_revision_id
			) values (
				snapshot_id, revision.id
			);
	end loop;
    end snapshot_server;

    procedure remove_action(
	server_id_in in number,
	action_id_in in number
    ) is
	-- this really wants "nulls last", but 8.1.7.3.0 sucks ass.
	-- instead, we make a local table that holds our
	-- list of ids with null prereqs.  There's surely a better way
	-- (an array instead of a table maybe?  who knows...)
	-- but I've got code to do this handy that I can look at ;)
	cursor chained_actions is
		select	id, prerequisite
		from	rhnAction
		start with id = action_id_in
		connect by prior id = prerequisite
		order by prerequisite desc;
	cursor sessions is
		select	s.id
		from	rhnKickstartSession s
		where	server_id_in in (s.old_server_id, s.new_server_id)
			and s.action_id = action_id_in
			and not exists (
				select	1
				from	rhnKickstartSessionState ss
				where	ss.id = s.state_id
					and ss.label in ('failed','complete')
			);
	type chain_end_type is table of number index by binary_integer;
	chain_ends chain_end_type;
	i number;
	prereq number := 1;
    begin
	select	prerequisite
	into	prereq
	from	rhnAction
	where	id = action_id_in;

	if prereq is not null then
		rhn_exception.raise_exception('action_is_child');
	end if;

	i := 0;
	for action in chained_actions loop
		if action.prerequisite is null then
			chain_ends(i) := action.id;
			i := i + 1;
		else
			delete from rhnServerAction
				where server_id = server_id_in
				and action_id = action.id;
		end if;
	end loop;
	i := chain_ends.first;
	while i is not null loop
		delete from rhnServerAction
			where server_id = server_id_in
			and action_id = chain_ends(i);
		i := chain_ends.next(i);
	end loop;
	for s in sessions loop
		update rhnKickstartSession
			set 	state_id = (
					select	id
					from	rhnKickstartSessionState
					where	label = 'failed'
				),
				action_id = null
			where	id = s.id;
		set_ks_session_history_message(s.id, 'failed', 'Kickstart cancelled due to action removal');
	end loop;
    end remove_action;

    function check_user_access(server_id_in in number, user_id_in in number)
    return number
    is
	has_access number;
    begin
	-- first check; if this returns no rows, then the server/user are in different orgs, and we bail
        select 1 into has_access
	  from rhnServer S,
	       web_contact wc
	 where wc.org_id = s.org_id
	   and s.id = server_id_in
	   and wc.id = user_id_in;

	-- okay, so they're in the same org.  if we have an org admin, they get a free pass
	if rhn_user.check_role(user_id_in, 'org_admin') = 1
	then
	    return 1;
	end if;

	select 1 into has_access
	  from rhnServerGroupMembers SGM,
	       rhnUserServerGroupPerms USG
	 where SGM.server_group_id = USG.server_group_id
	   and SGM.server_id = server_id_in
	   and USG.user_id = user_id_in
	   and rownum = 1;

	return 1;
    exception
	when no_data_found
	    then
	    return 0;
    end check_user_access;

    procedure insert_into_servergroup (
		server_id_in in number,
		server_group_id_in in number
    ) is
		used_slots number;
		max_slots number;
		org_id number;
		mgmt_available number;
		mgmt_upgrade number;
		mgmt_sgid number;
		prov_available number;
		prov_upgrade number;
		prov_sgid number;
		group_label rhnServerGroupType.label%TYPE;
		group_type number;
	begin
		-- frist, group_type = null, because it's easy...

		-- this will rowlock the servergroup we're trying to change;
		-- we probably need to lock the other one, but I think the chances
		-- of it being a real issue are very small for now...
		select	sg.group_type, sg.org_id, sg.current_members, sg.max_members
		into	group_type, org_id, used_slots, max_slots
		from	rhnServerGroup sg
		where	sg.id = server_group_id_in
		for update of sg.current_members;

		if group_type is null then
			if used_slots >= max_slots then
				rhn_exception.raise_exception('servergroup_max_members');
			end if;

			insert into rhnServerGroupMembers(
					server_id, server_group_id
				) values (
					server_id_in, server_group_id_in
				);
			update rhnServerGroup
				set current_members = current_members + 1
				where id = server_group_id_in;
			return;
		end if;

		-- now for group_type != null
		--
		select	label
		into	group_label
		from	rhnServerGroupType	sgt
		where	sgt.id = group_type;

		-- the naive easy path that gets hit most often and has to be quickest.
		if group_label in ('sw_mgr_entitled','enterprise_entitled') then
			if used_slots >= max_slots then
				rhn_exception.raise_exception('servergroup_max_members');
			end if;

			insert into rhnServerGroupMembers(
					server_id, server_group_id
				) values (
					server_id_in, server_group_id_in
				);
			update rhnServerGroup
				set current_members = current_members + 1
				where id = server_group_id_in;
			return;
		else -- we're doing provisioning
			-- now, complication
			-- first, find out what's available where.
			rhn_entitlements.get_available_slots(
					org_id, 'provisioning_entitled', prov_sgid,
					prov_available, prov_upgrade);
			rhn_entitlements.get_available_slots(
					org_id, 'enterprise_entitled', mgmt_sgid,
					mgmt_available, mgmt_upgrade);

			-- now, what're we trying to do...
			if prov_available < 1 then
				if prov_upgrade > 0 then
					rhn_exception.raise_exception('servergroup_use_upgrade');
				end if;
				rhn_exception.raise_exception('servergroup_max_members');
			end if;
			insert into rhnServerGroupMembers(
					server_id, server_group_id
				) values (
					server_id_in, server_group_id_in
				);
			update rhnServerGroup
				set current_members = current_members + 1
				where id = server_group_id_in;
			update rhnServerGroup
				set max_members = max_members - 1
				where id = mgmt_sgid;
		end if;
	end;

	function insert_into_servergroup_maybe (
		server_id_in in number,
		server_group_id_in in number
	) return number is
		retval number := 0;
		cursor servergroups is
			select	s.id	server_id,
					sg.id	server_group_id
			from	rhnServerGroup	sg,
					rhnServer		s
			where	s.id = server_id_in
				and sg.id = server_group_id_in
				and s.org_id = sg.org_id
				and not exists (
					select	1
					from	rhnServerGroupMembers sgm
					where	sgm.server_id = s.id
						and sgm.server_group_id = sg.id
				);
	begin
		for sgm in servergroups loop
			rhn_server.insert_into_servergroup(sgm.server_id, sgm.server_group_id);
			retval := retval + 1;
		end loop;
		return retval;
	end insert_into_servergroup_maybe;

	procedure insert_set_into_servergroup (
		server_group_id_in in number,
		user_id_in in number,
		set_label_in in varchar2
	) is
		cursor servers is
			select	st.element	id
			from	rhnSet		st
			where	st.user_id = user_id_in
				and st.label = set_label_in
				and exists (
					select	1
					from	rhnUserManagedServerGroups umsg
					where	umsg.server_group_id = server_group_id_in
						and umsg.user_id = user_id_in
					)
				and not exists (
					select	1
					from	rhnServerGroupMembers sgm
					where	sgm.server_id = st.element
						and sgm.server_group_id = server_group_id_in
				);
	begin
		for s in servers loop
			rhn_server.insert_into_servergroup(s.id, server_group_id_in);
		end loop;
	end insert_set_into_servergroup;

    procedure delete_from_servergroup (
	server_id_in in number,
		server_group_id_in in number
    ) is
		oid number;
		mgmt_sgid number;
		label rhnServerGroupType.label%TYPE;
		group_type number;
	begin
		begin
			select	sg.group_type, sg.org_id
			into	group_type,	oid
			from	rhnServerGroupMembers	sgm,
					rhnServerGroup			sg
			where	sg.id = server_group_id_in
				and sg.id = sgm.server_group_id
				and sgm.server_id = server_id_in
			for update of sg.current_members;
		exception
			when no_data_found then
				rhn_exception.raise_exception('server_not_in_group');
		end;

		-- do group_type is null first
		if group_type is null then
			delete from rhnServerGroupMembers
				where server_group_id = server_group_id_in
				and	server_id = server_id_in;
			update rhnServerGroup
				set current_members = current_members - 1
				where id = server_group_id_in;
			return;
		end if;

		select	sgt.label
		into	label
		from	rhnServerGroupType sgt
		where	sgt.id = group_type;

		if label in ('sw_mgr_entitled','enterprise_entitled') then
			delete from rhnServerGroupMembers
				where server_group_id = server_group_id_in
				and	server_id = server_id_in;
			update rhnServerGroup
				set current_members = current_members - 1
				where id = server_group_id_in;
		else
			-- now we're in provisoning land...
			-- 1) find the mgmt group this prov group is coupled with...
			select	sg.id
			into	mgmt_sgid
			from	rhnServerGroupType	sgt,
					rhnServerGroup		sg
			where	sg.org_id = oid
				and sgt.label = 'enterprise_entitled'
				and sgt.id = sg.group_type
			for update of sg.max_members;

			-- 2) do the delete
			delete from rhnServerGroupMembers
				where server_group_id = server_group_id_in
				and	server_id = server_id_in;
			-- 3) fix the current/max members for both server groups
			update rhnServerGroup
				set max_members = max_members + 1
				where id = mgmt_sgid;
			update rhnServerGroup
				set current_members = current_members - 1
				where id = server_group_id_in;
		end if;
	end;

	procedure delete_set_from_servergroup (
		server_group_id_in in number,
		user_id_in in number,
		set_label_in in varchar2
	) is
		cursor servergroups is
			select	sgm.server_id, sgm.server_group_id
			from	rhnSet st,
					rhnServerGroupMembers sgm
			where	sgm.server_group_id = server_group_id_in
				and st.user_id = user_id_in
				and st.label = set_label_in
				and sgm.server_id = st.element
				and exists (
					select	1
					from	rhnUserManagedServerGroups usgp
					where	usgp.server_group_id = server_group_id_in
						and usgp.user_id = user_id_in
				);
	begin
		for sgm in servergroups loop
			rhn_server.delete_from_servergroup(sgm.server_id, server_group_id_in);
		end loop;
	end delete_set_from_servergroup;

	procedure clear_servergroup (
		server_group_id_in in number
	) is
		cursor servers is
			select	sgm.server_id	id
			from	rhnServerGroupMembers sgm
			where	sgm.server_group_id = server_group_id_in;
	begin
		for s in servers loop
			rhn_server.delete_from_servergroup(s.id, server_group_id_in);
		end loop;
	end clear_servergroup;

	procedure delete_from_org_servergroups (
		server_id_in in number
	) is
		cursor servergroups is
			select	sgm.server_group_id id
			from	rhnServerGroup sg,
					rhnServerGroupMembers sgm
			where	sgm.server_id = server_id_in
				and sgm.server_group_id = sg.id
				and sg.group_type is null;
	begin
		for sg in servergroups loop
			rhn_server.delete_from_servergroup(server_id_in, sg.id);
		end loop;
	end delete_from_org_servergroups;
end rhn_server;
/
SHOW ERRORS

-- changes/115.rhn.sql

create table
db_change_lock
(
	locked			char(1)
				constraint dc_lock_locked_nn not null,
	bug_id			number
				constraint dc_lock_bid_nn not null,
	seq_no			number
				constraint dc_lock_sn_nn not null,
	owner			varchar2(255)
				constraint dc_lock_owner_nn not null,
	lock_date		date
				constraint dc_lock_ld_nn not null
)
	storage ( freelists 16 )
	initrans 32;

COMMENT ON TABLE db_change_lock IS
	'DBCLK  Database change lock for synchronization ';

create unique index dc_lock_locked_uq
	on db_change_lock( locked )
	storage ( freelists 16 )
	initrans 32;

create table
db_change_script
(
	bug_id		number
			constraint dc_script_bid_nn not null,
	seq_no		number
			constraint dc_script_sn_nn not null,
	owner		varchar2(255)
			constraint dc_script_owner_nn not null,
	description	varchar2(4000),
	release		varchar2(255),
	run_as		varchar2(255)
);

COMMENT ON TABLE db_change_script IS
	'DBCSC  Database change script meta-data';

create index dc_script_bid_sn_idx
	on db_change_script( bug_id, seq_no )
	storage ( freelists 16 )
	initrans 32;
alter table db_change_script add constraint dc_script_bid_sn_pk
	primary key ( bug_id, seq_no );

create table
db_change_script_source
(
	bug_id		number
			constraint dc_scriptsource_bid_nn not null,
	seq_no		number
			constraint dc_scriptsource_sn_nn not null,
	line_no		number
			constraint dc_scriptsource_ln_nn not null,
	line		varchar2(1000)
			constraint dc_scriptsource_l_nn not null
)
	storage ( freelists 16 )
	initrans 32;

COMMENT ON TABLE db_change_script_source IS
	'DBCSS  Database change script bodies';

create index dc_scriptsource_bid_sn_idx
	on db_change_script_source( bug_id, seq_no )
	storage ( freelists 16 )
	initrans 32;
alter table db_change_script_source add constraint dc_scriptsource_bid_sn_fk
	foreign key ( bug_id, seq_no )
	references db_change_script( bug_id, seq_no )
	on delete cascade;

create table
db_change_script_expanded
(
	bug_id		number
			constraint dc_scriptexpanded_bid_nn not null,
	seq_no		number
			constraint dc_scriptexpanded_sn_nn not null,
	line_no		number
			constraint dc_scriptexpanded_ln_nn not null,
	line		varchar2(1000)
			constraint dc_scriptexpanded_l_nn not null
)
	storage ( freelists 16 )
	initrans 32;

COMMENT ON TABLE db_change_script_expanded IS
	'DBCSS  Database change script bodies';

create index dc_scriptexpanded_bid_sn_idx
	on db_change_script_expanded( bug_id, seq_no )
	storage ( freelists 16 )
	initrans 32;
alter table db_change_script_expanded add constraint dc_scriptexpanded_bid_sn_fk
	foreign key ( bug_id, seq_no )
	references db_change_script( bug_id, seq_no )
	on delete cascade;

create table
db_change_ignore_errs
(
	bug_id		number
			constraint dc_ignoreerrs_bid_nn not null,
	seq_no		number
			constraint dc_ignoreerrs_sn_nn not null,
	err_no		number
			constraint dc_ignoreerrs_en_nn not null
)
	storage ( freelists 16 )
	initrans 32;

COMMENT ON TABLE db_change_ignore_errs IS
	'DBCIE  Error numbers that may be safely ignored ';

create index dc_ignoreerrs_bid_sn_idx
	on db_change_ignore_errs( bug_id, seq_no )
	storage ( freelists 16 )
	initrans 32;
alter table db_change_ignore_errs add constraint dc_ignorerrs_bid_sn_fk
	foreign key ( bug_id, seq_no )
	references db_change_script( bug_id, seq_no )
	on delete cascade;

create table
db_change_resource_types
(
	resource_type		varchar2(255)
				constraint dc_resourcetype_rt_nn not null
				constraint dc_resourcetype_rt_pk primary key
)
	storage ( freelists 16 )
	initrans 32;

COMMENT ON TABLE db_change_resource_types IS
	'DBCRT  Types of resources that can be changed (table, view, stored procedure, etc.)';

insert into db_change_resource_types
	select distinct object_type from all_objects;
commit;

create table
db_change_resource_names
(
	resource_type	varchar2(255)
			constraint dc_resourcename_rt_nn not null
			constraint dc_resourcename_rt_fk
				references db_change_resource_types(resource_type),
	resource_name	varchar2(255)
			constraint dc_resourcename_rn_nn not null
)
	storage ( freelists 16 )
	initrans 32;

COMMENT ON TABLE db_change_resource_names IS
	'DBCRN  Resources that can be changed (e.g. table WEB_USER)';

create index dc_resourcename_rt_rn_idx
	on db_change_resource_names( resource_type, resource_name )
	storage ( freelists 16 )
	initrans 32;
alter table db_change_resource_names add constraint dc_resourcename_rt_rn_pk
	primary key ( resource_type, resource_name );

create table
db_change_resource_changes
(
	change_type		varchar2(10)
				constraint dc_resourcechange_type_nn not null
)
	storage ( freelists 16 )
	initrans 32;

COMMENT ON TABLE db_change_resource_changes IS
	'DBCRC Recognized types of resource changes';

create index dc_resourcechange_type_idx
	on db_change_resource_changes( change_type )
	storage ( freelists 16 )
	initrans 32;
alter table db_change_resource_changes add constraint dc_resourcechange_type_pk
	primary key ( change_type );


INSERT INTO db_change_resource_changes( change_type )
	VALUES ('CREATED');
INSERT INTO db_change_resource_changes( change_type )
	VALUES ('DROPPED');
INSERT INTO db_change_resource_changes( change_type )
	VALUES ('ALTERED');
commit;

create table
db_change_resources
(
	bug_id		number
			constraint dc_resources_bid_nn not null,
	seq_no		number
			constraint dc_resources_sn_nn not null,
	resource_type	varchar2(255)
			constraint dc_resources_rt_nn not null,
	resource_name	varchar2(255)
			constraint dc_resources_rn_nn not null,
	change_type	varchar2(255)
			constraint dc_resources_ct_nn not null
)
	storage ( freelists 16 )
	initrans 32;

create index dc_resources_bid_sn_idx
	on db_change_resources( bug_id, seq_no )
	storage ( freelists 16 )
	initrans 32;
alter table db_change_resources add constraint dc_resources_bid_sn_fk
	foreign key ( bug_id, seq_no )
	references db_change_script( bug_id, seq_no )
	on delete cascade;

create index dc_resources_rt_rn_idx
	on db_change_resources( resource_type, resource_name )
	storage ( freelists 16 )
	initrans 32;
alter table db_change_resources add constraint dc_resources_rt_rn_fk
	foreign key ( resource_type, resource_name )
	references db_change_resource_names( resource_type, resource_name )
	on delete cascade;

create index dc_resources_ct_idx
	on db_change_resources( change_type )
	storage ( freelists 16 )
	initrans 32;
alter table db_change_resources add constraint dc_resources_ct_fk
	foreign key ( change_type )
	references db_change_resource_changes( change_type )
	on delete cascade;

create table
db_change_history
(
	bug_id		number
			constraint dc_history_bid_nn not null,
	seq_no		number
			constraint dc_history_sn_nn not null,
	date_applied	date
			constraint dc_history_da_nn not null,
	failed		char(1)
			constraint dc_history_f_nn not null
)
	storage ( freelists 16 )
	initrans 32;

COMMENT ON TABLE db_change_history IS
	'DBCHI  History of changes applied';

create index dc_history_bid_sn_idx
	on db_change_history( bug_id, seq_no )
	storage ( freelists 16 )
	initrans 32;
alter table db_change_history add constraint dc_history_bid_sn_fk
	foreign key ( bug_id, seq_no )
	references db_change_script( bug_id, seq_no )
	on delete cascade;

create table
db_change_history_output
(
	bug_id		number
			constraint dc_historyoutput_bid_nn not null,
	seq_no		number
			constraint dc_historyoutput_sn_nn not null,
	line_no		number
			constraint dc_historyoutput_ln_nn not null,
	line		varchar2(1000)
			constraint dc_historyoutput_l_nn not null
)
	storage ( freelists 16 )
	initrans 32;

COMMENT ON TABLE db_change_history_output IS
	'DBCHO  Database change output lines';

create index dc_historyoutput_bid_sn_idx
	on db_change_history_output( bug_id, seq_no )
	storage ( freelists 16 )
	initrans 32;
alter table db_change_history_output add constraint dc_historyoutput_bid_sn_fk
	foreign key ( bug_id, seq_no )
	references db_change_script( bug_id, seq_no )
	on delete cascade;

-- changes/117.rhn.sql

create or replace
package rhn_entitlements
is
	body_version varchar2(100) := '$Id: satellite-3.2-to-3.4.sql 64427 2005-09-09 14:08:21Z jslagle $';

	    function entitlement_grants_service (
		    entitlement_in in varchar2,
			service_level_in in varchar2
		) return number;

		function lookup_entitlement_group (
			org_id_in in number,
			type_label_in in varchar2 := 'sw_mgr_entitled'
		) return number;

		function create_entitlement_group (
			org_id_in in number,
			type_label_in in varchar2 := 'sw_mgr_entitled'
		) return number;

		procedure entitle_server (
			server_id_in in number,
			type_label_in in varchar2 := 'sw_mgr_entitled'
		);

		procedure unentitle_server (
			server_id_in in number,
			type_label_in in varchar2 := 'sw_mgr_entitled'
		);

		-- upgrade server wants you already to be in an
		-- enterprise_entitled server group, and tries to
		-- put you in a provisioning_entitled one instead.
		procedure upgrade_server (
			server_id_in in number
		);

		function get_server_entitlement (
			server_id_in in number
		) return varchar2;

		procedure modify_org_service (
			org_id_in in number,
			service_label_in in varchar2,
			enable_in in char
		);

	    procedure set_customer_enterprise (
			customer_id_in in number
		);

		procedure set_customer_provisioning (
			customer_id_in in number
		);

		procedure set_customer_nonlinux (
			customer_id_in in number
		);

	    procedure unset_customer_enterprise (
			customer_id_in in number
		);

		procedure unset_customer_provisioning (
			customer_id_in in number
		);

		procedure unset_customer_nonlinux (
			customer_id_in in number
		);

	    procedure set_group_count (
			customer_id_in in number,	-- customer_id
			type_in in char,			-- 'U' or 'S'
			group_type_in in number,	-- rhn[User|Server]GroupType.id
			quantity_in in number		-- quantity
	    );

	    procedure set_family_count (
			customer_id_in in number,		-- customer_id
			channel_family_id_in in number,	-- 246
			quantity_in in number			-- 3
	    );

	    -- this makes NO checks that the quantity is within max,
	    -- so we should NEVER run this unless we KNOW that we won't be
	    -- violating the max
	    procedure entitle_last_modified_servers (
			customer_id_in in number,	-- customer_id
			type_label_in in varchar2,	-- 'enterprise_entitled'
			quantity_in in number		-- 3
	    );

		-- results from this are valid _only_ in the context of the
		-- server group label queried.  If you ask for provisioning
		-- data, don't compare that with results for enterprise data.
		procedure get_available_slots (
			customer_id_in in number,
			type_label_in in varchar2,
			server_group_id_out out number,
			available_out out number,
			upgrade_out out number
		);

		procedure prune_everything (
			customer_id_in in number
		);

		procedure subscribe_newest_servers (
			customer_id_in in number
		);
end rhn_entitlements;
/
show errors

create or replace
package body rhn_entitlements
is
	body_version varchar2(100) := '$Id: satellite-3.2-to-3.4.sql 64427 2005-09-09 14:08:21Z jslagle $';

	function entitlement_grants_service (
	    entitlement_in in varchar2,
	    service_level_in in varchar2
	) return number	is
	begin
		if service_level_in = 'provisioning' then
			if entitlement_in = 'provisioning_entitled' then
				return 1;
			else
				return 0;
			end if;
		elsif service_level_in = 'management' then
			if entitlement_in = 'provisioning_entitled' then
				return 1;
			elsif entitlement_in = 'enterprise_entitled' then
				return 1;
			elsif entitlement_in = 'nonlinux_entitled' then
				return 1;
			else
				return 0;
			end if;
		elsif service_level_in = 'monitoring' then
			if entitlement_in = 'monitoring_entitled' then
				return 1;
			end if;
		elsif service_level_in = 'updates' then
			return 1;
		else
			return 0;
		end if;
	end entitlement_grants_service;

	function lookup_entitlement_group (
		org_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	) return number is
		cursor server_groups is
			select	sg.id				server_group_id
			from	rhnServerGroup		sg,
					rhnServerGroupType	sgt
			where	sgt.label = type_label_in
				and sgt.id = sg.group_type
				and sg.org_id = org_id_in;
	begin
		for sg in server_groups loop
			return sg.server_group_id;
		end loop;
		return rhn_entitlements.create_entitlement_group(
				org_id_in,
				type_label_in
			);
	end lookup_entitlement_group;

	function create_entitlement_group (
		org_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	) return number is
		sg_id_val number;
	begin
		select	rhn_server_group_id_seq.nextval
		into	sg_id_val
		from	dual;

		insert into rhnServerGroup (
				id, name, description, max_members, current_members,
				group_type, org_id
			) (
				select	sg_id_val, sgt.label, sgt.label,
						0, 0, sgt.id, org_id_in
				from	rhnServerGroupType sgt
				where	sgt.label = type_label_in
			);

		return sg_id_val;
	end create_entitlement_group;

	procedure entitle_server (
		server_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	) is
		cursor servergroups is
			select	sg.id id,
					s.server_arch_id server_arch_id,
					sgt.id server_group_type
			from	rhnServerGroupType sgt,
					rhnServerGroup sg,
					rhnServer s
			where	s.id = server_id_in
				and s.org_id = sg.org_id
				and sgt.label = type_label_in
				and sg.group_type = sgt.id;
		cursor sg_arches(sgt_id_in in number, sa_id_in in number) is
			select	1
			from	rhnServerServerGroupArchCompat
			where	server_group_type = sgt_id_in
				and server_arch_id = sa_id_in;
		previous_ent rhnServerGroupType.label%TYPE;
	begin
		previous_ent := rhn_entitlements.get_server_entitlement(server_id_in);
		if previous_ent != 'none' then
			rhn_exception.raise_exception(
								'no_server_multiple_swmgr_entitlements');
		end if;

		for sg in servergroups loop
			for a in sg_arches(sg.server_group_type, sg.server_arch_id) loop
				-- if the max_members is too low, this'll raise
				-- servergroup_max_members
				rhn_server.insert_into_servergroup(server_id_in, sg.id);
				return;
			end loop;
			-- we only get here if we can't find any compatible
			-- server_arch+server_group_type combination
			rhn_exception.raise_exception('mismatching_entitlement');
		end loop;
		-- we only get here if there's _no_ server group for that type;
		-- that's the same as max_members=0
		rhn_exception.raise_exception('servergroup_max_members');
	end entitle_server;

	procedure unentitle_server (
		server_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	) is
		group_id number;
	begin
		select	sg.id
		into	group_id
		from	rhnServerGroupType sgt,
				rhnServerGroup sg,
				rhnServerGroupMembers sgm,
				rhnServer s
		where	s.id = server_id_in
			and s.id = sgm.server_id
			and sgm.server_group_id = sg.id
			and sg.org_id = s.org_id
			and sgt.label = type_label_in
			and sgt.id = sg.group_type;

		rhn_server.delete_from_servergroup(server_id_in, group_id);
		exception
		when no_data_found then
					null;
	end unentitle_server;

	-- right now, this is racy.  Don't do it twice at once
	-- for the same org.  You've been warned...
	procedure upgrade_server (
		server_id_in in number
	) is
		old_sgid number;
		new_sgid number;
		new_sg_max number;
		new_sg_used number;
	begin
		begin
			select	sg0.id, sg1.id,
					sg1.max_members, sg1.current_members
			into	old_sgid, new_sgid,
					new_sg_max, new_sg_used
			from	rhnServerGroup sg1,
					rhnServerGroupType sgt1,
					rhnServerGroupMembers sgm,
					rhnServerGroup sg0,
					rhnServerGroupType sgt0,
					rhnServer s
			where	s.id = server_id_in
				and s.org_id = sg0.org_id
				and sgt0.label = 'enterprise_entitled'
				and sgt0.id = sg0.group_type
				and s.id = sgm.server_id
				and sgm.server_group_id = sg0.id
				and s.org_id = sg1.org_id
				and sgt1.label = 'provisioning_entitled'
				and sgt1.id = sg1.group_type;
		exception
			when no_data_found then
				rhn_exception.raise_exception('invalid_upgrade');
		end;
		-- it could still happen that you run out after we check this.
		-- that's what the comment above is all about...
		if new_sg_used >= new_sg_max then
			rhn_exception.raise_exception('servergroup_max_members');
		end if;
		rhn_server.delete_from_servergroup(server_id_in, old_sgid);
		rhn_server.insert_into_servergroup(server_id_in, new_sgid);
	end upgrade_server;

	function get_server_entitlement (
		server_id_in in number
	) return varchar2 is
		cursor server_groups is
			select	sgt.label
			from	rhnServerGroupType		sgt,
					rhnServerGroup			sg,
					rhnServerGroupMembers	sgm
			where	1=1
				and sgm.server_id = server_id_in
				and sg.id = sgm.server_group_id
				and sgt.id = sg.group_type
				and sgt.label in (
					'sw_mgr_entitled','enterprise_entitled',
					'provisioning_entitled', 'nonlinux_entitled',
					'monitoring_entitled'
					);
	begin
		for sg in server_groups loop
			return sg.label;
		end loop;
		return 'none';
	end get_server_entitlement;


	-- this desperately needs to be table driven.
	procedure modify_org_service (
		org_id_in in number,
		service_label_in in varchar2,
		enable_in in char
	) is
		type roles_v is varray(10) of rhnUserGroupType.label%TYPE;
		roles_to_process roles_v;
		cursor roles(role_label_in in varchar2) is
			select	label, id
			from	rhnUserGroupType
			where	label = role_label_in;
		cursor org_roles(role_label_in in varchar2) is
			select	1
			from	rhnUserGroup ug,
					rhnUserGroupType ugt
			where	ugt.label = role_label_in
				and ug.org_id = org_id_in
				and ugt.id = ug.group_type;

		type ents_v is varray(10) of rhnOrgEntitlementType.label%TYPE;
		ents_to_process ents_v;
		cursor ents(ent_label_in in varchar2) is
			select	label, id
			from	rhnOrgEntitlementType
			where	label = ent_label_in;
		cursor org_ents(ent_label_in in varchar2) is
			select	1
			from	rhnOrgEntitlements oe,
					rhnOrgEntitlementType oet
			where	oet.label = ent_label_in
				and oe.org_id = org_id_in
				and oet.id = oe.entitlement_id;
		create_row char(1);
	begin
		ents_to_process := ents_v();
		roles_to_process := roles_v();
		-- a bit kludgy, but only for 3.4 really.  Certainly no
		-- worse than the old code...
		if service_label_in = 'enterprise' or service_label_in = 'management' then
			ents_to_process.extend;
			ents_to_process(ents_to_process.count) := 'sw_mgr_enterprise';

			roles_to_process.extend;
			roles_to_process(roles_to_process.count) := 'org_admin';
			if is_satellite() = 1 then
				roles_to_process.extend;
				roles_to_process(roles_to_process.count) := 'org_applicant';
			end if;
		elsif service_label_in = 'provisioning' then
			ents_to_process.extend;
			ents_to_process(ents_to_process.count) := 'rhn_provisioning';
			if is_satellite() = 1 then
				roles_to_process.extend;
				roles_to_process(roles_to_process.count) := 'config_admin';
			end if;
			-- another nasty special case...
			if enable_in = 'Y' then
				ents_to_process.extend;
				ents_to_process(ents_to_process.count) := 'sw_mgr_enterprise';
			end if;
		elsif service_label_in = 'nonlinux' then
			ents_to_process.extend;
			ents_to_process(ents_to_process.count) := 'rhn_nonlinux';
			if is_satellite() = 1 then
				roles_to_process.extend;
				roles_to_process(roles_to_process.count) := 'config_admin';
			end if;
		end if;

		if enable_in = 'Y' then
			for i in 1..ents_to_process.count loop
				for ent in ents(ents_to_process(i)) loop
					create_row := 'Y';
					for oe in org_ents(ent.label) loop
						create_row := 'N';
					end loop;
					if create_row = 'Y' then
						insert into rhnOrgEntitlements(org_id, entitlement_id)
							values (org_id_in, ent.id);
					end if;
				end loop;
			end loop;
			for i in 1..roles_to_process.count loop
				for role in roles(roles_to_process(i)) loop
					create_row := 'Y';
					for o_r in org_roles(role.label) loop
						create_row := 'N';
					end loop;
					if create_row = 'Y' then
						insert into rhnUserGroup(
								id, name, description, current_members,
								group_type, org_id
							) (
								select	rhn_user_group_id_seq.nextval,
										ugt.name || 's',
										ugt.name || 's for Org ' ||
											o.name || ' ('|| o.id ||')',
										0, ugt.id, o.id
								from	rhnUserGroupType ugt,
										web_customer o
								where	o.id = org_id_in
									and ugt.id = role.id
							);
					end if;
				end loop;
			end loop;
		else
			for i in 1..ents_to_process.count loop
				for ent in ents(ents_to_process(i)) loop
					delete from rhnOrgEntitlements
					 where org_id = org_id_in
					   and entitlement_id = ent.id;
				end loop;
			end loop;
		end if;
	end modify_org_service;

	procedure set_customer_enterprise (
		customer_id_in in number
	) is
	begin
		modify_org_service(customer_id_in, 'enterprise', 'Y');
	end set_customer_enterprise;

	procedure set_customer_provisioning (
		customer_id_in in number
	) is
	begin
		modify_org_service(customer_id_in, 'provisioning', 'Y');
	end set_customer_provisioning;

	procedure set_customer_nonlinux (
		customer_id_in in number
	) is
	begin
		modify_org_service(customer_id_in, 'nonlinux', 'Y');
	end set_customer_nonlinux;

	procedure unset_customer_enterprise (
		customer_id_in in number
	) is
	begin
		modify_org_service(customer_id_in, 'enterprise', 'N');
	end unset_customer_enterprise;

	procedure unset_customer_provisioning (
		customer_id_in in number
	) is
	begin
		modify_org_service(customer_id_in, 'provisioning', 'N');
	end unset_customer_provisioning;

	procedure unset_customer_nonlinux (
		customer_id_in in number
	) is
	begin
		modify_org_service(customer_id_in, 'nonlinux', 'N');
	end unset_customer_nonlinux;

	procedure prune_group (
		group_id_in in number,
		type_in in char,
		quantity_in in number
	) is
		cursor usergroups is
			select	user_id, user_group_id, ugt.label
			from	rhnUserGroupType	ugt,
					rhnUserGroup		ug,
					rhnUserGroupMembers	ugm
			where	1=1
				and ugm.user_group_id = group_id_in
				and ugm.user_id in (
					select	user_id
					from	(
						select	rownum row_number,
								user_id,
								time
						from	(
							select	user_id,
									modified time
							from	rhnUserGroupMembers
							where	user_group_id = group_id_in
							order by time asc
						)
					)
					where	row_number > quantity_in
				)
				and ugm.user_group_id = ug.id
				and ug.group_type = ugt.id;
		cursor servergroups is
			select	server_id, server_group_id, sgt.label
			from	rhnServerGroupType		sgt,
					rhnServerGroup			sg,
					rhnServerGroupMembers	sgm
			where	1=1
				and sgm.server_group_id = group_id_in
				and sgm.server_id in (
					select	server_id
					from	(
						select	rownum row_number,
								server_id,
								time
						from	(
							select	server_id,
									modified time
							from	rhnServerGroupMembers
							where	server_group_id = group_id_in
							order by time asc
						)
					)
					where	row_number > quantity_in
				)
				and sgm.server_group_id = sg.id
				and sg.group_type = sgt.id;
	begin
		if type_in = 'U' then
			update		rhnUserGroup
				set		max_members = quantity_in
				where	id = group_id_in;

			for ug in usergroups loop
				-- rhnUserGroup.max_members gets fixed in a trigger, no
				-- need to do that here
				delete
					from	rhnUserGroupMembers
					where	user_group_id = ug.user_group_id
						and user_id = ug.user_id;
			end loop;
		elsif type_in = 'S' then
			update		rhnServerGroup
				set		max_members = quantity_in
				where	id = group_id_in;

			for sg in servergroups loop
				unentitle_server(sg.server_id, sg.label);
				rhn_channel.clear_subscriptions(sg.server_id);
			end loop;
		end if;
	end prune_group;

	procedure set_group_count (
		customer_id_in in number,
		type_in in char,
		group_type_in in number,
		quantity_in in number
	) is
		group_id number;
		quantity number;
	begin
		quantity := quantity_in;
		if quantity is not null and quantity < 0 then
			quantity := 0;
		end if;

		if type_in = 'U' then
			select	rug.id
			into	group_id
			from	rhnUserGroup rug
			where	1=1
				and rug.org_id = customer_id_in
				and rug.group_type = group_type_in;
		elsif type_in = 'S' then
			select	rsg.id
			into	group_id
			from	rhnServerGroup rsg
			where	1=1
				and rsg.org_id = customer_id_in
				and rsg.group_type = group_type_in;
		end if;

		rhn_entitlements.prune_group(
			group_id,
			type_in,
			quantity
		);
	exception
		when no_data_found then
			if type_in = 'U' then
				insert into rhnUserGroup (
						id, name, description, max_members, current_members,
						group_type, org_id, created, modified
					) (
						select	rhn_user_group_id_seq.nextval, name, name,
								quantity, 0, id, customer_id_in,
								sysdate, sysdate
						from	rhnUserGroupType
						where	id = group_type_in
				);
			elsif type_in = 'S' then
				insert into rhnServerGroup (
						id, name, description, max_members, current_members,
						group_type, org_id, created, modified
					) (
						select	rhn_server_group_id_seq.nextval, name, name,
								quantity, 0, id, customer_id_in,
								sysdate, sysdate
						from	rhnServerGroupType
						where	id = group_type_in
				);
			end if;
	end set_group_count;

	procedure prune_family (
		customer_id_in in number,
		channel_family_id_in in number,
		quantity_in in number
	) is
		cursor serverchannels is
			select	sc.server_id,
					sc.channel_id
			from	rhnServerChannel sc,
					rhnChannelFamilyMembers cfm
			where	1=1
				and cfm.channel_family_id = channel_family_id_in
				and cfm.channel_id = sc.channel_id
				and server_id in (
					select	server_id
					from	(
						select	server_id,
								time,
								rownum row_number
						from	(
							select	rs.id					server_id,
									rcfm.modified			time
							from	rhnServer				rs,
									rhnServerChannel		rsc,
									rhnChannelFamilyMembers	rcfm
							where	1=1
								and rs.org_id = customer_id_in
								and rs.id = rsc.server_id
								and rsc.channel_id = rcfm.channel_id
								and rcfm.channel_family_id =
									channel_family_id_in
							order by time asc
						)
					)
					where row_number > quantity_in
				);
	begin
		-- if we get a null customer_id, this is completely bogus.
		if customer_id_in is null then
			return;
		end if;

		update		rhnPrivateChannelFamily
			set		max_members = quantity_in
			where	1=1
				and org_id = customer_id_in
				and channel_family_id = channel_family_id_in;

		for sc in serverchannels loop
			rhn_channel.unsubscribe_server(sc.server_id, sc.channel_id, 1, 1);
		end loop;
	end prune_family;

	procedure set_family_count (
		customer_id_in in number,
		channel_family_id_in in number,
		quantity_in in number
	) is
		cursor privperms is
			select	1
			from	rhnPrivateChannelFamily
			where	org_id = customer_id_in
				and channel_family_id = channel_family_id_in;
		cursor pubperms is
			select	o.id org_id
			from	web_customer o,
					rhnPublicChannelFamily pcf
			where	pcf.channel_family_id = channel_family_id_in;
		quantity number;
		done number := 0;
	begin
		quantity := quantity_in;
		if quantity is not null and quantity < 0 then
			quantity := 0;
		end if;

		if customer_id_in is not null then
			for perm in privperms loop
				rhn_entitlements.prune_family(
					customer_id_in,
					channel_family_id_in,
					quantity
				);
				update rhnPrivateChannelFamily
					set max_members = quantity
					where org_id = customer_id_in
						and channel_family_id = channel_family_id_in;
				return;
			end loop;

			insert into rhnPrivateChannelFamily (
					channel_family_id, org_id, max_members, current_members
				) values (
					channel_family_id_in, customer_id_in, quantity, 0
				);
			return;
		end if;

		for perm in pubperms loop
			if quantity = 0 then
				rhn_entitlements.prune_family(
					perm.org_id,
					channel_family_id_in,
					quantity
				);
				if done = 0 then
					delete from rhnPublicChannelFamily
						where channel_family_id = channel_family_id_in;
				end if;
			end if;
			done := 1;
		end loop;
		-- if done's not 1, then we don't have any entitlements
		if done != 1 then
			insert into rhnPublicChannelFamily (
					channel_family_id
				) values (
					channel_family_id_in
				);
		end if;
	end set_family_count;

	-- this expects quantity_in to be the number of available slots, not the
	-- max_members of the server group.  If you give it too many, it'll fail
	-- and raise servergroup_max_members.
	-- We should NEVER run this unless we're SURE that we won't
	-- be violating the max.
	procedure entitle_last_modified_servers (
		customer_id_in in number,
		type_label_in in varchar2,
		quantity_in in number
	) is
		-- find the servers that aren't currently in slots
		cursor servers(cid_in in number, quant_in in number) is
			select	server_id
			from	(
						select	rownum row_number,
								server_id
						from	(
									select	rs.id server_iD
									from	rhnServer rs
									where	1=1
										and rs.org_id = cid_in
										and not exists (
											select	1
											from	rhnServerGroup sg,
													rhnServerGroupMembers rsgm
											where	rsgm.server_id = rs.id
												and rsgm.server_group_id = sg.id
												and sg.group_type is not null
										)
									order by modified desc
								)
					)
			where	row_number <= quant_in;
	begin
		for server in servers(customer_id_in, quantity_in) loop
			rhn_entitlements.entitle_server(server.server_id, type_label_in);
		end loop;
	end entitle_last_modified_servers;

	procedure get_available_slots (
		customer_id_in in number,
		type_label_in in varchar2,
		server_group_id_out out number,
		available_out out number,
		upgrade_out out number
	) is
		mgmt_slots_unused number;
		mgmt_slots_used number;
		prov_slots_unused number;
		prov_slots_used number;
		swmgr_slots_unused number;
		sgid number;
	begin
		-- if it's the simple case, do it and get out
		if type_label_in in (
					'sw_mgr_entitled',
					'nonlinux_entitled',
					'monitoring_entitled'
				) then
			begin
				select	max_members - current_members, sg.id
				into	swmgr_slots_unused, sgid
				from	rhnServerGroup		sg,
						rhnServerGroupType	sgt
				where	sgt.label = type_label_in
					and sg.org_id = customer_id_in
					and sg.group_type = sgt.id;

				available_out := swmgr_slots_unused;
				upgrade_out := 0;
				server_group_id_out := sgid;
			exception
				when no_data_found then
					available_out := 0;
					if type_label_in = 'sw_mgr_entitled' then
						available_out := 1;
					end if;
					upgrade_out := 0;
					server_group_id_out := null;
			end;
			return;
		end if;

		begin
			select	sg.current_members,
					sg.max_members - sg.current_members,
					sg.id
			into	mgmt_slots_used,
					mgmt_slots_unused,
					sgid
			from	rhnServerGroup		sg,
					rhnServerGroupType	sgt
			where	sgt.label = 'enterprise_entitled'
				and sg.org_id = customer_id_in
				and sg.group_type = sgt.id;
		exception
			when no_data_found then
				-- if there's no enterprise_entitled group, then
				-- this user doesn't have mgmt or prov at all,
				-- so bail out now.
				available_out := 0;
				upgrade_out := 0;
				server_group_id_out := null;
				return;
		end;

		-- we list all mgmt slots as things you can upgrade to
		-- from basic
		if type_label_in = 'enterprise_entitled' then
			available_out := mgmt_slots_unused;
			upgrade_out := 0;
			server_group_id_out := sgid;
			return;
		end if;

		-- the only thing left is provisioning
		begin
			select	sg.current_members,
					sg.max_members - sg.current_members,
					sg.id
			into	prov_slots_used,
					prov_slots_unused,
					sgid
			from	rhnServerGroup		sg,
					rhnServerGroupType	sgt
			where	sgt.label = 'provisioning_entitled'
				and sg.org_id = customer_id_in
				and sg.group_type = sgt.id;
		exception
			when no_data_found then
				available_out := 0;
				upgrade_out := 0;
				server_group_id_out := null;
				return;
		end;

		-- An example to illustrate what I'm doing to compute upgradable slots
		-- 1) The user buys 3 provisioning entitlements.  This means:
		--      enterprise_entitled max_members = 3, current_members = 0    (prov_slots_unused = 3)
		--      provisioning_entitled max_members = 3, current_members = 0  (prov_slots_unsued = 3)
		--    0 upgrade, 3 available
		-- 2) The user subscribes a system for management.  This means:
		--      enterprise_entitled max_members = 3, current_members = 1    (mgmt_slots_unused = 2)
		--      provisioning_entitled max_members = 3, current_members = 0  (prov_slots_unused = 3)
		--    1 upgrade, 2 available
		-- 3) The user subscribes a system for provisioning.  This means:
		--      enterprise_entitled max_members = 2, current_members = 1    (mgmt_slots_unused = 1)
		--      provisioning_entitled max_members = 3, current_members = 1  (prov_slots_unused = 2)
		--    1 upgrade, 1 available
		-- 4) The user subscribes another provisioning.  I.e.:
		--      enterprise_entitled max_members = 1, current_members = 1    (mgmt_slots_unused = 0)
		--      provisioning_entitled max_members = 3, current_members = 2  (prov_slots_unused = 1)
		--    1 upgrade, 0 available
		-- 5) the user upgrades 1 mgmt to prov.  Here:
		--    1) unsubscribe from mgmt
		--      enterprise_entitled max_members = 1, current_members = 0    (mgmt_slots_unused = 1)
		--      provisioning_entitled max_members = 3, current_members = 2  (prov_slots_unused = 1)
		--    0 upgrade, 1 available
		--    2) subscribe to prov
		--      enterprise_entitled max_members = 0, current_members = 0    (mgmt_slots_unused = 0)
		--      provisioning_entitled max_members = 3, current_members = 3  (prov_slots_unused = 0)
		--    that'll result in 0 upgrade, 0 available
		-- 6) user buys 1 mgmt:
		--      enterprise_entitled max_members = 1, current_members = 0    (mgmt_slots_unused = 1)
		--      provisioning_entitled max_members = 3, current_members = 3  (prov_slots_unused = 0)
		--    -1 on upgrade, 1 on available, BORK, should be 0, 0 (special cased with p-m<0)
		-- 7) user registers a management box
		--      enterprise_entitled max_members = 1, current_members = 1    (mgmt_slots_unused = 0)
		--      provisioning_entitled max_members = 3, current_members = 3  (prov_slots_unused = 0)
		--    0, 0, which is right.
		-- 8) user deletes that management box
		--      enterprise_entitled max_members = 1, current_members = 0    (mgmt_slots_unused = 1)
		--      provisioning_entitled max_members = 3, current_members = 3  (prov_slots_unused = 0)
		--    -1 on upgrade, 1 on available, BORK, should be 0, 0 (special cased with p-m<0)
		-- 9) user buys a provisioning slot
		--      enterprise_entitled max_members = 2, current_members = 0    (mgmt_slots_unused = 2)
		--      provisioning_entitled max_members = 4, current_members = 3  (prov_slots_unused = 1)
		--    -1 upgrade, 0 available, BORK.  special case makes it 1 available, 0 upgrade
		-- 10) user registers a mgmt box
		--      enterprise_entitled max_members = 2, current_members = 1    (mgmt_slots_unused = 1)
		--      provisioning_entitled max_members = 4, current_members = 3  (prov_slots_unused = 1)
		--    0 upgrade, 1 available
		if prov_slots_unused - mgmt_slots_unused < 0 then
			-- swmgr_slots_unused is tmp here
			available_out := prov_slots_unused;
			upgrade_out := 0;
		elsif prov_slots_unused > 0 then
			-- if there's one of each, we list it as available
			-- if there's only a prov slot, then it's upgradable.
			upgrade_out := prov_slots_unused - mgmt_slots_unused;
			available_out := prov_slots_unused - (prov_slots_unused - mgmt_slots_unused);
		else
			upgrade_out := 0;
			available_out := 0;
		end if;
		server_group_id_out := sgid;
		return;
	end get_available_slots;

	procedure prune_everything (
		customer_id_in in number
	) is
		cursor everything is
			-- all our server groups
			select	sg.id					id,
					'S'						type,
					sg.max_members			quantity
			from	rhnServerGroup			sg
			where	sg.org_id = customer_id_in
			union
			-- all our user groups
			select	ug.id					id,
					'U'						type,
					ug.max_members 			quantity
			from	rhnUserGroup			ug
			where	ug.org_id = customer_id_in
			union (
			-- all the channel families we have perms to
			select	cfp.channel_family_id	id,
					'C'						type,
					cfp.max_members			quantity
			from	rhnOrgChannelFamilyPermissions cfp
			where	cfp.org_id = customer_id_in
			union
			-- plus all the ones we're using that we have no perms for
			select	cfm.channel_family_id	id,
					'C'						type,
					0						quantity
			from	rhnChannelFamily		cf,
					rhnChannelFamilyMembers	cfm,
					rhnServerChannel		sc,
					rhnServer				s
			where	s.org_id = customer_id_in
				and s.id = sc.server_id
				and sc.channel_id = cfm.channel_id
				and cfm.channel_family_id = cf.id
				and cf.org_id is not null
				and cf.org_id != customer_id_in
				and not exists (
					select	1
					from	rhnOrgChannelFamilyPermissions cfp
					where	cfp.org_id = customer_id_in
						and cfp.channel_family_id = cfm.channel_family_id
					)
			);
	begin
		for one in everything loop
			if one.type in ('U','S') then
				prune_group(one.id, one.type, one.quantity);
			else
				prune_family(customer_id_in, one.id, one.quantity);
			end if;
		end loop;
	end prune_everything;

	procedure subscribe_newest_servers (
		customer_id_in in number
	) is
		-- find servers without base channels
		cursor servers(cid_in in number) is
			select	s.id
			from	rhnServer			s
			where	1=1
				and s.org_id = cid_in
				and not exists (
						select 1
						from	rhnChannel			c,
								rhnServerChannel	sc
						where	sc.server_id = s.id
							and sc.channel_id = c.id
							and c.parent_channel is null
					)
			order by s.modified desc;
		channel_id number;
	begin
		for server in servers(customer_id_in) loop
			channel_id := rhn_channel.guess_server_base(server.id);
			if channel_id is not null then
				begin
					rhn_channel.subscribe_server(server.id, channel_id);
					commit;
				-- exception is really channel_family_no_subscriptions
				exception
					when others then
						null;
				end;
			end if;
		end loop;
	end subscribe_newest_servers;
end rhn_entitlements;
/
show errors

-- this goes back in, just to make the comparisons show up the same.
-- next upgrade, we get to drop it again, since it's marked exclude now.
create or replace function
adler32(
	buf in varchar2,
	adler in number := 1
) return number
deterministic
is
	s1 number;
	s2 number;
	signed boolean;
	currchar number;
	our_adler number;
begin
        -- Modulo 2**32 to protect ourselves
	our_adler := mod(adler,4294967296);
        if buf is null then
		return our_adler;
        end if;
        -- Oracle's bitwise and works on integers (which are signed and in
        -- the range -2**31..2**31)
        -- Any number above 2**31 would generate a numeric overflow
        -- Solution: substract 2**31 from the number, if the number is larger
        -- than 2**31 (this would clear the most significant bit)
	if our_adler > 2147483647 then
		-- our adler has bit 31 set
                -- take countermeasures: substract 2**31
		our_adler := our_adler - 2147483648;
		signed := true;
	else
		our_adler := our_adler;
		signed := false;
	end if;

        -- Extract the 16 least significant bits
	s1 := bitand(our_adler,65535);
        -- Extract the 15 most significant bits after we ignore the most
        -- significant bit (2**31 - 2**16)
	s2 := bitand(our_adler,2147418112) / 65536;
	if signed then
                -- Add the sign bit back as 2**15
		s2 := s2 + 32768;
	end if;
	for n in 1..length(buf) loop
		currchar := ascii(substr(buf,n,1));
                -- 65521 is the highest prime under 0xffff
		s1 := mod((s1+currchar), 65521);
		s2 := mod((s2 + s1), 65521);
	end loop;
	return s2 * 65536 + s1;
end;
/
show errors

create or replace
procedure delete_server (
	server_id_in in number
) is
	cursor servergroups is
		select	server_id, server_group_id
		from	rhnServerGroupMembers sgm
		where	sgm.server_id = server_id_in;
	cursor configchannels is
		select	cc.id
		from	rhnConfigChannel cc,
			rhnConfigChannelType cct,
			rhnServerConfigChannel scc
		where	1=1
			and scc.server_id = server_id_in
			and scc.config_channel_id = cc.id
			-- these config channel types are reserved
			-- for use by a single server, so we don't
			-- need to check for other servers subscribed
			and cct.label in
				('local_override','server_import')
			and cct.id = cc.confchan_type_id;
	cursor filelists is
		select	spfl.file_list_id id
		from	rhnServerPreserveFileList spfl
		where	spfl.server_id = server_id_in
			and not exists (
				select	1
				from	rhnServerPreserveFileList
				where	file_list_id = spfl.file_list_id
					and server_id != server_id_in
				union
				select	1
				from	rhnKickstartPreserveFileList
				where	file_list_id = spfl.file_list_id
			);
begin
	rhn_channel.delete_server_channels(server_id_in);
	-- rhn_channel.clear_subscriptions(server_id_in);

	for filelist in filelists loop
		delete from rhnFileList where id = filelist.id;
	end loop;

	for configchannel in configchannels loop
		rhn_config.delete_channel(configchannel.id);
	end loop;
	for sgm in servergroups loop
		rhn_server.delete_from_servergroup(
			sgm.server_id, sgm.server_group_id);
	end loop;
	-- we're handling this instead of letting an "on delete
	-- set null" do it so that we don't run the risk
	-- of setting off the triggers and killing us with a
	-- mutating table

	-- we cna't use a cursor to do this because we need "case"
	-- in a select to do that, and 8.1.7.3.0 doesn't support it.
	update rhnKickstartSession
		set old_server_id = null
		where old_server_id = server_id_in;
	update rhnKickstartSession
		set new_server_id = null
		where new_server_id = server_id_in;

	rhn_channel.clear_subscriptions(server_id_in);
	-- We're deleting everything with a foreign key to rhnServer
	-- here, now.  I'm hoping this will help aleviate our deadlock
	-- problem.

	delete from rhnActionConfigChannel where server_id = server_id_in;
	delete from rhnActionConfigRevision where server_id = server_id_in;
	delete from rhnActionPackageRemovalFailure where server_id = server_id_in;
	delete from rhnChannelFamilyLicenseConsent where server_id = server_id_in;
	delete from rhnClientCapability where server_id = server_id_in;
	delete from rhnCpu where server_id = server_id_in;
	-- there's still a cascade here, because the constraint keeps the
	-- table locked for too long to rebuild it.  Ugh...
	delete from rhnDevice where server_id = server_id_in;
	delete from rhnProxyInfo where server_id = server_id_in;
	delete from rhnRam where server_id = server_id_in;
	delete from rhnRegToken where server_id = server_id_in;
	delete from rhnSNPServerQueue where server_id = server_id_in;
	delete from rhnSatelliteChannelFamily where server_id = server_id_in;
	delete from rhnSatelliteInfo where server_id = server_id_in;
	-- this cascades to rhnActionConfigChannel and rhnActionConfigFileName
	delete from rhnServerAction where server_id = server_id_in;
	delete from rhnServerActionPackageResult where server_id = server_id_in;
	delete from rhnServerActionScriptResult where server_id = server_id_in;
	delete from rhnServerActionVerifyResult where server_id = server_id_in;
	-- counts are handled above.  this should be a delete_ function.
	delete from rhnServerChannel where server_id = server_id_in;
	delete from rhnServerConfigChannel where server_id = server_id_in;
	delete from rhnServerCustomDataValue where server_id = server_id_in;
	delete from rhnServerDMI where server_id = server_id_in;
	delete from rhnServerMessage where server_id = server_id_in;
	-- this gets rhnServerMessage (only) on cascade; it's handled just above
	delete from rhnServerEvent where server_id = server_id_in;
	delete from rhnServerHistory where server_id = server_id_in;
	delete from rhnServerInfo where server_id = server_id_in;
	delete from rhnServerInstallInfo where server_id = server_id_in;
	delete from rhnServerLocation where server_id = server_id_in;
	delete from rhnServerLock where server_id = server_id_in;
	delete from rhnServerNeededPackageCache where server_id = server_id_in;
	delete from rhnServerNetwork where server_id = server_id_in;
	delete from rhnServerNotes where server_id = server_id_in;
	-- I'm not removing the foreign key from rhnServerPackage; that'll
	-- take forever.  Do the delete anyway.
	delete from rhnServerPackage where server_id = server_id_in;
	delete from rhnServerTokenRegs where server_id = server_id_in;
	delete from rhnSnapshotTag where server_id = server_id_in;
	-- this cascades to:
	--   rhnSnapshotChannel, rhnSnapshotConfigChannel, rhnSnapshotPackage,
	--   rhnSnapshotConfigRevision, rhnSnapshotServerGroup,
	--   rhnSnapshotTag.
	-- We may want to consider delete_snapshot() at some point, but
	--   I don't think we need to yet.
	delete from rhnSnapshot where server_id = server_id_in;
	delete from rhnTransaction where server_id = server_id_in;
	delete from rhnUserServerPrefs where server_id = server_id_in;
	-- hrm, this one's interesting... we _probably_ should delete
	-- everything for the parent server_id when we delete the proxy,
	-- but we don't currently.
	delete from rhnServerPath where server_id_in in (server_id, proxy_server_id);

	delete from rhn_check_probe where host_id = server_id_in;
	delete from rhn_host_probe where host_id = server_id_in;
	delete from rhn_interface_monitoring where server_id = server_id_in;
	delete from rhnServerNetInterface where server_id = server_id_in;
	delete from rhn_server_monitoring_info where recid = server_id_in;

	-- now get rhnServer itself.
	delete
	from	rhnServer
		where id = server_id_in;

	delete
	from	rhnSet
	where	1=1
		and user_id in (
			select	wc.id
			from	rhnServer rs,
				web_contact wc
			where	rs.id = server_id_in
				and rs.org_id = wc.org_id
		)
		and label = 'system_list'
		and element = server_id_in;
end delete_server;
/
show errors

create or replace
procedure delete_server_bulk (
	user_id_in in number
) is
	cursor systems is
		select	s.element id
		from	rhnSet s
		where	s.user_id = user_id_in
			and s.label = 'system_list';
	cursor servergroups is
		select	sgm.server_group_id, sgm.server_id
		from	rhnServerGroupMembers sgm,
			rhnSet s
		where	s.user_id = user_id_in
			and s.label = 'system_list'
			and s.element = sgm.server_id;
	cursor configchannels is
		select	cc.id
		from	rhnConfigChannel cc,
			rhnConfigChannelType cct,
			rhnServerConfigChannel scc,
			rhnSet s
		where	1=1
			and s.user_id = user_id_in
			and s.label = 'system_list'
			and s.element = scc.server_id
			and scc.config_channel_id = cc.id
			-- these config channel types are reserved
			-- for use by a single server, so we don't
			-- need to check for other servers subscribed
			and cct.label in
				('local_override','server_import')
			and cct.id = cc.confchan_type_id;
	cursor filelists is
		select	spfl.file_list_id id
		from	rhnServerPreserveFileList spfl,
			rhnSet s
		where	s.user_id = user_id_in
			and s.label = 'system_list'
			and s.element = spfl.server_id
			and not exists (
				select	1
				from	rhnKickstartPreserveFileList
				where	file_list_id = spfl.file_list_id
			)
			and not exists (
				-- this has the org_id just to make the set -much- smaller.
				select	spfl.server_id
				from	rhnServerPreserveFileList spfl,
					rhnServer s,
					web_contact u
				where	u.id = user_id_in
					and u.org_id = s.org_id
					and s.id = spfl.server_id
					and spfl.file_list_id = spfl.file_list_id
				minus
				select	element server_id
				from	rhnSet
				where	s.user_id = user_id_in
					and s.label = 'system_list'
			);
begin
	for filelist in filelists loop
		delete from rhnFileList where id = filelist.id;
	end loop;

	for cc in configchannels loop
		rhn_config.delete_channel(cc.id);
	end loop;

	for sgm in servergroups loop
		rhn_server.delete_from_servergroup(
			sgm.server_id, sgm.server_group_id);
	end loop;

	-- it's too bad you can't use "current of" with deletes
	for s in systems loop
		-- we can't use a cursor like planned to for delete_server
		-- to fix rhnKickstartSession entries, because
		-- we miss entries where old_server_id and new_server_id
		-- are both in the set.
		update rhnKickstartSession
			set old_server_id = null
			where old_server_id = s.id;
		update rhnKickstartSession
			set new_server_id = null
			where new_server_id = s.id;
		rhn_channel.clear_subscriptions(s.id);
		-- We're deleting everything with a foreign key to rhnServer
		-- here, now.  I'm hoping this will help aleviate our deadlock
		-- problem.

		delete from rhnActionConfigChannel where server_id = s.id;
		delete from rhnActionConfigRevision where server_id = s.id;
		delete from rhnActionPackageRemovalFailure where server_id = s.id;
		delete from rhnChannelFamilyLicenseConsent where server_id = s.id;
		delete from rhnClientCapability where server_id = s.id;
		delete from rhnCpu where server_id = s.id;
		-- there's still a cascade here, because the constraint keeps the
		-- table locked for too long to rebuild it.  Ugh...
		delete from rhnDevice where server_id = s.id;
		delete from rhnProxyInfo where server_id = s.id;
		delete from rhnRam where server_id = s.id;
		delete from rhnRegToken where server_id = s.id;
		delete from rhnSNPServerQueue where server_id = s.id;
		delete from rhnSatelliteChannelFamily where server_id = s.id;
		delete from rhnSatelliteInfo where server_id = s.id;
		-- this cascades to rhnActionConfigChannel and rhnActionConfigFileName
		delete from rhnServerAction where server_id = s.id;
		delete from rhnServerActionPackageResult where server_id = s.id;
		delete from rhnServerActionScriptResult where server_id = s.id;
		delete from rhnServerActionVerifyResult where server_id = s.id;
		-- counts are handled above.  this should be a delete_ function.
		delete from rhnServerChannel where server_id = s.id;
		delete from rhnServerConfigChannel where server_id = s.id;
		delete from rhnServerCustomDataValue where server_id = s.id;
		delete from rhnServerDMI where server_id = s.id;
		delete from rhnServerMessage where server_id = s.id;
		-- this gets rhnServerMessage (only) on cascade; it's handled just above
		delete from rhnServerEvent where server_id = s.id;
		delete from rhnServerHistory where server_id = s.id;
		delete from rhnServerInfo where server_id = s.id;
		delete from rhnServerInstallInfo where server_id = s.id;
		delete from rhnServerLocation where server_id = s.id;
		delete from rhnServerLock where server_id = s.id;
		delete from rhnServerNeededPackageCache where server_id = s.id;
		delete from rhnServerNetwork where server_id = s.id;
		delete from rhnServerNotes where server_id = s.id;
		-- I'm not removing the foreign key from rhnServerPackage; that'll
		-- take forever.  Do the delete anyway.
		delete from rhnServerPackage where server_id = s.id;
		delete from rhnServerTokenRegs where server_id = s.id;
		delete from rhnSnapshotTag where server_id = s.id;
		-- this cascades to:
		--   rhnSnapshotChannel, rhnSnapshotConfigChannel, rhnSnapshotPackage,
		--   rhnSnapshotConfigRevision, rhnSnapshotServerGroup,
		--   rhnSnapshotTag.
		-- We may want to consider delete_snapshot() at some point, but
		--   I don't think we need to yet.
		delete from rhnSnapshot where server_id = s.id;
		delete from rhnTransaction where server_id = s.id;
		delete from rhnUserServerPrefs where server_id = s.id;
		-- hrm, this one's interesting... we _probably_ should delete
		-- everything for the parent server_id when we delete the proxy,
		-- but we don't currently.
		delete from rhnServerPath where s.id in (server_id, proxy_server_id);

		delete from rhn_check_probe where host_id = s.id;
		delete from rhn_host_probe where host_id = s.id;
		delete from rhn_interface_monitoring where server_id = s.id;
		delete from rhnServerNetInterface where server_id = s.id;
		delete from rhn_server_monitoring_info where recid = s.id;

		delete from rhnServer
			where id = s.id;
		delete from rhnSet
			where user_id in (
				select	wc.id
				from	rhnServer rs,
					web_contact wc
				where	rs.id = s.id
					and rs.org_id = wc.org_id
			)
			and label = 'system_list'
			and element = s.id;
	end loop;
end delete_server_bulk;
/
show errors


CREATE OR REPLACE PACKAGE rpm AS
    FUNCTION vercmp(
        e1 VARCHAR2, v1 VARCHAR2, r1 VARCHAR2,
        e2 VARCHAR2, v2 VARCHAR2, r2 VARCHAR2)
    RETURN NUMBER
        DETERMINISTIC
        PARALLEL_ENABLE;
    PRAGMA RESTRICT_REFERENCES(vercmp, WNDS, RNDS);

    FUNCTION vercmpCounter
    return NUMBER
        DETERMINISTIC
        PARALLEL_ENABLE;
    PRAGMA RESTRICT_REFERENCES(vercmpCounter, WNDS, RNDS);

    FUNCTION vercmpResetCounter
    return NUMBER
        DETERMINISTIC
        PARALLEL_ENABLE;
    PRAGMA RESTRICT_REFERENCES(vercmpResetCounter, WNDS, RNDS);

END rpm;
/
SHOW ERRORS;

CREATE OR REPLACE PACKAGE BODY rpm AS
    vercmp_counter NUMBER := 0;

    FUNCTION isdigit(ch CHAR)
    RETURN BOOLEAN
    IS
    BEGIN
        if ascii(ch) between ascii('0') and ascii('9')
        then
            return TRUE;
        end if;
        return FALSE;
    END isdigit;


    FUNCTION isalpha(ch CHAR)
    RETURN BOOLEAN
    IS
    BEGIN
        if ascii(ch) between ascii('a') and ascii('z') or
            ascii(ch) between ascii('A') and ascii('Z')
        then
            return TRUE;
        end if;
        return FALSE;
    END isalpha;


    FUNCTION isalphanum(ch CHAR)
    RETURN BOOLEAN
    IS
    BEGIN
        if ascii(ch) between ascii('a') and ascii('z') or
            ascii(ch) between ascii('A') and ascii('Z') or
            ascii(ch) between ascii('0') and ascii('9')
        then
            return TRUE;
        end if;
        return FALSE;
    END isalphanum;


    FUNCTION rpmstrcmp (string1 IN VARCHAR2, string2 IN VARCHAR2)
    RETURN NUMBER
    IS
        digits CHAR(10) := '0123456789';
        lc_alpha CHAR(27) := 'abcdefghijklmnopqrstuvwxyz';
        uc_alpha CHAR(27) := 'ABCDEFGHIJKLMNOPQRSTUVWXYZ';
        alpha CHAR(54) := lc_alpha || uc_alpha;
        str1 VARCHAR2(32767) := string1;
        str2 VARCHAR2(32767) := string2;
        one VARCHAR2(32767);
        two VARCHAR2(32767);
        isnum BOOLEAN;
    BEGIN
        if str1 is NULL or str2 is NULL
        then
            raise VALUE_ERROR;
        end if;
        -- easy comparison to see if versions are identical
        if str1 = str2
        then
            return 0;
        end if;
        -- loop through each version segment of str1 and str2 and compare them
        one := str1;
        two := str2;

        <<segment_loop>>
        while one is not null and two is not null
        loop
            declare
                segm1 VARCHAR2(32767);
                segm2 VARCHAR2(32767);
            begin
                --DBMS_OUTPUT.PUT_LINE('Params: ' || one || ',' || two);
                -- Throw out all non-alphanum characters
                while one is not null and not isalphanum(one)
                loop
                    one := substr(one, 2);
                end loop;
                while two is not null and not isalphanum(two)
                loop
                    two := substr(two, 2);
                end loop;
                --DBMS_OUTPUT.PUT_LINE('new params: ' || one || ',' || two);

                str1 := one;
                str2 := two;

                /* grab first completely alpha or completely numeric segment */
                /* leave one and two pointing to the start of the alpha or numeric */
                /* segment and walk str1 and str2 to end of segment */

                if str1 is not null and isdigit(str1)
                then
                    str1 := ltrim(str1, digits);
                    str2 := ltrim(str2, digits);
                    isnum := true;
                else
                    str1 := ltrim(str1, alpha);
                    str2 := ltrim(str2, alpha);
                    isnum := false;
                end if;

                --DBMS_OUTPUT.PUT_LINE('Len: ' || length(str1) || ',' || length(str2));
                -- Oracle trats the length of an empty string as null
                if str1 is not null
                then segm1 := substr(one, 1, length(one) - length(str1));
                else segm1 := one;
                end if;

                if str2 is not null
                then segm2 := substr(two, 1, length(two) - length(str2));
                else segm2 := two;
                end if;

                --DBMS_OUTPUT.PUT_LINE('Segments: ' || segm1 || ',' || segm2);
                --DBMS_OUTPUT.PUT_LINE('Rest: ' || str1 || ',' || str2);
                /* take care of the case where the two version segments are */
                /* different types: one numeric and one alpha */
                if segm1 is null then return -1; end if; /* arbitrary */
                if segm2 is null then
					if isnum then
						return 1;
					else
						return -1;
					end if;
				end if;

                if isnum
                then
                    /* this used to be done by converting the digit segments */
                    /* to ints using atoi() - it's changed because long */
                    /* digit segments can overflow an int - this should fix that. */

                    /* throw away any leading zeros - it's a number, right? */
                    segm1 := ltrim(segm1, '0');
                    segm2 := ltrim(segm2, '0');

                    /* whichever number has more digits wins */
                    -- length of empty string is null
                    if segm1 is null and segm2 is not null
                    then
                        return -1;
                    end if;
                    if segm1 is not null and segm2 is null
                    then
                        return 1;
                    end if;
                    if length(segm1) > length(segm2) then return 1; end if;
                    if length(segm2) > length(segm1) then return -1; end if;
                end if;

                /* strcmp will return which one is greater - even if the two */
                /* segments are alpha or if they are numeric.  don't return  */
                /* if they are equal because there might be more segments to */
                /* compare */

                if segm1 < segm2 then return -1; end if;
                if segm1 > segm2 then return 1; end if;

                one := str1;
                two := str2;
            end;
        end loop segment_loop;
        /* this catches the case where all numeric and alpha segments have */
        /* compared identically but the segment sepparating characters were */
        /* different */
        if one is null and two is null then return 0; end if;

        /* whichever version still has characters left over wins */
        if one is null then return -1; end if;
        return 1;
    END rpmstrcmp;


    FUNCTION vercmp(
        e1 VARCHAR2, v1 VARCHAR2, r1 VARCHAR2,
        e2 VARCHAR2, v2 VARCHAR2, r2 VARCHAR2)
    RETURN NUMBER
    IS
        rc NUMBER;
    BEGIN
        vercmp_counter := vercmp_counter + 1;
        if e1 is not null and e2 is null then return 1; end if;
        if e1 is null and e2 is not null then return -1; end if;
        if e1 is not null and e2 is not null
        then
            DECLARE
                ep1 NUMBER;
                ep2 NUMBER;
            BEGIN
                -- Epochs are non-null; compare them
                ep1 := TO_NUMBER(e1);
                ep2 := TO_NUMBER(e2);
                if ep1 < ep2 then return -1; end if;
                if ep1 > ep2 then return 1; end if;
                -- Epoch is identical; fall through
            END;
        end if;
        rc := rpmstrcmp(v1, v2);
        if rc != 0 then return rc; end if;
        return rpmstrcmp(r1, r2);

    END vercmp;

    FUNCTION vercmpCounter
    RETURN NUMBER
    IS
    BEGIN
        return vercmp_counter;
    END vercmpCounter;

    FUNCTION vercmpResetCounter
    RETURN NUMBER
    IS
        result NUMBER;
    BEGIN
        result := vercmp_counter;
        vercmp_counter := 0;
        return result;
    END vercmpResetCounter;
END rpm;
/
SHOW ERRORS;

update rhnCpuArch set name = 'EM64T' where label = 'ia32e';
update rhnCpuArch set name = 'AMD64' where label = 'amd64';

update rhnPackageArch set name = 'EM64T' where label = 'ia32e';
update rhnPackageArch set name = 'AMD64' where label = 'x86_64';

update rhnServerArch set name = 'EM64T' where label = 'ia32e-redhat-linux';
update rhnServerArch set name = 'AMD64' where label = 'amd64-redhat-linux';

insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )        values (lookup_server_arch('ia32e-redhat-linux'), lookup_sg_type('sw_mgr_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )        values (lookup_server_arch('amd64-redhat-linux'), lookup_sg_type('sw_mgr_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )        values (lookup_server_arch('ia32e-redhat-linux'), lookup_sg_type('enterprise_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )        values (lookup_server_arch('amd64-redhat-linux'), lookup_sg_type('enterprise_entitled'));

commit;

CREATE OR REPLACE
PACKAGE BODY rhn_org
IS
	body_version varchar2(100) := '$Id: satellite-3.2-to-3.4.sql 64427 2005-09-09 14:08:21Z jslagle $';

    FUNCTION find_server_group_by_type(org_id_in NUMBER, group_label_in VARCHAR2)
    RETURN NUMBER
    IS
	server_group       server_group_by_label%ROWTYPE;
    BEGIN
	OPEN server_group_by_label(org_id_in, group_label_in);
	FETCH server_group_by_label INTO server_group;
	CLOSE server_group_by_label;

	RETURN server_group.id;
    END find_server_group_by_type;

    PROCEDURE update_errata_cache(org_id_in NUMBER, threshold_in NUMBER)
    IS
	records_present NUMBER;
    BEGIN
	SELECT NVL(SUM(server_count), 0) INTO records_present
	  FROM rhnOrgErrataCacheQueue
	 WHERE org_id = org_id_in
	   AND processed = 0;

	IF records_present < 1 OR records_present > threshold_in
	THEN
	    RETURN;
	END IF;

	DELETE FROM rhnOrgErrataCacheQueue WHERE org_id = org_id_in;

	DELETE FROM rhnServerNeededPackageCache
	      WHERE server_id IN (SELECT id
				    FROM rhnServer
				   WHERE org_id = org_id_in);

        INSERT INTO rhnServerNeededPackageCache
        SELECT *
	  FROM rhnServerNeededPackageView
	 WHERE server_id IN (SELECT id
			       FROM rhnServer
			      WHERE org_id = org_id_in);
    END update_errata_cache;

	procedure delete_user(user_id_in in number) is
		cursor is_admin is
			select	1
			from	rhnUserGroupType	ugt,
					rhnUserGroup		ug,
					rhnUserGroupMembers	ugm
			where	ugm.user_id = user_id_in
				and ugm.user_group_id = ug.id
				and ug.group_type = ugt.id
				and ugt.label = 'org_admin';
		cursor servergroups_needing_admins is
			select	usgp.server_group_id	server_group_id
			from	rhnUserServerGroupPerms	usgp
			where	1=1
				and usgp.user_id = user_id_in
				and not exists (
					select	1
					from	rhnUserServerGroupPerms	sq_usgp
					where	1=1
						and sq_usgp.server_group_id = usgp.server_group_id
						and	sq_usgp.user_id != user_id_in
				);
		cursor servergroups_for_deletion(org_id_in in number) is
			select	sgm.server_id, sgm.server_group_id
			from	rhnServerGroupMembers sgm,
					rhnServerGroup sg
			where	sg.org_id = org_id_in
				and sg.id = sgm.server_group_id;
		cursor servers_for_deletion(org_id_in in number) is
			select	id
			from	rhnServer
			where	org_id = org_id_in;
		cursor snapshots(sgid_in in number) is
			select	snapshot_id id
			from	rhnSnapshotServerGroup
			where	server_group_id = sgid_in;
		cursor messages is
			select	message_id id
			from	rhnUserMessage
			where	user_id = user_id_in;
		users			number;
		our_org_id		number;
		del_check_ok	number;
		other_users		number;
		other_org_admin	number;
	begin
		select	wc.org_id, xxrh_contact_del_check_num(user_id_in)
		into	our_org_id, del_check_ok
		from	web_contact wc
		where	id = user_id_in;

		-- bail early if we know it won't work
		if del_check_ok != 1 then
			rhn_exception.raise_exception('cannot_delete_user');
			return;
		end if;

		-- find any other users
		begin
			select	1
			into	other_users
			from	web_contact
			where	1=1
				and org_id = our_org_id
				and id != user_id_in
				and rownum = 1;
		exception
			when no_data_found then
				other_users := 0;
		end;

		-- now do org admin stuff
		if other_users != 0 then
			for ignore in is_admin loop
				begin
					select	new_ugm.user_id
					into	other_org_admin
					from	rhnUserGroupMembers	new_ugm,
							rhnUserGroupType	ugt,
							rhnUserGroup		ug,
							rhnUserGroupMembers	ugm
					where	ugm.user_id = user_id_in
						and ugm.user_group_id = ug.id
						and ug.group_type = ugt.id
						and ugt.label = 'org_admin'
						and ug.id = new_ugm.user_group_id
						and new_ugm.user_id != user_id_in
						and rownum = 1;
				exception
					when no_data_found then
						rhn_exception.raise_exception('cannot_delete_user');
				end;

				for sg in servergroups_needing_admins loop
					insert into rhnUserServerGroupPerms
						( user_id , server_group_id )
						values ( other_org_admin, sg.server_group_id );
				end loop;
			end loop;
		end if;

		-- and now things for every user
		for message in messages loop
			delete
				from	rhnUserMessage
				where	user_id = user_id_in
					and message_id = message.id;
			begin
				select	1
				into	users
				from	rhnUserMessage
				where	message_id = message.id
					and rownum = 1;
				delete
					from	rhnMessage
					where	id = message.id;
			exception
				when no_data_found then
					null;
			end;
		end loop;
		delete from rhn_command_queue_sessions where contact_id = user_id_in;
		delete from rhn_contact_methods where contact_id = user_id_in;
		delete from rhn_redirects where contact_id = user_id_in;
		if other_users != 0 then
			update		rhnRegToken
				set		user_id = other_org_admin
				where	org_id = our_org_id
					and user_id = user_id_in;
			begin
				delete from web_contact where id = user_id_in;
			exception
				when others then
					rhn_exception.raise_exception('cannot_delete_user');
			end;
		else
			-- so that the delete trigger doesn't bite us
			for sgm in servergroups_for_deletion(our_org_id) loop
				for snapshot in snapshots(sgm.server_group_id) loop
					update rhnSnapshot
						set invalid =
							lookup_snapshot_invalid_reason('sg_removed')
						where id = snapshot.id;
					delete from rhnSnapshotServerGroup
						where snapshot_id = snapshot.id
						and server_group_id = sgm.server_group_id;
				end loop;
				rhn_server.delete_from_servergroup(
						sgm.server_id, sgm.server_group_id);
			end loop;
			update rhnServerGroup set group_type = null
				where org_id = our_org_id;
			delete from rhnServerGroup where org_id = our_org_id;
			for s in servers_for_deletion(our_org_id) loop
				delete_server(s.id);
			end loop;
			begin
				delete from rhn_check_suites where customer_id = our_org_id;
				delete from rhn_command_target where customer_id = our_org_id;
				delete from rhn_contact_groups where customer_id = our_org_id;
				delete from rhn_notification_formats
					where customer_id = our_org_id;
				delete from rhn_probe where customer_id = our_org_id;
				delete from rhn_redirects where customer_id = our_org_id;
				delete from rhn_sat_cluster where customer_id = our_org_id;
				delete from rhn_schedules where customer_id = our_org_id;
				delete from web_contact where id = user_id_in;
				delete from web_customer where id = our_org_id;
			exception
				when others then
					rhn_exception.raise_exception('cannot_delete_user');
			end;
		end if;
		return;
	end delete_user;
END rhn_org;
/
SHOW ERRORS

alter table rhnSatelliteCert add (
	issued		date default(sysdate),
	expires		date default(sysdate),
	tmp_cert	varchar2(4000)
);

declare
	cursor lvs is
		select	label, version
		from	rhnSatelliteCert;
begin
	for lv in lvs loop
		update rhnSatelliteCert set tmp_cert = cert
			where label = lv.label and
				(version = lv.version or
				(version is null and lv.version is null));
	end loop;
end;
/

alter table rhnSatelliteCert drop ( cert );
alter table rhnSatelliteCert add (
	cert	blob
);

declare
	cursor certs is
		select	label, version, tmp_cert, length(tmp_cert) ltc
		from	rhnSatelliteCert
		for update;
	rawbuf raw(4000);
begin
	for cert in certs loop
		rawbuf := utl_raw.cast_to_raw(cert.tmp_cert);
		update rhnSatelliteCert set cert = rawbuf
			where label = cert.label and version = cert.version;
	end loop;
end;
/
commit;

alter table rhnSatelliteCert add constraint rhn_satcert_cert_nn
	check ("CERT" IS NOT NULL);

alter table rhnSatelliteCert drop ( tmp_cert );

alter trigger rhn_actionks_mod_trig compile;
alter trigger rhn_server_mod_trig compile;
alter trigger rhn_satcert_mod_trig compile;
alter trigger rhn_ksd_mod_trig compile;
alter trigger rhn_server_group_org_mapping compile;
alter trigger rhn_ks_session_history_trigger compile;
alter trigger rhn_satcert_mod_trig compile;
