set define off;

DROP FUNCTION LOOKUP_KS_COMMAND_NAME;

CREATE SEQUENCE RHN_INFO_PANE_ID_SEQ;

CREATE SEQUENCE RHN_KSCOMMAND_ID_SEQ;

CREATE SEQUENCE RHN_KS_TIMEZONE_ID_SEQ;

CREATE TABLE DEMO_LOG
(
  ORG_ID     NUMBER,
  SERVER_ID  NUMBER
)
LOGGING
NOCACHE
NOPARALLEL;

CREATE TABLE RHNINFOPANE
(
  ID     NUMBER
         constraint rhn_info_pane_id_pk primary key,
  LABEL  VARCHAR2(64 BYTE) CONSTRAINT RHN_INFO_PANE_LABL_NN NOT NULL,
  ACL    VARCHAR2(4000 BYTE)
)
LOGGING
NOCACHE
NOPARALLEL;

ALTER TABLE RHNKICKSTARTCOMMANDNAME ADD (REQUIRED  CHAR(1 BYTE) DEFAULT 'N' CONSTRAINT RHN_KSCOMMANDNAME_REQRD_NN NOT NULL);
alter table rhnKickstartCommandName add ( sort_order number );

CREATE INDEX DL_OID_SID_IDX ON DEMO_LOG
(ORG_ID, SERVER_ID)
NOLOGGING
NOPARALLEL;

CREATE UNIQUE INDEX RHN_INFO_PANE_LABL_UQ ON RHNINFOPANE
(LABEL)
LOGGING
NOPARALLEL;

CREATE OR REPLACE VIEW RHNDEMOORGS
(ORG_ID)
AS
(
    select org_id
    from demo_log
    where server_id = 0
);

CREATE TABLE RHNKICKSTARTTIMEZONE
(
  ID            NUMBER CONSTRAINT RHN_KS_TIMEZONE_ID_NN NOT NULL
                constraint rhn_ks_timezone_pk primary key,
  LABEL         VARCHAR2(128 BYTE) CONSTRAINT RHN_KS_TIMEZONE_LABEL_NN NOT NULL,
  NAME          VARCHAR2(128 BYTE) CONSTRAINT RHN_KS_TIMEZONE_NAME_NN NOT NULL,
  INSTALL_TYPE  NUMBER CONSTRAINT RHN_KS_TIMEZONE_IT_NN NOT NULL
                constraint rhn_ks_timezone_it_fk
                   references rhnKSInstallType(id)
)
LOGGING
NOCACHE
NOPARALLEL;

CREATE UNIQUE INDEX RHN_KS_TIMEZONE_IT_LABEL_UQ ON RHNKICKSTARTTIMEZONE
(INSTALL_TYPE, LABEL)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX RHN_KS_TIMEZONE_IT_NAME_UQ ON RHNKICKSTARTTIMEZONE
(INSTALL_TYPE, NAME)
LOGGING
NOPARALLEL;

CREATE INDEX RHN_SCLPB_PID_PTYPE_IDX ON RHN_SAT_CLUSTER_PROBE
(PROBE_ID, PROBE_TYPE)
LOGGING
NOPARALLEL;

CREATE INDEX RHN_URL_PROBE_PID_PTYPE_IDX ON RHN_URL_PROBE
(PROBE_ID, PROBE_TYPE)
LOGGING
NOPARALLEL;

CREATE OR REPLACE VIEW RHNCHANNELFAMILYOVERVIEW
(ORG_ID, ID, NAME, URL, LABEL,
 CURRENT_MEMBERS, MAX_MEMBERS, HAS_SUBSCRIPTION)
AS
select	pcf.org_id				org_id,
	f.id					id,
	f.name					name,
	f.product_url				url,
	f.label					label,
	NVL(pcf.current_members,0)		current_members,
	pcf.max_members				max_members,
	1					has_subscription
from	rhnChannelFamily			f,
	rhnPrivateChannelFamily			pcf
where	pcf.channel_family_id = f.id;
SHOW ERRORS;

CREATE OR REPLACE VIEW RHNPAIDORGS
(ORG_ID)
AS
select	org_id
from	rhnServerGroup
where	group_type = lookup_sg_type('enterprise_entitled')
	and NVL(max_members,1) > 0
union all
select	sg.org_id
from	rhnServerGroup sg
where	sg.group_type = lookup_sg_type('sw_mgr_entitled')
	and NVL(sg.max_members,1) > 0
    and not exists (
        select 1
        from
            rhnDemoOrgs do
        where
            do.org_id = sg.org_id
            and sg.max_members = 1
    )
union all
select	sg.org_id
from	rhnServerGroup sg
where	group_type = lookup_sg_type('provisioning_entitled')
	and NVL(sg.max_members,2) > 1;
SHOW ERRORS;

CREATE OR REPLACE TRIGGER RHN_PRIVCF_MOD_TRIG
BEFORE INSERT OR UPDATE ON RHNPRIVATECHANNELFAMILY
FOR EACH ROW
begin
    :new.modified := sysdate;
end;
/
SHOW ERRORS;

ALTER TABLE RHNUSERINFO ADD (PREFERRED_LOCALE  VARCHAR2(8 BYTE));

create table rhnUserInfoPane (
    user_id number
            constraint rhn_usr_info_pane_uid_nn not null
            constraint rhn_usr_info_pane_uid_fk
                references web_contact(id)
                on delete cascade,
    pane_id number
            constraint rhn_usr_info_pane_pid_nn not null
            constraint rhn_usr_info_pane_pid_fk
                references rhnInfoPane(id)
                on delete cascade
)
    storage ( freelists 16 )
    initrans 32;


CREATE UNIQUE INDEX RHNUSRINFOPANE_UID_PID_UQ ON RHNUSERINFOPANE
(USER_ID, PANE_ID)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX RHN_CHKPB_PID_PTYPE_UQ_IDX ON RHN_CHECK_PROBE
(PROBE_ID, PROBE_TYPE)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX RHN_HSTPB_PBID_PTYPE_IDX ON RHN_HOST_PROBE
(PROBE_ID, PROBE_TYPE)
LOGGING
NOPARALLEL;

CREATE UNIQUE INDEX RHN_INT_MONT_SID_SNAME_IDX ON RHN_INTERFACE_MONITORING
(SERVER_ID, SERVER_NAME)
NOLOGGING
NOPARALLEL;

CREATE INDEX RHN_SAT_NODE_SID_IDX ON RHN_SAT_NODE
(SERVER_ID)
NOLOGGING
NOPARALLEL;

CREATE UNIQUE INDEX RHN_SERVERUUID_UUID_SID_UNQ ON RHNSERVERUUID
(UUID, SERVER_ID)
LOGGING
NOPARALLEL;

CREATE INDEX RHN_SNDPB_PID_PTYPE_IDX ON RHN_SAT_NODE_PROBE
(PROBE_ID, PROBE_TYPE)
LOGGING
NOPARALLEL;

CREATE INDEX RHN_SNPSHT_CC_CCID_SID_IDX ON RHNSNAPSHOTCONFIGCHANNEL
(CONFIG_CHANNEL_ID, SNAPSHOT_ID)
LOGGING
NOPARALLEL;

CREATE OR REPLACE procedure pxt_session_cleanup
   (bound_in in number, commit_interval in number := 100,
batch_size in number := 50000, sessions_deleted in out number)
is
   PRAGMA AUTONOMOUS_TRANSACTION;
   cursor sessions (bound_val in number) is
   select rowid from PXTSessions
   where expires < bound_val;
   counter number := 0;
begin
   for session in sessions (bound_in) loop
      delete from PXTSessions where rowid = session.rowid;
       counter := counter + 1;
       if mod(counter, commit_interval) = 0 then
          commit;
       end if;
      if counter >= batch_size then
         commit;
         sessions_deleted := counter;
         return;
      end if;
   end loop;
    commit;
   sessions_deleted := counter;
end;
/

SHOW ERRORS;

CREATE OR REPLACE VIEW RHNSERVERFEATURESVIEW
(SERVER_ID, LABEL)
AS
select
   distinct
   sgm.server_id,
   f.label
from
   rhnFeature f,
   rhnServerGroupTypeFeature sgtf,
   rhnServerGroupMembers sgm,
   rhnServerGroup sg
where
   sg.id = sgm.server_group_id
   and sgtf.feature_id = f.id
   and sg.group_type = sgtf.server_group_type_id;

show errors;

CREATE INDEX RHN_ACT_CC_CCID_AID_SID_IDX ON RHNACTIONCONFIGCHANNEL
(CONFIG_CHANNEL_ID, ACTION_ID, SERVER_ID)
LOGGING
NOPARALLEL;

CREATE INDEX RHN_ACT_TRANS_FROM_TO_IDX ON RHNACTIONTRANSACTIONS
(FROM_TRANS_ID, TO_TRANS_ID, ACTION_ID)
LOGGING
NOPARALLEL;

CREATE INDEX RHN_ACT_TRANS_TO_FROM_IDX ON RHNACTIONTRANSACTIONS
(TO_TRANS_ID, FROM_TRANS_ID, ACTION_ID)
LOGGING
NOPARALLEL;

CREATE INDEX RHN_APPINST_SESSION_IID_ID_IDX ON RHNAPPINSTALLSESSION
(INSTANCE_ID, ID)
LOGGING
NOPARALLEL;

CREATE INDEX RHN_APPINST_SESSN_SID_IID_IDX ON RHNAPPINSTALLSESSION
(SERVER_ID, INSTANCE_ID)
LOGGING
NOPARALLEL;

CREATE INDEX RHN_APPINST_SESSN_UID_IID_IDX ON RHNAPPINSTALLSESSION
(USER_ID, INSTANCE_ID)
LOGGING
NOPARALLEL;

CREATE OR REPLACE VIEW RHNSERVEROVERVIEW
(ORG_ID, SERVER_ID, SERVER_NAME, NOTE_COUNT, MODIFIED,
 SERVER_ADMINS, GROUP_COUNT, CHANNEL_ID, CHANNEL_LABELS, HISTORY_COUNT,
 SECURITY_ERRATA, BUG_ERRATA, ENHANCEMENT_ERRATA, OUTDATED_PACKAGES, LAST_CHECKIN_DAYS_AGO,
 LAST_CHECKIN, PENDING_UPDATES, OS, RELEASE, SERVER_ARCH_NAME,
 LOCKED)
AS
select
    s.org_id, s.id, s.name, 0, s.modified,
    ( select count(user_id) from rhnUserServerPerms ap
      where server_id = s.id ),
    ( select count(server_group_id) from rhnVisibleServerGroupMembers
      where server_id = s.id ),
    ( select C.id
        from rhnChannel C,
	     rhnServerChannel SC
       where SC.server_id = S.id
         and SC.channel_id = C.id
	 and C.parent_channel IS NULL),
    NVL(( select C.name
        from rhnChannel C,
	     rhnServerChannel SC
       where SC.server_id = S.id
         and SC.channel_id = C.id
	 and C.parent_channel IS NULL), '(none)'),
    ( select count(id) from rhnServerHistory
      where
            server_id = S.id),
    ( select count(*) from rhnServerErrataTypeView setv
      where
            setv.server_id = s.id
        and setv.errata_type = 'Security Advisory'),
    ( select count(*) from rhnServerErrataTypeView setv
      where
            setv.server_id = s.id
        and setv.errata_type = 'Bug Fix Advisory'),
    ( select count(*) from rhnServerErrataTypeView setv
      where
            setv.server_id = s.id
        and setv.errata_type = 'Product Enhancement Advisory'),
    ( select count(distinct p.name_id) from rhnPackage p, rhnServerNeededPackageCache snpc
      where
             snpc.server_id = S.id
	 and p.id = snpc.package_id
	 ),
    ( select sysdate - checkin from rhnServerInfo where server_id = S.id ),
    ( select TO_CHAR(checkin, 'YYYY-MM-DD HH24:MI:SS') from rhnServerInfo where server_id = S.id ),
    ( select count(1)
        from rhnServerAction
       where server_id = S.id
         and status in (0, 1)),
    os,
    release,
    ( select name from rhnServerArch where id = s.server_arch_id),
    NVL((select 1 from rhnServerLock SL WHERE SL.server_id = S.id), 0)
from
    rhnServer S;

show errors;

CREATE INDEX RHN_ACT_KEY_RTID_IDX ON RHNACTIVATIONKEY
(REG_TOKEN_ID)
NOLOGGING
NOPARALLEL;

CREATE INDEX RHN_ACT_CNFG_FN_CRID_IDX ON RHNACTIONCONFIGFILENAME
(CONFIG_REVISION_ID)
LOGGING
NOPARALLEL;

CREATE INDEX RHN_ACT_CR_CRID_IDX ON RHNACTIONCONFIGREVISION
(CONFIG_REVISION_ID)
LOGGING
NOPARALLEL;

CREATE INDEX RHN_CNF_FL_LCRID_IDX ON RHNCONFIGFILE
(LATEST_CONFIG_REVISION_ID)
LOGGING
NOPARALLEL;

CREATE INDEX RHN_SSCR_CRID_SID_IDX ON RHNSNAPSHOTCONFIGREVISION
(CONFIG_REVISION_ID, SNAPSHOT_ID)
LOGGING
NOPARALLEL;

drop sequence RHN_WCON_DISABLED_SEQ;

declare
    seq_val number;
begin

    select nvl(max(id)+1,1)
    into seq_val
    from rhnWebContactChangeLog;

    execute immediate ' create sequence RHN_WCON_DISABLED_SEQ start with ' || seq_val;

end;
/

-- Data Changes
update rhn_command_parameter
set default_value = 'hda'
where command_id = 118
and param_name = 'disk_0';

-- New Data
insert into RHNINFOPANE(ID,LABEL,ACL) values (rhn_info_pane_id_seq.nextval,'tasks',null);
insert into RHNINFOPANE(ID,LABEL,ACL) values (rhn_info_pane_id_seq.nextval,'critical-systems',null);
insert into RHNINFOPANE(ID,LABEL,ACL) values (rhn_info_pane_id_seq.nextval,'critical-probes','show_monitoring();');
insert into RHNINFOPANE(ID,LABEL,ACL) values (rhn_info_pane_id_seq.nextval,'warning-probes','show_monitoring();');
insert into RHNINFOPANE(ID,LABEL,ACL) values (rhn_info_pane_id_seq.nextval,'system-groups-widget','org_entitlement(sw_mgr_enterprise);');
insert into RHNINFOPANE(ID,LABEL,ACL) values (rhn_info_pane_id_seq.nextval,'latest-errata',null);
insert into RHNINFOPANE(ID,LABEL,ACL) values (rhn_info_pane_id_seq.nextval,'inactive-systems',null);
insert into RHNINFOPANE(ID,LABEL,ACL) values (rhn_info_pane_id_seq.nextval,'pending-actions',null);


insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'deviceprobe',
       upper('y'), 17
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'deviceprobe');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'device',
       upper('y'), 16
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'device');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'nfs',
       upper('y'), 10
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'nfs');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'interactive',
       upper('n'), 2
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'interactive');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'harddrive',
       upper('y'), 9
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'harddrive');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'upgrade',
       upper('n'), 4
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'upgrade');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'install',
       upper('n'), 3
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'install');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'lilocheck',
       upper('n'), 5
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'lilocheck');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'text',
       upper('n'), 6
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'text');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'network',
       upper('y'), 7
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'network');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'url',
       upper('y'), 11
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'url');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'lang',
       upper('y'), 12
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'lang');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'langsupport',
       upper('y'), 13
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'langsupport');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'keyboard',
       upper('y'), 14
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'keyboard');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'mouse',
       upper('y'), 15
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'mouse');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'zerombr',
       upper('y'), 19
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'zerombr');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'clearpart',
       upper('y'), 20
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'clearpart');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'bootloader',
       upper('y'), 26
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'bootloader');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'timezone',
       upper('y'), 27
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'timezone');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'auth',
       upper('y'), 28
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'auth');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'reboot',
       upper('n'), 31
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'reboot');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'xconfig',
       upper('y'), 32
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'xconfig');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'partitions',
       upper('y'), 21
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'partitions');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'rootpw',
       upper('y'), 29
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'rootpw');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'firewall',
       upper('y'), 31
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'firewall');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'skipx',
       upper('n'), 32
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'skipx');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'volgroups',
       upper('y'), 24
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'volgroups');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'logvols',
       upper('y'), 25
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'logvols');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'raids',
       upper('y'), 22
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'raids');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'cdrom',
       upper('n'), 8
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'cdrom');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'selinux',
       upper('y'), 30
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'selinux');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'autostep',
       upper('n'), 1
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'autostep');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'driverdisk',
       upper('y'), 18
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'driverdisk');

insert into rhnKickstartCommandName
select rhn_kscommandname_id_seq.nextval, 'include',
       upper('y'), 23
from dual
where not exists (
select 1 from rhnKickstartCommandName
where name = 'include');

alter table rhnKickstartCommandName add ( uses_arguments char(1) );

update rhnKickstartCommandName
set uses_arguments='Y',
    sort_order=17,
    required='N'
where name = 'deviceprobe';

update rhnKickstartCommandName
set uses_arguments='Y',
    sort_order=16,
    required='N'
where name = 'device';

update rhnKickstartCommandName
set uses_arguments='Y',
    sort_order=18,
    required='N'
where name = 'driverdisk';

update rhnKickstartCommandName
set uses_arguments='Y',
    sort_order=10,
    required='N'
where name = 'nfs';

update rhnKickstartCommandName
set uses_arguments='N',
    sort_order=2,
    required='N'
where name = 'interactive';

update rhnKickstartCommandName
set uses_arguments='Y',
    sort_order=9,
    required='N'
where name = 'harddrive';

update rhnKickstartCommandName
set uses_arguments='N',
    sort_order=4,
    required='N'
where name = 'upgrade';

update rhnKickstartCommandName
set uses_arguments='Y',
    sort_order=23,
    required='N'
where name = 'include';

update rhnKickstartCommandName
set uses_arguments='N',
    sort_order=3,
    required='N'
where name = 'install';

update rhnKickstartCommandName
set uses_arguments='N',
    sort_order=5,
    required='N'
where name = 'lilocheck';

update rhnKickstartCommandName
set uses_arguments='N',
    sort_order=6,
    required='N'
where name = 'text';

update rhnKickstartCommandName
set uses_arguments='Y',
    sort_order=7,
    required='N'
where name = 'network';

update rhnKickstartCommandName
set uses_arguments='Y',
    sort_order=11,
    required='N'
where name = 'url';

update rhnKickstartCommandName
set uses_arguments='Y',
    sort_order=12,
    required='Y'
where name = 'lang';

update rhnKickstartCommandName
set uses_arguments='Y',
    sort_order=13,
    required='Y'
where name = 'langsupport';

update rhnKickstartCommandName
set uses_arguments='Y',
    sort_order=14,
    required='Y'
where name = 'keyboard';

update rhnKickstartCommandName
set uses_arguments='Y',
    sort_order=15,
    required='Y'
where name = 'mouse';

update rhnKickstartCommandName
set uses_arguments='Y',
    sort_order=19,
    required='N'
where name = 'zerombr';

update rhnKickstartCommandName
set uses_arguments='Y',
    sort_order=20,
    required='N'
where name = 'clearpart';

update rhnKickstartCommandName
set uses_arguments='Y',
    sort_order=26,
    required='Y'
where name = 'bootloader';

update rhnKickstartCommandName
set uses_arguments='Y',
    sort_order=27,
    required='Y'
where name = 'timezone';

update rhnKickstartCommandName
set uses_arguments='Y',
    sort_order=28,
    required='Y'
where name = 'auth';

update rhnKickstartCommandName
set uses_arguments='N',
    sort_order=31,
    required='N'
where name = 'reboot';

update rhnKickstartCommandName
set uses_arguments='Y',
    sort_order=32,
    required='N'
where name = 'xconfig';

update rhnKickstartCommandName
set uses_arguments='Y',
    sort_order=21,
    required='N'
where name = 'partitions';

update rhnKickstartCommandName
set uses_arguments='Y',
    sort_order=29,
    required='Y'
where name = 'rootpw';

update rhnKickstartCommandName
set uses_arguments='Y',
    sort_order=31,
    required='N'
where name = 'firewall';

update rhnKickstartCommandName
set uses_arguments='N',
    sort_order=32,
    required='N'
where name = 'skipx';

update rhnKickstartCommandName
set uses_arguments='Y',
    sort_order=24,
    required='N'
where name = 'volgroups';

update rhnKickstartCommandName
set uses_arguments='Y',
    sort_order=25,
    required='N'
where name = 'logvols';

update rhnKickstartCommandName
set uses_arguments='Y',
    sort_order=22,
    required='N'
where name = 'raids';

update rhnKickstartCommandName
set uses_arguments='N',
    sort_order=8,
    required='N'
where name = 'cdrom';

update rhnKickstartCommandName
set uses_arguments='Y',
    sort_order=30,
    required='N'
where name = 'selinux';

update rhnKickstartCommandName
set uses_arguments='N',
    sort_order=1,
    required='N'
where name = 'autostep';

alter table rhnKickstartCommandName
add constraint rhn_kscommandname_uses_args_nn
check (uses_arguments is not null);

alter table rhnKickstartCommandName
add constraint rhn_kscommandname_sortordr_nn
check (sort_order is not null);

ALTER TABLE RHNKICKSTARTCOMMANDNAME ADD CONSTRAINT RHN_KSCOMMANDNAME_USES_ARGS_CK CHECK (uses_arguments in ('Y','N'));
ALTER TABLE RHNKICKSTARTCOMMANDNAME ADD CONSTRAINT RHN_KSCOMMANDNAME_REQRD_CK CHECK ( required in ('Y', 'N') );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Andorra',
		'Europe/Andorra',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Dubai',
		'Asia/Dubai',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Kabul',
		'Asia/Kabul',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Antigua',
		'America/Antigua',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Anguilla',
		'America/Anguilla',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Tirane',
		'Europe/Tirane',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Yerevan',
		'Asia/Yerevan',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Curacao',
		'America/Curacao',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Luanda',
		'Africa/Luanda',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Antarctica/McMurdo',
		'Antarctica/McMurdo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Antarctica/South_Pole',
		'Antarctica/South_Pole',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Antarctica/Palmer',
		'Antarctica/Palmer',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Antarctica/Mawson',
		'Antarctica/Mawson',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Antarctica/Davis',
		'Antarctica/Davis',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Antarctica/Casey',
		'Antarctica/Casey',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Antarctica/Vostok',
		'Antarctica/Vostok',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Antarctica/DumontDUrville',
		'Antarctica/DumontDUrville',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Antarctica/Syowa',
		'Antarctica/Syowa',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Buenos_Aires',
		'America/Buenos_Aires',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Cordoba',
		'America/Cordoba',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Jujuy',
		'America/Jujuy',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Catamarca',
		'America/Catamarca',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Mendoza',
		'America/Mendoza',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Pago_Pago',
		'Pacific/Pago_Pago',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Vienna',
		'Europe/Vienna',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Australia/Lord_Howe',
		'Australia/Lord_Howe',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Australia/Hobart',
		'Australia/Hobart',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Australia/Melbourne',
		'Australia/Melbourne',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Australia/Sydney',
		'Australia/Sydney',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Australia/Broken_Hill',
		'Australia/Broken_Hill',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Australia/Brisbane',
		'Australia/Brisbane',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Australia/Lindeman',
		'Australia/Lindeman',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Australia/Adelaide',
		'Australia/Adelaide',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Australia/Darwin',
		'Australia/Darwin',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Australia/Perth',
		'Australia/Perth',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Aruba',
		'America/Aruba',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Baku',
		'Asia/Baku',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Sarajevo',
		'Europe/Sarajevo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Barbados',
		'America/Barbados',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Dhaka',
		'Asia/Dhaka',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Brussels',
		'Europe/Brussels',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Ouagadougou',
		'Africa/Ouagadougou',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Sofia',
		'Europe/Sofia',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Bahrain',
		'Asia/Bahrain',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Bujumbura',
		'Africa/Bujumbura',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Porto-Novo',
		'Africa/Porto-Novo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/Bermuda',
		'Atlantic/Bermuda',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Brunei',
		'Asia/Brunei',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/La_Paz',
		'America/La_Paz',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Noronha',
		'America/Noronha',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Belem',
		'America/Belem',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Fortaleza',
		'America/Fortaleza',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Recife',
		'America/Recife',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Araguaina',
		'America/Araguaina',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Maceio',
		'America/Maceio',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Sao_Paulo',
		'America/Sao_Paulo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Cuiaba',
		'America/Cuiaba',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Porto_Velho',
		'America/Porto_Velho',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Boa_Vista',
		'America/Boa_Vista',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Manaus',
		'America/Manaus',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Eirunepe',
		'America/Eirunepe',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Rio_Branco',
		'America/Rio_Branco',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Nassau',
		'America/Nassau',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Thimphu',
		'Asia/Thimphu',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Gaborone',
		'Africa/Gaborone',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Minsk',
		'Europe/Minsk',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Belize',
		'America/Belize',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/St_Johns',
		'America/St_Johns',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Halifax',
		'America/Halifax',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Glace_Bay',
		'America/Glace_Bay',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Goose_Bay',
		'America/Goose_Bay',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Montreal',
		'America/Montreal',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Nipigon',
		'America/Nipigon',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Thunder_Bay',
		'America/Thunder_Bay',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Pangnirtung',
		'America/Pangnirtung',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Iqaluit',
		'America/Iqaluit',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Rankin_Inlet',
		'America/Rankin_Inlet',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Winnipeg',
		'America/Winnipeg',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Rainy_River',
		'America/Rainy_River',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Cambridge_Bay',
		'America/Cambridge_Bay',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Regina',
		'America/Regina',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Swift_Current',
		'America/Swift_Current',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Edmonton',
		'America/Edmonton',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Yellowknife',
		'America/Yellowknife',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Inuvik',
		'America/Inuvik',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Dawson_Creek',
		'America/Dawson_Creek',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Vancouver',
		'America/Vancouver',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Whitehorse',
		'America/Whitehorse',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Dawson',
		'America/Dawson',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Cocos',
		'Indian/Cocos',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Kinshasa',
		'Africa/Kinshasa',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Lubumbashi',
		'Africa/Lubumbashi',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Bangui',
		'Africa/Bangui',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Brazzaville',
		'Africa/Brazzaville',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Zurich',
		'Europe/Zurich',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Abidjan',
		'Africa/Abidjan',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Rarotonga',
		'Pacific/Rarotonga',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Santiago',
		'America/Santiago',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Easter',
		'Pacific/Easter',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Douala',
		'Africa/Douala',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Shanghai',
		'Asia/Shanghai',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Harbin',
		'Asia/Harbin',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Chongqing',
		'Asia/Chongqing',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Urumqi',
		'Asia/Urumqi',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Kashgar',
		'Asia/Kashgar',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Bogota',
		'America/Bogota',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Costa_Rica',
		'America/Costa_Rica',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Havana',
		'America/Havana',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/Cape_Verde',
		'Atlantic/Cape_Verde',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Christmas',
		'Indian/Christmas',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Nicosia',
		'Asia/Nicosia',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Prague',
		'Europe/Prague',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Berlin',
		'Europe/Berlin',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Djibouti',
		'Africa/Djibouti',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Copenhagen',
		'Europe/Copenhagen',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Dominica',
		'America/Dominica',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Santo_Domingo',
		'America/Santo_Domingo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Algiers',
		'Africa/Algiers',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Guayaquil',
		'America/Guayaquil',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Galapagos',
		'Pacific/Galapagos',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Tallinn',
		'Europe/Tallinn',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Cairo',
		'Africa/Cairo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/El_Aaiun',
		'Africa/El_Aaiun',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Asmera',
		'Africa/Asmera',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Madrid',
		'Europe/Madrid',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Ceuta',
		'Africa/Ceuta',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/Canary',
		'Atlantic/Canary',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Addis_Ababa',
		'Africa/Addis_Ababa',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Helsinki',
		'Europe/Helsinki',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Fiji',
		'Pacific/Fiji',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/Stanley',
		'Atlantic/Stanley',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Yap',
		'Pacific/Yap',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Truk',
		'Pacific/Truk',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Ponape',
		'Pacific/Ponape',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Kosrae',
		'Pacific/Kosrae',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/Faeroe',
		'Atlantic/Faeroe',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Paris',
		'Europe/Paris',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Libreville',
		'Africa/Libreville',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/London',
		'Europe/London',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Belfast',
		'Europe/Belfast',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Grenada',
		'America/Grenada',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Tbilisi',
		'Asia/Tbilisi',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Cayenne',
		'America/Cayenne',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Accra',
		'Africa/Accra',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Gibraltar',
		'Europe/Gibraltar',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Godthab',
		'America/Godthab',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Danmarkshavn',
		'America/Danmarkshavn',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Scoresbysund',
		'America/Scoresbysund',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Thule',
		'America/Thule',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Banjul',
		'Africa/Banjul',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Conakry',
		'Africa/Conakry',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Guadeloupe',
		'America/Guadeloupe',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Malabo',
		'Africa/Malabo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Athens',
		'Europe/Athens',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/South_Georgia',
		'Atlantic/South_Georgia',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Guatemala',
		'America/Guatemala',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Guam',
		'Pacific/Guam',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Bissau',
		'Africa/Bissau',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Guyana',
		'America/Guyana',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Hong_Kong',
		'Asia/Hong_Kong',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Tegucigalpa',
		'America/Tegucigalpa',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Zagreb',
		'Europe/Zagreb',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Port-au-Prince',
		'America/Port-au-Prince',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Budapest',
		'Europe/Budapest',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Jakarta',
		'Asia/Jakarta',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Pontianak',
		'Asia/Pontianak',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Makassar',
		'Asia/Makassar',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Jayapura',
		'Asia/Jayapura',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Dublin',
		'Europe/Dublin',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Jerusalem',
		'Asia/Jerusalem',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Calcutta',
		'Asia/Calcutta',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Chagos',
		'Indian/Chagos',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Baghdad',
		'Asia/Baghdad',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Tehran',
		'Asia/Tehran',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/Reykjavik',
		'Atlantic/Reykjavik',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Rome',
		'Europe/Rome',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Jamaica',
		'America/Jamaica',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Amman',
		'Asia/Amman',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Tokyo',
		'Asia/Tokyo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Nairobi',
		'Africa/Nairobi',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Bishkek',
		'Asia/Bishkek',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Phnom_Penh',
		'Asia/Phnom_Penh',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Tarawa',
		'Pacific/Tarawa',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Enderbury',
		'Pacific/Enderbury',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Kiritimati',
		'Pacific/Kiritimati',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Comoro',
		'Indian/Comoro',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/St_Kitts',
		'America/St_Kitts',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Pyongyang',
		'Asia/Pyongyang',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Seoul',
		'Asia/Seoul',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Kuwait',
		'Asia/Kuwait',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Cayman',
		'America/Cayman',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Almaty',
		'Asia/Almaty',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Qyzylorda',
		'Asia/Qyzylorda',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Aqtobe',
		'Asia/Aqtobe',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Aqtau',
		'Asia/Aqtau',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Oral',
		'Asia/Oral',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Vientiane',
		'Asia/Vientiane',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Beirut',
		'Asia/Beirut',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/St_Lucia',
		'America/St_Lucia',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Vaduz',
		'Europe/Vaduz',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Colombo',
		'Asia/Colombo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Monrovia',
		'Africa/Monrovia',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Maseru',
		'Africa/Maseru',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Vilnius',
		'Europe/Vilnius',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Luxembourg',
		'Europe/Luxembourg',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Riga',
		'Europe/Riga',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Tripoli',
		'Africa/Tripoli',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Casablanca',
		'Africa/Casablanca',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Monaco',
		'Europe/Monaco',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Chisinau',
		'Europe/Chisinau',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Antananarivo',
		'Indian/Antananarivo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Majuro',
		'Pacific/Majuro',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Kwajalein',
		'Pacific/Kwajalein',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Skopje',
		'Europe/Skopje',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Bamako',
		'Africa/Bamako',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Timbuktu',
		'Africa/Timbuktu',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Rangoon',
		'Asia/Rangoon',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Ulaanbaatar',
		'Asia/Ulaanbaatar',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Hovd',
		'Asia/Hovd',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Choibalsan',
		'Asia/Choibalsan',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Macau',
		'Asia/Macau',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Saipan',
		'Pacific/Saipan',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Martinique',
		'America/Martinique',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Nouakchott',
		'Africa/Nouakchott',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Montserrat',
		'America/Montserrat',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Malta',
		'Europe/Malta',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Mauritius',
		'Indian/Mauritius',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Maldives',
		'Indian/Maldives',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Blantyre',
		'Africa/Blantyre',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Mexico_City',
		'America/Mexico_City',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Cancun',
		'America/Cancun',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Merida',
		'America/Merida',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Monterrey',
		'America/Monterrey',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Mazatlan',
		'America/Mazatlan',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Chihuahua',
		'America/Chihuahua',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Hermosillo',
		'America/Hermosillo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Tijuana',
		'America/Tijuana',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Kuala_Lumpur',
		'Asia/Kuala_Lumpur',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Kuching',
		'Asia/Kuching',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Maputo',
		'Africa/Maputo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Windhoek',
		'Africa/Windhoek',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Noumea',
		'Pacific/Noumea',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Niamey',
		'Africa/Niamey',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Norfolk',
		'Pacific/Norfolk',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Lagos',
		'Africa/Lagos',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Managua',
		'America/Managua',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Amsterdam',
		'Europe/Amsterdam',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Oslo',
		'Europe/Oslo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Katmandu',
		'Asia/Katmandu',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Nauru',
		'Pacific/Nauru',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Niue',
		'Pacific/Niue',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Auckland',
		'Pacific/Auckland',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Chatham',
		'Pacific/Chatham',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Muscat',
		'Asia/Muscat',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Panama',
		'America/Panama',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Lima',
		'America/Lima',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Tahiti',
		'Pacific/Tahiti',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Marquesas',
		'Pacific/Marquesas',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Gambier',
		'Pacific/Gambier',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Port_Moresby',
		'Pacific/Port_Moresby',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Manila',
		'Asia/Manila',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Karachi',
		'Asia/Karachi',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Warsaw',
		'Europe/Warsaw',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Miquelon',
		'America/Miquelon',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Pitcairn',
		'Pacific/Pitcairn',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Puerto_Rico',
		'America/Puerto_Rico',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Gaza',
		'Asia/Gaza',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Lisbon',
		'Europe/Lisbon',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/Madeira',
		'Atlantic/Madeira',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/Azores',
		'Atlantic/Azores',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Palau',
		'Pacific/Palau',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Asuncion',
		'America/Asuncion',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Qatar',
		'Asia/Qatar',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Reunion',
		'Indian/Reunion',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Bucharest',
		'Europe/Bucharest',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Kaliningrad',
		'Europe/Kaliningrad',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Moscow',
		'Europe/Moscow',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Samara',
		'Europe/Samara',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Yekaterinburg',
		'Asia/Yekaterinburg',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Omsk',
		'Asia/Omsk',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Novosibirsk',
		'Asia/Novosibirsk',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Krasnoyarsk',
		'Asia/Krasnoyarsk',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Irkutsk',
		'Asia/Irkutsk',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Yakutsk',
		'Asia/Yakutsk',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Vladivostok',
		'Asia/Vladivostok',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Sakhalin',
		'Asia/Sakhalin',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Magadan',
		'Asia/Magadan',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Kamchatka',
		'Asia/Kamchatka',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Anadyr',
		'Asia/Anadyr',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Kigali',
		'Africa/Kigali',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Riyadh',
		'Asia/Riyadh',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Guadalcanal',
		'Pacific/Guadalcanal',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Mahe',
		'Indian/Mahe',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Khartoum',
		'Africa/Khartoum',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Stockholm',
		'Europe/Stockholm',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Singapore',
		'Asia/Singapore',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/St_Helena',
		'Atlantic/St_Helena',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Ljubljana',
		'Europe/Ljubljana',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Arctic/Longyearbyen',
		'Arctic/Longyearbyen',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/Jan_Mayen',
		'Atlantic/Jan_Mayen',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Bratislava',
		'Europe/Bratislava',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Freetown',
		'Africa/Freetown',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/San_Marino',
		'Europe/San_Marino',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Dakar',
		'Africa/Dakar',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Mogadishu',
		'Africa/Mogadishu',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Paramaribo',
		'America/Paramaribo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Sao_Tome',
		'Africa/Sao_Tome',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/El_Salvador',
		'America/El_Salvador',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Damascus',
		'Asia/Damascus',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Mbabane',
		'Africa/Mbabane',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Grand_Turk',
		'America/Grand_Turk',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Ndjamena',
		'Africa/Ndjamena',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Kerguelen',
		'Indian/Kerguelen',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Lome',
		'Africa/Lome',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Bangkok',
		'Asia/Bangkok',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Dushanbe',
		'Asia/Dushanbe',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Fakaofo',
		'Pacific/Fakaofo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Ashgabat',
		'Asia/Ashgabat',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Tunis',
		'Africa/Tunis',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Tongatapu',
		'Pacific/Tongatapu',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Dili',
		'Asia/Dili',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Istanbul',
		'Europe/Istanbul',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Port_of_Spain',
		'America/Port_of_Spain',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Funafuti',
		'Pacific/Funafuti',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Taipei',
		'Asia/Taipei',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Dar_es_Salaam',
		'Africa/Dar_es_Salaam',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Kiev',
		'Europe/Kiev',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Uzhgorod',
		'Europe/Uzhgorod',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Zaporozhye',
		'Europe/Zaporozhye',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Simferopol',
		'Europe/Simferopol',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Kampala',
		'Africa/Kampala',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Johnston',
		'Pacific/Johnston',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Midway',
		'Pacific/Midway',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Wake',
		'Pacific/Wake',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/New_York',
		'America/New_York',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Detroit',
		'America/Detroit',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Louisville',
		'America/Louisville',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Kentucky/Monticello',
		'America/Kentucky/Monticello',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Indianapolis',
		'America/Indianapolis',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Indiana/Marengo',
		'America/Indiana/Marengo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Indiana/Knox',
		'America/Indiana/Knox',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Indiana/Vevay',
		'America/Indiana/Vevay',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Chicago',
		'America/Chicago',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Menominee',
		'America/Menominee',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/North_Dakota/Center',
		'America/North_Dakota/Center',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Denver',
		'America/Denver',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Boise',
		'America/Boise',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Shiprock',
		'America/Shiprock',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Phoenix',
		'America/Phoenix',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Los_Angeles',
		'America/Los_Angeles',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Anchorage',
		'America/Anchorage',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Juneau',
		'America/Juneau',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Yakutat',
		'America/Yakutat',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Nome',
		'America/Nome',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Adak',
		'America/Adak',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Honolulu',
		'Pacific/Honolulu',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Montevideo',
		'America/Montevideo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Samarkand',
		'Asia/Samarkand',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Tashkent',
		'Asia/Tashkent',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Vatican',
		'Europe/Vatican',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/St_Vincent',
		'America/St_Vincent',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Caracas',
		'America/Caracas',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Tortola',
		'America/Tortola',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/St_Thomas',
		'America/St_Thomas',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Saigon',
		'Asia/Saigon',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Efate',
		'Pacific/Efate',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Wallis',
		'Pacific/Wallis',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Apia',
		'Pacific/Apia',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Aden',
		'Asia/Aden',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Mayotte',
		'Indian/Mayotte',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Belgrade',
		'Europe/Belgrade',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Johannesburg',
		'Africa/Johannesburg',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Lusaka',
		'Africa/Lusaka',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Harare',
		'Africa/Harare',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );


-- RHEL 3 timezones

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Andorra',
		'Europe/Andorra',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Dubai',
		'Asia/Dubai',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Kabul',
		'Asia/Kabul',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Antigua',
		'America/Antigua',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Anguilla',
		'America/Anguilla',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Tirane',
		'Europe/Tirane',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Yerevan',
		'Asia/Yerevan',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Curacao',
		'America/Curacao',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Luanda',
		'Africa/Luanda',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Antarctica/McMurdo',
		'Antarctica/McMurdo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Antarctica/South_Pole',
		'Antarctica/South_Pole',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Antarctica/Palmer',
		'Antarctica/Palmer',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Antarctica/Mawson',
		'Antarctica/Mawson',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Antarctica/Davis',
		'Antarctica/Davis',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Antarctica/Casey',
		'Antarctica/Casey',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Antarctica/Vostok',
		'Antarctica/Vostok',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Antarctica/DumontDUrville',
		'Antarctica/DumontDUrville',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Antarctica/Syowa',
		'Antarctica/Syowa',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Buenos_Aires',
		'America/Buenos_Aires',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Cordoba',
		'America/Cordoba',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Jujuy',
		'America/Jujuy',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Catamarca',
		'America/Catamarca',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Mendoza',
		'America/Mendoza',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Pago_Pago',
		'Pacific/Pago_Pago',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Vienna',
		'Europe/Vienna',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Australia/Lord_Howe',
		'Australia/Lord_Howe',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Australia/Hobart',
		'Australia/Hobart',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Australia/Melbourne',
		'Australia/Melbourne',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Australia/Sydney',
		'Australia/Sydney',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Australia/Broken_Hill',
		'Australia/Broken_Hill',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Australia/Brisbane',
		'Australia/Brisbane',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Australia/Lindeman',
		'Australia/Lindeman',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Australia/Adelaide',
		'Australia/Adelaide',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Australia/Darwin',
		'Australia/Darwin',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Australia/Perth',
		'Australia/Perth',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Aruba',
		'America/Aruba',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Baku',
		'Asia/Baku',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Sarajevo',
		'Europe/Sarajevo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Barbados',
		'America/Barbados',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Dhaka',
		'Asia/Dhaka',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Brussels',
		'Europe/Brussels',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Ouagadougou',
		'Africa/Ouagadougou',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Sofia',
		'Europe/Sofia',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Bahrain',
		'Asia/Bahrain',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Bujumbura',
		'Africa/Bujumbura',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Porto-Novo',
		'Africa/Porto-Novo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/Bermuda',
		'Atlantic/Bermuda',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Brunei',
		'Asia/Brunei',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/La_Paz',
		'America/La_Paz',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Noronha',
		'America/Noronha',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Belem',
		'America/Belem',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Fortaleza',
		'America/Fortaleza',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Recife',
		'America/Recife',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Araguaina',
		'America/Araguaina',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Maceio',
		'America/Maceio',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Sao_Paulo',
		'America/Sao_Paulo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Cuiaba',
		'America/Cuiaba',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Porto_Velho',
		'America/Porto_Velho',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Boa_Vista',
		'America/Boa_Vista',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Manaus',
		'America/Manaus',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Eirunepe',
		'America/Eirunepe',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Rio_Branco',
		'America/Rio_Branco',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Nassau',
		'America/Nassau',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Thimphu',
		'Asia/Thimphu',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Gaborone',
		'Africa/Gaborone',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Minsk',
		'Europe/Minsk',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Belize',
		'America/Belize',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/St_Johns',
		'America/St_Johns',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Halifax',
		'America/Halifax',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Glace_Bay',
		'America/Glace_Bay',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Goose_Bay',
		'America/Goose_Bay',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Montreal',
		'America/Montreal',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Nipigon',
		'America/Nipigon',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Thunder_Bay',
		'America/Thunder_Bay',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Pangnirtung',
		'America/Pangnirtung',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Iqaluit',
		'America/Iqaluit',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Rankin_Inlet',
		'America/Rankin_Inlet',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Winnipeg',
		'America/Winnipeg',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Rainy_River',
		'America/Rainy_River',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Cambridge_Bay',
		'America/Cambridge_Bay',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Regina',
		'America/Regina',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Swift_Current',
		'America/Swift_Current',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Edmonton',
		'America/Edmonton',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Yellowknife',
		'America/Yellowknife',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Inuvik',
		'America/Inuvik',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Dawson_Creek',
		'America/Dawson_Creek',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Vancouver',
		'America/Vancouver',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Whitehorse',
		'America/Whitehorse',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Dawson',
		'America/Dawson',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Cocos',
		'Indian/Cocos',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Kinshasa',
		'Africa/Kinshasa',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Lubumbashi',
		'Africa/Lubumbashi',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Bangui',
		'Africa/Bangui',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Brazzaville',
		'Africa/Brazzaville',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Zurich',
		'Europe/Zurich',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Abidjan',
		'Africa/Abidjan',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Rarotonga',
		'Pacific/Rarotonga',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Santiago',
		'America/Santiago',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Easter',
		'Pacific/Easter',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Douala',
		'Africa/Douala',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Shanghai',
		'Asia/Shanghai',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Harbin',
		'Asia/Harbin',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Chongqing',
		'Asia/Chongqing',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Urumqi',
		'Asia/Urumqi',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Kashgar',
		'Asia/Kashgar',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Bogota',
		'America/Bogota',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Costa_Rica',
		'America/Costa_Rica',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Havana',
		'America/Havana',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/Cape_Verde',
		'Atlantic/Cape_Verde',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Christmas',
		'Indian/Christmas',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Nicosia',
		'Asia/Nicosia',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Prague',
		'Europe/Prague',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Berlin',
		'Europe/Berlin',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Djibouti',
		'Africa/Djibouti',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Copenhagen',
		'Europe/Copenhagen',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Dominica',
		'America/Dominica',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Santo_Domingo',
		'America/Santo_Domingo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Algiers',
		'Africa/Algiers',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Guayaquil',
		'America/Guayaquil',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Galapagos',
		'Pacific/Galapagos',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Tallinn',
		'Europe/Tallinn',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Cairo',
		'Africa/Cairo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/El_Aaiun',
		'Africa/El_Aaiun',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Asmera',
		'Africa/Asmera',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Madrid',
		'Europe/Madrid',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Ceuta',
		'Africa/Ceuta',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/Canary',
		'Atlantic/Canary',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Addis_Ababa',
		'Africa/Addis_Ababa',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Helsinki',
		'Europe/Helsinki',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Fiji',
		'Pacific/Fiji',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/Stanley',
		'Atlantic/Stanley',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Yap',
		'Pacific/Yap',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Truk',
		'Pacific/Truk',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Ponape',
		'Pacific/Ponape',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Kosrae',
		'Pacific/Kosrae',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/Faeroe',
		'Atlantic/Faeroe',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Paris',
		'Europe/Paris',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Libreville',
		'Africa/Libreville',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/London',
		'Europe/London',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Belfast',
		'Europe/Belfast',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Grenada',
		'America/Grenada',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Tbilisi',
		'Asia/Tbilisi',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Cayenne',
		'America/Cayenne',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Accra',
		'Africa/Accra',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Gibraltar',
		'Europe/Gibraltar',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Godthab',
		'America/Godthab',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Danmarkshavn',
		'America/Danmarkshavn',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Scoresbysund',
		'America/Scoresbysund',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Thule',
		'America/Thule',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Banjul',
		'Africa/Banjul',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Conakry',
		'Africa/Conakry',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Guadeloupe',
		'America/Guadeloupe',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Malabo',
		'Africa/Malabo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Athens',
		'Europe/Athens',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/South_Georgia',
		'Atlantic/South_Georgia',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Guatemala',
		'America/Guatemala',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Guam',
		'Pacific/Guam',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Bissau',
		'Africa/Bissau',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Guyana',
		'America/Guyana',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Hong_Kong',
		'Asia/Hong_Kong',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Tegucigalpa',
		'America/Tegucigalpa',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Zagreb',
		'Europe/Zagreb',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Port-au-Prince',
		'America/Port-au-Prince',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Budapest',
		'Europe/Budapest',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Jakarta',
		'Asia/Jakarta',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Pontianak',
		'Asia/Pontianak',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Makassar',
		'Asia/Makassar',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Jayapura',
		'Asia/Jayapura',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Dublin',
		'Europe/Dublin',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Jerusalem',
		'Asia/Jerusalem',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Calcutta',
		'Asia/Calcutta',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Chagos',
		'Indian/Chagos',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Baghdad',
		'Asia/Baghdad',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Tehran',
		'Asia/Tehran',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/Reykjavik',
		'Atlantic/Reykjavik',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Rome',
		'Europe/Rome',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Jamaica',
		'America/Jamaica',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Amman',
		'Asia/Amman',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Tokyo',
		'Asia/Tokyo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Nairobi',
		'Africa/Nairobi',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Bishkek',
		'Asia/Bishkek',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Phnom_Penh',
		'Asia/Phnom_Penh',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Tarawa',
		'Pacific/Tarawa',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Enderbury',
		'Pacific/Enderbury',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Kiritimati',
		'Pacific/Kiritimati',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Comoro',
		'Indian/Comoro',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/St_Kitts',
		'America/St_Kitts',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Pyongyang',
		'Asia/Pyongyang',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Seoul',
		'Asia/Seoul',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Kuwait',
		'Asia/Kuwait',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Cayman',
		'America/Cayman',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Almaty',
		'Asia/Almaty',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Qyzylorda',
		'Asia/Qyzylorda',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Aqtobe',
		'Asia/Aqtobe',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Aqtau',
		'Asia/Aqtau',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Oral',
		'Asia/Oral',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Vientiane',
		'Asia/Vientiane',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Beirut',
		'Asia/Beirut',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/St_Lucia',
		'America/St_Lucia',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Vaduz',
		'Europe/Vaduz',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Colombo',
		'Asia/Colombo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Monrovia',
		'Africa/Monrovia',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Maseru',
		'Africa/Maseru',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Vilnius',
		'Europe/Vilnius',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Luxembourg',
		'Europe/Luxembourg',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Riga',
		'Europe/Riga',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Tripoli',
		'Africa/Tripoli',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Casablanca',
		'Africa/Casablanca',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Monaco',
		'Europe/Monaco',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Chisinau',
		'Europe/Chisinau',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Antananarivo',
		'Indian/Antananarivo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Majuro',
		'Pacific/Majuro',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Kwajalein',
		'Pacific/Kwajalein',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Skopje',
		'Europe/Skopje',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Bamako',
		'Africa/Bamako',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Timbuktu',
		'Africa/Timbuktu',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Rangoon',
		'Asia/Rangoon',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Ulaanbaatar',
		'Asia/Ulaanbaatar',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Hovd',
		'Asia/Hovd',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Choibalsan',
		'Asia/Choibalsan',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Macau',
		'Asia/Macau',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Saipan',
		'Pacific/Saipan',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Martinique',
		'America/Martinique',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Nouakchott',
		'Africa/Nouakchott',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Montserrat',
		'America/Montserrat',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Malta',
		'Europe/Malta',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Mauritius',
		'Indian/Mauritius',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Maldives',
		'Indian/Maldives',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Blantyre',
		'Africa/Blantyre',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Mexico_City',
		'America/Mexico_City',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Cancun',
		'America/Cancun',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Merida',
		'America/Merida',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Monterrey',
		'America/Monterrey',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Mazatlan',
		'America/Mazatlan',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Chihuahua',
		'America/Chihuahua',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Hermosillo',
		'America/Hermosillo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Tijuana',
		'America/Tijuana',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Kuala_Lumpur',
		'Asia/Kuala_Lumpur',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Kuching',
		'Asia/Kuching',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Maputo',
		'Africa/Maputo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Windhoek',
		'Africa/Windhoek',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Noumea',
		'Pacific/Noumea',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Niamey',
		'Africa/Niamey',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Norfolk',
		'Pacific/Norfolk',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Lagos',
		'Africa/Lagos',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Managua',
		'America/Managua',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Amsterdam',
		'Europe/Amsterdam',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Oslo',
		'Europe/Oslo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Katmandu',
		'Asia/Katmandu',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Nauru',
		'Pacific/Nauru',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Niue',
		'Pacific/Niue',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Auckland',
		'Pacific/Auckland',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Chatham',
		'Pacific/Chatham',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Muscat',
		'Asia/Muscat',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Panama',
		'America/Panama',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Lima',
		'America/Lima',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Tahiti',
		'Pacific/Tahiti',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Marquesas',
		'Pacific/Marquesas',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Gambier',
		'Pacific/Gambier',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Port_Moresby',
		'Pacific/Port_Moresby',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Manila',
		'Asia/Manila',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Karachi',
		'Asia/Karachi',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Warsaw',
		'Europe/Warsaw',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Miquelon',
		'America/Miquelon',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Pitcairn',
		'Pacific/Pitcairn',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Puerto_Rico',
		'America/Puerto_Rico',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Gaza',
		'Asia/Gaza',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Lisbon',
		'Europe/Lisbon',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/Madeira',
		'Atlantic/Madeira',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/Azores',
		'Atlantic/Azores',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Palau',
		'Pacific/Palau',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Asuncion',
		'America/Asuncion',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Qatar',
		'Asia/Qatar',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Reunion',
		'Indian/Reunion',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Bucharest',
		'Europe/Bucharest',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Kaliningrad',
		'Europe/Kaliningrad',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Moscow',
		'Europe/Moscow',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Samara',
		'Europe/Samara',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Yekaterinburg',
		'Asia/Yekaterinburg',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Omsk',
		'Asia/Omsk',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Novosibirsk',
		'Asia/Novosibirsk',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Krasnoyarsk',
		'Asia/Krasnoyarsk',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Irkutsk',
		'Asia/Irkutsk',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Yakutsk',
		'Asia/Yakutsk',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Vladivostok',
		'Asia/Vladivostok',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Sakhalin',
		'Asia/Sakhalin',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Magadan',
		'Asia/Magadan',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Kamchatka',
		'Asia/Kamchatka',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Anadyr',
		'Asia/Anadyr',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Kigali',
		'Africa/Kigali',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Riyadh',
		'Asia/Riyadh',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Guadalcanal',
		'Pacific/Guadalcanal',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Mahe',
		'Indian/Mahe',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Khartoum',
		'Africa/Khartoum',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Stockholm',
		'Europe/Stockholm',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Singapore',
		'Asia/Singapore',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/St_Helena',
		'Atlantic/St_Helena',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Ljubljana',
		'Europe/Ljubljana',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Arctic/Longyearbyen',
		'Arctic/Longyearbyen',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/Jan_Mayen',
		'Atlantic/Jan_Mayen',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Bratislava',
		'Europe/Bratislava',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Freetown',
		'Africa/Freetown',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/San_Marino',
		'Europe/San_Marino',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Dakar',
		'Africa/Dakar',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Mogadishu',
		'Africa/Mogadishu',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Paramaribo',
		'America/Paramaribo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Sao_Tome',
		'Africa/Sao_Tome',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/El_Salvador',
		'America/El_Salvador',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Damascus',
		'Asia/Damascus',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Mbabane',
		'Africa/Mbabane',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Grand_Turk',
		'America/Grand_Turk',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Ndjamena',
		'Africa/Ndjamena',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Kerguelen',
		'Indian/Kerguelen',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Lome',
		'Africa/Lome',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Bangkok',
		'Asia/Bangkok',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Dushanbe',
		'Asia/Dushanbe',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Fakaofo',
		'Pacific/Fakaofo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Ashgabat',
		'Asia/Ashgabat',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Tunis',
		'Africa/Tunis',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Tongatapu',
		'Pacific/Tongatapu',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Dili',
		'Asia/Dili',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Istanbul',
		'Europe/Istanbul',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Port_of_Spain',
		'America/Port_of_Spain',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Funafuti',
		'Pacific/Funafuti',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Taipei',
		'Asia/Taipei',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Dar_es_Salaam',
		'Africa/Dar_es_Salaam',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Kiev',
		'Europe/Kiev',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Uzhgorod',
		'Europe/Uzhgorod',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Zaporozhye',
		'Europe/Zaporozhye',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Simferopol',
		'Europe/Simferopol',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Kampala',
		'Africa/Kampala',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Johnston',
		'Pacific/Johnston',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Midway',
		'Pacific/Midway',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Wake',
		'Pacific/Wake',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/New_York',
		'America/New_York',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Detroit',
		'America/Detroit',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Louisville',
		'America/Louisville',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Kentucky/Monticello',
		'America/Kentucky/Monticello',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Indianapolis',
		'America/Indianapolis',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Indiana/Marengo',
		'America/Indiana/Marengo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Indiana/Knox',
		'America/Indiana/Knox',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Indiana/Vevay',
		'America/Indiana/Vevay',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Chicago',
		'America/Chicago',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Menominee',
		'America/Menominee',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/North_Dakota/Center',
		'America/North_Dakota/Center',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Denver',
		'America/Denver',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Boise',
		'America/Boise',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Shiprock',
		'America/Shiprock',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Phoenix',
		'America/Phoenix',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Los_Angeles',
		'America/Los_Angeles',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Anchorage',
		'America/Anchorage',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Juneau',
		'America/Juneau',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Yakutat',
		'America/Yakutat',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Nome',
		'America/Nome',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Adak',
		'America/Adak',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Honolulu',
		'Pacific/Honolulu',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Montevideo',
		'America/Montevideo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Samarkand',
		'Asia/Samarkand',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Tashkent',
		'Asia/Tashkent',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Vatican',
		'Europe/Vatican',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/St_Vincent',
		'America/St_Vincent',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Caracas',
		'America/Caracas',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Tortola',
		'America/Tortola',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/St_Thomas',
		'America/St_Thomas',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Saigon',
		'Asia/Saigon',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Efate',
		'Pacific/Efate',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Wallis',
		'Pacific/Wallis',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Apia',
		'Pacific/Apia',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Aden',
		'Asia/Aden',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Mayotte',
		'Indian/Mayotte',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Belgrade',
		'Europe/Belgrade',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Johannesburg',
		'Africa/Johannesburg',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Lusaka',
		'Africa/Lusaka',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Harare',
		'Africa/Harare',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );


-- RHEL 4 timezones

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Andorra',
		'Europe/Andorra',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Dubai',
		'Asia/Dubai',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Kabul',
		'Asia/Kabul',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Antigua',
		'America/Antigua',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Anguilla',
		'America/Anguilla',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Tirane',
		'Europe/Tirane',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Yerevan',
		'Asia/Yerevan',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Curacao',
		'America/Curacao',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Luanda',
		'Africa/Luanda',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Antarctica/McMurdo',
		'Antarctica/McMurdo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Antarctica/South_Pole',
		'Antarctica/South_Pole',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Antarctica/Palmer',
		'Antarctica/Palmer',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Antarctica/Mawson',
		'Antarctica/Mawson',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Antarctica/Davis',
		'Antarctica/Davis',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Antarctica/Casey',
		'Antarctica/Casey',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Antarctica/Vostok',
		'Antarctica/Vostok',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Antarctica/DumontDUrville',
		'Antarctica/DumontDUrville',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Antarctica/Syowa',
		'Antarctica/Syowa',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Buenos_Aires',
		'America/Buenos_Aires',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Cordoba',
		'America/Cordoba',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Jujuy',
		'America/Jujuy',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Catamarca',
		'America/Catamarca',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Mendoza',
		'America/Mendoza',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Pago_Pago',
		'Pacific/Pago_Pago',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Vienna',
		'Europe/Vienna',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Australia/Lord_Howe',
		'Australia/Lord_Howe',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Australia/Hobart',
		'Australia/Hobart',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Australia/Melbourne',
		'Australia/Melbourne',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Australia/Sydney',
		'Australia/Sydney',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Australia/Broken_Hill',
		'Australia/Broken_Hill',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Australia/Brisbane',
		'Australia/Brisbane',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Australia/Lindeman',
		'Australia/Lindeman',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Australia/Adelaide',
		'Australia/Adelaide',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Australia/Darwin',
		'Australia/Darwin',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Australia/Perth',
		'Australia/Perth',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Aruba',
		'America/Aruba',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Baku',
		'Asia/Baku',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Sarajevo',
		'Europe/Sarajevo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Barbados',
		'America/Barbados',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Dhaka',
		'Asia/Dhaka',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Brussels',
		'Europe/Brussels',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Ouagadougou',
		'Africa/Ouagadougou',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Sofia',
		'Europe/Sofia',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Bahrain',
		'Asia/Bahrain',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Bujumbura',
		'Africa/Bujumbura',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Porto-Novo',
		'Africa/Porto-Novo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/Bermuda',
		'Atlantic/Bermuda',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Brunei',
		'Asia/Brunei',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/La_Paz',
		'America/La_Paz',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Noronha',
		'America/Noronha',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Belem',
		'America/Belem',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Fortaleza',
		'America/Fortaleza',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Recife',
		'America/Recife',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Araguaina',
		'America/Araguaina',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Maceio',
		'America/Maceio',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Sao_Paulo',
		'America/Sao_Paulo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Cuiaba',
		'America/Cuiaba',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Porto_Velho',
		'America/Porto_Velho',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Boa_Vista',
		'America/Boa_Vista',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Manaus',
		'America/Manaus',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Eirunepe',
		'America/Eirunepe',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Rio_Branco',
		'America/Rio_Branco',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Nassau',
		'America/Nassau',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Thimphu',
		'Asia/Thimphu',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Gaborone',
		'Africa/Gaborone',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Minsk',
		'Europe/Minsk',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Belize',
		'America/Belize',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/St_Johns',
		'America/St_Johns',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Halifax',
		'America/Halifax',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Glace_Bay',
		'America/Glace_Bay',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Goose_Bay',
		'America/Goose_Bay',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Montreal',
		'America/Montreal',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Nipigon',
		'America/Nipigon',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Thunder_Bay',
		'America/Thunder_Bay',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Pangnirtung',
		'America/Pangnirtung',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Iqaluit',
		'America/Iqaluit',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Rankin_Inlet',
		'America/Rankin_Inlet',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Winnipeg',
		'America/Winnipeg',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Rainy_River',
		'America/Rainy_River',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Cambridge_Bay',
		'America/Cambridge_Bay',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Regina',
		'America/Regina',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Swift_Current',
		'America/Swift_Current',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Edmonton',
		'America/Edmonton',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Yellowknife',
		'America/Yellowknife',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Inuvik',
		'America/Inuvik',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Dawson_Creek',
		'America/Dawson_Creek',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Vancouver',
		'America/Vancouver',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Whitehorse',
		'America/Whitehorse',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Dawson',
		'America/Dawson',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Cocos',
		'Indian/Cocos',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Kinshasa',
		'Africa/Kinshasa',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Lubumbashi',
		'Africa/Lubumbashi',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Bangui',
		'Africa/Bangui',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Brazzaville',
		'Africa/Brazzaville',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Zurich',
		'Europe/Zurich',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Abidjan',
		'Africa/Abidjan',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Rarotonga',
		'Pacific/Rarotonga',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Santiago',
		'America/Santiago',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Easter',
		'Pacific/Easter',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Douala',
		'Africa/Douala',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Shanghai',
		'Asia/Shanghai',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Harbin',
		'Asia/Harbin',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Chongqing',
		'Asia/Chongqing',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Urumqi',
		'Asia/Urumqi',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Kashgar',
		'Asia/Kashgar',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Bogota',
		'America/Bogota',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Costa_Rica',
		'America/Costa_Rica',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Havana',
		'America/Havana',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/Cape_Verde',
		'Atlantic/Cape_Verde',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Christmas',
		'Indian/Christmas',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Nicosia',
		'Asia/Nicosia',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Prague',
		'Europe/Prague',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Berlin',
		'Europe/Berlin',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Djibouti',
		'Africa/Djibouti',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Copenhagen',
		'Europe/Copenhagen',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Dominica',
		'America/Dominica',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Santo_Domingo',
		'America/Santo_Domingo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Algiers',
		'Africa/Algiers',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Guayaquil',
		'America/Guayaquil',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Galapagos',
		'Pacific/Galapagos',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Tallinn',
		'Europe/Tallinn',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Cairo',
		'Africa/Cairo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/El_Aaiun',
		'Africa/El_Aaiun',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Asmera',
		'Africa/Asmera',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Madrid',
		'Europe/Madrid',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Ceuta',
		'Africa/Ceuta',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/Canary',
		'Atlantic/Canary',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Addis_Ababa',
		'Africa/Addis_Ababa',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Helsinki',
		'Europe/Helsinki',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Fiji',
		'Pacific/Fiji',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/Stanley',
		'Atlantic/Stanley',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Yap',
		'Pacific/Yap',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Truk',
		'Pacific/Truk',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Ponape',
		'Pacific/Ponape',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Kosrae',
		'Pacific/Kosrae',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/Faeroe',
		'Atlantic/Faeroe',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Paris',
		'Europe/Paris',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Libreville',
		'Africa/Libreville',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/London',
		'Europe/London',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Belfast',
		'Europe/Belfast',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Grenada',
		'America/Grenada',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Tbilisi',
		'Asia/Tbilisi',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Cayenne',
		'America/Cayenne',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Accra',
		'Africa/Accra',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Gibraltar',
		'Europe/Gibraltar',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Godthab',
		'America/Godthab',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Danmarkshavn',
		'America/Danmarkshavn',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Scoresbysund',
		'America/Scoresbysund',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Thule',
		'America/Thule',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Banjul',
		'Africa/Banjul',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Conakry',
		'Africa/Conakry',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Guadeloupe',
		'America/Guadeloupe',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Malabo',
		'Africa/Malabo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Athens',
		'Europe/Athens',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/South_Georgia',
		'Atlantic/South_Georgia',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Guatemala',
		'America/Guatemala',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Guam',
		'Pacific/Guam',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Bissau',
		'Africa/Bissau',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Guyana',
		'America/Guyana',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Hong_Kong',
		'Asia/Hong_Kong',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Tegucigalpa',
		'America/Tegucigalpa',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Zagreb',
		'Europe/Zagreb',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Port-au-Prince',
		'America/Port-au-Prince',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Budapest',
		'Europe/Budapest',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Jakarta',
		'Asia/Jakarta',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Pontianak',
		'Asia/Pontianak',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Makassar',
		'Asia/Makassar',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Jayapura',
		'Asia/Jayapura',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Dublin',
		'Europe/Dublin',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Jerusalem',
		'Asia/Jerusalem',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Calcutta',
		'Asia/Calcutta',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Chagos',
		'Indian/Chagos',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Baghdad',
		'Asia/Baghdad',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Tehran',
		'Asia/Tehran',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/Reykjavik',
		'Atlantic/Reykjavik',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Rome',
		'Europe/Rome',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Jamaica',
		'America/Jamaica',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Amman',
		'Asia/Amman',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Tokyo',
		'Asia/Tokyo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Nairobi',
		'Africa/Nairobi',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Bishkek',
		'Asia/Bishkek',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Phnom_Penh',
		'Asia/Phnom_Penh',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Tarawa',
		'Pacific/Tarawa',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Enderbury',
		'Pacific/Enderbury',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Kiritimati',
		'Pacific/Kiritimati',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Comoro',
		'Indian/Comoro',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/St_Kitts',
		'America/St_Kitts',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Pyongyang',
		'Asia/Pyongyang',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Seoul',
		'Asia/Seoul',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Kuwait',
		'Asia/Kuwait',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Cayman',
		'America/Cayman',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Almaty',
		'Asia/Almaty',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Qyzylorda',
		'Asia/Qyzylorda',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Aqtobe',
		'Asia/Aqtobe',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Aqtau',
		'Asia/Aqtau',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Oral',
		'Asia/Oral',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Vientiane',
		'Asia/Vientiane',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Beirut',
		'Asia/Beirut',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/St_Lucia',
		'America/St_Lucia',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Vaduz',
		'Europe/Vaduz',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Colombo',
		'Asia/Colombo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Monrovia',
		'Africa/Monrovia',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Maseru',
		'Africa/Maseru',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Vilnius',
		'Europe/Vilnius',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Luxembourg',
		'Europe/Luxembourg',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Riga',
		'Europe/Riga',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Tripoli',
		'Africa/Tripoli',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Casablanca',
		'Africa/Casablanca',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Monaco',
		'Europe/Monaco',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Chisinau',
		'Europe/Chisinau',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Antananarivo',
		'Indian/Antananarivo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Majuro',
		'Pacific/Majuro',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Kwajalein',
		'Pacific/Kwajalein',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Skopje',
		'Europe/Skopje',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Bamako',
		'Africa/Bamako',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Timbuktu',
		'Africa/Timbuktu',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Rangoon',
		'Asia/Rangoon',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Ulaanbaatar',
		'Asia/Ulaanbaatar',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Hovd',
		'Asia/Hovd',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Choibalsan',
		'Asia/Choibalsan',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Macau',
		'Asia/Macau',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Saipan',
		'Pacific/Saipan',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Martinique',
		'America/Martinique',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Nouakchott',
		'Africa/Nouakchott',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Montserrat',
		'America/Montserrat',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Malta',
		'Europe/Malta',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Mauritius',
		'Indian/Mauritius',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Maldives',
		'Indian/Maldives',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Blantyre',
		'Africa/Blantyre',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Mexico_City',
		'America/Mexico_City',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Cancun',
		'America/Cancun',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Merida',
		'America/Merida',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Monterrey',
		'America/Monterrey',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Mazatlan',
		'America/Mazatlan',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Chihuahua',
		'America/Chihuahua',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Hermosillo',
		'America/Hermosillo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Tijuana',
		'America/Tijuana',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Kuala_Lumpur',
		'Asia/Kuala_Lumpur',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Kuching',
		'Asia/Kuching',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Maputo',
		'Africa/Maputo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Windhoek',
		'Africa/Windhoek',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Noumea',
		'Pacific/Noumea',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Niamey',
		'Africa/Niamey',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Norfolk',
		'Pacific/Norfolk',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Lagos',
		'Africa/Lagos',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Managua',
		'America/Managua',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Amsterdam',
		'Europe/Amsterdam',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Oslo',
		'Europe/Oslo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Katmandu',
		'Asia/Katmandu',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Nauru',
		'Pacific/Nauru',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Niue',
		'Pacific/Niue',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Auckland',
		'Pacific/Auckland',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Chatham',
		'Pacific/Chatham',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Muscat',
		'Asia/Muscat',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Panama',
		'America/Panama',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Lima',
		'America/Lima',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Tahiti',
		'Pacific/Tahiti',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Marquesas',
		'Pacific/Marquesas',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Gambier',
		'Pacific/Gambier',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Port_Moresby',
		'Pacific/Port_Moresby',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Manila',
		'Asia/Manila',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Karachi',
		'Asia/Karachi',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Warsaw',
		'Europe/Warsaw',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Miquelon',
		'America/Miquelon',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Pitcairn',
		'Pacific/Pitcairn',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Puerto_Rico',
		'America/Puerto_Rico',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Gaza',
		'Asia/Gaza',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Lisbon',
		'Europe/Lisbon',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/Madeira',
		'Atlantic/Madeira',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/Azores',
		'Atlantic/Azores',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Palau',
		'Pacific/Palau',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Asuncion',
		'America/Asuncion',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Qatar',
		'Asia/Qatar',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Reunion',
		'Indian/Reunion',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Bucharest',
		'Europe/Bucharest',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Kaliningrad',
		'Europe/Kaliningrad',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Moscow',
		'Europe/Moscow',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Samara',
		'Europe/Samara',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Yekaterinburg',
		'Asia/Yekaterinburg',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Omsk',
		'Asia/Omsk',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Novosibirsk',
		'Asia/Novosibirsk',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Krasnoyarsk',
		'Asia/Krasnoyarsk',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Irkutsk',
		'Asia/Irkutsk',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Yakutsk',
		'Asia/Yakutsk',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Vladivostok',
		'Asia/Vladivostok',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Sakhalin',
		'Asia/Sakhalin',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Magadan',
		'Asia/Magadan',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Kamchatka',
		'Asia/Kamchatka',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Anadyr',
		'Asia/Anadyr',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Kigali',
		'Africa/Kigali',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Riyadh',
		'Asia/Riyadh',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Guadalcanal',
		'Pacific/Guadalcanal',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Mahe',
		'Indian/Mahe',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Khartoum',
		'Africa/Khartoum',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Stockholm',
		'Europe/Stockholm',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Singapore',
		'Asia/Singapore',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/St_Helena',
		'Atlantic/St_Helena',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Ljubljana',
		'Europe/Ljubljana',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Arctic/Longyearbyen',
		'Arctic/Longyearbyen',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Atlantic/Jan_Mayen',
		'Atlantic/Jan_Mayen',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Bratislava',
		'Europe/Bratislava',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Freetown',
		'Africa/Freetown',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/San_Marino',
		'Europe/San_Marino',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Dakar',
		'Africa/Dakar',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Mogadishu',
		'Africa/Mogadishu',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Paramaribo',
		'America/Paramaribo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Sao_Tome',
		'Africa/Sao_Tome',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/El_Salvador',
		'America/El_Salvador',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Damascus',
		'Asia/Damascus',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Mbabane',
		'Africa/Mbabane',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Grand_Turk',
		'America/Grand_Turk',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Ndjamena',
		'Africa/Ndjamena',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Kerguelen',
		'Indian/Kerguelen',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Lome',
		'Africa/Lome',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Bangkok',
		'Asia/Bangkok',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Dushanbe',
		'Asia/Dushanbe',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Fakaofo',
		'Pacific/Fakaofo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Ashgabat',
		'Asia/Ashgabat',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Tunis',
		'Africa/Tunis',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Tongatapu',
		'Pacific/Tongatapu',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Dili',
		'Asia/Dili',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Istanbul',
		'Europe/Istanbul',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Port_of_Spain',
		'America/Port_of_Spain',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Funafuti',
		'Pacific/Funafuti',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Taipei',
		'Asia/Taipei',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Dar_es_Salaam',
		'Africa/Dar_es_Salaam',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Kiev',
		'Europe/Kiev',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Uzhgorod',
		'Europe/Uzhgorod',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Zaporozhye',
		'Europe/Zaporozhye',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Simferopol',
		'Europe/Simferopol',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Kampala',
		'Africa/Kampala',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Johnston',
		'Pacific/Johnston',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Midway',
		'Pacific/Midway',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Wake',
		'Pacific/Wake',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/New_York',
		'America/New_York',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Detroit',
		'America/Detroit',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Louisville',
		'America/Louisville',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Kentucky/Monticello',
		'America/Kentucky/Monticello',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Indianapolis',
		'America/Indianapolis',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Indiana/Marengo',
		'America/Indiana/Marengo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Indiana/Knox',
		'America/Indiana/Knox',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Indiana/Vevay',
		'America/Indiana/Vevay',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Chicago',
		'America/Chicago',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Menominee',
		'America/Menominee',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/North_Dakota/Center',
		'America/North_Dakota/Center',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Denver',
		'America/Denver',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Boise',
		'America/Boise',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Shiprock',
		'America/Shiprock',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Phoenix',
		'America/Phoenix',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Los_Angeles',
		'America/Los_Angeles',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Anchorage',
		'America/Anchorage',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Juneau',
		'America/Juneau',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Yakutat',
		'America/Yakutat',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Nome',
		'America/Nome',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Adak',
		'America/Adak',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Honolulu',
		'Pacific/Honolulu',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Montevideo',
		'America/Montevideo',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Samarkand',
		'Asia/Samarkand',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Tashkent',
		'Asia/Tashkent',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Vatican',
		'Europe/Vatican',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/St_Vincent',
		'America/St_Vincent',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Caracas',
		'America/Caracas',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/Tortola',
		'America/Tortola',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'America/St_Thomas',
		'America/St_Thomas',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Saigon',
		'Asia/Saigon',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Efate',
		'Pacific/Efate',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Wallis',
		'Pacific/Wallis',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Pacific/Apia',
		'Pacific/Apia',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Asia/Aden',
		'Asia/Aden',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Indian/Mayotte',
		'Indian/Mayotte',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Europe/Belgrade',
		'Europe/Belgrade',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Johannesburg',
		'Africa/Johannesburg',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Lusaka',
		'Africa/Lusaka',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );

insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
		'Africa/Harare',
		'Africa/Harare',
		(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );


commit;

DECLARE
  -- grab any rows that need the pre/post script to be migrated
  CURSOR kdata is
    select id, pre, post, nochroot_post
    from rhnksdata
    where 1=1
    and (pre is not null or
         post is not null or
         nochroot_post is not null);
BEGIN
  FOR kdata_rec IN kdata
  LOOP

    IF kdata_rec.pre IS NOT NULL THEN
      INSERT INTO rhnkickstartscript (id, kickstart_id, position, script_type, chroot, data)
             VALUES (rhn_ksscript_id_seq.nextval, kdata_rec.id, 3, 'pre', 'Y', kdata_rec.pre);
    END IF;

    IF kdata_rec.post IS NOT NULL THEN
      INSERT INTO rhnkickstartscript (id, kickstart_id, position, script_type, chroot, data)
             VALUES (rhn_ksscript_id_seq.nextval, kdata_rec.id, 4, 'post', 'Y', kdata_rec.post);
    END IF;

    IF kdata_rec.nochroot_post IS NOT NULL THEN
      INSERT INTO rhnkickstartscript (id, kickstart_id, position, script_type, chroot, data)
             VALUES (rhn_ksscript_id_seq.nextval, kdata_rec.id, 5, 'post', 'N', kdata_rec.nochroot_post);
    END IF;

  END LOOP;
  commit;
END;
/

ALTER TABLE RHNKICKSTARTCOMMAND ADD (ID  NUMBER);

declare

    seq_val number;
    cursor rhnkickstartcommand_rows is
    select rowid from rhnkickstartcommand;

begin

    for rhnkickstartcommand_row in rhnkickstartcommand_rows loop

        select rhn_kscommand_id_seq.nextval
        into seq_val
        from dual;

        update rhnkickstartcommand set id = seq_val
        where rowid = rhnkickstartcommand_row.rowid;

    end loop;
end;
/

alter table rhnKickstartCommand
add constraint rhn_kscommand_id_pk
primary key (id);

commit;

create table
rhnChannelProduct
(
    id      number
            constraint rhn_channelprod_id_nn not null
            constraint rhn_channelprod_id_pk primary key,
        product         varchar2(256)
                    constraint rhn_channelprod_product_nn not null,
    version         varchar2(64)
                    constraint rhn_channelprod_version_nn not null,
    beta            char(1) default 'N'
                        constraint rhn_channelprod_beta_nn not null
                        constraint rhn_channelprod_beta_ck
                                check (beta in ('Y', 'N')),
    created     date default (sysdate)
            constraint rhn_channelprod_created_nn not null,
    modified    date default (sysdate)
            constraint rhn_channelprod_modified_nn not null
)
    storage ( freelists 16 )
    initrans 32;

create sequence rhn_channelprod_id_seq;

create unique index rhn_channelprod_p_v_b_uq
    on rhnChannelProduct(product, version, beta)
    storage ( freelists 16 )
    initrans 32;

alter table rhnChannel add (
channel_product_id number
constraint rhn_channel_cpid_fk
references rhnChannelProduct(id) );


declare
   schema_name varchar2(30);
begin
   select owner
   into schema_name
   from all_tables
   where table_name = 'RHNSERVER';

   dbms_utility.compile_schema (schema_name);
end;
/
show errors;

alter type evr_t compile body;
